#include "tree_sitter/parser.h"

#if defined(__GNUC__) || defined(__clang__)
#pragma GCC diagnostic ignored "-Wmissing-field-initializers"
#endif

#define LANGUAGE_VERSION 14
#define STATE_COUNT 1219
#define LARGE_STATE_COUNT 76
#define SYMBOL_COUNT 186
#define ALIAS_COUNT 1
#define TOKEN_COUNT 87
#define EXTERNAL_TOKEN_COUNT 14
#define FIELD_COUNT 10
#define MAX_ALIAS_SEQUENCE_LENGTH 9
#define PRODUCTION_ID_COUNT 25

enum ts_symbol_identifiers {
  sym_identifier = 1,
  anon_sym_SEMI = 2,
  anon_sym_COMMA = 3,
  anon_sym_LPAREN = 4,
  anon_sym_RPAREN = 5,
  anon_sym_PLUS = 6,
  anon_sym_DOT_PLUS = 7,
  anon_sym_DASH = 8,
  anon_sym_DOT_DASH = 9,
  anon_sym_STAR = 10,
  anon_sym_DOT_STAR = 11,
  anon_sym_SLASH = 12,
  anon_sym_DOT_SLASH = 13,
  anon_sym_BSLASH = 14,
  anon_sym_DOT_BSLASH = 15,
  anon_sym_CARET = 16,
  anon_sym_DOT_CARET = 17,
  anon_sym_PIPE = 18,
  anon_sym_AMP = 19,
  anon_sym_DOT = 20,
  anon_sym_TILDE = 21,
  anon_sym_QMARK = 22,
  anon_sym_AT = 23,
  anon_sym_LT = 24,
  anon_sym_LT_EQ = 25,
  anon_sym_EQ_EQ = 26,
  anon_sym_TILDE_EQ = 27,
  anon_sym_GT_EQ = 28,
  anon_sym_GT = 29,
  anon_sym_AMP_AMP = 30,
  anon_sym_PIPE_PIPE = 31,
  anon_sym_DOT_SQUOTE = 32,
  anon_sym_SQUOTE = 33,
  anon_sym_LBRACK = 34,
  aux_sym_matrix_token1 = 35,
  anon_sym_RBRACK = 36,
  anon_sym_LBRACE = 37,
  anon_sym_RBRACE = 38,
  anon_sym_EQ = 39,
  anon_sym_COLON = 40,
  sym_return_statement = 41,
  sym_continue_statement = 42,
  sym_break_statement = 43,
  anon_sym_elseif = 44,
  anon_sym_else = 45,
  anon_sym_if = 46,
  anon_sym_end = 47,
  anon_sym_for = 48,
  anon_sym_parfor = 49,
  anon_sym_while = 50,
  anon_sym_case = 51,
  anon_sym_otherwise = 52,
  anon_sym_switch = 53,
  anon_sym_global = 54,
  anon_sym_persistent = 55,
  anon_sym_arguments = 56,
  anon_sym_function = 57,
  anon_sym_get_DOT = 58,
  anon_sym_set_DOT = 59,
  anon_sym_endfunction = 60,
  anon_sym_properties = 61,
  anon_sym_methods = 62,
  anon_sym_events = 63,
  anon_sym_enumeration = 64,
  anon_sym_classdef = 65,
  anon_sym_catch = 66,
  anon_sym_try = 67,
  sym_number = 68,
  anon_sym_true = 69,
  anon_sym_false = 70,
  anon_sym_LF = 71,
  anon_sym_CR = 72,
  sym_comment = 73,
  sym_line_continuation = 74,
  sym_command_name = 75,
  sym_command_argument = 76,
  sym__single_quote_string_start = 77,
  sym__single_quote_string_end = 78,
  sym__double_quote_string_start = 79,
  sym__double_quote_string_end = 80,
  sym_formatting_sequence = 81,
  sym_escape_sequence = 82,
  sym_string_content = 83,
  sym__entry_delimiter = 84,
  sym__multioutput_variable_start = 85,
  sym_error_sentinel = 86,
  sym_source_file = 87,
  aux_sym__block = 88,
  sym_block = 89,
  sym__statement = 90,
  sym__expression = 91,
  sym_parenthesis = 92,
  sym__binary_expression = 93,
  sym_binary_operator = 94,
  sym_unary_operator = 95,
  sym_indirect_access = 96,
  sym_field_expression = 97,
  sym_not_operator = 98,
  sym_metaclass_operator = 99,
  sym_handle_operator = 100,
  sym_comparison_operator = 101,
  sym_boolean_operator = 102,
  sym_postfix_operator = 103,
  sym_string = 104,
  sym_row = 105,
  sym_matrix = 106,
  sym_cell = 107,
  sym_ignored_argument = 108,
  sym_assignment = 109,
  sym_multioutput_variable = 110,
  sym_spread_operator = 111,
  sym_arguments = 112,
  sym__args = 113,
  sym_function_call = 114,
  sym_command = 115,
  sym__range_element = 116,
  sym_range = 117,
  sym_elseif_clause = 118,
  sym_else_clause = 119,
  sym_if_statement = 120,
  sym_iterator = 121,
  sym_parfor_options = 122,
  sym_for_statement = 123,
  sym_while_statement = 124,
  sym_case_clause = 125,
  sym_otherwise_clause = 126,
  sym_switch_statement = 127,
  sym__lambda_arguments = 128,
  sym_lambda = 129,
  sym_global_operator = 130,
  sym_persistent_operator = 131,
  sym__argument_attributes = 132,
  sym_arguments_statement = 133,
  sym_function_output = 134,
  sym_function_arguments = 135,
  sym_function_definition = 136,
  sym__function_definition_with_end = 137,
  sym_attribute = 138,
  sym_attributes = 139,
  sym_superclasses = 140,
  sym_dimensions = 141,
  sym_validation_functions = 142,
  sym_default_value = 143,
  sym_property_name = 144,
  sym_property = 145,
  sym_properties = 146,
  sym_function_signature = 147,
  sym_methods = 148,
  sym_events = 149,
  sym__enum_value = 150,
  sym_enum = 151,
  sym_enumeration = 152,
  sym_class_definition = 153,
  sym_catch_clause = 154,
  sym_try_statement = 155,
  sym_boolean = 156,
  sym__end_of_line = 157,
  aux_sym_source_file_repeat1 = 158,
  aux_sym__block_repeat1 = 159,
  aux_sym_field_expression_repeat1 = 160,
  aux_sym_handle_operator_repeat1 = 161,
  aux_sym_string_repeat1 = 162,
  aux_sym_row_repeat1 = 163,
  aux_sym_matrix_repeat1 = 164,
  aux_sym_multioutput_variable_repeat1 = 165,
  aux_sym_arguments_repeat1 = 166,
  aux_sym_arguments_repeat2 = 167,
  aux_sym_command_repeat1 = 168,
  aux_sym_elseif_clause_repeat1 = 169,
  aux_sym_if_statement_repeat1 = 170,
  aux_sym_switch_statement_repeat1 = 171,
  aux_sym__lambda_arguments_repeat1 = 172,
  aux_sym_global_operator_repeat1 = 173,
  aux_sym__argument_attributes_repeat1 = 174,
  aux_sym_arguments_statement_repeat1 = 175,
  aux_sym_function_definition_repeat1 = 176,
  aux_sym_attributes_repeat1 = 177,
  aux_sym_superclasses_repeat1 = 178,
  aux_sym_dimensions_repeat1 = 179,
  aux_sym_validation_functions_repeat1 = 180,
  aux_sym_methods_repeat1 = 181,
  aux_sym_events_repeat1 = 182,
  aux_sym_enum_repeat1 = 183,
  aux_sym_enumeration_repeat1 = 184,
  aux_sym_class_definition_repeat1 = 185,
  alias_sym_superclass = 186,
};

static const char * const ts_symbol_names[] = {
  [ts_builtin_sym_end] = "end",
  [sym_identifier] = "identifier",
  [anon_sym_SEMI] = ";",
  [anon_sym_COMMA] = ",",
  [anon_sym_LPAREN] = "(",
  [anon_sym_RPAREN] = ")",
  [anon_sym_PLUS] = "+",
  [anon_sym_DOT_PLUS] = ".+",
  [anon_sym_DASH] = "-",
  [anon_sym_DOT_DASH] = ".-",
  [anon_sym_STAR] = "*",
  [anon_sym_DOT_STAR] = ".*",
  [anon_sym_SLASH] = "/",
  [anon_sym_DOT_SLASH] = "./",
  [anon_sym_BSLASH] = "\\",
  [anon_sym_DOT_BSLASH] = ".\\",
  [anon_sym_CARET] = "^",
  [anon_sym_DOT_CARET] = ".^",
  [anon_sym_PIPE] = "|",
  [anon_sym_AMP] = "&",
  [anon_sym_DOT] = ".",
  [anon_sym_TILDE] = "~",
  [anon_sym_QMARK] = "\?",
  [anon_sym_AT] = "@",
  [anon_sym_LT] = "<",
  [anon_sym_LT_EQ] = "<=",
  [anon_sym_EQ_EQ] = "==",
  [anon_sym_TILDE_EQ] = "~=",
  [anon_sym_GT_EQ] = ">=",
  [anon_sym_GT] = ">",
  [anon_sym_AMP_AMP] = "&&",
  [anon_sym_PIPE_PIPE] = "||",
  [anon_sym_DOT_SQUOTE] = ".'",
  [anon_sym_SQUOTE] = "'",
  [anon_sym_LBRACK] = "[",
  [aux_sym_matrix_token1] = "matrix_token1",
  [anon_sym_RBRACK] = "]",
  [anon_sym_LBRACE] = "{",
  [anon_sym_RBRACE] = "}",
  [anon_sym_EQ] = "=",
  [anon_sym_COLON] = ":",
  [sym_return_statement] = "return_statement",
  [sym_continue_statement] = "continue_statement",
  [sym_break_statement] = "break_statement",
  [anon_sym_elseif] = "elseif",
  [anon_sym_else] = "else",
  [anon_sym_if] = "if",
  [anon_sym_end] = "end",
  [anon_sym_for] = "for",
  [anon_sym_parfor] = "parfor",
  [anon_sym_while] = "while",
  [anon_sym_case] = "case",
  [anon_sym_otherwise] = "otherwise",
  [anon_sym_switch] = "switch",
  [anon_sym_global] = "global",
  [anon_sym_persistent] = "persistent",
  [anon_sym_arguments] = "arguments",
  [anon_sym_function] = "function",
  [anon_sym_get_DOT] = "get.",
  [anon_sym_set_DOT] = "set.",
  [anon_sym_endfunction] = "endfunction",
  [anon_sym_properties] = "properties",
  [anon_sym_methods] = "methods",
  [anon_sym_events] = "events",
  [anon_sym_enumeration] = "enumeration",
  [anon_sym_classdef] = "classdef",
  [anon_sym_catch] = "catch",
  [anon_sym_try] = "try",
  [sym_number] = "number",
  [anon_sym_true] = "true",
  [anon_sym_false] = "false",
  [anon_sym_LF] = "\n",
  [anon_sym_CR] = "\r",
  [sym_comment] = "comment",
  [sym_line_continuation] = "line_continuation",
  [sym_command_name] = "command_name",
  [sym_command_argument] = "command_argument",
  [sym__single_quote_string_start] = "'",
  [sym__single_quote_string_end] = "'",
  [sym__double_quote_string_start] = "\"",
  [sym__double_quote_string_end] = "\"",
  [sym_formatting_sequence] = "formatting_sequence",
  [sym_escape_sequence] = "escape_sequence",
  [sym_string_content] = "string_content",
  [sym__entry_delimiter] = ";",
  [sym__multioutput_variable_start] = "[",
  [sym_error_sentinel] = "error_sentinel",
  [sym_source_file] = "source_file",
  [aux_sym__block] = "_block",
  [sym_block] = "block",
  [sym__statement] = "_statement",
  [sym__expression] = "_expression",
  [sym_parenthesis] = "parenthesis",
  [sym__binary_expression] = "_binary_expression",
  [sym_binary_operator] = "binary_operator",
  [sym_unary_operator] = "unary_operator",
  [sym_indirect_access] = "indirect_access",
  [sym_field_expression] = "field_expression",
  [sym_not_operator] = "not_operator",
  [sym_metaclass_operator] = "metaclass_operator",
  [sym_handle_operator] = "handle_operator",
  [sym_comparison_operator] = "comparison_operator",
  [sym_boolean_operator] = "boolean_operator",
  [sym_postfix_operator] = "postfix_operator",
  [sym_string] = "string",
  [sym_row] = "row",
  [sym_matrix] = "matrix",
  [sym_cell] = "cell",
  [sym_ignored_argument] = "ignored_argument",
  [sym_assignment] = "assignment",
  [sym_multioutput_variable] = "multioutput_variable",
  [sym_spread_operator] = "spread_operator",
  [sym_arguments] = "arguments",
  [sym__args] = "_args",
  [sym_function_call] = "function_call",
  [sym_command] = "command",
  [sym__range_element] = "_range_element",
  [sym_range] = "range",
  [sym_elseif_clause] = "elseif_clause",
  [sym_else_clause] = "else_clause",
  [sym_if_statement] = "if_statement",
  [sym_iterator] = "iterator",
  [sym_parfor_options] = "parfor_options",
  [sym_for_statement] = "for_statement",
  [sym_while_statement] = "while_statement",
  [sym_case_clause] = "case_clause",
  [sym_otherwise_clause] = "otherwise_clause",
  [sym_switch_statement] = "switch_statement",
  [sym__lambda_arguments] = "_lambda_arguments",
  [sym_lambda] = "lambda",
  [sym_global_operator] = "global_operator",
  [sym_persistent_operator] = "persistent_operator",
  [sym__argument_attributes] = "attributes",
  [sym_arguments_statement] = "arguments_statement",
  [sym_function_output] = "function_output",
  [sym_function_arguments] = "function_arguments",
  [sym_function_definition] = "function_definition",
  [sym__function_definition_with_end] = "function_definition",
  [sym_attribute] = "attribute",
  [sym_attributes] = "attributes",
  [sym_superclasses] = "superclasses",
  [sym_dimensions] = "dimensions",
  [sym_validation_functions] = "validation_functions",
  [sym_default_value] = "default_value",
  [sym_property_name] = "property_name",
  [sym_property] = "property",
  [sym_properties] = "properties",
  [sym_function_signature] = "function_signature",
  [sym_methods] = "methods",
  [sym_events] = "events",
  [sym__enum_value] = "_enum_value",
  [sym_enum] = "enum",
  [sym_enumeration] = "enumeration",
  [sym_class_definition] = "class_definition",
  [sym_catch_clause] = "catch_clause",
  [sym_try_statement] = "try_statement",
  [sym_boolean] = "boolean",
  [sym__end_of_line] = "_end_of_line",
  [aux_sym_source_file_repeat1] = "source_file_repeat1",
  [aux_sym__block_repeat1] = "_block_repeat1",
  [aux_sym_field_expression_repeat1] = "field_expression_repeat1",
  [aux_sym_handle_operator_repeat1] = "handle_operator_repeat1",
  [aux_sym_string_repeat1] = "string_repeat1",
  [aux_sym_row_repeat1] = "row_repeat1",
  [aux_sym_matrix_repeat1] = "matrix_repeat1",
  [aux_sym_multioutput_variable_repeat1] = "multioutput_variable_repeat1",
  [aux_sym_arguments_repeat1] = "arguments_repeat1",
  [aux_sym_arguments_repeat2] = "arguments_repeat2",
  [aux_sym_command_repeat1] = "command_repeat1",
  [aux_sym_elseif_clause_repeat1] = "elseif_clause_repeat1",
  [aux_sym_if_statement_repeat1] = "if_statement_repeat1",
  [aux_sym_switch_statement_repeat1] = "switch_statement_repeat1",
  [aux_sym__lambda_arguments_repeat1] = "_lambda_arguments_repeat1",
  [aux_sym_global_operator_repeat1] = "global_operator_repeat1",
  [aux_sym__argument_attributes_repeat1] = "_argument_attributes_repeat1",
  [aux_sym_arguments_statement_repeat1] = "arguments_statement_repeat1",
  [aux_sym_function_definition_repeat1] = "function_definition_repeat1",
  [aux_sym_attributes_repeat1] = "attributes_repeat1",
  [aux_sym_superclasses_repeat1] = "superclasses_repeat1",
  [aux_sym_dimensions_repeat1] = "dimensions_repeat1",
  [aux_sym_validation_functions_repeat1] = "validation_functions_repeat1",
  [aux_sym_methods_repeat1] = "methods_repeat1",
  [aux_sym_events_repeat1] = "events_repeat1",
  [aux_sym_enum_repeat1] = "enum_repeat1",
  [aux_sym_enumeration_repeat1] = "enumeration_repeat1",
  [aux_sym_class_definition_repeat1] = "class_definition_repeat1",
  [alias_sym_superclass] = "superclass",
};

static const TSSymbol ts_symbol_map[] = {
  [ts_builtin_sym_end] = ts_builtin_sym_end,
  [sym_identifier] = sym_identifier,
  [anon_sym_SEMI] = anon_sym_SEMI,
  [anon_sym_COMMA] = anon_sym_COMMA,
  [anon_sym_LPAREN] = anon_sym_LPAREN,
  [anon_sym_RPAREN] = anon_sym_RPAREN,
  [anon_sym_PLUS] = anon_sym_PLUS,
  [anon_sym_DOT_PLUS] = anon_sym_DOT_PLUS,
  [anon_sym_DASH] = anon_sym_DASH,
  [anon_sym_DOT_DASH] = anon_sym_DOT_DASH,
  [anon_sym_STAR] = anon_sym_STAR,
  [anon_sym_DOT_STAR] = anon_sym_DOT_STAR,
  [anon_sym_SLASH] = anon_sym_SLASH,
  [anon_sym_DOT_SLASH] = anon_sym_DOT_SLASH,
  [anon_sym_BSLASH] = anon_sym_BSLASH,
  [anon_sym_DOT_BSLASH] = anon_sym_DOT_BSLASH,
  [anon_sym_CARET] = anon_sym_CARET,
  [anon_sym_DOT_CARET] = anon_sym_DOT_CARET,
  [anon_sym_PIPE] = anon_sym_PIPE,
  [anon_sym_AMP] = anon_sym_AMP,
  [anon_sym_DOT] = anon_sym_DOT,
  [anon_sym_TILDE] = anon_sym_TILDE,
  [anon_sym_QMARK] = anon_sym_QMARK,
  [anon_sym_AT] = anon_sym_AT,
  [anon_sym_LT] = anon_sym_LT,
  [anon_sym_LT_EQ] = anon_sym_LT_EQ,
  [anon_sym_EQ_EQ] = anon_sym_EQ_EQ,
  [anon_sym_TILDE_EQ] = anon_sym_TILDE_EQ,
  [anon_sym_GT_EQ] = anon_sym_GT_EQ,
  [anon_sym_GT] = anon_sym_GT,
  [anon_sym_AMP_AMP] = anon_sym_AMP_AMP,
  [anon_sym_PIPE_PIPE] = anon_sym_PIPE_PIPE,
  [anon_sym_DOT_SQUOTE] = anon_sym_DOT_SQUOTE,
  [anon_sym_SQUOTE] = anon_sym_SQUOTE,
  [anon_sym_LBRACK] = anon_sym_LBRACK,
  [aux_sym_matrix_token1] = aux_sym_matrix_token1,
  [anon_sym_RBRACK] = anon_sym_RBRACK,
  [anon_sym_LBRACE] = anon_sym_LBRACE,
  [anon_sym_RBRACE] = anon_sym_RBRACE,
  [anon_sym_EQ] = anon_sym_EQ,
  [anon_sym_COLON] = anon_sym_COLON,
  [sym_return_statement] = sym_return_statement,
  [sym_continue_statement] = sym_continue_statement,
  [sym_break_statement] = sym_break_statement,
  [anon_sym_elseif] = anon_sym_elseif,
  [anon_sym_else] = anon_sym_else,
  [anon_sym_if] = anon_sym_if,
  [anon_sym_end] = anon_sym_end,
  [anon_sym_for] = anon_sym_for,
  [anon_sym_parfor] = anon_sym_parfor,
  [anon_sym_while] = anon_sym_while,
  [anon_sym_case] = anon_sym_case,
  [anon_sym_otherwise] = anon_sym_otherwise,
  [anon_sym_switch] = anon_sym_switch,
  [anon_sym_global] = anon_sym_global,
  [anon_sym_persistent] = anon_sym_persistent,
  [anon_sym_arguments] = anon_sym_arguments,
  [anon_sym_function] = anon_sym_function,
  [anon_sym_get_DOT] = anon_sym_get_DOT,
  [anon_sym_set_DOT] = anon_sym_set_DOT,
  [anon_sym_endfunction] = anon_sym_endfunction,
  [anon_sym_properties] = anon_sym_properties,
  [anon_sym_methods] = anon_sym_methods,
  [anon_sym_events] = anon_sym_events,
  [anon_sym_enumeration] = anon_sym_enumeration,
  [anon_sym_classdef] = anon_sym_classdef,
  [anon_sym_catch] = anon_sym_catch,
  [anon_sym_try] = anon_sym_try,
  [sym_number] = sym_number,
  [anon_sym_true] = anon_sym_true,
  [anon_sym_false] = anon_sym_false,
  [anon_sym_LF] = anon_sym_LF,
  [anon_sym_CR] = anon_sym_CR,
  [sym_comment] = sym_comment,
  [sym_line_continuation] = sym_line_continuation,
  [sym_command_name] = sym_command_name,
  [sym_command_argument] = sym_command_argument,
  [sym__single_quote_string_start] = anon_sym_SQUOTE,
  [sym__single_quote_string_end] = anon_sym_SQUOTE,
  [sym__double_quote_string_start] = sym__double_quote_string_start,
  [sym__double_quote_string_end] = sym__double_quote_string_start,
  [sym_formatting_sequence] = sym_formatting_sequence,
  [sym_escape_sequence] = sym_escape_sequence,
  [sym_string_content] = sym_string_content,
  [sym__entry_delimiter] = anon_sym_SEMI,
  [sym__multioutput_variable_start] = anon_sym_LBRACK,
  [sym_error_sentinel] = sym_error_sentinel,
  [sym_source_file] = sym_source_file,
  [aux_sym__block] = aux_sym__block,
  [sym_block] = sym_block,
  [sym__statement] = sym__statement,
  [sym__expression] = sym__expression,
  [sym_parenthesis] = sym_parenthesis,
  [sym__binary_expression] = sym__binary_expression,
  [sym_binary_operator] = sym_binary_operator,
  [sym_unary_operator] = sym_unary_operator,
  [sym_indirect_access] = sym_indirect_access,
  [sym_field_expression] = sym_field_expression,
  [sym_not_operator] = sym_not_operator,
  [sym_metaclass_operator] = sym_metaclass_operator,
  [sym_handle_operator] = sym_handle_operator,
  [sym_comparison_operator] = sym_comparison_operator,
  [sym_boolean_operator] = sym_boolean_operator,
  [sym_postfix_operator] = sym_postfix_operator,
  [sym_string] = sym_string,
  [sym_row] = sym_row,
  [sym_matrix] = sym_matrix,
  [sym_cell] = sym_cell,
  [sym_ignored_argument] = sym_ignored_argument,
  [sym_assignment] = sym_assignment,
  [sym_multioutput_variable] = sym_multioutput_variable,
  [sym_spread_operator] = sym_spread_operator,
  [sym_arguments] = sym_arguments,
  [sym__args] = sym__args,
  [sym_function_call] = sym_function_call,
  [sym_command] = sym_command,
  [sym__range_element] = sym__range_element,
  [sym_range] = sym_range,
  [sym_elseif_clause] = sym_elseif_clause,
  [sym_else_clause] = sym_else_clause,
  [sym_if_statement] = sym_if_statement,
  [sym_iterator] = sym_iterator,
  [sym_parfor_options] = sym_parfor_options,
  [sym_for_statement] = sym_for_statement,
  [sym_while_statement] = sym_while_statement,
  [sym_case_clause] = sym_case_clause,
  [sym_otherwise_clause] = sym_otherwise_clause,
  [sym_switch_statement] = sym_switch_statement,
  [sym__lambda_arguments] = sym__lambda_arguments,
  [sym_lambda] = sym_lambda,
  [sym_global_operator] = sym_global_operator,
  [sym_persistent_operator] = sym_persistent_operator,
  [sym__argument_attributes] = sym_attributes,
  [sym_arguments_statement] = sym_arguments_statement,
  [sym_function_output] = sym_function_output,
  [sym_function_arguments] = sym_function_arguments,
  [sym_function_definition] = sym_function_definition,
  [sym__function_definition_with_end] = sym_function_definition,
  [sym_attribute] = sym_attribute,
  [sym_attributes] = sym_attributes,
  [sym_superclasses] = sym_superclasses,
  [sym_dimensions] = sym_dimensions,
  [sym_validation_functions] = sym_validation_functions,
  [sym_default_value] = sym_default_value,
  [sym_property_name] = sym_property_name,
  [sym_property] = sym_property,
  [sym_properties] = sym_properties,
  [sym_function_signature] = sym_function_signature,
  [sym_methods] = sym_methods,
  [sym_events] = sym_events,
  [sym__enum_value] = sym__enum_value,
  [sym_enum] = sym_enum,
  [sym_enumeration] = sym_enumeration,
  [sym_class_definition] = sym_class_definition,
  [sym_catch_clause] = sym_catch_clause,
  [sym_try_statement] = sym_try_statement,
  [sym_boolean] = sym_boolean,
  [sym__end_of_line] = sym__end_of_line,
  [aux_sym_source_file_repeat1] = aux_sym_source_file_repeat1,
  [aux_sym__block_repeat1] = aux_sym__block_repeat1,
  [aux_sym_field_expression_repeat1] = aux_sym_field_expression_repeat1,
  [aux_sym_handle_operator_repeat1] = aux_sym_handle_operator_repeat1,
  [aux_sym_string_repeat1] = aux_sym_string_repeat1,
  [aux_sym_row_repeat1] = aux_sym_row_repeat1,
  [aux_sym_matrix_repeat1] = aux_sym_matrix_repeat1,
  [aux_sym_multioutput_variable_repeat1] = aux_sym_multioutput_variable_repeat1,
  [aux_sym_arguments_repeat1] = aux_sym_arguments_repeat1,
  [aux_sym_arguments_repeat2] = aux_sym_arguments_repeat2,
  [aux_sym_command_repeat1] = aux_sym_command_repeat1,
  [aux_sym_elseif_clause_repeat1] = aux_sym_elseif_clause_repeat1,
  [aux_sym_if_statement_repeat1] = aux_sym_if_statement_repeat1,
  [aux_sym_switch_statement_repeat1] = aux_sym_switch_statement_repeat1,
  [aux_sym__lambda_arguments_repeat1] = aux_sym__lambda_arguments_repeat1,
  [aux_sym_global_operator_repeat1] = aux_sym_global_operator_repeat1,
  [aux_sym__argument_attributes_repeat1] = aux_sym__argument_attributes_repeat1,
  [aux_sym_arguments_statement_repeat1] = aux_sym_arguments_statement_repeat1,
  [aux_sym_function_definition_repeat1] = aux_sym_function_definition_repeat1,
  [aux_sym_attributes_repeat1] = aux_sym_attributes_repeat1,
  [aux_sym_superclasses_repeat1] = aux_sym_superclasses_repeat1,
  [aux_sym_dimensions_repeat1] = aux_sym_dimensions_repeat1,
  [aux_sym_validation_functions_repeat1] = aux_sym_validation_functions_repeat1,
  [aux_sym_methods_repeat1] = aux_sym_methods_repeat1,
  [aux_sym_events_repeat1] = aux_sym_events_repeat1,
  [aux_sym_enum_repeat1] = aux_sym_enum_repeat1,
  [aux_sym_enumeration_repeat1] = aux_sym_enumeration_repeat1,
  [aux_sym_class_definition_repeat1] = aux_sym_class_definition_repeat1,
  [alias_sym_superclass] = alias_sym_superclass,
};

static const TSSymbolMetadata ts_symbol_metadata[] = {
  [ts_builtin_sym_end] = {
    .visible = false,
    .named = true,
  },
  [sym_identifier] = {
    .visible = true,
    .named = true,
  },
  [anon_sym_SEMI] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_COMMA] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_LPAREN] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_RPAREN] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_PLUS] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_DOT_PLUS] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_DASH] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_DOT_DASH] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_STAR] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_DOT_STAR] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_SLASH] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_DOT_SLASH] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_BSLASH] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_DOT_BSLASH] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_CARET] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_DOT_CARET] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_PIPE] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_AMP] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_DOT] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_TILDE] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_QMARK] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_AT] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_LT] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_LT_EQ] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_EQ_EQ] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_TILDE_EQ] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_GT_EQ] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_GT] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_AMP_AMP] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_PIPE_PIPE] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_DOT_SQUOTE] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_SQUOTE] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_LBRACK] = {
    .visible = true,
    .named = false,
  },
  [aux_sym_matrix_token1] = {
    .visible = false,
    .named = false,
  },
  [anon_sym_RBRACK] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_LBRACE] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_RBRACE] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_EQ] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_COLON] = {
    .visible = true,
    .named = false,
  },
  [sym_return_statement] = {
    .visible = true,
    .named = true,
  },
  [sym_continue_statement] = {
    .visible = true,
    .named = true,
  },
  [sym_break_statement] = {
    .visible = true,
    .named = true,
  },
  [anon_sym_elseif] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_else] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_if] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_end] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_for] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_parfor] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_while] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_case] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_otherwise] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_switch] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_global] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_persistent] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_arguments] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_function] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_get_DOT] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_set_DOT] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_endfunction] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_properties] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_methods] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_events] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_enumeration] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_classdef] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_catch] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_try] = {
    .visible = true,
    .named = false,
  },
  [sym_number] = {
    .visible = true,
    .named = true,
  },
  [anon_sym_true] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_false] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_LF] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_CR] = {
    .visible = true,
    .named = false,
  },
  [sym_comment] = {
    .visible = true,
    .named = true,
  },
  [sym_line_continuation] = {
    .visible = true,
    .named = true,
  },
  [sym_command_name] = {
    .visible = true,
    .named = true,
  },
  [sym_command_argument] = {
    .visible = true,
    .named = true,
  },
  [sym__single_quote_string_start] = {
    .visible = true,
    .named = false,
  },
  [sym__single_quote_string_end] = {
    .visible = true,
    .named = false,
  },
  [sym__double_quote_string_start] = {
    .visible = true,
    .named = false,
  },
  [sym__double_quote_string_end] = {
    .visible = true,
    .named = false,
  },
  [sym_formatting_sequence] = {
    .visible = true,
    .named = true,
  },
  [sym_escape_sequence] = {
    .visible = true,
    .named = true,
  },
  [sym_string_content] = {
    .visible = true,
    .named = true,
  },
  [sym__entry_delimiter] = {
    .visible = true,
    .named = false,
  },
  [sym__multioutput_variable_start] = {
    .visible = true,
    .named = false,
  },
  [sym_error_sentinel] = {
    .visible = true,
    .named = true,
  },
  [sym_source_file] = {
    .visible = true,
    .named = true,
  },
  [aux_sym__block] = {
    .visible = false,
    .named = false,
  },
  [sym_block] = {
    .visible = true,
    .named = true,
  },
  [sym__statement] = {
    .visible = false,
    .named = true,
  },
  [sym__expression] = {
    .visible = false,
    .named = true,
  },
  [sym_parenthesis] = {
    .visible = true,
    .named = true,
  },
  [sym__binary_expression] = {
    .visible = false,
    .named = true,
  },
  [sym_binary_operator] = {
    .visible = true,
    .named = true,
  },
  [sym_unary_operator] = {
    .visible = true,
    .named = true,
  },
  [sym_indirect_access] = {
    .visible = true,
    .named = true,
  },
  [sym_field_expression] = {
    .visible = true,
    .named = true,
  },
  [sym_not_operator] = {
    .visible = true,
    .named = true,
  },
  [sym_metaclass_operator] = {
    .visible = true,
    .named = true,
  },
  [sym_handle_operator] = {
    .visible = true,
    .named = true,
  },
  [sym_comparison_operator] = {
    .visible = true,
    .named = true,
  },
  [sym_boolean_operator] = {
    .visible = true,
    .named = true,
  },
  [sym_postfix_operator] = {
    .visible = true,
    .named = true,
  },
  [sym_string] = {
    .visible = true,
    .named = true,
  },
  [sym_row] = {
    .visible = true,
    .named = true,
  },
  [sym_matrix] = {
    .visible = true,
    .named = true,
  },
  [sym_cell] = {
    .visible = true,
    .named = true,
  },
  [sym_ignored_argument] = {
    .visible = true,
    .named = true,
  },
  [sym_assignment] = {
    .visible = true,
    .named = true,
  },
  [sym_multioutput_variable] = {
    .visible = true,
    .named = true,
  },
  [sym_spread_operator] = {
    .visible = true,
    .named = true,
  },
  [sym_arguments] = {
    .visible = true,
    .named = true,
  },
  [sym__args] = {
    .visible = false,
    .named = true,
  },
  [sym_function_call] = {
    .visible = true,
    .named = true,
  },
  [sym_command] = {
    .visible = true,
    .named = true,
  },
  [sym__range_element] = {
    .visible = false,
    .named = true,
  },
  [sym_range] = {
    .visible = true,
    .named = true,
  },
  [sym_elseif_clause] = {
    .visible = true,
    .named = true,
  },
  [sym_else_clause] = {
    .visible = true,
    .named = true,
  },
  [sym_if_statement] = {
    .visible = true,
    .named = true,
  },
  [sym_iterator] = {
    .visible = true,
    .named = true,
  },
  [sym_parfor_options] = {
    .visible = true,
    .named = true,
  },
  [sym_for_statement] = {
    .visible = true,
    .named = true,
  },
  [sym_while_statement] = {
    .visible = true,
    .named = true,
  },
  [sym_case_clause] = {
    .visible = true,
    .named = true,
  },
  [sym_otherwise_clause] = {
    .visible = true,
    .named = true,
  },
  [sym_switch_statement] = {
    .visible = true,
    .named = true,
  },
  [sym__lambda_arguments] = {
    .visible = false,
    .named = true,
  },
  [sym_lambda] = {
    .visible = true,
    .named = true,
  },
  [sym_global_operator] = {
    .visible = true,
    .named = true,
  },
  [sym_persistent_operator] = {
    .visible = true,
    .named = true,
  },
  [sym__argument_attributes] = {
    .visible = true,
    .named = true,
  },
  [sym_arguments_statement] = {
    .visible = true,
    .named = true,
  },
  [sym_function_output] = {
    .visible = true,
    .named = true,
  },
  [sym_function_arguments] = {
    .visible = true,
    .named = true,
  },
  [sym_function_definition] = {
    .visible = true,
    .named = true,
  },
  [sym__function_definition_with_end] = {
    .visible = true,
    .named = true,
  },
  [sym_attribute] = {
    .visible = true,
    .named = true,
  },
  [sym_attributes] = {
    .visible = true,
    .named = true,
  },
  [sym_superclasses] = {
    .visible = true,
    .named = true,
  },
  [sym_dimensions] = {
    .visible = true,
    .named = true,
  },
  [sym_validation_functions] = {
    .visible = true,
    .named = true,
  },
  [sym_default_value] = {
    .visible = true,
    .named = true,
  },
  [sym_property_name] = {
    .visible = true,
    .named = true,
  },
  [sym_property] = {
    .visible = true,
    .named = true,
  },
  [sym_properties] = {
    .visible = true,
    .named = true,
  },
  [sym_function_signature] = {
    .visible = true,
    .named = true,
  },
  [sym_methods] = {
    .visible = true,
    .named = true,
  },
  [sym_events] = {
    .visible = true,
    .named = true,
  },
  [sym__enum_value] = {
    .visible = false,
    .named = true,
  },
  [sym_enum] = {
    .visible = true,
    .named = true,
  },
  [sym_enumeration] = {
    .visible = true,
    .named = true,
  },
  [sym_class_definition] = {
    .visible = true,
    .named = true,
  },
  [sym_catch_clause] = {
    .visible = true,
    .named = true,
  },
  [sym_try_statement] = {
    .visible = true,
    .named = true,
  },
  [sym_boolean] = {
    .visible = true,
    .named = true,
  },
  [sym__end_of_line] = {
    .visible = false,
    .named = true,
  },
  [aux_sym_source_file_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym__block_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_field_expression_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_handle_operator_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_string_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_row_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_matrix_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_multioutput_variable_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_arguments_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_arguments_repeat2] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_command_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_elseif_clause_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_if_statement_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_switch_statement_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym__lambda_arguments_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_global_operator_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym__argument_attributes_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_arguments_statement_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_function_definition_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_attributes_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_superclasses_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_dimensions_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_validation_functions_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_methods_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_events_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_enum_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_enumeration_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_class_definition_repeat1] = {
    .visible = false,
    .named = false,
  },
  [alias_sym_superclass] = {
    .visible = true,
    .named = true,
  },
};

enum ts_field_identifiers {
  field_argument = 1,
  field_arguments = 2,
  field_condition = 3,
  field_expression = 4,
  field_field = 5,
  field_left = 6,
  field_name = 7,
  field_object = 8,
  field_operand = 9,
  field_right = 10,
};

static const char * const ts_field_names[] = {
  [0] = NULL,
  [field_argument] = "argument",
  [field_arguments] = "arguments",
  [field_condition] = "condition",
  [field_expression] = "expression",
  [field_field] = "field",
  [field_left] = "left",
  [field_name] = "name",
  [field_object] = "object",
  [field_operand] = "operand",
  [field_right] = "right",
};

static const TSFieldMapSlice ts_field_map_slices[PRODUCTION_ID_COUNT] = {
  [1] = {.index = 0, .length = 1},
  [2] = {.index = 1, .length = 1},
  [3] = {.index = 2, .length = 1},
  [4] = {.index = 3, .length = 2},
  [5] = {.index = 5, .length = 1},
  [6] = {.index = 2, .length = 1},
  [7] = {.index = 6, .length = 1},
  [8] = {.index = 7, .length = 1},
  [9] = {.index = 8, .length = 1},
  [10] = {.index = 9, .length = 1},
  [11] = {.index = 10, .length = 2},
  [12] = {.index = 12, .length = 2},
  [13] = {.index = 14, .length = 1},
  [14] = {.index = 15, .length = 1},
  [15] = {.index = 16, .length = 2},
  [16] = {.index = 2, .length = 1},
  [17] = {.index = 2, .length = 1},
  [18] = {.index = 18, .length = 1},
  [19] = {.index = 19, .length = 1},
  [20] = {.index = 20, .length = 1},
  [21] = {.index = 21, .length = 1},
  [22] = {.index = 22, .length = 2},
  [23] = {.index = 24, .length = 1},
  [24] = {.index = 25, .length = 2},
};

static const TSFieldMapEntry ts_field_map_entries[] = {
  [0] =
    {field_operand, 1},
  [1] =
    {field_operand, 0},
  [2] =
    {field_name, 0},
  [3] =
    {field_field, 1, .inherited = true},
    {field_object, 0},
  [5] =
    {field_name, 0, .inherited = true},
  [6] =
    {field_condition, 1},
  [7] =
    {field_name, 1},
  [8] =
    {field_argument, 0},
  [9] =
    {field_field, 1},
  [10] =
    {field_left, 0},
    {field_right, 2},
  [12] =
    {field_field, 0, .inherited = true},
    {field_field, 1, .inherited = true},
  [14] =
    {field_expression, 3},
  [15] =
    {field_name, 2},
  [16] =
    {field_argument, 0},
    {field_argument, 1, .inherited = true},
  [18] =
    {field_expression, 4},
  [19] =
    {field_arguments, 1},
  [20] =
    {field_name, 3},
  [21] =
    {field_argument, 1},
  [22] =
    {field_argument, 0, .inherited = true},
    {field_argument, 1, .inherited = true},
  [24] =
    {field_argument, 1, .inherited = true},
  [25] =
    {field_argument, 1},
    {field_argument, 2, .inherited = true},
};

static const TSSymbol ts_alias_sequences[PRODUCTION_ID_COUNT][MAX_ALIAS_SEQUENCE_LENGTH] = {
  [0] = {0},
  [6] = {
    [0] = sym_identifier,
  },
  [16] = {
    [2] = alias_sym_superclass,
  },
  [17] = {
    [0] = sym_identifier,
    [2] = alias_sym_superclass,
  },
  [18] = {
    [2] = sym_arguments,
  },
};

static const uint16_t ts_non_terminal_alias_map[] = {
  sym__lambda_arguments, 2,
    sym__lambda_arguments,
    sym_arguments,
  sym_property_name, 2,
    sym_property_name,
    alias_sym_superclass,
  sym_boolean, 2,
    sym_boolean,
    sym_identifier,
  0,
};

static const TSStateId ts_primary_state_ids[STATE_COUNT] = {
  [0] = 0,
  [1] = 1,
  [2] = 2,
  [3] = 3,
  [4] = 4,
  [5] = 5,
  [6] = 6,
  [7] = 7,
  [8] = 8,
  [9] = 9,
  [10] = 10,
  [11] = 11,
  [12] = 12,
  [13] = 13,
  [14] = 14,
  [15] = 15,
  [16] = 16,
  [17] = 17,
  [18] = 18,
  [19] = 19,
  [20] = 20,
  [21] = 21,
  [22] = 22,
  [23] = 23,
  [24] = 24,
  [25] = 25,
  [26] = 26,
  [27] = 27,
  [28] = 28,
  [29] = 29,
  [30] = 30,
  [31] = 31,
  [32] = 32,
  [33] = 33,
  [34] = 34,
  [35] = 35,
  [36] = 36,
  [37] = 37,
  [38] = 38,
  [39] = 39,
  [40] = 40,
  [41] = 41,
  [42] = 42,
  [43] = 43,
  [44] = 44,
  [45] = 45,
  [46] = 46,
  [47] = 47,
  [48] = 48,
  [49] = 49,
  [50] = 50,
  [51] = 48,
  [52] = 50,
  [53] = 47,
  [54] = 54,
  [55] = 55,
  [56] = 45,
  [57] = 49,
  [58] = 58,
  [59] = 59,
  [60] = 60,
  [61] = 61,
  [62] = 61,
  [63] = 63,
  [64] = 60,
  [65] = 58,
  [66] = 66,
  [67] = 55,
  [68] = 46,
  [69] = 66,
  [70] = 63,
  [71] = 71,
  [72] = 59,
  [73] = 54,
  [74] = 54,
  [75] = 59,
  [76] = 76,
  [77] = 76,
  [78] = 78,
  [79] = 76,
  [80] = 76,
  [81] = 81,
  [82] = 82,
  [83] = 83,
  [84] = 84,
  [85] = 85,
  [86] = 86,
  [87] = 87,
  [88] = 88,
  [89] = 89,
  [90] = 90,
  [91] = 91,
  [92] = 92,
  [93] = 93,
  [94] = 94,
  [95] = 91,
  [96] = 96,
  [97] = 91,
  [98] = 98,
  [99] = 91,
  [100] = 100,
  [101] = 101,
  [102] = 102,
  [103] = 103,
  [104] = 104,
  [105] = 105,
  [106] = 106,
  [107] = 103,
  [108] = 108,
  [109] = 109,
  [110] = 110,
  [111] = 111,
  [112] = 112,
  [113] = 113,
  [114] = 114,
  [115] = 115,
  [116] = 116,
  [117] = 117,
  [118] = 118,
  [119] = 109,
  [120] = 120,
  [121] = 103,
  [122] = 122,
  [123] = 123,
  [124] = 103,
  [125] = 125,
  [126] = 105,
  [127] = 104,
  [128] = 104,
  [129] = 105,
  [130] = 130,
  [131] = 131,
  [132] = 132,
  [133] = 104,
  [134] = 105,
  [135] = 135,
  [136] = 136,
  [137] = 137,
  [138] = 138,
  [139] = 136,
  [140] = 140,
  [141] = 141,
  [142] = 142,
  [143] = 143,
  [144] = 144,
  [145] = 145,
  [146] = 136,
  [147] = 111,
  [148] = 135,
  [149] = 112,
  [150] = 113,
  [151] = 118,
  [152] = 86,
  [153] = 82,
  [154] = 85,
  [155] = 89,
  [156] = 156,
  [157] = 157,
  [158] = 158,
  [159] = 159,
  [160] = 160,
  [161] = 161,
  [162] = 162,
  [163] = 163,
  [164] = 163,
  [165] = 163,
  [166] = 166,
  [167] = 167,
  [168] = 168,
  [169] = 166,
  [170] = 170,
  [171] = 171,
  [172] = 166,
  [173] = 171,
  [174] = 166,
  [175] = 175,
  [176] = 176,
  [177] = 177,
  [178] = 176,
  [179] = 179,
  [180] = 171,
  [181] = 163,
  [182] = 171,
  [183] = 176,
  [184] = 176,
  [185] = 163,
  [186] = 176,
  [187] = 76,
  [188] = 78,
  [189] = 76,
  [190] = 76,
  [191] = 84,
  [192] = 76,
  [193] = 193,
  [194] = 96,
  [195] = 195,
  [196] = 196,
  [197] = 93,
  [198] = 94,
  [199] = 98,
  [200] = 88,
  [201] = 90,
  [202] = 202,
  [203] = 87,
  [204] = 204,
  [205] = 91,
  [206] = 92,
  [207] = 76,
  [208] = 208,
  [209] = 209,
  [210] = 210,
  [211] = 91,
  [212] = 76,
  [213] = 161,
  [214] = 76,
  [215] = 215,
  [216] = 76,
  [217] = 78,
  [218] = 91,
  [219] = 91,
  [220] = 220,
  [221] = 221,
  [222] = 222,
  [223] = 175,
  [224] = 224,
  [225] = 177,
  [226] = 226,
  [227] = 168,
  [228] = 228,
  [229] = 229,
  [230] = 230,
  [231] = 226,
  [232] = 232,
  [233] = 233,
  [234] = 234,
  [235] = 235,
  [236] = 236,
  [237] = 237,
  [238] = 224,
  [239] = 239,
  [240] = 179,
  [241] = 224,
  [242] = 226,
  [243] = 232,
  [244] = 244,
  [245] = 244,
  [246] = 246,
  [247] = 247,
  [248] = 248,
  [249] = 226,
  [250] = 224,
  [251] = 244,
  [252] = 252,
  [253] = 253,
  [254] = 254,
  [255] = 248,
  [256] = 239,
  [257] = 237,
  [258] = 236,
  [259] = 226,
  [260] = 235,
  [261] = 234,
  [262] = 233,
  [263] = 230,
  [264] = 229,
  [265] = 228,
  [266] = 254,
  [267] = 239,
  [268] = 246,
  [269] = 232,
  [270] = 226,
  [271] = 246,
  [272] = 272,
  [273] = 273,
  [274] = 246,
  [275] = 246,
  [276] = 224,
  [277] = 254,
  [278] = 278,
  [279] = 222,
  [280] = 239,
  [281] = 246,
  [282] = 252,
  [283] = 283,
  [284] = 252,
  [285] = 228,
  [286] = 229,
  [287] = 230,
  [288] = 233,
  [289] = 224,
  [290] = 234,
  [291] = 235,
  [292] = 292,
  [293] = 246,
  [294] = 236,
  [295] = 237,
  [296] = 224,
  [297] = 297,
  [298] = 226,
  [299] = 236,
  [300] = 300,
  [301] = 301,
  [302] = 222,
  [303] = 236,
  [304] = 239,
  [305] = 237,
  [306] = 246,
  [307] = 239,
  [308] = 224,
  [309] = 226,
  [310] = 81,
  [311] = 83,
  [312] = 224,
  [313] = 313,
  [314] = 140,
  [315] = 226,
  [316] = 224,
  [317] = 232,
  [318] = 244,
  [319] = 226,
  [320] = 237,
  [321] = 239,
  [322] = 237,
  [323] = 236,
  [324] = 224,
  [325] = 235,
  [326] = 234,
  [327] = 233,
  [328] = 230,
  [329] = 229,
  [330] = 222,
  [331] = 226,
  [332] = 236,
  [333] = 228,
  [334] = 237,
  [335] = 239,
  [336] = 237,
  [337] = 337,
  [338] = 226,
  [339] = 236,
  [340] = 226,
  [341] = 341,
  [342] = 246,
  [343] = 254,
  [344] = 224,
  [345] = 84,
  [346] = 252,
  [347] = 170,
  [348] = 246,
  [349] = 246,
  [350] = 246,
  [351] = 246,
  [352] = 224,
  [353] = 232,
  [354] = 354,
  [355] = 355,
  [356] = 356,
  [357] = 92,
  [358] = 76,
  [359] = 91,
  [360] = 88,
  [361] = 87,
  [362] = 90,
  [363] = 91,
  [364] = 364,
  [365] = 85,
  [366] = 78,
  [367] = 76,
  [368] = 76,
  [369] = 98,
  [370] = 82,
  [371] = 91,
  [372] = 93,
  [373] = 86,
  [374] = 91,
  [375] = 76,
  [376] = 96,
  [377] = 76,
  [378] = 94,
  [379] = 140,
  [380] = 380,
  [381] = 381,
  [382] = 382,
  [383] = 84,
  [384] = 384,
  [385] = 89,
  [386] = 386,
  [387] = 387,
  [388] = 137,
  [389] = 105,
  [390] = 141,
  [391] = 130,
  [392] = 104,
  [393] = 145,
  [394] = 91,
  [395] = 380,
  [396] = 101,
  [397] = 125,
  [398] = 92,
  [399] = 100,
  [400] = 380,
  [401] = 132,
  [402] = 91,
  [403] = 131,
  [404] = 105,
  [405] = 143,
  [406] = 144,
  [407] = 103,
  [408] = 138,
  [409] = 136,
  [410] = 104,
  [411] = 104,
  [412] = 380,
  [413] = 117,
  [414] = 380,
  [415] = 118,
  [416] = 93,
  [417] = 135,
  [418] = 87,
  [419] = 105,
  [420] = 116,
  [421] = 115,
  [422] = 103,
  [423] = 109,
  [424] = 96,
  [425] = 81,
  [426] = 85,
  [427] = 380,
  [428] = 110,
  [429] = 102,
  [430] = 109,
  [431] = 108,
  [432] = 98,
  [433] = 122,
  [434] = 106,
  [435] = 103,
  [436] = 82,
  [437] = 90,
  [438] = 86,
  [439] = 104,
  [440] = 91,
  [441] = 123,
  [442] = 380,
  [443] = 103,
  [444] = 113,
  [445] = 88,
  [446] = 114,
  [447] = 112,
  [448] = 91,
  [449] = 105,
  [450] = 142,
  [451] = 120,
  [452] = 111,
  [453] = 83,
  [454] = 136,
  [455] = 94,
  [456] = 456,
  [457] = 89,
  [458] = 140,
  [459] = 130,
  [460] = 113,
  [461] = 101,
  [462] = 85,
  [463] = 104,
  [464] = 86,
  [465] = 138,
  [466] = 105,
  [467] = 125,
  [468] = 145,
  [469] = 136,
  [470] = 144,
  [471] = 143,
  [472] = 103,
  [473] = 123,
  [474] = 142,
  [475] = 141,
  [476] = 137,
  [477] = 136,
  [478] = 82,
  [479] = 479,
  [480] = 104,
  [481] = 100,
  [482] = 132,
  [483] = 81,
  [484] = 111,
  [485] = 485,
  [486] = 112,
  [487] = 122,
  [488] = 83,
  [489] = 105,
  [490] = 120,
  [491] = 117,
  [492] = 104,
  [493] = 118,
  [494] = 116,
  [495] = 103,
  [496] = 105,
  [497] = 115,
  [498] = 110,
  [499] = 103,
  [500] = 136,
  [501] = 108,
  [502] = 135,
  [503] = 106,
  [504] = 131,
  [505] = 109,
  [506] = 102,
  [507] = 104,
  [508] = 105,
  [509] = 103,
  [510] = 109,
  [511] = 114,
  [512] = 118,
  [513] = 135,
  [514] = 89,
  [515] = 113,
  [516] = 112,
  [517] = 111,
  [518] = 109,
  [519] = 136,
  [520] = 114,
  [521] = 104,
  [522] = 131,
  [523] = 132,
  [524] = 135,
  [525] = 136,
  [526] = 102,
  [527] = 104,
  [528] = 100,
  [529] = 103,
  [530] = 103,
  [531] = 105,
  [532] = 106,
  [533] = 108,
  [534] = 137,
  [535] = 141,
  [536] = 110,
  [537] = 142,
  [538] = 143,
  [539] = 144,
  [540] = 145,
  [541] = 115,
  [542] = 105,
  [543] = 101,
  [544] = 136,
  [545] = 138,
  [546] = 130,
  [547] = 105,
  [548] = 125,
  [549] = 104,
  [550] = 111,
  [551] = 116,
  [552] = 109,
  [553] = 105,
  [554] = 117,
  [555] = 120,
  [556] = 103,
  [557] = 122,
  [558] = 112,
  [559] = 123,
  [560] = 113,
  [561] = 103,
  [562] = 118,
  [563] = 104,
  [564] = 564,
  [565] = 565,
  [566] = 111,
  [567] = 112,
  [568] = 135,
  [569] = 118,
  [570] = 570,
  [571] = 113,
  [572] = 572,
  [573] = 573,
  [574] = 565,
  [575] = 570,
  [576] = 570,
  [577] = 565,
  [578] = 570,
  [579] = 564,
  [580] = 564,
  [581] = 565,
  [582] = 564,
  [583] = 565,
  [584] = 570,
  [585] = 585,
  [586] = 136,
  [587] = 564,
  [588] = 565,
  [589] = 564,
  [590] = 570,
  [591] = 103,
  [592] = 103,
  [593] = 118,
  [594] = 103,
  [595] = 135,
  [596] = 112,
  [597] = 111,
  [598] = 113,
  [599] = 599,
  [600] = 109,
  [601] = 109,
  [602] = 109,
  [603] = 85,
  [604] = 89,
  [605] = 605,
  [606] = 606,
  [607] = 82,
  [608] = 86,
  [609] = 85,
  [610] = 86,
  [611] = 611,
  [612] = 85,
  [613] = 82,
  [614] = 614,
  [615] = 614,
  [616] = 616,
  [617] = 614,
  [618] = 89,
  [619] = 619,
  [620] = 89,
  [621] = 621,
  [622] = 614,
  [623] = 82,
  [624] = 624,
  [625] = 625,
  [626] = 86,
  [627] = 627,
  [628] = 628,
  [629] = 629,
  [630] = 627,
  [631] = 631,
  [632] = 627,
  [633] = 633,
  [634] = 634,
  [635] = 94,
  [636] = 636,
  [637] = 88,
  [638] = 87,
  [639] = 639,
  [640] = 640,
  [641] = 641,
  [642] = 642,
  [643] = 643,
  [644] = 644,
  [645] = 645,
  [646] = 646,
  [647] = 90,
  [648] = 98,
  [649] = 96,
  [650] = 650,
  [651] = 651,
  [652] = 652,
  [653] = 653,
  [654] = 654,
  [655] = 84,
  [656] = 656,
  [657] = 657,
  [658] = 658,
  [659] = 659,
  [660] = 660,
  [661] = 661,
  [662] = 662,
  [663] = 663,
  [664] = 664,
  [665] = 665,
  [666] = 666,
  [667] = 667,
  [668] = 668,
  [669] = 669,
  [670] = 670,
  [671] = 671,
  [672] = 93,
  [673] = 673,
  [674] = 674,
  [675] = 675,
  [676] = 676,
  [677] = 83,
  [678] = 678,
  [679] = 81,
  [680] = 680,
  [681] = 680,
  [682] = 682,
  [683] = 683,
  [684] = 680,
  [685] = 157,
  [686] = 686,
  [687] = 680,
  [688] = 158,
  [689] = 689,
  [690] = 689,
  [691] = 689,
  [692] = 692,
  [693] = 693,
  [694] = 694,
  [695] = 695,
  [696] = 689,
  [697] = 697,
  [698] = 697,
  [699] = 692,
  [700] = 689,
  [701] = 701,
  [702] = 702,
  [703] = 703,
  [704] = 704,
  [705] = 705,
  [706] = 706,
  [707] = 707,
  [708] = 708,
  [709] = 709,
  [710] = 710,
  [711] = 706,
  [712] = 712,
  [713] = 713,
  [714] = 714,
  [715] = 715,
  [716] = 716,
  [717] = 717,
  [718] = 718,
  [719] = 719,
  [720] = 720,
  [721] = 721,
  [722] = 722,
  [723] = 706,
  [724] = 706,
  [725] = 702,
  [726] = 726,
  [727] = 727,
  [728] = 728,
  [729] = 729,
  [730] = 730,
  [731] = 731,
  [732] = 732,
  [733] = 733,
  [734] = 734,
  [735] = 735,
  [736] = 736,
  [737] = 737,
  [738] = 706,
  [739] = 739,
  [740] = 740,
  [741] = 703,
  [742] = 742,
  [743] = 743,
  [744] = 744,
  [745] = 745,
  [746] = 746,
  [747] = 747,
  [748] = 748,
  [749] = 749,
  [750] = 750,
  [751] = 751,
  [752] = 752,
  [753] = 753,
  [754] = 754,
  [755] = 755,
  [756] = 756,
  [757] = 757,
  [758] = 758,
  [759] = 759,
  [760] = 760,
  [761] = 761,
  [762] = 762,
  [763] = 763,
  [764] = 764,
  [765] = 765,
  [766] = 748,
  [767] = 767,
  [768] = 768,
  [769] = 769,
  [770] = 770,
  [771] = 771,
  [772] = 772,
  [773] = 773,
  [774] = 774,
  [775] = 775,
  [776] = 776,
  [777] = 777,
  [778] = 778,
  [779] = 779,
  [780] = 780,
  [781] = 781,
  [782] = 782,
  [783] = 783,
  [784] = 784,
  [785] = 785,
  [786] = 786,
  [787] = 787,
  [788] = 788,
  [789] = 789,
  [790] = 790,
  [791] = 791,
  [792] = 792,
  [793] = 793,
  [794] = 794,
  [795] = 795,
  [796] = 796,
  [797] = 797,
  [798] = 798,
  [799] = 799,
  [800] = 800,
  [801] = 801,
  [802] = 802,
  [803] = 803,
  [804] = 804,
  [805] = 805,
  [806] = 806,
  [807] = 807,
  [808] = 807,
  [809] = 809,
  [810] = 810,
  [811] = 811,
  [812] = 812,
  [813] = 807,
  [814] = 814,
  [815] = 815,
  [816] = 807,
  [817] = 817,
  [818] = 818,
  [819] = 807,
  [820] = 820,
  [821] = 807,
  [822] = 822,
  [823] = 823,
  [824] = 824,
  [825] = 825,
  [826] = 807,
  [827] = 827,
  [828] = 807,
  [829] = 829,
  [830] = 830,
  [831] = 831,
  [832] = 832,
  [833] = 833,
  [834] = 834,
  [835] = 835,
  [836] = 825,
  [837] = 837,
  [838] = 838,
  [839] = 834,
  [840] = 807,
  [841] = 841,
  [842] = 842,
  [843] = 843,
  [844] = 844,
  [845] = 838,
  [846] = 807,
  [847] = 847,
  [848] = 825,
  [849] = 849,
  [850] = 833,
  [851] = 851,
  [852] = 807,
  [853] = 817,
  [854] = 833,
  [855] = 825,
  [856] = 856,
  [857] = 857,
  [858] = 858,
  [859] = 859,
  [860] = 860,
  [861] = 861,
  [862] = 862,
  [863] = 863,
  [864] = 807,
  [865] = 865,
  [866] = 866,
  [867] = 867,
  [868] = 811,
  [869] = 869,
  [870] = 870,
  [871] = 871,
  [872] = 872,
  [873] = 873,
  [874] = 817,
  [875] = 875,
  [876] = 876,
  [877] = 860,
  [878] = 838,
  [879] = 807,
  [880] = 834,
  [881] = 833,
  [882] = 849,
  [883] = 883,
  [884] = 884,
  [885] = 834,
  [886] = 838,
  [887] = 842,
  [888] = 860,
  [889] = 876,
  [890] = 753,
  [891] = 891,
  [892] = 892,
  [893] = 893,
  [894] = 894,
  [895] = 895,
  [896] = 896,
  [897] = 897,
  [898] = 898,
  [899] = 899,
  [900] = 795,
  [901] = 901,
  [902] = 902,
  [903] = 903,
  [904] = 904,
  [905] = 905,
  [906] = 906,
  [907] = 907,
  [908] = 908,
  [909] = 909,
  [910] = 910,
  [911] = 911,
  [912] = 912,
  [913] = 913,
  [914] = 914,
  [915] = 749,
  [916] = 916,
  [917] = 917,
  [918] = 918,
  [919] = 905,
  [920] = 920,
  [921] = 921,
  [922] = 922,
  [923] = 923,
  [924] = 924,
  [925] = 925,
  [926] = 926,
  [927] = 927,
  [928] = 928,
  [929] = 929,
  [930] = 930,
  [931] = 892,
  [932] = 932,
  [933] = 933,
  [934] = 934,
  [935] = 935,
  [936] = 908,
  [937] = 909,
  [938] = 938,
  [939] = 893,
  [940] = 904,
  [941] = 941,
  [942] = 942,
  [943] = 651,
  [944] = 944,
  [945] = 945,
  [946] = 946,
  [947] = 947,
  [948] = 948,
  [949] = 949,
  [950] = 950,
  [951] = 757,
  [952] = 908,
  [953] = 758,
  [954] = 909,
  [955] = 760,
  [956] = 905,
  [957] = 904,
  [958] = 958,
  [959] = 959,
  [960] = 892,
  [961] = 961,
  [962] = 962,
  [963] = 963,
  [964] = 964,
  [965] = 965,
  [966] = 966,
  [967] = 893,
  [968] = 968,
  [969] = 969,
  [970] = 970,
  [971] = 971,
  [972] = 892,
  [973] = 973,
  [974] = 974,
  [975] = 761,
  [976] = 976,
  [977] = 763,
  [978] = 770,
  [979] = 979,
  [980] = 980,
  [981] = 719,
  [982] = 982,
  [983] = 983,
  [984] = 984,
  [985] = 985,
  [986] = 986,
  [987] = 905,
  [988] = 988,
  [989] = 771,
  [990] = 778,
  [991] = 991,
  [992] = 892,
  [993] = 993,
  [994] = 905,
  [995] = 995,
  [996] = 893,
  [997] = 904,
  [998] = 998,
  [999] = 782,
  [1000] = 908,
  [1001] = 909,
  [1002] = 1002,
  [1003] = 1003,
  [1004] = 1004,
  [1005] = 1005,
  [1006] = 1006,
  [1007] = 1007,
  [1008] = 1008,
  [1009] = 1009,
  [1010] = 1010,
  [1011] = 1011,
  [1012] = 1012,
  [1013] = 1013,
  [1014] = 1014,
  [1015] = 1015,
  [1016] = 1016,
  [1017] = 1004,
  [1018] = 1018,
  [1019] = 1019,
  [1020] = 1020,
  [1021] = 1021,
  [1022] = 1022,
  [1023] = 1023,
  [1024] = 1024,
  [1025] = 1025,
  [1026] = 1026,
  [1027] = 1027,
  [1028] = 1028,
  [1029] = 1029,
  [1030] = 1030,
  [1031] = 1031,
  [1032] = 1023,
  [1033] = 1026,
  [1034] = 1034,
  [1035] = 1025,
  [1036] = 1036,
  [1037] = 1026,
  [1038] = 1023,
  [1039] = 1023,
  [1040] = 1026,
  [1041] = 1041,
  [1042] = 1042,
  [1043] = 1041,
  [1044] = 1044,
  [1045] = 1045,
  [1046] = 1046,
  [1047] = 1047,
  [1048] = 1048,
  [1049] = 1049,
  [1050] = 1050,
  [1051] = 1023,
  [1052] = 1052,
  [1053] = 1053,
  [1054] = 1026,
  [1055] = 1055,
  [1056] = 1056,
  [1057] = 1057,
  [1058] = 1058,
  [1059] = 1059,
  [1060] = 686,
  [1061] = 1061,
  [1062] = 1062,
  [1063] = 1063,
  [1064] = 1064,
  [1065] = 1065,
  [1066] = 1066,
  [1067] = 1061,
  [1068] = 1068,
  [1069] = 1064,
  [1070] = 1070,
  [1071] = 1065,
  [1072] = 1072,
  [1073] = 1073,
  [1074] = 1061,
  [1075] = 1075,
  [1076] = 1076,
  [1077] = 1077,
  [1078] = 1062,
  [1079] = 1065,
  [1080] = 1061,
  [1081] = 1081,
  [1082] = 1082,
  [1083] = 1083,
  [1084] = 1084,
  [1085] = 1085,
  [1086] = 1086,
  [1087] = 1062,
  [1088] = 1075,
  [1089] = 1089,
  [1090] = 1090,
  [1091] = 1065,
  [1092] = 1092,
  [1093] = 1065,
  [1094] = 1094,
  [1095] = 1095,
  [1096] = 1096,
  [1097] = 682,
  [1098] = 1061,
  [1099] = 1099,
  [1100] = 1100,
  [1101] = 1101,
  [1102] = 1062,
  [1103] = 1062,
  [1104] = 1062,
  [1105] = 1062,
  [1106] = 1106,
  [1107] = 1095,
  [1108] = 1063,
  [1109] = 1073,
  [1110] = 1062,
  [1111] = 1062,
  [1112] = 1072,
  [1113] = 1096,
  [1114] = 1062,
  [1115] = 1115,
  [1116] = 1062,
  [1117] = 1117,
  [1118] = 1062,
  [1119] = 1119,
  [1120] = 1099,
  [1121] = 1121,
  [1122] = 1122,
  [1123] = 1123,
  [1124] = 1124,
  [1125] = 1070,
  [1126] = 1126,
  [1127] = 1094,
  [1128] = 1128,
  [1129] = 1068,
  [1130] = 1062,
  [1131] = 1131,
  [1132] = 1066,
  [1133] = 1133,
  [1134] = 1134,
  [1135] = 1135,
  [1136] = 1136,
  [1137] = 1137,
  [1138] = 1138,
  [1139] = 1139,
  [1140] = 1140,
  [1141] = 1135,
  [1142] = 1142,
  [1143] = 1143,
  [1144] = 1144,
  [1145] = 1145,
  [1146] = 1146,
  [1147] = 1139,
  [1148] = 1138,
  [1149] = 1136,
  [1150] = 1136,
  [1151] = 1135,
  [1152] = 1152,
  [1153] = 1153,
  [1154] = 1154,
  [1155] = 1136,
  [1156] = 1139,
  [1157] = 1138,
  [1158] = 1139,
  [1159] = 1159,
  [1160] = 925,
  [1161] = 1139,
  [1162] = 1138,
  [1163] = 1163,
  [1164] = 1164,
  [1165] = 1165,
  [1166] = 1139,
  [1167] = 1138,
  [1168] = 1135,
  [1169] = 1136,
  [1170] = 1138,
  [1171] = 1139,
  [1172] = 1172,
  [1173] = 1173,
  [1174] = 1174,
  [1175] = 1138,
  [1176] = 1176,
  [1177] = 1177,
  [1178] = 1178,
  [1179] = 1159,
  [1180] = 1139,
  [1181] = 1159,
  [1182] = 1135,
  [1183] = 1183,
  [1184] = 933,
  [1185] = 1185,
  [1186] = 1186,
  [1187] = 1187,
  [1188] = 1188,
  [1189] = 1189,
  [1190] = 1190,
  [1191] = 1191,
  [1192] = 1192,
  [1193] = 1193,
  [1194] = 1194,
  [1195] = 1139,
  [1196] = 1159,
  [1197] = 1137,
  [1198] = 1139,
  [1199] = 1199,
  [1200] = 1200,
  [1201] = 1139,
  [1202] = 1139,
  [1203] = 1138,
  [1204] = 1204,
  [1205] = 1205,
  [1206] = 1206,
  [1207] = 1207,
  [1208] = 1139,
  [1209] = 1209,
  [1210] = 1210,
  [1211] = 1211,
  [1212] = 1212,
  [1213] = 1213,
  [1214] = 1214,
  [1215] = 1191,
  [1216] = 1216,
  [1217] = 1176,
  [1218] = 1218,
};

static bool ts_lex(TSLexer *lexer, TSStateId state) {
  START_LEXER();
  eof = lexer->eof(lexer);
  switch (state) {
    case 0:
      if (eof) ADVANCE(16);
      ADVANCE_MAP(
        '&', 35,
        '\'', 53,
        '(', 19,
        ')', 20,
        '*', 25,
        '+', 21,
        ',', 18,
        '-', 23,
        '.', 38,
        '/', 27,
        ':', 61,
        ';', 17,
        '<', 44,
        '=', 60,
        '>', 49,
        '?', 42,
        '@', 43,
        '[', 54,
        '\\', 29,
        ']', 56,
        '^', 31,
        'g', 70,
        's', 71,
        '{', 57,
        '|', 33,
        '}', 58,
        '~', 41,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(0);
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(65);
      if (('A' <= lookahead && lookahead <= '_') ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(74);
      END_STATE();
    case 1:
      ADVANCE_MAP(
        '\n', 75,
        '\r', 76,
        '&', 35,
        '(', 19,
        '+', 21,
        ',', 18,
        '-', 23,
        '.', 39,
        ';', 17,
        '<', 44,
        '=', 60,
        '>', 49,
        '?', 42,
        '@', 43,
        '[', 54,
        '{', 57,
        '|', 10,
        '~', 41,
      );
      if (('\t' <= lookahead && lookahead <= '\f') ||
          lookahead == ' ') SKIP(1);
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(65);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(74);
      END_STATE();
    case 2:
      ADVANCE_MAP(
        '\n', 75,
        '\r', 76,
        '&', 34,
        '(', 19,
        '+', 21,
        ',', 18,
        '-', 23,
        '.', 39,
        ';', 17,
        '=', 59,
        '?', 42,
        '@', 43,
        '[', 54,
        '{', 57,
        '~', 40,
      );
      if (('\t' <= lookahead && lookahead <= '\f') ||
          lookahead == ' ') SKIP(2);
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(65);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(74);
      END_STATE();
    case 3:
      ADVANCE_MAP(
        '&', 35,
        '\'', 53,
        '(', 19,
        '*', 25,
        '+', 21,
        '-', 23,
        '.', 37,
        '/', 27,
        ':', 61,
        ';', 17,
        '<', 44,
        '=', 8,
        '>', 49,
        '@', 43,
        '\\', 29,
        ']', 56,
        '^', 31,
        '{', 57,
        '|', 33,
        '}', 58,
        '~', 9,
        '\n', 55,
        '\r', 55,
      );
      if (('\t' <= lookahead && lookahead <= '\f') ||
          lookahead == ' ') SKIP(3);
      END_STATE();
    case 4:
      if (lookahead == '&') ADVANCE(50);
      END_STATE();
    case 5:
      ADVANCE_MAP(
        '&', 4,
        '(', 19,
        ')', 20,
        ',', 18,
        '.', 36,
        '<', 44,
        '=', 8,
        '>', 49,
        '{', 57,
        '|', 10,
        '}', 58,
        '~', 9,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(5);
      END_STATE();
    case 6:
      ADVANCE_MAP(
        '&', 4,
        '.', 36,
        ';', 17,
        '<', 44,
        '=', 8,
        '>', 49,
        ']', 56,
        '|', 10,
        '}', 58,
        '~', 9,
        '\n', 55,
        '\r', 55,
      );
      if (('\t' <= lookahead && lookahead <= '\f') ||
          lookahead == ' ') SKIP(6);
      END_STATE();
    case 7:
      ADVANCE_MAP(
        '(', 19,
        '+', 21,
        ',', 18,
        '-', 23,
        '.', 12,
        ';', 17,
        '?', 42,
        '@', 43,
        '[', 54,
        ']', 56,
        '{', 57,
        '}', 58,
        '~', 40,
        '\n', 55,
        '\r', 55,
      );
      if (('\t' <= lookahead && lookahead <= '\f') ||
          lookahead == ' ') SKIP(7);
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(65);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(74);
      END_STATE();
    case 8:
      if (lookahead == '=') ADVANCE(46);
      END_STATE();
    case 9:
      if (lookahead == '=') ADVANCE(47);
      END_STATE();
    case 10:
      if (lookahead == '|') ADVANCE(51);
      END_STATE();
    case 11:
      if (lookahead == '+' ||
          lookahead == '-') ADVANCE(13);
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(67);
      END_STATE();
    case 12:
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(66);
      END_STATE();
    case 13:
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(67);
      END_STATE();
    case 14:
      if (eof) ADVANCE(16);
      ADVANCE_MAP(
        '\n', 75,
        '\r', 76,
        '&', 35,
        '\'', 53,
        '(', 19,
        '*', 25,
        '+', 21,
        ',', 18,
        '-', 23,
        '.', 38,
        '/', 27,
        ':', 61,
        ';', 17,
        '<', 44,
        '=', 60,
        '>', 49,
        '?', 42,
        '@', 43,
        '[', 54,
        '\\', 29,
        '^', 31,
        '{', 57,
        '|', 33,
        '~', 41,
      );
      if (('\t' <= lookahead && lookahead <= '\f') ||
          lookahead == ' ') SKIP(14);
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(65);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(74);
      END_STATE();
    case 15:
      if (eof) ADVANCE(16);
      ADVANCE_MAP(
        '(', 19,
        ')', 20,
        '*', 25,
        '+', 21,
        ',', 18,
        '-', 23,
        '.', 39,
        ':', 61,
        ';', 17,
        '=', 59,
        '?', 42,
        '@', 43,
        '[', 54,
        ']', 56,
        '{', 57,
        '}', 58,
        '~', 40,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(15);
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(65);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(74);
      END_STATE();
    case 16:
      ACCEPT_TOKEN(ts_builtin_sym_end);
      END_STATE();
    case 17:
      ACCEPT_TOKEN(anon_sym_SEMI);
      END_STATE();
    case 18:
      ACCEPT_TOKEN(anon_sym_COMMA);
      END_STATE();
    case 19:
      ACCEPT_TOKEN(anon_sym_LPAREN);
      END_STATE();
    case 20:
      ACCEPT_TOKEN(anon_sym_RPAREN);
      END_STATE();
    case 21:
      ACCEPT_TOKEN(anon_sym_PLUS);
      END_STATE();
    case 22:
      ACCEPT_TOKEN(anon_sym_DOT_PLUS);
      END_STATE();
    case 23:
      ACCEPT_TOKEN(anon_sym_DASH);
      END_STATE();
    case 24:
      ACCEPT_TOKEN(anon_sym_DOT_DASH);
      END_STATE();
    case 25:
      ACCEPT_TOKEN(anon_sym_STAR);
      END_STATE();
    case 26:
      ACCEPT_TOKEN(anon_sym_DOT_STAR);
      END_STATE();
    case 27:
      ACCEPT_TOKEN(anon_sym_SLASH);
      END_STATE();
    case 28:
      ACCEPT_TOKEN(anon_sym_DOT_SLASH);
      END_STATE();
    case 29:
      ACCEPT_TOKEN(anon_sym_BSLASH);
      END_STATE();
    case 30:
      ACCEPT_TOKEN(anon_sym_DOT_BSLASH);
      END_STATE();
    case 31:
      ACCEPT_TOKEN(anon_sym_CARET);
      END_STATE();
    case 32:
      ACCEPT_TOKEN(anon_sym_DOT_CARET);
      END_STATE();
    case 33:
      ACCEPT_TOKEN(anon_sym_PIPE);
      if (lookahead == '|') ADVANCE(51);
      END_STATE();
    case 34:
      ACCEPT_TOKEN(anon_sym_AMP);
      END_STATE();
    case 35:
      ACCEPT_TOKEN(anon_sym_AMP);
      if (lookahead == '&') ADVANCE(50);
      END_STATE();
    case 36:
      ACCEPT_TOKEN(anon_sym_DOT);
      END_STATE();
    case 37:
      ACCEPT_TOKEN(anon_sym_DOT);
      if (lookahead == '\'') ADVANCE(52);
      if (lookahead == '*') ADVANCE(26);
      if (lookahead == '+') ADVANCE(22);
      if (lookahead == '-') ADVANCE(24);
      if (lookahead == '/') ADVANCE(28);
      if (lookahead == '\\') ADVANCE(30);
      if (lookahead == '^') ADVANCE(32);
      END_STATE();
    case 38:
      ACCEPT_TOKEN(anon_sym_DOT);
      if (lookahead == '\'') ADVANCE(52);
      if (lookahead == '*') ADVANCE(26);
      if (lookahead == '+') ADVANCE(22);
      if (lookahead == '-') ADVANCE(24);
      if (lookahead == '/') ADVANCE(28);
      if (lookahead == '\\') ADVANCE(30);
      if (lookahead == '^') ADVANCE(32);
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(66);
      END_STATE();
    case 39:
      ACCEPT_TOKEN(anon_sym_DOT);
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(66);
      END_STATE();
    case 40:
      ACCEPT_TOKEN(anon_sym_TILDE);
      END_STATE();
    case 41:
      ACCEPT_TOKEN(anon_sym_TILDE);
      if (lookahead == '=') ADVANCE(47);
      END_STATE();
    case 42:
      ACCEPT_TOKEN(anon_sym_QMARK);
      END_STATE();
    case 43:
      ACCEPT_TOKEN(anon_sym_AT);
      END_STATE();
    case 44:
      ACCEPT_TOKEN(anon_sym_LT);
      if (lookahead == '=') ADVANCE(45);
      END_STATE();
    case 45:
      ACCEPT_TOKEN(anon_sym_LT_EQ);
      END_STATE();
    case 46:
      ACCEPT_TOKEN(anon_sym_EQ_EQ);
      END_STATE();
    case 47:
      ACCEPT_TOKEN(anon_sym_TILDE_EQ);
      END_STATE();
    case 48:
      ACCEPT_TOKEN(anon_sym_GT_EQ);
      END_STATE();
    case 49:
      ACCEPT_TOKEN(anon_sym_GT);
      if (lookahead == '=') ADVANCE(48);
      END_STATE();
    case 50:
      ACCEPT_TOKEN(anon_sym_AMP_AMP);
      END_STATE();
    case 51:
      ACCEPT_TOKEN(anon_sym_PIPE_PIPE);
      END_STATE();
    case 52:
      ACCEPT_TOKEN(anon_sym_DOT_SQUOTE);
      END_STATE();
    case 53:
      ACCEPT_TOKEN(anon_sym_SQUOTE);
      END_STATE();
    case 54:
      ACCEPT_TOKEN(anon_sym_LBRACK);
      END_STATE();
    case 55:
      ACCEPT_TOKEN(aux_sym_matrix_token1);
      if (lookahead == '\n' ||
          lookahead == '\r') ADVANCE(55);
      END_STATE();
    case 56:
      ACCEPT_TOKEN(anon_sym_RBRACK);
      END_STATE();
    case 57:
      ACCEPT_TOKEN(anon_sym_LBRACE);
      END_STATE();
    case 58:
      ACCEPT_TOKEN(anon_sym_RBRACE);
      END_STATE();
    case 59:
      ACCEPT_TOKEN(anon_sym_EQ);
      END_STATE();
    case 60:
      ACCEPT_TOKEN(anon_sym_EQ);
      if (lookahead == '=') ADVANCE(46);
      END_STATE();
    case 61:
      ACCEPT_TOKEN(anon_sym_COLON);
      END_STATE();
    case 62:
      ACCEPT_TOKEN(anon_sym_get_DOT);
      END_STATE();
    case 63:
      ACCEPT_TOKEN(anon_sym_set_DOT);
      END_STATE();
    case 64:
      ACCEPT_TOKEN(sym_number);
      END_STATE();
    case 65:
      ACCEPT_TOKEN(sym_number);
      if (lookahead == '.') ADVANCE(66);
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(11);
      if (lookahead == 'i' ||
          lookahead == 'j') ADVANCE(64);
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(65);
      END_STATE();
    case 66:
      ACCEPT_TOKEN(sym_number);
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(11);
      if (lookahead == 'i' ||
          lookahead == 'j') ADVANCE(64);
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(66);
      END_STATE();
    case 67:
      ACCEPT_TOKEN(sym_number);
      if (lookahead == 'i' ||
          lookahead == 'j') ADVANCE(64);
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(67);
      END_STATE();
    case 68:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == '.') ADVANCE(62);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(74);
      END_STATE();
    case 69:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == '.') ADVANCE(63);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(74);
      END_STATE();
    case 70:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == 'e') ADVANCE(72);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(74);
      END_STATE();
    case 71:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == 'e') ADVANCE(73);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(74);
      END_STATE();
    case 72:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == 't') ADVANCE(68);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(74);
      END_STATE();
    case 73:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == 't') ADVANCE(69);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(74);
      END_STATE();
    case 74:
      ACCEPT_TOKEN(sym_identifier);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(74);
      END_STATE();
    case 75:
      ACCEPT_TOKEN(anon_sym_LF);
      if (lookahead == '\n') ADVANCE(75);
      if (lookahead == '\r') ADVANCE(76);
      END_STATE();
    case 76:
      ACCEPT_TOKEN(anon_sym_CR);
      if (lookahead == '\n') ADVANCE(75);
      if (lookahead == '\r') ADVANCE(76);
      END_STATE();
    default:
      return false;
  }
}

static bool ts_lex_keywords(TSLexer *lexer, TSStateId state) {
  START_LEXER();
  eof = lexer->eof(lexer);
  switch (state) {
    case 0:
      ADVANCE_MAP(
        'a', 1,
        'b', 2,
        'c', 3,
        'e', 4,
        'f', 5,
        'g', 6,
        'i', 7,
        'm', 8,
        'o', 9,
        'p', 10,
        'r', 11,
        's', 12,
        't', 13,
        'w', 14,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(0);
      END_STATE();
    case 1:
      if (lookahead == 'r') ADVANCE(15);
      END_STATE();
    case 2:
      if (lookahead == 'r') ADVANCE(16);
      END_STATE();
    case 3:
      if (lookahead == 'a') ADVANCE(17);
      if (lookahead == 'l') ADVANCE(18);
      if (lookahead == 'o') ADVANCE(19);
      END_STATE();
    case 4:
      if (lookahead == 'l') ADVANCE(20);
      if (lookahead == 'n') ADVANCE(21);
      if (lookahead == 'v') ADVANCE(22);
      END_STATE();
    case 5:
      if (lookahead == 'a') ADVANCE(23);
      if (lookahead == 'o') ADVANCE(24);
      if (lookahead == 'u') ADVANCE(25);
      END_STATE();
    case 6:
      if (lookahead == 'l') ADVANCE(26);
      END_STATE();
    case 7:
      if (lookahead == 'f') ADVANCE(27);
      END_STATE();
    case 8:
      if (lookahead == 'e') ADVANCE(28);
      END_STATE();
    case 9:
      if (lookahead == 't') ADVANCE(29);
      END_STATE();
    case 10:
      if (lookahead == 'a') ADVANCE(30);
      if (lookahead == 'e') ADVANCE(31);
      if (lookahead == 'r') ADVANCE(32);
      END_STATE();
    case 11:
      if (lookahead == 'e') ADVANCE(33);
      END_STATE();
    case 12:
      if (lookahead == 'w') ADVANCE(34);
      END_STATE();
    case 13:
      if (lookahead == 'r') ADVANCE(35);
      END_STATE();
    case 14:
      if (lookahead == 'h') ADVANCE(36);
      END_STATE();
    case 15:
      if (lookahead == 'g') ADVANCE(37);
      END_STATE();
    case 16:
      if (lookahead == 'e') ADVANCE(38);
      END_STATE();
    case 17:
      if (lookahead == 's') ADVANCE(39);
      if (lookahead == 't') ADVANCE(40);
      END_STATE();
    case 18:
      if (lookahead == 'a') ADVANCE(41);
      END_STATE();
    case 19:
      if (lookahead == 'n') ADVANCE(42);
      END_STATE();
    case 20:
      if (lookahead == 's') ADVANCE(43);
      END_STATE();
    case 21:
      if (lookahead == 'd') ADVANCE(44);
      if (lookahead == 'u') ADVANCE(45);
      END_STATE();
    case 22:
      if (lookahead == 'e') ADVANCE(46);
      END_STATE();
    case 23:
      if (lookahead == 'l') ADVANCE(47);
      END_STATE();
    case 24:
      if (lookahead == 'r') ADVANCE(48);
      END_STATE();
    case 25:
      if (lookahead == 'n') ADVANCE(49);
      END_STATE();
    case 26:
      if (lookahead == 'o') ADVANCE(50);
      END_STATE();
    case 27:
      ACCEPT_TOKEN(anon_sym_if);
      END_STATE();
    case 28:
      if (lookahead == 't') ADVANCE(51);
      END_STATE();
    case 29:
      if (lookahead == 'h') ADVANCE(52);
      END_STATE();
    case 30:
      if (lookahead == 'r') ADVANCE(53);
      END_STATE();
    case 31:
      if (lookahead == 'r') ADVANCE(54);
      END_STATE();
    case 32:
      if (lookahead == 'o') ADVANCE(55);
      END_STATE();
    case 33:
      if (lookahead == 't') ADVANCE(56);
      END_STATE();
    case 34:
      if (lookahead == 'i') ADVANCE(57);
      END_STATE();
    case 35:
      if (lookahead == 'u') ADVANCE(58);
      if (lookahead == 'y') ADVANCE(59);
      END_STATE();
    case 36:
      if (lookahead == 'i') ADVANCE(60);
      END_STATE();
    case 37:
      if (lookahead == 'u') ADVANCE(61);
      END_STATE();
    case 38:
      if (lookahead == 'a') ADVANCE(62);
      END_STATE();
    case 39:
      if (lookahead == 'e') ADVANCE(63);
      END_STATE();
    case 40:
      if (lookahead == 'c') ADVANCE(64);
      END_STATE();
    case 41:
      if (lookahead == 's') ADVANCE(65);
      END_STATE();
    case 42:
      if (lookahead == 't') ADVANCE(66);
      END_STATE();
    case 43:
      if (lookahead == 'e') ADVANCE(67);
      END_STATE();
    case 44:
      ACCEPT_TOKEN(anon_sym_end);
      if (lookahead == 'f') ADVANCE(68);
      END_STATE();
    case 45:
      if (lookahead == 'm') ADVANCE(69);
      END_STATE();
    case 46:
      if (lookahead == 'n') ADVANCE(70);
      END_STATE();
    case 47:
      if (lookahead == 's') ADVANCE(71);
      END_STATE();
    case 48:
      ACCEPT_TOKEN(anon_sym_for);
      END_STATE();
    case 49:
      if (lookahead == 'c') ADVANCE(72);
      END_STATE();
    case 50:
      if (lookahead == 'b') ADVANCE(73);
      END_STATE();
    case 51:
      if (lookahead == 'h') ADVANCE(74);
      END_STATE();
    case 52:
      if (lookahead == 'e') ADVANCE(75);
      END_STATE();
    case 53:
      if (lookahead == 'f') ADVANCE(76);
      END_STATE();
    case 54:
      if (lookahead == 's') ADVANCE(77);
      END_STATE();
    case 55:
      if (lookahead == 'p') ADVANCE(78);
      END_STATE();
    case 56:
      if (lookahead == 'u') ADVANCE(79);
      END_STATE();
    case 57:
      if (lookahead == 't') ADVANCE(80);
      END_STATE();
    case 58:
      if (lookahead == 'e') ADVANCE(81);
      END_STATE();
    case 59:
      ACCEPT_TOKEN(anon_sym_try);
      END_STATE();
    case 60:
      if (lookahead == 'l') ADVANCE(82);
      END_STATE();
    case 61:
      if (lookahead == 'm') ADVANCE(83);
      END_STATE();
    case 62:
      if (lookahead == 'k') ADVANCE(84);
      END_STATE();
    case 63:
      ACCEPT_TOKEN(anon_sym_case);
      END_STATE();
    case 64:
      if (lookahead == 'h') ADVANCE(85);
      END_STATE();
    case 65:
      if (lookahead == 's') ADVANCE(86);
      END_STATE();
    case 66:
      if (lookahead == 'i') ADVANCE(87);
      END_STATE();
    case 67:
      ACCEPT_TOKEN(anon_sym_else);
      if (lookahead == 'i') ADVANCE(88);
      END_STATE();
    case 68:
      if (lookahead == 'u') ADVANCE(89);
      END_STATE();
    case 69:
      if (lookahead == 'e') ADVANCE(90);
      END_STATE();
    case 70:
      if (lookahead == 't') ADVANCE(91);
      END_STATE();
    case 71:
      if (lookahead == 'e') ADVANCE(92);
      END_STATE();
    case 72:
      if (lookahead == 't') ADVANCE(93);
      END_STATE();
    case 73:
      if (lookahead == 'a') ADVANCE(94);
      END_STATE();
    case 74:
      if (lookahead == 'o') ADVANCE(95);
      END_STATE();
    case 75:
      if (lookahead == 'r') ADVANCE(96);
      END_STATE();
    case 76:
      if (lookahead == 'o') ADVANCE(97);
      END_STATE();
    case 77:
      if (lookahead == 'i') ADVANCE(98);
      END_STATE();
    case 78:
      if (lookahead == 'e') ADVANCE(99);
      END_STATE();
    case 79:
      if (lookahead == 'r') ADVANCE(100);
      END_STATE();
    case 80:
      if (lookahead == 'c') ADVANCE(101);
      END_STATE();
    case 81:
      ACCEPT_TOKEN(anon_sym_true);
      END_STATE();
    case 82:
      if (lookahead == 'e') ADVANCE(102);
      END_STATE();
    case 83:
      if (lookahead == 'e') ADVANCE(103);
      END_STATE();
    case 84:
      ACCEPT_TOKEN(sym_break_statement);
      END_STATE();
    case 85:
      ACCEPT_TOKEN(anon_sym_catch);
      END_STATE();
    case 86:
      if (lookahead == 'd') ADVANCE(104);
      END_STATE();
    case 87:
      if (lookahead == 'n') ADVANCE(105);
      END_STATE();
    case 88:
      if (lookahead == 'f') ADVANCE(106);
      END_STATE();
    case 89:
      if (lookahead == 'n') ADVANCE(107);
      END_STATE();
    case 90:
      if (lookahead == 'r') ADVANCE(108);
      END_STATE();
    case 91:
      if (lookahead == 's') ADVANCE(109);
      END_STATE();
    case 92:
      ACCEPT_TOKEN(anon_sym_false);
      END_STATE();
    case 93:
      if (lookahead == 'i') ADVANCE(110);
      END_STATE();
    case 94:
      if (lookahead == 'l') ADVANCE(111);
      END_STATE();
    case 95:
      if (lookahead == 'd') ADVANCE(112);
      END_STATE();
    case 96:
      if (lookahead == 'w') ADVANCE(113);
      END_STATE();
    case 97:
      if (lookahead == 'r') ADVANCE(114);
      END_STATE();
    case 98:
      if (lookahead == 's') ADVANCE(115);
      END_STATE();
    case 99:
      if (lookahead == 'r') ADVANCE(116);
      END_STATE();
    case 100:
      if (lookahead == 'n') ADVANCE(117);
      END_STATE();
    case 101:
      if (lookahead == 'h') ADVANCE(118);
      END_STATE();
    case 102:
      ACCEPT_TOKEN(anon_sym_while);
      END_STATE();
    case 103:
      if (lookahead == 'n') ADVANCE(119);
      END_STATE();
    case 104:
      if (lookahead == 'e') ADVANCE(120);
      END_STATE();
    case 105:
      if (lookahead == 'u') ADVANCE(121);
      END_STATE();
    case 106:
      ACCEPT_TOKEN(anon_sym_elseif);
      END_STATE();
    case 107:
      if (lookahead == 'c') ADVANCE(122);
      END_STATE();
    case 108:
      if (lookahead == 'a') ADVANCE(123);
      END_STATE();
    case 109:
      ACCEPT_TOKEN(anon_sym_events);
      END_STATE();
    case 110:
      if (lookahead == 'o') ADVANCE(124);
      END_STATE();
    case 111:
      ACCEPT_TOKEN(anon_sym_global);
      END_STATE();
    case 112:
      if (lookahead == 's') ADVANCE(125);
      END_STATE();
    case 113:
      if (lookahead == 'i') ADVANCE(126);
      END_STATE();
    case 114:
      ACCEPT_TOKEN(anon_sym_parfor);
      END_STATE();
    case 115:
      if (lookahead == 't') ADVANCE(127);
      END_STATE();
    case 116:
      if (lookahead == 't') ADVANCE(128);
      END_STATE();
    case 117:
      ACCEPT_TOKEN(sym_return_statement);
      END_STATE();
    case 118:
      ACCEPT_TOKEN(anon_sym_switch);
      END_STATE();
    case 119:
      if (lookahead == 't') ADVANCE(129);
      END_STATE();
    case 120:
      if (lookahead == 'f') ADVANCE(130);
      END_STATE();
    case 121:
      if (lookahead == 'e') ADVANCE(131);
      END_STATE();
    case 122:
      if (lookahead == 't') ADVANCE(132);
      END_STATE();
    case 123:
      if (lookahead == 't') ADVANCE(133);
      END_STATE();
    case 124:
      if (lookahead == 'n') ADVANCE(134);
      END_STATE();
    case 125:
      ACCEPT_TOKEN(anon_sym_methods);
      END_STATE();
    case 126:
      if (lookahead == 's') ADVANCE(135);
      END_STATE();
    case 127:
      if (lookahead == 'e') ADVANCE(136);
      END_STATE();
    case 128:
      if (lookahead == 'i') ADVANCE(137);
      END_STATE();
    case 129:
      if (lookahead == 's') ADVANCE(138);
      END_STATE();
    case 130:
      ACCEPT_TOKEN(anon_sym_classdef);
      END_STATE();
    case 131:
      ACCEPT_TOKEN(sym_continue_statement);
      END_STATE();
    case 132:
      if (lookahead == 'i') ADVANCE(139);
      END_STATE();
    case 133:
      if (lookahead == 'i') ADVANCE(140);
      END_STATE();
    case 134:
      ACCEPT_TOKEN(anon_sym_function);
      END_STATE();
    case 135:
      if (lookahead == 'e') ADVANCE(141);
      END_STATE();
    case 136:
      if (lookahead == 'n') ADVANCE(142);
      END_STATE();
    case 137:
      if (lookahead == 'e') ADVANCE(143);
      END_STATE();
    case 138:
      ACCEPT_TOKEN(anon_sym_arguments);
      END_STATE();
    case 139:
      if (lookahead == 'o') ADVANCE(144);
      END_STATE();
    case 140:
      if (lookahead == 'o') ADVANCE(145);
      END_STATE();
    case 141:
      ACCEPT_TOKEN(anon_sym_otherwise);
      END_STATE();
    case 142:
      if (lookahead == 't') ADVANCE(146);
      END_STATE();
    case 143:
      if (lookahead == 's') ADVANCE(147);
      END_STATE();
    case 144:
      if (lookahead == 'n') ADVANCE(148);
      END_STATE();
    case 145:
      if (lookahead == 'n') ADVANCE(149);
      END_STATE();
    case 146:
      ACCEPT_TOKEN(anon_sym_persistent);
      END_STATE();
    case 147:
      ACCEPT_TOKEN(anon_sym_properties);
      END_STATE();
    case 148:
      ACCEPT_TOKEN(anon_sym_endfunction);
      END_STATE();
    case 149:
      ACCEPT_TOKEN(anon_sym_enumeration);
      END_STATE();
    default:
      return false;
  }
}

static const TSLexMode ts_lex_modes[STATE_COUNT] = {
  [0] = {.lex_state = 0, .external_lex_state = 1},
  [1] = {.lex_state = 15, .external_lex_state = 2},
  [2] = {.lex_state = 14, .external_lex_state = 2},
  [3] = {.lex_state = 14, .external_lex_state = 2},
  [4] = {.lex_state = 14, .external_lex_state = 2},
  [5] = {.lex_state = 2, .external_lex_state = 2},
  [6] = {.lex_state = 2, .external_lex_state = 2},
  [7] = {.lex_state = 2, .external_lex_state = 2},
  [8] = {.lex_state = 2, .external_lex_state = 2},
  [9] = {.lex_state = 2, .external_lex_state = 2},
  [10] = {.lex_state = 2, .external_lex_state = 2},
  [11] = {.lex_state = 2, .external_lex_state = 2},
  [12] = {.lex_state = 2, .external_lex_state = 2},
  [13] = {.lex_state = 2, .external_lex_state = 2},
  [14] = {.lex_state = 2, .external_lex_state = 2},
  [15] = {.lex_state = 2, .external_lex_state = 2},
  [16] = {.lex_state = 2, .external_lex_state = 2},
  [17] = {.lex_state = 2, .external_lex_state = 2},
  [18] = {.lex_state = 2, .external_lex_state = 2},
  [19] = {.lex_state = 2, .external_lex_state = 2},
  [20] = {.lex_state = 2, .external_lex_state = 2},
  [21] = {.lex_state = 15, .external_lex_state = 2},
  [22] = {.lex_state = 15, .external_lex_state = 2},
  [23] = {.lex_state = 15, .external_lex_state = 2},
  [24] = {.lex_state = 15, .external_lex_state = 2},
  [25] = {.lex_state = 15, .external_lex_state = 2},
  [26] = {.lex_state = 15, .external_lex_state = 2},
  [27] = {.lex_state = 15, .external_lex_state = 2},
  [28] = {.lex_state = 15, .external_lex_state = 2},
  [29] = {.lex_state = 15, .external_lex_state = 2},
  [30] = {.lex_state = 15, .external_lex_state = 2},
  [31] = {.lex_state = 15, .external_lex_state = 2},
  [32] = {.lex_state = 15, .external_lex_state = 2},
  [33] = {.lex_state = 15, .external_lex_state = 2},
  [34] = {.lex_state = 15, .external_lex_state = 2},
  [35] = {.lex_state = 15, .external_lex_state = 2},
  [36] = {.lex_state = 15, .external_lex_state = 2},
  [37] = {.lex_state = 15, .external_lex_state = 2},
  [38] = {.lex_state = 15, .external_lex_state = 2},
  [39] = {.lex_state = 15, .external_lex_state = 2},
  [40] = {.lex_state = 15, .external_lex_state = 2},
  [41] = {.lex_state = 15, .external_lex_state = 2},
  [42] = {.lex_state = 15, .external_lex_state = 2},
  [43] = {.lex_state = 15, .external_lex_state = 2},
  [44] = {.lex_state = 15, .external_lex_state = 2},
  [45] = {.lex_state = 15, .external_lex_state = 2},
  [46] = {.lex_state = 15, .external_lex_state = 2},
  [47] = {.lex_state = 15, .external_lex_state = 2},
  [48] = {.lex_state = 15, .external_lex_state = 2},
  [49] = {.lex_state = 15, .external_lex_state = 2},
  [50] = {.lex_state = 15, .external_lex_state = 2},
  [51] = {.lex_state = 15, .external_lex_state = 2},
  [52] = {.lex_state = 15, .external_lex_state = 2},
  [53] = {.lex_state = 15, .external_lex_state = 2},
  [54] = {.lex_state = 15, .external_lex_state = 2},
  [55] = {.lex_state = 15, .external_lex_state = 2},
  [56] = {.lex_state = 15, .external_lex_state = 2},
  [57] = {.lex_state = 15, .external_lex_state = 2},
  [58] = {.lex_state = 15, .external_lex_state = 2},
  [59] = {.lex_state = 15, .external_lex_state = 2},
  [60] = {.lex_state = 15, .external_lex_state = 2},
  [61] = {.lex_state = 15, .external_lex_state = 2},
  [62] = {.lex_state = 15, .external_lex_state = 2},
  [63] = {.lex_state = 15, .external_lex_state = 2},
  [64] = {.lex_state = 15, .external_lex_state = 2},
  [65] = {.lex_state = 15, .external_lex_state = 2},
  [66] = {.lex_state = 15, .external_lex_state = 2},
  [67] = {.lex_state = 15, .external_lex_state = 2},
  [68] = {.lex_state = 15, .external_lex_state = 2},
  [69] = {.lex_state = 15, .external_lex_state = 2},
  [70] = {.lex_state = 15, .external_lex_state = 2},
  [71] = {.lex_state = 15, .external_lex_state = 2},
  [72] = {.lex_state = 15, .external_lex_state = 2},
  [73] = {.lex_state = 15, .external_lex_state = 2},
  [74] = {.lex_state = 15, .external_lex_state = 2},
  [75] = {.lex_state = 15, .external_lex_state = 2},
  [76] = {.lex_state = 14, .external_lex_state = 2},
  [77] = {.lex_state = 14, .external_lex_state = 2},
  [78] = {.lex_state = 14, .external_lex_state = 2},
  [79] = {.lex_state = 14, .external_lex_state = 2},
  [80] = {.lex_state = 14, .external_lex_state = 2},
  [81] = {.lex_state = 14, .external_lex_state = 2},
  [82] = {.lex_state = 14, .external_lex_state = 2},
  [83] = {.lex_state = 14, .external_lex_state = 2},
  [84] = {.lex_state = 14, .external_lex_state = 2},
  [85] = {.lex_state = 14, .external_lex_state = 2},
  [86] = {.lex_state = 14, .external_lex_state = 2},
  [87] = {.lex_state = 14, .external_lex_state = 2},
  [88] = {.lex_state = 14, .external_lex_state = 2},
  [89] = {.lex_state = 14, .external_lex_state = 2},
  [90] = {.lex_state = 14, .external_lex_state = 2},
  [91] = {.lex_state = 14, .external_lex_state = 2},
  [92] = {.lex_state = 14, .external_lex_state = 2},
  [93] = {.lex_state = 14, .external_lex_state = 2},
  [94] = {.lex_state = 14, .external_lex_state = 2},
  [95] = {.lex_state = 14, .external_lex_state = 2},
  [96] = {.lex_state = 14, .external_lex_state = 2},
  [97] = {.lex_state = 14, .external_lex_state = 2},
  [98] = {.lex_state = 14, .external_lex_state = 2},
  [99] = {.lex_state = 14, .external_lex_state = 2},
  [100] = {.lex_state = 14, .external_lex_state = 2},
  [101] = {.lex_state = 14, .external_lex_state = 2},
  [102] = {.lex_state = 14, .external_lex_state = 2},
  [103] = {.lex_state = 14, .external_lex_state = 2},
  [104] = {.lex_state = 14, .external_lex_state = 2},
  [105] = {.lex_state = 14, .external_lex_state = 2},
  [106] = {.lex_state = 14, .external_lex_state = 2},
  [107] = {.lex_state = 14, .external_lex_state = 2},
  [108] = {.lex_state = 14, .external_lex_state = 2},
  [109] = {.lex_state = 14, .external_lex_state = 2},
  [110] = {.lex_state = 14, .external_lex_state = 2},
  [111] = {.lex_state = 14, .external_lex_state = 2},
  [112] = {.lex_state = 14, .external_lex_state = 2},
  [113] = {.lex_state = 14, .external_lex_state = 2},
  [114] = {.lex_state = 14, .external_lex_state = 2},
  [115] = {.lex_state = 14, .external_lex_state = 2},
  [116] = {.lex_state = 14, .external_lex_state = 2},
  [117] = {.lex_state = 14, .external_lex_state = 2},
  [118] = {.lex_state = 14, .external_lex_state = 2},
  [119] = {.lex_state = 14, .external_lex_state = 2},
  [120] = {.lex_state = 14, .external_lex_state = 2},
  [121] = {.lex_state = 14, .external_lex_state = 2},
  [122] = {.lex_state = 14, .external_lex_state = 2},
  [123] = {.lex_state = 14, .external_lex_state = 2},
  [124] = {.lex_state = 14, .external_lex_state = 2},
  [125] = {.lex_state = 14, .external_lex_state = 2},
  [126] = {.lex_state = 14, .external_lex_state = 2},
  [127] = {.lex_state = 14, .external_lex_state = 2},
  [128] = {.lex_state = 14, .external_lex_state = 2},
  [129] = {.lex_state = 14, .external_lex_state = 2},
  [130] = {.lex_state = 14, .external_lex_state = 2},
  [131] = {.lex_state = 14, .external_lex_state = 2},
  [132] = {.lex_state = 14, .external_lex_state = 2},
  [133] = {.lex_state = 14, .external_lex_state = 2},
  [134] = {.lex_state = 14, .external_lex_state = 2},
  [135] = {.lex_state = 14, .external_lex_state = 2},
  [136] = {.lex_state = 14, .external_lex_state = 2},
  [137] = {.lex_state = 14, .external_lex_state = 2},
  [138] = {.lex_state = 14, .external_lex_state = 2},
  [139] = {.lex_state = 14, .external_lex_state = 2},
  [140] = {.lex_state = 14, .external_lex_state = 2},
  [141] = {.lex_state = 14, .external_lex_state = 2},
  [142] = {.lex_state = 14, .external_lex_state = 2},
  [143] = {.lex_state = 14, .external_lex_state = 2},
  [144] = {.lex_state = 14, .external_lex_state = 2},
  [145] = {.lex_state = 14, .external_lex_state = 2},
  [146] = {.lex_state = 14, .external_lex_state = 2},
  [147] = {.lex_state = 14, .external_lex_state = 2},
  [148] = {.lex_state = 14, .external_lex_state = 2},
  [149] = {.lex_state = 14, .external_lex_state = 2},
  [150] = {.lex_state = 14, .external_lex_state = 2},
  [151] = {.lex_state = 14, .external_lex_state = 2},
  [152] = {.lex_state = 1, .external_lex_state = 2},
  [153] = {.lex_state = 1, .external_lex_state = 2},
  [154] = {.lex_state = 1, .external_lex_state = 2},
  [155] = {.lex_state = 1, .external_lex_state = 2},
  [156] = {.lex_state = 7, .external_lex_state = 3},
  [157] = {.lex_state = 14, .external_lex_state = 2},
  [158] = {.lex_state = 2, .external_lex_state = 2},
  [159] = {.lex_state = 7, .external_lex_state = 3},
  [160] = {.lex_state = 7, .external_lex_state = 3},
  [161] = {.lex_state = 7, .external_lex_state = 4},
  [162] = {.lex_state = 7, .external_lex_state = 3},
  [163] = {.lex_state = 15, .external_lex_state = 3},
  [164] = {.lex_state = 15, .external_lex_state = 3},
  [165] = {.lex_state = 15, .external_lex_state = 3},
  [166] = {.lex_state = 15, .external_lex_state = 3},
  [167] = {.lex_state = 15, .external_lex_state = 3},
  [168] = {.lex_state = 15, .external_lex_state = 2},
  [169] = {.lex_state = 15, .external_lex_state = 3},
  [170] = {.lex_state = 15, .external_lex_state = 2},
  [171] = {.lex_state = 15, .external_lex_state = 3},
  [172] = {.lex_state = 15, .external_lex_state = 3},
  [173] = {.lex_state = 15, .external_lex_state = 3},
  [174] = {.lex_state = 15, .external_lex_state = 3},
  [175] = {.lex_state = 15, .external_lex_state = 2},
  [176] = {.lex_state = 15, .external_lex_state = 3},
  [177] = {.lex_state = 15, .external_lex_state = 2},
  [178] = {.lex_state = 15, .external_lex_state = 3},
  [179] = {.lex_state = 15, .external_lex_state = 2},
  [180] = {.lex_state = 15, .external_lex_state = 3},
  [181] = {.lex_state = 15, .external_lex_state = 3},
  [182] = {.lex_state = 15, .external_lex_state = 3},
  [183] = {.lex_state = 15, .external_lex_state = 3},
  [184] = {.lex_state = 15, .external_lex_state = 3},
  [185] = {.lex_state = 15, .external_lex_state = 3},
  [186] = {.lex_state = 15, .external_lex_state = 3},
  [187] = {.lex_state = 14, .external_lex_state = 5},
  [188] = {.lex_state = 14, .external_lex_state = 5},
  [189] = {.lex_state = 14, .external_lex_state = 5},
  [190] = {.lex_state = 14, .external_lex_state = 5},
  [191] = {.lex_state = 14, .external_lex_state = 5},
  [192] = {.lex_state = 14, .external_lex_state = 5},
  [193] = {.lex_state = 15, .external_lex_state = 3},
  [194] = {.lex_state = 14, .external_lex_state = 5},
  [195] = {.lex_state = 15, .external_lex_state = 3},
  [196] = {.lex_state = 15, .external_lex_state = 3},
  [197] = {.lex_state = 14, .external_lex_state = 5},
  [198] = {.lex_state = 14, .external_lex_state = 5},
  [199] = {.lex_state = 14, .external_lex_state = 5},
  [200] = {.lex_state = 14, .external_lex_state = 5},
  [201] = {.lex_state = 14, .external_lex_state = 5},
  [202] = {.lex_state = 15, .external_lex_state = 3},
  [203] = {.lex_state = 14, .external_lex_state = 5},
  [204] = {.lex_state = 15, .external_lex_state = 3},
  [205] = {.lex_state = 14, .external_lex_state = 5},
  [206] = {.lex_state = 14, .external_lex_state = 5},
  [207] = {.lex_state = 3, .external_lex_state = 6},
  [208] = {.lex_state = 15, .external_lex_state = 3},
  [209] = {.lex_state = 15, .external_lex_state = 3},
  [210] = {.lex_state = 14, .external_lex_state = 5},
  [211] = {.lex_state = 14, .external_lex_state = 5},
  [212] = {.lex_state = 3, .external_lex_state = 6},
  [213] = {.lex_state = 15, .external_lex_state = 3},
  [214] = {.lex_state = 3, .external_lex_state = 6},
  [215] = {.lex_state = 15, .external_lex_state = 3},
  [216] = {.lex_state = 3, .external_lex_state = 6},
  [217] = {.lex_state = 3, .external_lex_state = 6},
  [218] = {.lex_state = 14, .external_lex_state = 5},
  [219] = {.lex_state = 14, .external_lex_state = 5},
  [220] = {.lex_state = 15, .external_lex_state = 3},
  [221] = {.lex_state = 15, .external_lex_state = 3},
  [222] = {.lex_state = 15, .external_lex_state = 3},
  [223] = {.lex_state = 15, .external_lex_state = 2},
  [224] = {.lex_state = 15, .external_lex_state = 3},
  [225] = {.lex_state = 15, .external_lex_state = 2},
  [226] = {.lex_state = 15, .external_lex_state = 3},
  [227] = {.lex_state = 15, .external_lex_state = 2},
  [228] = {.lex_state = 15, .external_lex_state = 3},
  [229] = {.lex_state = 15, .external_lex_state = 3},
  [230] = {.lex_state = 15, .external_lex_state = 3},
  [231] = {.lex_state = 15, .external_lex_state = 3},
  [232] = {.lex_state = 15, .external_lex_state = 3},
  [233] = {.lex_state = 15, .external_lex_state = 3},
  [234] = {.lex_state = 15, .external_lex_state = 3},
  [235] = {.lex_state = 15, .external_lex_state = 3},
  [236] = {.lex_state = 15, .external_lex_state = 3},
  [237] = {.lex_state = 15, .external_lex_state = 3},
  [238] = {.lex_state = 15, .external_lex_state = 3},
  [239] = {.lex_state = 15, .external_lex_state = 3},
  [240] = {.lex_state = 15, .external_lex_state = 2},
  [241] = {.lex_state = 15, .external_lex_state = 3},
  [242] = {.lex_state = 15, .external_lex_state = 3},
  [243] = {.lex_state = 15, .external_lex_state = 3},
  [244] = {.lex_state = 15, .external_lex_state = 3},
  [245] = {.lex_state = 15, .external_lex_state = 3},
  [246] = {.lex_state = 15, .external_lex_state = 3},
  [247] = {.lex_state = 0, .external_lex_state = 5},
  [248] = {.lex_state = 15, .external_lex_state = 3},
  [249] = {.lex_state = 15, .external_lex_state = 3},
  [250] = {.lex_state = 15, .external_lex_state = 3},
  [251] = {.lex_state = 15, .external_lex_state = 3},
  [252] = {.lex_state = 15, .external_lex_state = 3},
  [253] = {.lex_state = 0, .external_lex_state = 5},
  [254] = {.lex_state = 15, .external_lex_state = 3},
  [255] = {.lex_state = 15, .external_lex_state = 3},
  [256] = {.lex_state = 15, .external_lex_state = 3},
  [257] = {.lex_state = 15, .external_lex_state = 3},
  [258] = {.lex_state = 15, .external_lex_state = 3},
  [259] = {.lex_state = 15, .external_lex_state = 3},
  [260] = {.lex_state = 15, .external_lex_state = 3},
  [261] = {.lex_state = 15, .external_lex_state = 3},
  [262] = {.lex_state = 15, .external_lex_state = 3},
  [263] = {.lex_state = 15, .external_lex_state = 3},
  [264] = {.lex_state = 15, .external_lex_state = 3},
  [265] = {.lex_state = 15, .external_lex_state = 3},
  [266] = {.lex_state = 15, .external_lex_state = 3},
  [267] = {.lex_state = 15, .external_lex_state = 3},
  [268] = {.lex_state = 15, .external_lex_state = 3},
  [269] = {.lex_state = 15, .external_lex_state = 3},
  [270] = {.lex_state = 15, .external_lex_state = 3},
  [271] = {.lex_state = 15, .external_lex_state = 3},
  [272] = {.lex_state = 15, .external_lex_state = 3},
  [273] = {.lex_state = 15, .external_lex_state = 3},
  [274] = {.lex_state = 15, .external_lex_state = 3},
  [275] = {.lex_state = 15, .external_lex_state = 3},
  [276] = {.lex_state = 15, .external_lex_state = 3},
  [277] = {.lex_state = 15, .external_lex_state = 3},
  [278] = {.lex_state = 15, .external_lex_state = 3},
  [279] = {.lex_state = 15, .external_lex_state = 3},
  [280] = {.lex_state = 15, .external_lex_state = 3},
  [281] = {.lex_state = 15, .external_lex_state = 3},
  [282] = {.lex_state = 15, .external_lex_state = 3},
  [283] = {.lex_state = 15, .external_lex_state = 3},
  [284] = {.lex_state = 15, .external_lex_state = 3},
  [285] = {.lex_state = 15, .external_lex_state = 3},
  [286] = {.lex_state = 15, .external_lex_state = 3},
  [287] = {.lex_state = 15, .external_lex_state = 3},
  [288] = {.lex_state = 15, .external_lex_state = 3},
  [289] = {.lex_state = 15, .external_lex_state = 3},
  [290] = {.lex_state = 15, .external_lex_state = 3},
  [291] = {.lex_state = 15, .external_lex_state = 3},
  [292] = {.lex_state = 15, .external_lex_state = 3},
  [293] = {.lex_state = 15, .external_lex_state = 3},
  [294] = {.lex_state = 15, .external_lex_state = 3},
  [295] = {.lex_state = 15, .external_lex_state = 3},
  [296] = {.lex_state = 15, .external_lex_state = 3},
  [297] = {.lex_state = 15, .external_lex_state = 3},
  [298] = {.lex_state = 15, .external_lex_state = 3},
  [299] = {.lex_state = 15, .external_lex_state = 3},
  [300] = {.lex_state = 15, .external_lex_state = 3},
  [301] = {.lex_state = 15, .external_lex_state = 3},
  [302] = {.lex_state = 15, .external_lex_state = 3},
  [303] = {.lex_state = 15, .external_lex_state = 3},
  [304] = {.lex_state = 15, .external_lex_state = 3},
  [305] = {.lex_state = 15, .external_lex_state = 3},
  [306] = {.lex_state = 15, .external_lex_state = 3},
  [307] = {.lex_state = 15, .external_lex_state = 3},
  [308] = {.lex_state = 15, .external_lex_state = 3},
  [309] = {.lex_state = 15, .external_lex_state = 3},
  [310] = {.lex_state = 14, .external_lex_state = 5},
  [311] = {.lex_state = 14, .external_lex_state = 5},
  [312] = {.lex_state = 15, .external_lex_state = 3},
  [313] = {.lex_state = 15, .external_lex_state = 3},
  [314] = {.lex_state = 14, .external_lex_state = 5},
  [315] = {.lex_state = 15, .external_lex_state = 3},
  [316] = {.lex_state = 15, .external_lex_state = 3},
  [317] = {.lex_state = 15, .external_lex_state = 3},
  [318] = {.lex_state = 15, .external_lex_state = 3},
  [319] = {.lex_state = 15, .external_lex_state = 3},
  [320] = {.lex_state = 15, .external_lex_state = 3},
  [321] = {.lex_state = 15, .external_lex_state = 3},
  [322] = {.lex_state = 15, .external_lex_state = 3},
  [323] = {.lex_state = 15, .external_lex_state = 3},
  [324] = {.lex_state = 15, .external_lex_state = 3},
  [325] = {.lex_state = 15, .external_lex_state = 3},
  [326] = {.lex_state = 15, .external_lex_state = 3},
  [327] = {.lex_state = 15, .external_lex_state = 3},
  [328] = {.lex_state = 15, .external_lex_state = 3},
  [329] = {.lex_state = 15, .external_lex_state = 3},
  [330] = {.lex_state = 15, .external_lex_state = 3},
  [331] = {.lex_state = 15, .external_lex_state = 3},
  [332] = {.lex_state = 15, .external_lex_state = 3},
  [333] = {.lex_state = 15, .external_lex_state = 3},
  [334] = {.lex_state = 15, .external_lex_state = 3},
  [335] = {.lex_state = 15, .external_lex_state = 3},
  [336] = {.lex_state = 15, .external_lex_state = 3},
  [337] = {.lex_state = 15, .external_lex_state = 3},
  [338] = {.lex_state = 15, .external_lex_state = 3},
  [339] = {.lex_state = 15, .external_lex_state = 3},
  [340] = {.lex_state = 15, .external_lex_state = 3},
  [341] = {.lex_state = 15, .external_lex_state = 2},
  [342] = {.lex_state = 15, .external_lex_state = 3},
  [343] = {.lex_state = 15, .external_lex_state = 3},
  [344] = {.lex_state = 15, .external_lex_state = 3},
  [345] = {.lex_state = 3, .external_lex_state = 6},
  [346] = {.lex_state = 15, .external_lex_state = 3},
  [347] = {.lex_state = 15, .external_lex_state = 2},
  [348] = {.lex_state = 15, .external_lex_state = 3},
  [349] = {.lex_state = 15, .external_lex_state = 3},
  [350] = {.lex_state = 15, .external_lex_state = 3},
  [351] = {.lex_state = 15, .external_lex_state = 3},
  [352] = {.lex_state = 15, .external_lex_state = 3},
  [353] = {.lex_state = 15, .external_lex_state = 3},
  [354] = {.lex_state = 0, .external_lex_state = 5},
  [355] = {.lex_state = 0, .external_lex_state = 5},
  [356] = {.lex_state = 15, .external_lex_state = 3},
  [357] = {.lex_state = 3, .external_lex_state = 6},
  [358] = {.lex_state = 0, .external_lex_state = 5},
  [359] = {.lex_state = 3, .external_lex_state = 6},
  [360] = {.lex_state = 3, .external_lex_state = 6},
  [361] = {.lex_state = 3, .external_lex_state = 6},
  [362] = {.lex_state = 3, .external_lex_state = 6},
  [363] = {.lex_state = 3, .external_lex_state = 6},
  [364] = {.lex_state = 0, .external_lex_state = 5},
  [365] = {.lex_state = 14, .external_lex_state = 5},
  [366] = {.lex_state = 0, .external_lex_state = 5},
  [367] = {.lex_state = 0, .external_lex_state = 5},
  [368] = {.lex_state = 0, .external_lex_state = 5},
  [369] = {.lex_state = 3, .external_lex_state = 6},
  [370] = {.lex_state = 14, .external_lex_state = 5},
  [371] = {.lex_state = 3, .external_lex_state = 6},
  [372] = {.lex_state = 3, .external_lex_state = 6},
  [373] = {.lex_state = 14, .external_lex_state = 5},
  [374] = {.lex_state = 3, .external_lex_state = 6},
  [375] = {.lex_state = 0, .external_lex_state = 5},
  [376] = {.lex_state = 3, .external_lex_state = 6},
  [377] = {.lex_state = 0, .external_lex_state = 5},
  [378] = {.lex_state = 3, .external_lex_state = 6},
  [379] = {.lex_state = 3, .external_lex_state = 6},
  [380] = {.lex_state = 0, .external_lex_state = 5},
  [381] = {.lex_state = 15, .external_lex_state = 2},
  [382] = {.lex_state = 15, .external_lex_state = 2},
  [383] = {.lex_state = 0, .external_lex_state = 5},
  [384] = {.lex_state = 0, .external_lex_state = 5},
  [385] = {.lex_state = 14, .external_lex_state = 5},
  [386] = {.lex_state = 15, .external_lex_state = 2},
  [387] = {.lex_state = 15, .external_lex_state = 2},
  [388] = {.lex_state = 14, .external_lex_state = 5},
  [389] = {.lex_state = 14, .external_lex_state = 5},
  [390] = {.lex_state = 14, .external_lex_state = 5},
  [391] = {.lex_state = 14, .external_lex_state = 5},
  [392] = {.lex_state = 14, .external_lex_state = 5},
  [393] = {.lex_state = 14, .external_lex_state = 5},
  [394] = {.lex_state = 0, .external_lex_state = 5},
  [395] = {.lex_state = 0, .external_lex_state = 5},
  [396] = {.lex_state = 14, .external_lex_state = 5},
  [397] = {.lex_state = 14, .external_lex_state = 5},
  [398] = {.lex_state = 0, .external_lex_state = 5},
  [399] = {.lex_state = 14, .external_lex_state = 5},
  [400] = {.lex_state = 0, .external_lex_state = 5},
  [401] = {.lex_state = 14, .external_lex_state = 5},
  [402] = {.lex_state = 0, .external_lex_state = 5},
  [403] = {.lex_state = 14, .external_lex_state = 5},
  [404] = {.lex_state = 14, .external_lex_state = 5},
  [405] = {.lex_state = 14, .external_lex_state = 5},
  [406] = {.lex_state = 14, .external_lex_state = 5},
  [407] = {.lex_state = 14, .external_lex_state = 5},
  [408] = {.lex_state = 14, .external_lex_state = 5},
  [409] = {.lex_state = 14, .external_lex_state = 5},
  [410] = {.lex_state = 14, .external_lex_state = 5},
  [411] = {.lex_state = 14, .external_lex_state = 5},
  [412] = {.lex_state = 0, .external_lex_state = 5},
  [413] = {.lex_state = 14, .external_lex_state = 5},
  [414] = {.lex_state = 0, .external_lex_state = 5},
  [415] = {.lex_state = 14, .external_lex_state = 5},
  [416] = {.lex_state = 0, .external_lex_state = 5},
  [417] = {.lex_state = 14, .external_lex_state = 5},
  [418] = {.lex_state = 0, .external_lex_state = 5},
  [419] = {.lex_state = 14, .external_lex_state = 5},
  [420] = {.lex_state = 14, .external_lex_state = 5},
  [421] = {.lex_state = 14, .external_lex_state = 5},
  [422] = {.lex_state = 14, .external_lex_state = 5},
  [423] = {.lex_state = 14, .external_lex_state = 5},
  [424] = {.lex_state = 0, .external_lex_state = 5},
  [425] = {.lex_state = 3, .external_lex_state = 6},
  [426] = {.lex_state = 3, .external_lex_state = 6},
  [427] = {.lex_state = 0, .external_lex_state = 5},
  [428] = {.lex_state = 14, .external_lex_state = 5},
  [429] = {.lex_state = 14, .external_lex_state = 5},
  [430] = {.lex_state = 14, .external_lex_state = 5},
  [431] = {.lex_state = 14, .external_lex_state = 5},
  [432] = {.lex_state = 0, .external_lex_state = 5},
  [433] = {.lex_state = 14, .external_lex_state = 5},
  [434] = {.lex_state = 14, .external_lex_state = 5},
  [435] = {.lex_state = 14, .external_lex_state = 5},
  [436] = {.lex_state = 3, .external_lex_state = 6},
  [437] = {.lex_state = 0, .external_lex_state = 5},
  [438] = {.lex_state = 3, .external_lex_state = 6},
  [439] = {.lex_state = 14, .external_lex_state = 5},
  [440] = {.lex_state = 0, .external_lex_state = 5},
  [441] = {.lex_state = 14, .external_lex_state = 5},
  [442] = {.lex_state = 0, .external_lex_state = 5},
  [443] = {.lex_state = 14, .external_lex_state = 5},
  [444] = {.lex_state = 14, .external_lex_state = 5},
  [445] = {.lex_state = 0, .external_lex_state = 5},
  [446] = {.lex_state = 14, .external_lex_state = 5},
  [447] = {.lex_state = 14, .external_lex_state = 5},
  [448] = {.lex_state = 0, .external_lex_state = 5},
  [449] = {.lex_state = 14, .external_lex_state = 5},
  [450] = {.lex_state = 14, .external_lex_state = 5},
  [451] = {.lex_state = 14, .external_lex_state = 5},
  [452] = {.lex_state = 14, .external_lex_state = 5},
  [453] = {.lex_state = 3, .external_lex_state = 6},
  [454] = {.lex_state = 14, .external_lex_state = 5},
  [455] = {.lex_state = 0, .external_lex_state = 5},
  [456] = {.lex_state = 0, .external_lex_state = 5},
  [457] = {.lex_state = 3, .external_lex_state = 6},
  [458] = {.lex_state = 0, .external_lex_state = 5},
  [459] = {.lex_state = 3, .external_lex_state = 6},
  [460] = {.lex_state = 3, .external_lex_state = 6},
  [461] = {.lex_state = 3, .external_lex_state = 6},
  [462] = {.lex_state = 0, .external_lex_state = 5},
  [463] = {.lex_state = 3, .external_lex_state = 6},
  [464] = {.lex_state = 0, .external_lex_state = 5},
  [465] = {.lex_state = 3, .external_lex_state = 6},
  [466] = {.lex_state = 3, .external_lex_state = 6},
  [467] = {.lex_state = 3, .external_lex_state = 6},
  [468] = {.lex_state = 3, .external_lex_state = 6},
  [469] = {.lex_state = 3, .external_lex_state = 6},
  [470] = {.lex_state = 3, .external_lex_state = 6},
  [471] = {.lex_state = 3, .external_lex_state = 6},
  [472] = {.lex_state = 3, .external_lex_state = 6},
  [473] = {.lex_state = 3, .external_lex_state = 6},
  [474] = {.lex_state = 3, .external_lex_state = 6},
  [475] = {.lex_state = 3, .external_lex_state = 6},
  [476] = {.lex_state = 3, .external_lex_state = 6},
  [477] = {.lex_state = 14, .external_lex_state = 5},
  [478] = {.lex_state = 0, .external_lex_state = 5},
  [479] = {.lex_state = 0, .external_lex_state = 5},
  [480] = {.lex_state = 3, .external_lex_state = 6},
  [481] = {.lex_state = 3, .external_lex_state = 6},
  [482] = {.lex_state = 3, .external_lex_state = 6},
  [483] = {.lex_state = 0, .external_lex_state = 5},
  [484] = {.lex_state = 3, .external_lex_state = 6},
  [485] = {.lex_state = 14, .external_lex_state = 5},
  [486] = {.lex_state = 3, .external_lex_state = 6},
  [487] = {.lex_state = 3, .external_lex_state = 6},
  [488] = {.lex_state = 0, .external_lex_state = 5},
  [489] = {.lex_state = 3, .external_lex_state = 6},
  [490] = {.lex_state = 3, .external_lex_state = 6},
  [491] = {.lex_state = 3, .external_lex_state = 6},
  [492] = {.lex_state = 3, .external_lex_state = 6},
  [493] = {.lex_state = 3, .external_lex_state = 6},
  [494] = {.lex_state = 3, .external_lex_state = 6},
  [495] = {.lex_state = 3, .external_lex_state = 6},
  [496] = {.lex_state = 3, .external_lex_state = 6},
  [497] = {.lex_state = 3, .external_lex_state = 6},
  [498] = {.lex_state = 3, .external_lex_state = 6},
  [499] = {.lex_state = 3, .external_lex_state = 6},
  [500] = {.lex_state = 3, .external_lex_state = 6},
  [501] = {.lex_state = 3, .external_lex_state = 6},
  [502] = {.lex_state = 3, .external_lex_state = 6},
  [503] = {.lex_state = 3, .external_lex_state = 6},
  [504] = {.lex_state = 3, .external_lex_state = 6},
  [505] = {.lex_state = 3, .external_lex_state = 6},
  [506] = {.lex_state = 3, .external_lex_state = 6},
  [507] = {.lex_state = 3, .external_lex_state = 6},
  [508] = {.lex_state = 3, .external_lex_state = 6},
  [509] = {.lex_state = 3, .external_lex_state = 6},
  [510] = {.lex_state = 3, .external_lex_state = 6},
  [511] = {.lex_state = 3, .external_lex_state = 6},
  [512] = {.lex_state = 14, .external_lex_state = 5},
  [513] = {.lex_state = 14, .external_lex_state = 5},
  [514] = {.lex_state = 0, .external_lex_state = 5},
  [515] = {.lex_state = 14, .external_lex_state = 5},
  [516] = {.lex_state = 14, .external_lex_state = 5},
  [517] = {.lex_state = 14, .external_lex_state = 5},
  [518] = {.lex_state = 0, .external_lex_state = 5},
  [519] = {.lex_state = 0, .external_lex_state = 5},
  [520] = {.lex_state = 0, .external_lex_state = 5},
  [521] = {.lex_state = 0, .external_lex_state = 5},
  [522] = {.lex_state = 0, .external_lex_state = 5},
  [523] = {.lex_state = 0, .external_lex_state = 5},
  [524] = {.lex_state = 0, .external_lex_state = 5},
  [525] = {.lex_state = 3, .external_lex_state = 6},
  [526] = {.lex_state = 0, .external_lex_state = 5},
  [527] = {.lex_state = 0, .external_lex_state = 5},
  [528] = {.lex_state = 0, .external_lex_state = 5},
  [529] = {.lex_state = 0, .external_lex_state = 5},
  [530] = {.lex_state = 0, .external_lex_state = 5},
  [531] = {.lex_state = 0, .external_lex_state = 5},
  [532] = {.lex_state = 0, .external_lex_state = 5},
  [533] = {.lex_state = 0, .external_lex_state = 5},
  [534] = {.lex_state = 0, .external_lex_state = 5},
  [535] = {.lex_state = 0, .external_lex_state = 5},
  [536] = {.lex_state = 0, .external_lex_state = 5},
  [537] = {.lex_state = 0, .external_lex_state = 5},
  [538] = {.lex_state = 0, .external_lex_state = 5},
  [539] = {.lex_state = 0, .external_lex_state = 5},
  [540] = {.lex_state = 0, .external_lex_state = 5},
  [541] = {.lex_state = 0, .external_lex_state = 5},
  [542] = {.lex_state = 0, .external_lex_state = 5},
  [543] = {.lex_state = 0, .external_lex_state = 5},
  [544] = {.lex_state = 0, .external_lex_state = 5},
  [545] = {.lex_state = 0, .external_lex_state = 5},
  [546] = {.lex_state = 0, .external_lex_state = 5},
  [547] = {.lex_state = 0, .external_lex_state = 5},
  [548] = {.lex_state = 0, .external_lex_state = 5},
  [549] = {.lex_state = 0, .external_lex_state = 5},
  [550] = {.lex_state = 0, .external_lex_state = 5},
  [551] = {.lex_state = 0, .external_lex_state = 5},
  [552] = {.lex_state = 0, .external_lex_state = 5},
  [553] = {.lex_state = 0, .external_lex_state = 5},
  [554] = {.lex_state = 0, .external_lex_state = 5},
  [555] = {.lex_state = 0, .external_lex_state = 5},
  [556] = {.lex_state = 0, .external_lex_state = 5},
  [557] = {.lex_state = 0, .external_lex_state = 5},
  [558] = {.lex_state = 0, .external_lex_state = 5},
  [559] = {.lex_state = 0, .external_lex_state = 5},
  [560] = {.lex_state = 0, .external_lex_state = 5},
  [561] = {.lex_state = 0, .external_lex_state = 5},
  [562] = {.lex_state = 0, .external_lex_state = 5},
  [563] = {.lex_state = 0, .external_lex_state = 5},
  [564] = {.lex_state = 0, .external_lex_state = 5},
  [565] = {.lex_state = 0, .external_lex_state = 5},
  [566] = {.lex_state = 3, .external_lex_state = 6},
  [567] = {.lex_state = 3, .external_lex_state = 6},
  [568] = {.lex_state = 3, .external_lex_state = 6},
  [569] = {.lex_state = 3, .external_lex_state = 6},
  [570] = {.lex_state = 0, .external_lex_state = 5},
  [571] = {.lex_state = 3, .external_lex_state = 6},
  [572] = {.lex_state = 0, .external_lex_state = 5},
  [573] = {.lex_state = 0, .external_lex_state = 5},
  [574] = {.lex_state = 0, .external_lex_state = 5},
  [575] = {.lex_state = 0, .external_lex_state = 5},
  [576] = {.lex_state = 0, .external_lex_state = 5},
  [577] = {.lex_state = 0, .external_lex_state = 5},
  [578] = {.lex_state = 0, .external_lex_state = 5},
  [579] = {.lex_state = 0, .external_lex_state = 5},
  [580] = {.lex_state = 0, .external_lex_state = 5},
  [581] = {.lex_state = 0, .external_lex_state = 5},
  [582] = {.lex_state = 0, .external_lex_state = 5},
  [583] = {.lex_state = 0, .external_lex_state = 5},
  [584] = {.lex_state = 0, .external_lex_state = 5},
  [585] = {.lex_state = 0, .external_lex_state = 5},
  [586] = {.lex_state = 0, .external_lex_state = 5},
  [587] = {.lex_state = 0, .external_lex_state = 5},
  [588] = {.lex_state = 0, .external_lex_state = 5},
  [589] = {.lex_state = 0, .external_lex_state = 5},
  [590] = {.lex_state = 0, .external_lex_state = 5},
  [591] = {.lex_state = 0, .external_lex_state = 5},
  [592] = {.lex_state = 0, .external_lex_state = 5},
  [593] = {.lex_state = 0, .external_lex_state = 5},
  [594] = {.lex_state = 0, .external_lex_state = 5},
  [595] = {.lex_state = 0, .external_lex_state = 5},
  [596] = {.lex_state = 0, .external_lex_state = 5},
  [597] = {.lex_state = 0, .external_lex_state = 5},
  [598] = {.lex_state = 0, .external_lex_state = 5},
  [599] = {.lex_state = 0, .external_lex_state = 5},
  [600] = {.lex_state = 0, .external_lex_state = 5},
  [601] = {.lex_state = 0, .external_lex_state = 5},
  [602] = {.lex_state = 0, .external_lex_state = 5},
  [603] = {.lex_state = 1, .external_lex_state = 5},
  [604] = {.lex_state = 1, .external_lex_state = 5},
  [605] = {.lex_state = 14, .external_lex_state = 5},
  [606] = {.lex_state = 15, .external_lex_state = 5},
  [607] = {.lex_state = 1, .external_lex_state = 5},
  [608] = {.lex_state = 1, .external_lex_state = 5},
  [609] = {.lex_state = 5, .external_lex_state = 5},
  [610] = {.lex_state = 6, .external_lex_state = 6},
  [611] = {.lex_state = 2, .external_lex_state = 5},
  [612] = {.lex_state = 6, .external_lex_state = 6},
  [613] = {.lex_state = 6, .external_lex_state = 6},
  [614] = {.lex_state = 0, .external_lex_state = 5},
  [615] = {.lex_state = 0, .external_lex_state = 5},
  [616] = {.lex_state = 3, .external_lex_state = 6},
  [617] = {.lex_state = 0, .external_lex_state = 5},
  [618] = {.lex_state = 5, .external_lex_state = 5},
  [619] = {.lex_state = 3, .external_lex_state = 6},
  [620] = {.lex_state = 6, .external_lex_state = 6},
  [621] = {.lex_state = 14, .external_lex_state = 5},
  [622] = {.lex_state = 0, .external_lex_state = 5},
  [623] = {.lex_state = 5, .external_lex_state = 5},
  [624] = {.lex_state = 3, .external_lex_state = 6},
  [625] = {.lex_state = 15, .external_lex_state = 5},
  [626] = {.lex_state = 5, .external_lex_state = 5},
  [627] = {.lex_state = 14, .external_lex_state = 5},
  [628] = {.lex_state = 15, .external_lex_state = 5},
  [629] = {.lex_state = 14, .external_lex_state = 5},
  [630] = {.lex_state = 14, .external_lex_state = 5},
  [631] = {.lex_state = 15, .external_lex_state = 5},
  [632] = {.lex_state = 14, .external_lex_state = 5},
  [633] = {.lex_state = 14, .external_lex_state = 5},
  [634] = {.lex_state = 0, .external_lex_state = 5},
  [635] = {.lex_state = 15, .external_lex_state = 5},
  [636] = {.lex_state = 15, .external_lex_state = 3},
  [637] = {.lex_state = 15, .external_lex_state = 5},
  [638] = {.lex_state = 15, .external_lex_state = 5},
  [639] = {.lex_state = 14, .external_lex_state = 5},
  [640] = {.lex_state = 14, .external_lex_state = 5},
  [641] = {.lex_state = 0, .external_lex_state = 5},
  [642] = {.lex_state = 15, .external_lex_state = 5},
  [643] = {.lex_state = 15, .external_lex_state = 5},
  [644] = {.lex_state = 0, .external_lex_state = 5},
  [645] = {.lex_state = 0, .external_lex_state = 5},
  [646] = {.lex_state = 0, .external_lex_state = 5},
  [647] = {.lex_state = 15, .external_lex_state = 5},
  [648] = {.lex_state = 15, .external_lex_state = 5},
  [649] = {.lex_state = 15, .external_lex_state = 5},
  [650] = {.lex_state = 2, .external_lex_state = 5},
  [651] = {.lex_state = 2, .external_lex_state = 5},
  [652] = {.lex_state = 0, .external_lex_state = 7},
  [653] = {.lex_state = 0, .external_lex_state = 7},
  [654] = {.lex_state = 0, .external_lex_state = 5},
  [655] = {.lex_state = 15, .external_lex_state = 5},
  [656] = {.lex_state = 0, .external_lex_state = 5},
  [657] = {.lex_state = 15, .external_lex_state = 5},
  [658] = {.lex_state = 15, .external_lex_state = 5},
  [659] = {.lex_state = 0, .external_lex_state = 7},
  [660] = {.lex_state = 0, .external_lex_state = 7},
  [661] = {.lex_state = 14, .external_lex_state = 5},
  [662] = {.lex_state = 2, .external_lex_state = 5},
  [663] = {.lex_state = 0, .external_lex_state = 7},
  [664] = {.lex_state = 15, .external_lex_state = 5},
  [665] = {.lex_state = 0, .external_lex_state = 5},
  [666] = {.lex_state = 15, .external_lex_state = 5},
  [667] = {.lex_state = 15, .external_lex_state = 5},
  [668] = {.lex_state = 15, .external_lex_state = 5},
  [669] = {.lex_state = 15, .external_lex_state = 5},
  [670] = {.lex_state = 15, .external_lex_state = 5},
  [671] = {.lex_state = 15, .external_lex_state = 5},
  [672] = {.lex_state = 15, .external_lex_state = 5},
  [673] = {.lex_state = 15, .external_lex_state = 5},
  [674] = {.lex_state = 15, .external_lex_state = 5},
  [675] = {.lex_state = 15, .external_lex_state = 5},
  [676] = {.lex_state = 15, .external_lex_state = 5},
  [677] = {.lex_state = 15, .external_lex_state = 5},
  [678] = {.lex_state = 14, .external_lex_state = 5},
  [679] = {.lex_state = 15, .external_lex_state = 5},
  [680] = {.lex_state = 0, .external_lex_state = 5},
  [681] = {.lex_state = 0, .external_lex_state = 5},
  [682] = {.lex_state = 14, .external_lex_state = 5},
  [683] = {.lex_state = 14, .external_lex_state = 5},
  [684] = {.lex_state = 0, .external_lex_state = 5},
  [685] = {.lex_state = 0, .external_lex_state = 5},
  [686] = {.lex_state = 14, .external_lex_state = 5},
  [687] = {.lex_state = 0, .external_lex_state = 5},
  [688] = {.lex_state = 14, .external_lex_state = 5},
  [689] = {.lex_state = 0, .external_lex_state = 5},
  [690] = {.lex_state = 0, .external_lex_state = 5},
  [691] = {.lex_state = 0, .external_lex_state = 5},
  [692] = {.lex_state = 14, .external_lex_state = 5},
  [693] = {.lex_state = 14, .external_lex_state = 5},
  [694] = {.lex_state = 14, .external_lex_state = 5},
  [695] = {.lex_state = 14, .external_lex_state = 5},
  [696] = {.lex_state = 0, .external_lex_state = 5},
  [697] = {.lex_state = 14, .external_lex_state = 5},
  [698] = {.lex_state = 14, .external_lex_state = 5},
  [699] = {.lex_state = 15, .external_lex_state = 5},
  [700] = {.lex_state = 0, .external_lex_state = 5},
  [701] = {.lex_state = 14, .external_lex_state = 5},
  [702] = {.lex_state = 14, .external_lex_state = 5},
  [703] = {.lex_state = 14, .external_lex_state = 5},
  [704] = {.lex_state = 14, .external_lex_state = 5},
  [705] = {.lex_state = 14, .external_lex_state = 5},
  [706] = {.lex_state = 15, .external_lex_state = 5},
  [707] = {.lex_state = 15, .external_lex_state = 5},
  [708] = {.lex_state = 15, .external_lex_state = 5},
  [709] = {.lex_state = 15, .external_lex_state = 5},
  [710] = {.lex_state = 15, .external_lex_state = 5},
  [711] = {.lex_state = 15, .external_lex_state = 5},
  [712] = {.lex_state = 14, .external_lex_state = 5},
  [713] = {.lex_state = 15, .external_lex_state = 5},
  [714] = {.lex_state = 14, .external_lex_state = 5},
  [715] = {.lex_state = 15, .external_lex_state = 5},
  [716] = {.lex_state = 15, .external_lex_state = 5},
  [717] = {.lex_state = 15, .external_lex_state = 5},
  [718] = {.lex_state = 14, .external_lex_state = 5},
  [719] = {.lex_state = 2, .external_lex_state = 5},
  [720] = {.lex_state = 15, .external_lex_state = 5},
  [721] = {.lex_state = 15, .external_lex_state = 5},
  [722] = {.lex_state = 14, .external_lex_state = 5},
  [723] = {.lex_state = 15, .external_lex_state = 5},
  [724] = {.lex_state = 15, .external_lex_state = 5},
  [725] = {.lex_state = 14, .external_lex_state = 5},
  [726] = {.lex_state = 14, .external_lex_state = 5},
  [727] = {.lex_state = 14, .external_lex_state = 5},
  [728] = {.lex_state = 14, .external_lex_state = 5},
  [729] = {.lex_state = 14, .external_lex_state = 5},
  [730] = {.lex_state = 14, .external_lex_state = 5},
  [731] = {.lex_state = 0, .external_lex_state = 5},
  [732] = {.lex_state = 15, .external_lex_state = 5},
  [733] = {.lex_state = 14, .external_lex_state = 5},
  [734] = {.lex_state = 14, .external_lex_state = 5},
  [735] = {.lex_state = 14, .external_lex_state = 5},
  [736] = {.lex_state = 14, .external_lex_state = 5},
  [737] = {.lex_state = 14, .external_lex_state = 5},
  [738] = {.lex_state = 15, .external_lex_state = 5},
  [739] = {.lex_state = 14, .external_lex_state = 5},
  [740] = {.lex_state = 14, .external_lex_state = 5},
  [741] = {.lex_state = 14, .external_lex_state = 5},
  [742] = {.lex_state = 15, .external_lex_state = 5},
  [743] = {.lex_state = 0, .external_lex_state = 7},
  [744] = {.lex_state = 15, .external_lex_state = 5},
  [745] = {.lex_state = 0, .external_lex_state = 5},
  [746] = {.lex_state = 0, .external_lex_state = 7},
  [747] = {.lex_state = 14, .external_lex_state = 8},
  [748] = {.lex_state = 0, .external_lex_state = 7},
  [749] = {.lex_state = 0, .external_lex_state = 7},
  [750] = {.lex_state = 14, .external_lex_state = 5},
  [751] = {.lex_state = 14, .external_lex_state = 5},
  [752] = {.lex_state = 14, .external_lex_state = 5},
  [753] = {.lex_state = 0, .external_lex_state = 7},
  [754] = {.lex_state = 14, .external_lex_state = 5},
  [755] = {.lex_state = 14, .external_lex_state = 5},
  [756] = {.lex_state = 0, .external_lex_state = 7},
  [757] = {.lex_state = 0, .external_lex_state = 7},
  [758] = {.lex_state = 0, .external_lex_state = 7},
  [759] = {.lex_state = 14, .external_lex_state = 5},
  [760] = {.lex_state = 0, .external_lex_state = 7},
  [761] = {.lex_state = 0, .external_lex_state = 7},
  [762] = {.lex_state = 0, .external_lex_state = 7},
  [763] = {.lex_state = 0, .external_lex_state = 7},
  [764] = {.lex_state = 14, .external_lex_state = 5},
  [765] = {.lex_state = 0, .external_lex_state = 7},
  [766] = {.lex_state = 0, .external_lex_state = 7},
  [767] = {.lex_state = 14, .external_lex_state = 8},
  [768] = {.lex_state = 7, .external_lex_state = 6},
  [769] = {.lex_state = 14, .external_lex_state = 8},
  [770] = {.lex_state = 0, .external_lex_state = 7},
  [771] = {.lex_state = 0, .external_lex_state = 7},
  [772] = {.lex_state = 7, .external_lex_state = 6},
  [773] = {.lex_state = 14, .external_lex_state = 5},
  [774] = {.lex_state = 14, .external_lex_state = 5},
  [775] = {.lex_state = 15, .external_lex_state = 5},
  [776] = {.lex_state = 14, .external_lex_state = 5},
  [777] = {.lex_state = 14, .external_lex_state = 5},
  [778] = {.lex_state = 0, .external_lex_state = 7},
  [779] = {.lex_state = 0, .external_lex_state = 7},
  [780] = {.lex_state = 0, .external_lex_state = 7},
  [781] = {.lex_state = 7, .external_lex_state = 6},
  [782] = {.lex_state = 0, .external_lex_state = 7},
  [783] = {.lex_state = 14, .external_lex_state = 5},
  [784] = {.lex_state = 15, .external_lex_state = 5},
  [785] = {.lex_state = 14, .external_lex_state = 5},
  [786] = {.lex_state = 14, .external_lex_state = 5},
  [787] = {.lex_state = 15, .external_lex_state = 5},
  [788] = {.lex_state = 0, .external_lex_state = 7},
  [789] = {.lex_state = 14, .external_lex_state = 5},
  [790] = {.lex_state = 7, .external_lex_state = 6},
  [791] = {.lex_state = 14, .external_lex_state = 5},
  [792] = {.lex_state = 14, .external_lex_state = 5},
  [793] = {.lex_state = 14, .external_lex_state = 5},
  [794] = {.lex_state = 15, .external_lex_state = 5},
  [795] = {.lex_state = 0, .external_lex_state = 7},
  [796] = {.lex_state = 7, .external_lex_state = 6},
  [797] = {.lex_state = 14, .external_lex_state = 5},
  [798] = {.lex_state = 14, .external_lex_state = 5},
  [799] = {.lex_state = 14, .external_lex_state = 5},
  [800] = {.lex_state = 15, .external_lex_state = 5},
  [801] = {.lex_state = 0, .external_lex_state = 7},
  [802] = {.lex_state = 15, .external_lex_state = 5},
  [803] = {.lex_state = 15, .external_lex_state = 5},
  [804] = {.lex_state = 14, .external_lex_state = 5},
  [805] = {.lex_state = 15, .external_lex_state = 5},
  [806] = {.lex_state = 14, .external_lex_state = 5},
  [807] = {.lex_state = 15, .external_lex_state = 5},
  [808] = {.lex_state = 15, .external_lex_state = 5},
  [809] = {.lex_state = 14, .external_lex_state = 5},
  [810] = {.lex_state = 14, .external_lex_state = 5},
  [811] = {.lex_state = 14, .external_lex_state = 5},
  [812] = {.lex_state = 14, .external_lex_state = 5},
  [813] = {.lex_state = 15, .external_lex_state = 5},
  [814] = {.lex_state = 15, .external_lex_state = 5},
  [815] = {.lex_state = 14, .external_lex_state = 5},
  [816] = {.lex_state = 15, .external_lex_state = 5},
  [817] = {.lex_state = 14, .external_lex_state = 5},
  [818] = {.lex_state = 14, .external_lex_state = 5},
  [819] = {.lex_state = 15, .external_lex_state = 5},
  [820] = {.lex_state = 15, .external_lex_state = 5},
  [821] = {.lex_state = 15, .external_lex_state = 5},
  [822] = {.lex_state = 15, .external_lex_state = 5},
  [823] = {.lex_state = 15, .external_lex_state = 5},
  [824] = {.lex_state = 14, .external_lex_state = 5},
  [825] = {.lex_state = 0, .external_lex_state = 9},
  [826] = {.lex_state = 15, .external_lex_state = 5},
  [827] = {.lex_state = 14, .external_lex_state = 5},
  [828] = {.lex_state = 15, .external_lex_state = 5},
  [829] = {.lex_state = 15, .external_lex_state = 5},
  [830] = {.lex_state = 15, .external_lex_state = 5},
  [831] = {.lex_state = 14, .external_lex_state = 5},
  [832] = {.lex_state = 0, .external_lex_state = 5},
  [833] = {.lex_state = 0, .external_lex_state = 10},
  [834] = {.lex_state = 0, .external_lex_state = 9},
  [835] = {.lex_state = 15, .external_lex_state = 5},
  [836] = {.lex_state = 0, .external_lex_state = 9},
  [837] = {.lex_state = 15, .external_lex_state = 5},
  [838] = {.lex_state = 0, .external_lex_state = 10},
  [839] = {.lex_state = 0, .external_lex_state = 9},
  [840] = {.lex_state = 15, .external_lex_state = 5},
  [841] = {.lex_state = 14, .external_lex_state = 5},
  [842] = {.lex_state = 0, .external_lex_state = 10},
  [843] = {.lex_state = 14, .external_lex_state = 5},
  [844] = {.lex_state = 7, .external_lex_state = 5},
  [845] = {.lex_state = 0, .external_lex_state = 10},
  [846] = {.lex_state = 15, .external_lex_state = 5},
  [847] = {.lex_state = 7, .external_lex_state = 6},
  [848] = {.lex_state = 0, .external_lex_state = 9},
  [849] = {.lex_state = 14, .external_lex_state = 5},
  [850] = {.lex_state = 0, .external_lex_state = 10},
  [851] = {.lex_state = 15, .external_lex_state = 5},
  [852] = {.lex_state = 15, .external_lex_state = 5},
  [853] = {.lex_state = 14, .external_lex_state = 5},
  [854] = {.lex_state = 0, .external_lex_state = 10},
  [855] = {.lex_state = 0, .external_lex_state = 9},
  [856] = {.lex_state = 14, .external_lex_state = 5},
  [857] = {.lex_state = 14, .external_lex_state = 5},
  [858] = {.lex_state = 15, .external_lex_state = 5},
  [859] = {.lex_state = 14, .external_lex_state = 5},
  [860] = {.lex_state = 14, .external_lex_state = 5},
  [861] = {.lex_state = 14, .external_lex_state = 5},
  [862] = {.lex_state = 15, .external_lex_state = 5},
  [863] = {.lex_state = 14, .external_lex_state = 5},
  [864] = {.lex_state = 15, .external_lex_state = 5},
  [865] = {.lex_state = 14, .external_lex_state = 5},
  [866] = {.lex_state = 14, .external_lex_state = 5},
  [867] = {.lex_state = 15, .external_lex_state = 5},
  [868] = {.lex_state = 14, .external_lex_state = 5},
  [869] = {.lex_state = 15, .external_lex_state = 5},
  [870] = {.lex_state = 14, .external_lex_state = 5},
  [871] = {.lex_state = 14, .external_lex_state = 5},
  [872] = {.lex_state = 14, .external_lex_state = 5},
  [873] = {.lex_state = 14, .external_lex_state = 5},
  [874] = {.lex_state = 14, .external_lex_state = 5},
  [875] = {.lex_state = 14, .external_lex_state = 5},
  [876] = {.lex_state = 14, .external_lex_state = 5},
  [877] = {.lex_state = 14, .external_lex_state = 5},
  [878] = {.lex_state = 0, .external_lex_state = 10},
  [879] = {.lex_state = 15, .external_lex_state = 5},
  [880] = {.lex_state = 0, .external_lex_state = 9},
  [881] = {.lex_state = 0, .external_lex_state = 10},
  [882] = {.lex_state = 14, .external_lex_state = 5},
  [883] = {.lex_state = 14, .external_lex_state = 5},
  [884] = {.lex_state = 14, .external_lex_state = 5},
  [885] = {.lex_state = 0, .external_lex_state = 9},
  [886] = {.lex_state = 0, .external_lex_state = 10},
  [887] = {.lex_state = 0, .external_lex_state = 9},
  [888] = {.lex_state = 14, .external_lex_state = 5},
  [889] = {.lex_state = 14, .external_lex_state = 5},
  [890] = {.lex_state = 14, .external_lex_state = 5},
  [891] = {.lex_state = 14, .external_lex_state = 5},
  [892] = {.lex_state = 0, .external_lex_state = 5},
  [893] = {.lex_state = 7, .external_lex_state = 5},
  [894] = {.lex_state = 0, .external_lex_state = 5},
  [895] = {.lex_state = 15, .external_lex_state = 5},
  [896] = {.lex_state = 14, .external_lex_state = 5},
  [897] = {.lex_state = 14, .external_lex_state = 5},
  [898] = {.lex_state = 15, .external_lex_state = 5},
  [899] = {.lex_state = 15, .external_lex_state = 5},
  [900] = {.lex_state = 14, .external_lex_state = 5},
  [901] = {.lex_state = 15, .external_lex_state = 5},
  [902] = {.lex_state = 14, .external_lex_state = 5},
  [903] = {.lex_state = 15, .external_lex_state = 5},
  [904] = {.lex_state = 7, .external_lex_state = 5},
  [905] = {.lex_state = 0, .external_lex_state = 5},
  [906] = {.lex_state = 14, .external_lex_state = 5},
  [907] = {.lex_state = 14, .external_lex_state = 5},
  [908] = {.lex_state = 7, .external_lex_state = 5},
  [909] = {.lex_state = 7, .external_lex_state = 5},
  [910] = {.lex_state = 14, .external_lex_state = 5},
  [911] = {.lex_state = 15, .external_lex_state = 5},
  [912] = {.lex_state = 15, .external_lex_state = 5},
  [913] = {.lex_state = 14, .external_lex_state = 5},
  [914] = {.lex_state = 15, .external_lex_state = 5},
  [915] = {.lex_state = 14, .external_lex_state = 5},
  [916] = {.lex_state = 0, .external_lex_state = 5},
  [917] = {.lex_state = 14, .external_lex_state = 5},
  [918] = {.lex_state = 15, .external_lex_state = 5},
  [919] = {.lex_state = 0, .external_lex_state = 5},
  [920] = {.lex_state = 15, .external_lex_state = 5},
  [921] = {.lex_state = 15, .external_lex_state = 5},
  [922] = {.lex_state = 14, .external_lex_state = 5},
  [923] = {.lex_state = 15, .external_lex_state = 5},
  [924] = {.lex_state = 14, .external_lex_state = 5},
  [925] = {.lex_state = 14, .external_lex_state = 5},
  [926] = {.lex_state = 14, .external_lex_state = 5},
  [927] = {.lex_state = 15, .external_lex_state = 5},
  [928] = {.lex_state = 14, .external_lex_state = 5},
  [929] = {.lex_state = 15, .external_lex_state = 5},
  [930] = {.lex_state = 14, .external_lex_state = 5},
  [931] = {.lex_state = 0, .external_lex_state = 5},
  [932] = {.lex_state = 14, .external_lex_state = 5},
  [933] = {.lex_state = 14, .external_lex_state = 5},
  [934] = {.lex_state = 15, .external_lex_state = 5},
  [935] = {.lex_state = 14, .external_lex_state = 5},
  [936] = {.lex_state = 7, .external_lex_state = 5},
  [937] = {.lex_state = 7, .external_lex_state = 5},
  [938] = {.lex_state = 14, .external_lex_state = 5},
  [939] = {.lex_state = 7, .external_lex_state = 5},
  [940] = {.lex_state = 7, .external_lex_state = 5},
  [941] = {.lex_state = 14, .external_lex_state = 5},
  [942] = {.lex_state = 15, .external_lex_state = 5},
  [943] = {.lex_state = 15, .external_lex_state = 5},
  [944] = {.lex_state = 14, .external_lex_state = 5},
  [945] = {.lex_state = 0, .external_lex_state = 5},
  [946] = {.lex_state = 0, .external_lex_state = 5},
  [947] = {.lex_state = 14, .external_lex_state = 5},
  [948] = {.lex_state = 14, .external_lex_state = 5},
  [949] = {.lex_state = 15, .external_lex_state = 5},
  [950] = {.lex_state = 14, .external_lex_state = 5},
  [951] = {.lex_state = 14, .external_lex_state = 5},
  [952] = {.lex_state = 7, .external_lex_state = 5},
  [953] = {.lex_state = 14, .external_lex_state = 5},
  [954] = {.lex_state = 7, .external_lex_state = 5},
  [955] = {.lex_state = 14, .external_lex_state = 5},
  [956] = {.lex_state = 0, .external_lex_state = 5},
  [957] = {.lex_state = 7, .external_lex_state = 5},
  [958] = {.lex_state = 14, .external_lex_state = 5},
  [959] = {.lex_state = 0, .external_lex_state = 5},
  [960] = {.lex_state = 0, .external_lex_state = 5},
  [961] = {.lex_state = 15, .external_lex_state = 5},
  [962] = {.lex_state = 15, .external_lex_state = 5},
  [963] = {.lex_state = 15, .external_lex_state = 5},
  [964] = {.lex_state = 15, .external_lex_state = 5},
  [965] = {.lex_state = 14, .external_lex_state = 5},
  [966] = {.lex_state = 14, .external_lex_state = 5},
  [967] = {.lex_state = 7, .external_lex_state = 5},
  [968] = {.lex_state = 14, .external_lex_state = 5},
  [969] = {.lex_state = 14, .external_lex_state = 5},
  [970] = {.lex_state = 14, .external_lex_state = 5},
  [971] = {.lex_state = 14, .external_lex_state = 5},
  [972] = {.lex_state = 0, .external_lex_state = 5},
  [973] = {.lex_state = 15, .external_lex_state = 5},
  [974] = {.lex_state = 14, .external_lex_state = 5},
  [975] = {.lex_state = 14, .external_lex_state = 5},
  [976] = {.lex_state = 7, .external_lex_state = 5},
  [977] = {.lex_state = 14, .external_lex_state = 5},
  [978] = {.lex_state = 14, .external_lex_state = 5},
  [979] = {.lex_state = 0, .external_lex_state = 5},
  [980] = {.lex_state = 15, .external_lex_state = 5},
  [981] = {.lex_state = 15, .external_lex_state = 5},
  [982] = {.lex_state = 15, .external_lex_state = 5},
  [983] = {.lex_state = 15, .external_lex_state = 5},
  [984] = {.lex_state = 0, .external_lex_state = 5},
  [985] = {.lex_state = 14, .external_lex_state = 5},
  [986] = {.lex_state = 14, .external_lex_state = 5},
  [987] = {.lex_state = 0, .external_lex_state = 5},
  [988] = {.lex_state = 14, .external_lex_state = 5},
  [989] = {.lex_state = 14, .external_lex_state = 5},
  [990] = {.lex_state = 14, .external_lex_state = 5},
  [991] = {.lex_state = 0, .external_lex_state = 5},
  [992] = {.lex_state = 0, .external_lex_state = 5},
  [993] = {.lex_state = 0, .external_lex_state = 5},
  [994] = {.lex_state = 0, .external_lex_state = 5},
  [995] = {.lex_state = 15, .external_lex_state = 5},
  [996] = {.lex_state = 7, .external_lex_state = 5},
  [997] = {.lex_state = 7, .external_lex_state = 5},
  [998] = {.lex_state = 14, .external_lex_state = 5},
  [999] = {.lex_state = 14, .external_lex_state = 5},
  [1000] = {.lex_state = 7, .external_lex_state = 5},
  [1001] = {.lex_state = 7, .external_lex_state = 5},
  [1002] = {.lex_state = 0, .external_lex_state = 5},
  [1003] = {.lex_state = 15, .external_lex_state = 5},
  [1004] = {.lex_state = 0, .external_lex_state = 5},
  [1005] = {.lex_state = 0, .external_lex_state = 5},
  [1006] = {.lex_state = 15, .external_lex_state = 5},
  [1007] = {.lex_state = 15, .external_lex_state = 5},
  [1008] = {.lex_state = 0, .external_lex_state = 5},
  [1009] = {.lex_state = 15, .external_lex_state = 5},
  [1010] = {.lex_state = 15, .external_lex_state = 5},
  [1011] = {.lex_state = 0, .external_lex_state = 5},
  [1012] = {.lex_state = 0, .external_lex_state = 5},
  [1013] = {.lex_state = 0, .external_lex_state = 5},
  [1014] = {.lex_state = 0, .external_lex_state = 5},
  [1015] = {.lex_state = 15, .external_lex_state = 5},
  [1016] = {.lex_state = 15, .external_lex_state = 5},
  [1017] = {.lex_state = 0, .external_lex_state = 5},
  [1018] = {.lex_state = 0, .external_lex_state = 5},
  [1019] = {.lex_state = 15, .external_lex_state = 5},
  [1020] = {.lex_state = 0, .external_lex_state = 5},
  [1021] = {.lex_state = 0, .external_lex_state = 5},
  [1022] = {.lex_state = 0, .external_lex_state = 5},
  [1023] = {.lex_state = 0, .external_lex_state = 5},
  [1024] = {.lex_state = 0, .external_lex_state = 5},
  [1025] = {.lex_state = 0, .external_lex_state = 5},
  [1026] = {.lex_state = 0, .external_lex_state = 5},
  [1027] = {.lex_state = 0, .external_lex_state = 5},
  [1028] = {.lex_state = 0, .external_lex_state = 5},
  [1029] = {.lex_state = 15, .external_lex_state = 5},
  [1030] = {.lex_state = 0, .external_lex_state = 5},
  [1031] = {.lex_state = 0, .external_lex_state = 5},
  [1032] = {.lex_state = 0, .external_lex_state = 5},
  [1033] = {.lex_state = 0, .external_lex_state = 5},
  [1034] = {.lex_state = 0, .external_lex_state = 5},
  [1035] = {.lex_state = 0, .external_lex_state = 5},
  [1036] = {.lex_state = 15, .external_lex_state = 5},
  [1037] = {.lex_state = 0, .external_lex_state = 5},
  [1038] = {.lex_state = 0, .external_lex_state = 5},
  [1039] = {.lex_state = 0, .external_lex_state = 5},
  [1040] = {.lex_state = 0, .external_lex_state = 5},
  [1041] = {.lex_state = 0, .external_lex_state = 5},
  [1042] = {.lex_state = 0, .external_lex_state = 5},
  [1043] = {.lex_state = 0, .external_lex_state = 5},
  [1044] = {.lex_state = 15, .external_lex_state = 5},
  [1045] = {.lex_state = 15, .external_lex_state = 5},
  [1046] = {.lex_state = 0, .external_lex_state = 5},
  [1047] = {.lex_state = 0, .external_lex_state = 5},
  [1048] = {.lex_state = 15, .external_lex_state = 5},
  [1049] = {.lex_state = 15, .external_lex_state = 5},
  [1050] = {.lex_state = 0, .external_lex_state = 5},
  [1051] = {.lex_state = 0, .external_lex_state = 5},
  [1052] = {.lex_state = 0, .external_lex_state = 5},
  [1053] = {.lex_state = 15, .external_lex_state = 5},
  [1054] = {.lex_state = 0, .external_lex_state = 5},
  [1055] = {.lex_state = 15, .external_lex_state = 5},
  [1056] = {.lex_state = 0, .external_lex_state = 5},
  [1057] = {.lex_state = 0, .external_lex_state = 5},
  [1058] = {.lex_state = 15, .external_lex_state = 5},
  [1059] = {.lex_state = 15, .external_lex_state = 5},
  [1060] = {.lex_state = 0, .external_lex_state = 5},
  [1061] = {.lex_state = 15, .external_lex_state = 5},
  [1062] = {.lex_state = 15, .external_lex_state = 5},
  [1063] = {.lex_state = 15, .external_lex_state = 5},
  [1064] = {.lex_state = 15, .external_lex_state = 5},
  [1065] = {.lex_state = 15, .external_lex_state = 5},
  [1066] = {.lex_state = 15, .external_lex_state = 5},
  [1067] = {.lex_state = 15, .external_lex_state = 5},
  [1068] = {.lex_state = 15, .external_lex_state = 5},
  [1069] = {.lex_state = 15, .external_lex_state = 5},
  [1070] = {.lex_state = 15, .external_lex_state = 5},
  [1071] = {.lex_state = 15, .external_lex_state = 5},
  [1072] = {.lex_state = 15, .external_lex_state = 5},
  [1073] = {.lex_state = 15, .external_lex_state = 5},
  [1074] = {.lex_state = 15, .external_lex_state = 5},
  [1075] = {.lex_state = 15, .external_lex_state = 5},
  [1076] = {.lex_state = 15, .external_lex_state = 5},
  [1077] = {.lex_state = 0, .external_lex_state = 5},
  [1078] = {.lex_state = 15, .external_lex_state = 5},
  [1079] = {.lex_state = 15, .external_lex_state = 5},
  [1080] = {.lex_state = 15, .external_lex_state = 5},
  [1081] = {.lex_state = 15, .external_lex_state = 5},
  [1082] = {.lex_state = 15, .external_lex_state = 5},
  [1083] = {.lex_state = 0, .external_lex_state = 5},
  [1084] = {.lex_state = 0, .external_lex_state = 5},
  [1085] = {.lex_state = 15, .external_lex_state = 5},
  [1086] = {.lex_state = 15, .external_lex_state = 5},
  [1087] = {.lex_state = 15, .external_lex_state = 5},
  [1088] = {.lex_state = 15, .external_lex_state = 5},
  [1089] = {.lex_state = 0, .external_lex_state = 5},
  [1090] = {.lex_state = 15, .external_lex_state = 5},
  [1091] = {.lex_state = 15, .external_lex_state = 5},
  [1092] = {.lex_state = 15, .external_lex_state = 5},
  [1093] = {.lex_state = 15, .external_lex_state = 5},
  [1094] = {.lex_state = 15, .external_lex_state = 5},
  [1095] = {.lex_state = 15, .external_lex_state = 5},
  [1096] = {.lex_state = 15, .external_lex_state = 5},
  [1097] = {.lex_state = 0, .external_lex_state = 5},
  [1098] = {.lex_state = 15, .external_lex_state = 5},
  [1099] = {.lex_state = 15, .external_lex_state = 5},
  [1100] = {.lex_state = 15, .external_lex_state = 5},
  [1101] = {.lex_state = 15, .external_lex_state = 5},
  [1102] = {.lex_state = 15, .external_lex_state = 5},
  [1103] = {.lex_state = 15, .external_lex_state = 5},
  [1104] = {.lex_state = 15, .external_lex_state = 5},
  [1105] = {.lex_state = 15, .external_lex_state = 5},
  [1106] = {.lex_state = 15, .external_lex_state = 5},
  [1107] = {.lex_state = 15, .external_lex_state = 5},
  [1108] = {.lex_state = 15, .external_lex_state = 5},
  [1109] = {.lex_state = 15, .external_lex_state = 5},
  [1110] = {.lex_state = 15, .external_lex_state = 5},
  [1111] = {.lex_state = 15, .external_lex_state = 5},
  [1112] = {.lex_state = 15, .external_lex_state = 5},
  [1113] = {.lex_state = 15, .external_lex_state = 5},
  [1114] = {.lex_state = 15, .external_lex_state = 5},
  [1115] = {.lex_state = 15, .external_lex_state = 5},
  [1116] = {.lex_state = 15, .external_lex_state = 5},
  [1117] = {.lex_state = 15, .external_lex_state = 5},
  [1118] = {.lex_state = 15, .external_lex_state = 5},
  [1119] = {.lex_state = 0, .external_lex_state = 5},
  [1120] = {.lex_state = 15, .external_lex_state = 5},
  [1121] = {.lex_state = 15, .external_lex_state = 5},
  [1122] = {.lex_state = 15, .external_lex_state = 5},
  [1123] = {.lex_state = 15, .external_lex_state = 5},
  [1124] = {.lex_state = 15, .external_lex_state = 5},
  [1125] = {.lex_state = 15, .external_lex_state = 5},
  [1126] = {.lex_state = 15, .external_lex_state = 5},
  [1127] = {.lex_state = 15, .external_lex_state = 5},
  [1128] = {.lex_state = 15, .external_lex_state = 5},
  [1129] = {.lex_state = 15, .external_lex_state = 5},
  [1130] = {.lex_state = 15, .external_lex_state = 5},
  [1131] = {.lex_state = 15, .external_lex_state = 5},
  [1132] = {.lex_state = 15, .external_lex_state = 5},
  [1133] = {.lex_state = 15, .external_lex_state = 5},
  [1134] = {.lex_state = 0, .external_lex_state = 5},
  [1135] = {.lex_state = 0, .external_lex_state = 5},
  [1136] = {.lex_state = 0, .external_lex_state = 5},
  [1137] = {.lex_state = 0, .external_lex_state = 5},
  [1138] = {.lex_state = 15, .external_lex_state = 5},
  [1139] = {.lex_state = 0, .external_lex_state = 5},
  [1140] = {.lex_state = 15, .external_lex_state = 5},
  [1141] = {.lex_state = 0, .external_lex_state = 5},
  [1142] = {.lex_state = 15, .external_lex_state = 5},
  [1143] = {.lex_state = 15, .external_lex_state = 5},
  [1144] = {.lex_state = 15, .external_lex_state = 5},
  [1145] = {.lex_state = 15, .external_lex_state = 5},
  [1146] = {.lex_state = 0, .external_lex_state = 5},
  [1147] = {.lex_state = 0, .external_lex_state = 5},
  [1148] = {.lex_state = 15, .external_lex_state = 5},
  [1149] = {.lex_state = 0, .external_lex_state = 5},
  [1150] = {.lex_state = 0, .external_lex_state = 5},
  [1151] = {.lex_state = 0, .external_lex_state = 5},
  [1152] = {.lex_state = 15, .external_lex_state = 5},
  [1153] = {.lex_state = 15, .external_lex_state = 5},
  [1154] = {.lex_state = 15, .external_lex_state = 5},
  [1155] = {.lex_state = 0, .external_lex_state = 5},
  [1156] = {.lex_state = 0, .external_lex_state = 5},
  [1157] = {.lex_state = 15, .external_lex_state = 5},
  [1158] = {.lex_state = 0, .external_lex_state = 5},
  [1159] = {.lex_state = 0, .external_lex_state = 5},
  [1160] = {.lex_state = 15, .external_lex_state = 5},
  [1161] = {.lex_state = 0, .external_lex_state = 5},
  [1162] = {.lex_state = 15, .external_lex_state = 5},
  [1163] = {.lex_state = 15, .external_lex_state = 5},
  [1164] = {.lex_state = 15, .external_lex_state = 5},
  [1165] = {.lex_state = 15, .external_lex_state = 5},
  [1166] = {.lex_state = 0, .external_lex_state = 5},
  [1167] = {.lex_state = 15, .external_lex_state = 5},
  [1168] = {.lex_state = 0, .external_lex_state = 5},
  [1169] = {.lex_state = 0, .external_lex_state = 5},
  [1170] = {.lex_state = 15, .external_lex_state = 5},
  [1171] = {.lex_state = 0, .external_lex_state = 5},
  [1172] = {.lex_state = 15, .external_lex_state = 5},
  [1173] = {.lex_state = 15, .external_lex_state = 5},
  [1174] = {.lex_state = 15, .external_lex_state = 5},
  [1175] = {.lex_state = 15, .external_lex_state = 5},
  [1176] = {.lex_state = 15, .external_lex_state = 5},
  [1177] = {.lex_state = 15, .external_lex_state = 5},
  [1178] = {.lex_state = 15, .external_lex_state = 5},
  [1179] = {.lex_state = 0, .external_lex_state = 5},
  [1180] = {.lex_state = 0, .external_lex_state = 5},
  [1181] = {.lex_state = 0, .external_lex_state = 5},
  [1182] = {.lex_state = 0, .external_lex_state = 5},
  [1183] = {.lex_state = 15, .external_lex_state = 5},
  [1184] = {.lex_state = 15, .external_lex_state = 5},
  [1185] = {.lex_state = 0, .external_lex_state = 5},
  [1186] = {.lex_state = 15, .external_lex_state = 5},
  [1187] = {.lex_state = 0, .external_lex_state = 5},
  [1188] = {.lex_state = 15, .external_lex_state = 5},
  [1189] = {.lex_state = 0, .external_lex_state = 5},
  [1190] = {.lex_state = 0, .external_lex_state = 5},
  [1191] = {.lex_state = 15, .external_lex_state = 5},
  [1192] = {.lex_state = 15, .external_lex_state = 5},
  [1193] = {.lex_state = 15, .external_lex_state = 5},
  [1194] = {.lex_state = 0, .external_lex_state = 5},
  [1195] = {.lex_state = 0, .external_lex_state = 5},
  [1196] = {.lex_state = 0, .external_lex_state = 5},
  [1197] = {.lex_state = 0, .external_lex_state = 5},
  [1198] = {.lex_state = 0, .external_lex_state = 5},
  [1199] = {.lex_state = 15, .external_lex_state = 5},
  [1200] = {.lex_state = 0, .external_lex_state = 5},
  [1201] = {.lex_state = 0, .external_lex_state = 5},
  [1202] = {.lex_state = 0, .external_lex_state = 5},
  [1203] = {.lex_state = 15, .external_lex_state = 5},
  [1204] = {.lex_state = 15, .external_lex_state = 5},
  [1205] = {.lex_state = 15, .external_lex_state = 5},
  [1206] = {.lex_state = 0, .external_lex_state = 5},
  [1207] = {.lex_state = 15, .external_lex_state = 5},
  [1208] = {.lex_state = 0, .external_lex_state = 5},
  [1209] = {.lex_state = 0, .external_lex_state = 5},
  [1210] = {.lex_state = 15, .external_lex_state = 5},
  [1211] = {.lex_state = 15, .external_lex_state = 5},
  [1212] = {.lex_state = 15, .external_lex_state = 5},
  [1213] = {.lex_state = 0, .external_lex_state = 5},
  [1214] = {.lex_state = 15, .external_lex_state = 5},
  [1215] = {.lex_state = 15, .external_lex_state = 5},
  [1216] = {.lex_state = 15, .external_lex_state = 5},
  [1217] = {.lex_state = 15, .external_lex_state = 5},
  [1218] = {.lex_state = 15, .external_lex_state = 5},
};

static const uint16_t ts_parse_table[LARGE_STATE_COUNT][SYMBOL_COUNT] = {
  [0] = {
    [ts_builtin_sym_end] = ACTIONS(1),
    [sym_identifier] = ACTIONS(1),
    [anon_sym_SEMI] = ACTIONS(1),
    [anon_sym_COMMA] = ACTIONS(1),
    [anon_sym_LPAREN] = ACTIONS(1),
    [anon_sym_RPAREN] = ACTIONS(1),
    [anon_sym_PLUS] = ACTIONS(1),
    [anon_sym_DOT_PLUS] = ACTIONS(1),
    [anon_sym_DASH] = ACTIONS(1),
    [anon_sym_DOT_DASH] = ACTIONS(1),
    [anon_sym_STAR] = ACTIONS(1),
    [anon_sym_DOT_STAR] = ACTIONS(1),
    [anon_sym_SLASH] = ACTIONS(1),
    [anon_sym_DOT_SLASH] = ACTIONS(1),
    [anon_sym_BSLASH] = ACTIONS(1),
    [anon_sym_DOT_BSLASH] = ACTIONS(1),
    [anon_sym_CARET] = ACTIONS(1),
    [anon_sym_DOT_CARET] = ACTIONS(1),
    [anon_sym_PIPE] = ACTIONS(1),
    [anon_sym_AMP] = ACTIONS(1),
    [anon_sym_DOT] = ACTIONS(1),
    [anon_sym_TILDE] = ACTIONS(1),
    [anon_sym_QMARK] = ACTIONS(1),
    [anon_sym_AT] = ACTIONS(1),
    [anon_sym_LT] = ACTIONS(1),
    [anon_sym_LT_EQ] = ACTIONS(1),
    [anon_sym_EQ_EQ] = ACTIONS(1),
    [anon_sym_TILDE_EQ] = ACTIONS(1),
    [anon_sym_GT_EQ] = ACTIONS(1),
    [anon_sym_GT] = ACTIONS(1),
    [anon_sym_AMP_AMP] = ACTIONS(1),
    [anon_sym_PIPE_PIPE] = ACTIONS(1),
    [anon_sym_DOT_SQUOTE] = ACTIONS(1),
    [anon_sym_SQUOTE] = ACTIONS(1),
    [anon_sym_LBRACK] = ACTIONS(1),
    [anon_sym_RBRACK] = ACTIONS(1),
    [anon_sym_LBRACE] = ACTIONS(1),
    [anon_sym_RBRACE] = ACTIONS(1),
    [anon_sym_EQ] = ACTIONS(1),
    [anon_sym_COLON] = ACTIONS(1),
    [sym_return_statement] = ACTIONS(1),
    [sym_continue_statement] = ACTIONS(1),
    [sym_break_statement] = ACTIONS(1),
    [anon_sym_elseif] = ACTIONS(1),
    [anon_sym_else] = ACTIONS(1),
    [anon_sym_if] = ACTIONS(1),
    [anon_sym_end] = ACTIONS(1),
    [anon_sym_for] = ACTIONS(1),
    [anon_sym_parfor] = ACTIONS(1),
    [anon_sym_while] = ACTIONS(1),
    [anon_sym_case] = ACTIONS(1),
    [anon_sym_otherwise] = ACTIONS(1),
    [anon_sym_switch] = ACTIONS(1),
    [anon_sym_global] = ACTIONS(1),
    [anon_sym_persistent] = ACTIONS(1),
    [anon_sym_arguments] = ACTIONS(1),
    [anon_sym_function] = ACTIONS(1),
    [anon_sym_get_DOT] = ACTIONS(1),
    [anon_sym_set_DOT] = ACTIONS(1),
    [anon_sym_endfunction] = ACTIONS(1),
    [anon_sym_properties] = ACTIONS(1),
    [anon_sym_methods] = ACTIONS(1),
    [anon_sym_events] = ACTIONS(1),
    [anon_sym_enumeration] = ACTIONS(1),
    [anon_sym_classdef] = ACTIONS(1),
    [anon_sym_catch] = ACTIONS(1),
    [anon_sym_try] = ACTIONS(1),
    [sym_number] = ACTIONS(1),
    [anon_sym_true] = ACTIONS(1),
    [anon_sym_false] = ACTIONS(1),
    [sym_comment] = ACTIONS(3),
    [sym_line_continuation] = ACTIONS(3),
    [sym_command_name] = ACTIONS(1),
    [sym_command_argument] = ACTIONS(1),
    [sym__single_quote_string_start] = ACTIONS(1),
    [sym__single_quote_string_end] = ACTIONS(1),
    [sym__double_quote_string_start] = ACTIONS(1),
    [sym__double_quote_string_end] = ACTIONS(1),
    [sym_formatting_sequence] = ACTIONS(1),
    [sym_escape_sequence] = ACTIONS(1),
    [sym_string_content] = ACTIONS(1),
    [sym__entry_delimiter] = ACTIONS(1),
    [sym__multioutput_variable_start] = ACTIONS(1),
    [sym_error_sentinel] = ACTIONS(1),
  },
  [1] = {
    [sym_source_file] = STATE(1190),
    [aux_sym__block] = STATE(71),
    [sym__statement] = STATE(817),
    [sym__expression] = STATE(630),
    [sym_parenthesis] = STATE(411),
    [sym__binary_expression] = STATE(622),
    [sym_binary_operator] = STATE(422),
    [sym_unary_operator] = STATE(389),
    [sym_indirect_access] = STATE(994),
    [sym_field_expression] = STATE(485),
    [sym_not_operator] = STATE(477),
    [sym_metaclass_operator] = STATE(630),
    [sym_handle_operator] = STATE(630),
    [sym_comparison_operator] = STATE(446),
    [sym_boolean_operator] = STATE(446),
    [sym_postfix_operator] = STATE(411),
    [sym_string] = STATE(411),
    [sym_matrix] = STATE(411),
    [sym_cell] = STATE(423),
    [sym_ignored_argument] = STATE(1187),
    [sym_assignment] = STATE(817),
    [sym_multioutput_variable] = STATE(1187),
    [sym_function_call] = STATE(210),
    [sym_command] = STATE(817),
    [sym__range_element] = STATE(1181),
    [sym_range] = STATE(630),
    [sym_if_statement] = STATE(817),
    [sym_for_statement] = STATE(817),
    [sym_while_statement] = STATE(817),
    [sym_switch_statement] = STATE(817),
    [sym_lambda] = STATE(630),
    [sym_global_operator] = STATE(817),
    [sym_persistent_operator] = STATE(817),
    [sym_function_definition] = STATE(982),
    [sym__function_definition_with_end] = STATE(860),
    [sym_class_definition] = STATE(817),
    [sym_try_statement] = STATE(817),
    [sym_boolean] = STATE(205),
    [aux_sym_source_file_repeat1] = STATE(982),
    [ts_builtin_sym_end] = ACTIONS(5),
    [sym_identifier] = ACTIONS(7),
    [anon_sym_LPAREN] = ACTIONS(9),
    [anon_sym_PLUS] = ACTIONS(11),
    [anon_sym_DASH] = ACTIONS(11),
    [anon_sym_TILDE] = ACTIONS(13),
    [anon_sym_QMARK] = ACTIONS(15),
    [anon_sym_AT] = ACTIONS(17),
    [anon_sym_LBRACK] = ACTIONS(19),
    [anon_sym_LBRACE] = ACTIONS(21),
    [sym_return_statement] = ACTIONS(23),
    [sym_continue_statement] = ACTIONS(23),
    [sym_break_statement] = ACTIONS(23),
    [anon_sym_if] = ACTIONS(25),
    [anon_sym_for] = ACTIONS(27),
    [anon_sym_parfor] = ACTIONS(29),
    [anon_sym_while] = ACTIONS(31),
    [anon_sym_switch] = ACTIONS(33),
    [anon_sym_global] = ACTIONS(35),
    [anon_sym_persistent] = ACTIONS(37),
    [anon_sym_function] = ACTIONS(39),
    [anon_sym_classdef] = ACTIONS(41),
    [anon_sym_try] = ACTIONS(43),
    [sym_number] = ACTIONS(45),
    [anon_sym_true] = ACTIONS(47),
    [anon_sym_false] = ACTIONS(47),
    [sym_comment] = ACTIONS(3),
    [sym_line_continuation] = ACTIONS(3),
    [sym_command_name] = ACTIONS(49),
    [sym__single_quote_string_start] = ACTIONS(51),
    [sym__double_quote_string_start] = ACTIONS(53),
    [sym__multioutput_variable_start] = ACTIONS(55),
  },
  [2] = {
    [aux_sym__block] = STATE(54),
    [sym_block] = STATE(800),
    [sym__statement] = STATE(874),
    [sym__expression] = STATE(627),
    [sym_parenthesis] = STATE(411),
    [sym__binary_expression] = STATE(622),
    [sym_binary_operator] = STATE(422),
    [sym_unary_operator] = STATE(389),
    [sym_indirect_access] = STATE(994),
    [sym_field_expression] = STATE(485),
    [sym_not_operator] = STATE(477),
    [sym_metaclass_operator] = STATE(627),
    [sym_handle_operator] = STATE(627),
    [sym_comparison_operator] = STATE(446),
    [sym_boolean_operator] = STATE(446),
    [sym_postfix_operator] = STATE(411),
    [sym_string] = STATE(411),
    [sym_matrix] = STATE(411),
    [sym_cell] = STATE(423),
    [sym_ignored_argument] = STATE(1187),
    [sym_assignment] = STATE(874),
    [sym_multioutput_variable] = STATE(1187),
    [sym_function_call] = STATE(210),
    [sym_command] = STATE(874),
    [sym__range_element] = STATE(1181),
    [sym_range] = STATE(627),
    [sym_elseif_clause] = STATE(744),
    [sym_else_clause] = STATE(1210),
    [sym_if_statement] = STATE(874),
    [sym_for_statement] = STATE(874),
    [sym_while_statement] = STATE(874),
    [sym_switch_statement] = STATE(874),
    [sym_lambda] = STATE(627),
    [sym_global_operator] = STATE(874),
    [sym_persistent_operator] = STATE(874),
    [sym__function_definition_with_end] = STATE(877),
    [sym_class_definition] = STATE(874),
    [sym_try_statement] = STATE(874),
    [sym_boolean] = STATE(205),
    [sym__end_of_line] = STATE(5),
    [aux_sym_elseif_clause_repeat1] = STATE(5),
    [aux_sym_if_statement_repeat1] = STATE(744),
    [sym_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(57),
    [anon_sym_COMMA] = ACTIONS(57),
    [anon_sym_LPAREN] = ACTIONS(59),
    [anon_sym_PLUS] = ACTIONS(61),
    [anon_sym_DASH] = ACTIONS(61),
    [anon_sym_TILDE] = ACTIONS(63),
    [anon_sym_QMARK] = ACTIONS(65),
    [anon_sym_AT] = ACTIONS(67),
    [anon_sym_LT] = ACTIONS(69),
    [anon_sym_LT_EQ] = ACTIONS(69),
    [anon_sym_EQ_EQ] = ACTIONS(69),
    [anon_sym_TILDE_EQ] = ACTIONS(69),
    [anon_sym_GT_EQ] = ACTIONS(69),
    [anon_sym_GT] = ACTIONS(69),
    [anon_sym_AMP_AMP] = ACTIONS(71),
    [anon_sym_PIPE_PIPE] = ACTIONS(73),
    [anon_sym_LBRACK] = ACTIONS(75),
    [anon_sym_LBRACE] = ACTIONS(77),
    [sym_return_statement] = ACTIONS(79),
    [sym_continue_statement] = ACTIONS(79),
    [sym_break_statement] = ACTIONS(79),
    [anon_sym_elseif] = ACTIONS(81),
    [anon_sym_else] = ACTIONS(83),
    [anon_sym_if] = ACTIONS(25),
    [anon_sym_end] = ACTIONS(85),
    [anon_sym_for] = ACTIONS(27),
    [anon_sym_parfor] = ACTIONS(29),
    [anon_sym_while] = ACTIONS(31),
    [anon_sym_switch] = ACTIONS(33),
    [anon_sym_global] = ACTIONS(35),
    [anon_sym_persistent] = ACTIONS(37),
    [anon_sym_function] = ACTIONS(87),
    [anon_sym_classdef] = ACTIONS(41),
    [anon_sym_try] = ACTIONS(43),
    [sym_number] = ACTIONS(89),
    [anon_sym_true] = ACTIONS(47),
    [anon_sym_false] = ACTIONS(47),
    [anon_sym_LF] = ACTIONS(57),
    [anon_sym_CR] = ACTIONS(57),
    [sym_comment] = ACTIONS(3),
    [sym_line_continuation] = ACTIONS(3),
    [sym_command_name] = ACTIONS(49),
    [sym__single_quote_string_start] = ACTIONS(51),
    [sym__double_quote_string_start] = ACTIONS(53),
    [sym__multioutput_variable_start] = ACTIONS(55),
  },
  [3] = {
    [aux_sym__block] = STATE(54),
    [sym_block] = STATE(1053),
    [sym__statement] = STATE(874),
    [sym__expression] = STATE(627),
    [sym_parenthesis] = STATE(411),
    [sym__binary_expression] = STATE(622),
    [sym_binary_operator] = STATE(422),
    [sym_unary_operator] = STATE(389),
    [sym_indirect_access] = STATE(994),
    [sym_field_expression] = STATE(485),
    [sym_not_operator] = STATE(477),
    [sym_metaclass_operator] = STATE(627),
    [sym_handle_operator] = STATE(627),
    [sym_comparison_operator] = STATE(446),
    [sym_boolean_operator] = STATE(446),
    [sym_postfix_operator] = STATE(411),
    [sym_string] = STATE(411),
    [sym_matrix] = STATE(411),
    [sym_cell] = STATE(423),
    [sym_ignored_argument] = STATE(1187),
    [sym_assignment] = STATE(874),
    [sym_multioutput_variable] = STATE(1187),
    [sym_function_call] = STATE(210),
    [sym_command] = STATE(874),
    [sym__range_element] = STATE(1181),
    [sym_range] = STATE(627),
    [sym_if_statement] = STATE(874),
    [sym_for_statement] = STATE(874),
    [sym_while_statement] = STATE(874),
    [sym_switch_statement] = STATE(874),
    [sym_lambda] = STATE(627),
    [sym_global_operator] = STATE(874),
    [sym_persistent_operator] = STATE(874),
    [sym__function_definition_with_end] = STATE(877),
    [sym_class_definition] = STATE(874),
    [sym_try_statement] = STATE(874),
    [sym_boolean] = STATE(205),
    [sym__end_of_line] = STATE(9),
    [aux_sym_elseif_clause_repeat1] = STATE(9),
    [sym_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(91),
    [anon_sym_COMMA] = ACTIONS(91),
    [anon_sym_LPAREN] = ACTIONS(59),
    [anon_sym_PLUS] = ACTIONS(61),
    [anon_sym_DASH] = ACTIONS(61),
    [anon_sym_TILDE] = ACTIONS(63),
    [anon_sym_QMARK] = ACTIONS(65),
    [anon_sym_AT] = ACTIONS(67),
    [anon_sym_LT] = ACTIONS(69),
    [anon_sym_LT_EQ] = ACTIONS(69),
    [anon_sym_EQ_EQ] = ACTIONS(69),
    [anon_sym_TILDE_EQ] = ACTIONS(69),
    [anon_sym_GT_EQ] = ACTIONS(69),
    [anon_sym_GT] = ACTIONS(69),
    [anon_sym_AMP_AMP] = ACTIONS(71),
    [anon_sym_PIPE_PIPE] = ACTIONS(73),
    [anon_sym_LBRACK] = ACTIONS(75),
    [anon_sym_LBRACE] = ACTIONS(77),
    [sym_return_statement] = ACTIONS(79),
    [sym_continue_statement] = ACTIONS(79),
    [sym_break_statement] = ACTIONS(79),
    [anon_sym_elseif] = ACTIONS(93),
    [anon_sym_else] = ACTIONS(93),
    [anon_sym_if] = ACTIONS(25),
    [anon_sym_end] = ACTIONS(93),
    [anon_sym_for] = ACTIONS(27),
    [anon_sym_parfor] = ACTIONS(29),
    [anon_sym_while] = ACTIONS(31),
    [anon_sym_switch] = ACTIONS(33),
    [anon_sym_global] = ACTIONS(35),
    [anon_sym_persistent] = ACTIONS(37),
    [anon_sym_function] = ACTIONS(87),
    [anon_sym_classdef] = ACTIONS(41),
    [anon_sym_try] = ACTIONS(43),
    [sym_number] = ACTIONS(89),
    [anon_sym_true] = ACTIONS(47),
    [anon_sym_false] = ACTIONS(47),
    [anon_sym_LF] = ACTIONS(91),
    [anon_sym_CR] = ACTIONS(91),
    [sym_comment] = ACTIONS(3),
    [sym_line_continuation] = ACTIONS(3),
    [sym_command_name] = ACTIONS(49),
    [sym__single_quote_string_start] = ACTIONS(51),
    [sym__double_quote_string_start] = ACTIONS(53),
    [sym__multioutput_variable_start] = ACTIONS(55),
  },
  [4] = {
    [aux_sym__block] = STATE(54),
    [sym_block] = STATE(1218),
    [sym__statement] = STATE(874),
    [sym__expression] = STATE(627),
    [sym_parenthesis] = STATE(411),
    [sym__binary_expression] = STATE(622),
    [sym_binary_operator] = STATE(422),
    [sym_unary_operator] = STATE(389),
    [sym_indirect_access] = STATE(994),
    [sym_field_expression] = STATE(485),
    [sym_not_operator] = STATE(477),
    [sym_metaclass_operator] = STATE(627),
    [sym_handle_operator] = STATE(627),
    [sym_comparison_operator] = STATE(446),
    [sym_boolean_operator] = STATE(446),
    [sym_postfix_operator] = STATE(411),
    [sym_string] = STATE(411),
    [sym_matrix] = STATE(411),
    [sym_cell] = STATE(423),
    [sym_ignored_argument] = STATE(1187),
    [sym_assignment] = STATE(874),
    [sym_multioutput_variable] = STATE(1187),
    [sym_function_call] = STATE(210),
    [sym_command] = STATE(874),
    [sym__range_element] = STATE(1181),
    [sym_range] = STATE(627),
    [sym_if_statement] = STATE(874),
    [sym_for_statement] = STATE(874),
    [sym_while_statement] = STATE(874),
    [sym_switch_statement] = STATE(874),
    [sym_lambda] = STATE(627),
    [sym_global_operator] = STATE(874),
    [sym_persistent_operator] = STATE(874),
    [sym__function_definition_with_end] = STATE(877),
    [sym_class_definition] = STATE(874),
    [sym_try_statement] = STATE(874),
    [sym_boolean] = STATE(205),
    [sym__end_of_line] = STATE(17),
    [aux_sym_elseif_clause_repeat1] = STATE(17),
    [sym_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(95),
    [anon_sym_COMMA] = ACTIONS(95),
    [anon_sym_LPAREN] = ACTIONS(59),
    [anon_sym_PLUS] = ACTIONS(61),
    [anon_sym_DASH] = ACTIONS(61),
    [anon_sym_TILDE] = ACTIONS(63),
    [anon_sym_QMARK] = ACTIONS(65),
    [anon_sym_AT] = ACTIONS(67),
    [anon_sym_LT] = ACTIONS(69),
    [anon_sym_LT_EQ] = ACTIONS(69),
    [anon_sym_EQ_EQ] = ACTIONS(69),
    [anon_sym_TILDE_EQ] = ACTIONS(69),
    [anon_sym_GT_EQ] = ACTIONS(69),
    [anon_sym_GT] = ACTIONS(69),
    [anon_sym_AMP_AMP] = ACTIONS(71),
    [anon_sym_PIPE_PIPE] = ACTIONS(73),
    [anon_sym_LBRACK] = ACTIONS(75),
    [anon_sym_LBRACE] = ACTIONS(77),
    [sym_return_statement] = ACTIONS(79),
    [sym_continue_statement] = ACTIONS(79),
    [sym_break_statement] = ACTIONS(79),
    [anon_sym_if] = ACTIONS(25),
    [anon_sym_end] = ACTIONS(97),
    [anon_sym_for] = ACTIONS(27),
    [anon_sym_parfor] = ACTIONS(29),
    [anon_sym_while] = ACTIONS(31),
    [anon_sym_switch] = ACTIONS(33),
    [anon_sym_global] = ACTIONS(35),
    [anon_sym_persistent] = ACTIONS(37),
    [anon_sym_function] = ACTIONS(87),
    [anon_sym_classdef] = ACTIONS(41),
    [anon_sym_try] = ACTIONS(43),
    [sym_number] = ACTIONS(89),
    [anon_sym_true] = ACTIONS(47),
    [anon_sym_false] = ACTIONS(47),
    [anon_sym_LF] = ACTIONS(95),
    [anon_sym_CR] = ACTIONS(95),
    [sym_comment] = ACTIONS(3),
    [sym_line_continuation] = ACTIONS(3),
    [sym_command_name] = ACTIONS(49),
    [sym__single_quote_string_start] = ACTIONS(51),
    [sym__double_quote_string_start] = ACTIONS(53),
    [sym__multioutput_variable_start] = ACTIONS(55),
  },
  [5] = {
    [aux_sym__block] = STATE(54),
    [sym_block] = STATE(784),
    [sym__statement] = STATE(874),
    [sym__expression] = STATE(627),
    [sym_parenthesis] = STATE(411),
    [sym__binary_expression] = STATE(622),
    [sym_binary_operator] = STATE(422),
    [sym_unary_operator] = STATE(389),
    [sym_indirect_access] = STATE(994),
    [sym_field_expression] = STATE(485),
    [sym_not_operator] = STATE(477),
    [sym_metaclass_operator] = STATE(627),
    [sym_handle_operator] = STATE(627),
    [sym_comparison_operator] = STATE(446),
    [sym_boolean_operator] = STATE(446),
    [sym_postfix_operator] = STATE(411),
    [sym_string] = STATE(411),
    [sym_matrix] = STATE(411),
    [sym_cell] = STATE(423),
    [sym_ignored_argument] = STATE(1187),
    [sym_assignment] = STATE(874),
    [sym_multioutput_variable] = STATE(1187),
    [sym_function_call] = STATE(210),
    [sym_command] = STATE(874),
    [sym__range_element] = STATE(1181),
    [sym_range] = STATE(627),
    [sym_elseif_clause] = STATE(775),
    [sym_else_clause] = STATE(1153),
    [sym_if_statement] = STATE(874),
    [sym_for_statement] = STATE(874),
    [sym_while_statement] = STATE(874),
    [sym_switch_statement] = STATE(874),
    [sym_lambda] = STATE(627),
    [sym_global_operator] = STATE(874),
    [sym_persistent_operator] = STATE(874),
    [sym__function_definition_with_end] = STATE(877),
    [sym_class_definition] = STATE(874),
    [sym_try_statement] = STATE(874),
    [sym_boolean] = STATE(205),
    [sym__end_of_line] = STATE(158),
    [aux_sym_elseif_clause_repeat1] = STATE(158),
    [aux_sym_if_statement_repeat1] = STATE(775),
    [sym_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(99),
    [anon_sym_COMMA] = ACTIONS(99),
    [anon_sym_LPAREN] = ACTIONS(59),
    [anon_sym_PLUS] = ACTIONS(61),
    [anon_sym_DASH] = ACTIONS(61),
    [anon_sym_TILDE] = ACTIONS(63),
    [anon_sym_QMARK] = ACTIONS(65),
    [anon_sym_AT] = ACTIONS(67),
    [anon_sym_LBRACK] = ACTIONS(75),
    [anon_sym_LBRACE] = ACTIONS(77),
    [sym_return_statement] = ACTIONS(79),
    [sym_continue_statement] = ACTIONS(79),
    [sym_break_statement] = ACTIONS(79),
    [anon_sym_elseif] = ACTIONS(81),
    [anon_sym_else] = ACTIONS(83),
    [anon_sym_if] = ACTIONS(25),
    [anon_sym_end] = ACTIONS(101),
    [anon_sym_for] = ACTIONS(27),
    [anon_sym_parfor] = ACTIONS(29),
    [anon_sym_while] = ACTIONS(31),
    [anon_sym_switch] = ACTIONS(33),
    [anon_sym_global] = ACTIONS(35),
    [anon_sym_persistent] = ACTIONS(37),
    [anon_sym_function] = ACTIONS(87),
    [anon_sym_classdef] = ACTIONS(41),
    [anon_sym_try] = ACTIONS(43),
    [sym_number] = ACTIONS(89),
    [anon_sym_true] = ACTIONS(47),
    [anon_sym_false] = ACTIONS(47),
    [anon_sym_LF] = ACTIONS(99),
    [anon_sym_CR] = ACTIONS(99),
    [sym_comment] = ACTIONS(3),
    [sym_line_continuation] = ACTIONS(3),
    [sym_command_name] = ACTIONS(49),
    [sym__single_quote_string_start] = ACTIONS(51),
    [sym__double_quote_string_start] = ACTIONS(53),
    [sym__multioutput_variable_start] = ACTIONS(55),
  },
  [6] = {
    [aux_sym__block] = STATE(54),
    [sym_block] = STATE(1049),
    [sym__statement] = STATE(874),
    [sym__expression] = STATE(627),
    [sym_parenthesis] = STATE(411),
    [sym__binary_expression] = STATE(622),
    [sym_binary_operator] = STATE(422),
    [sym_unary_operator] = STATE(389),
    [sym_indirect_access] = STATE(994),
    [sym_field_expression] = STATE(485),
    [sym_not_operator] = STATE(477),
    [sym_metaclass_operator] = STATE(627),
    [sym_handle_operator] = STATE(627),
    [sym_comparison_operator] = STATE(446),
    [sym_boolean_operator] = STATE(446),
    [sym_postfix_operator] = STATE(411),
    [sym_string] = STATE(411),
    [sym_matrix] = STATE(411),
    [sym_cell] = STATE(423),
    [sym_ignored_argument] = STATE(1187),
    [sym_assignment] = STATE(874),
    [sym_multioutput_variable] = STATE(1187),
    [sym_function_call] = STATE(210),
    [sym_command] = STATE(874),
    [sym__range_element] = STATE(1181),
    [sym_range] = STATE(627),
    [sym_if_statement] = STATE(874),
    [sym_for_statement] = STATE(874),
    [sym_while_statement] = STATE(874),
    [sym_switch_statement] = STATE(874),
    [sym_lambda] = STATE(627),
    [sym_global_operator] = STATE(874),
    [sym_persistent_operator] = STATE(874),
    [sym__function_definition_with_end] = STATE(877),
    [sym_class_definition] = STATE(874),
    [sym_catch_clause] = STATE(1174),
    [sym_try_statement] = STATE(874),
    [sym_boolean] = STATE(205),
    [sym__end_of_line] = STATE(8),
    [aux_sym_elseif_clause_repeat1] = STATE(8),
    [sym_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(103),
    [anon_sym_COMMA] = ACTIONS(103),
    [anon_sym_LPAREN] = ACTIONS(59),
    [anon_sym_PLUS] = ACTIONS(61),
    [anon_sym_DASH] = ACTIONS(61),
    [anon_sym_TILDE] = ACTIONS(63),
    [anon_sym_QMARK] = ACTIONS(65),
    [anon_sym_AT] = ACTIONS(67),
    [anon_sym_LBRACK] = ACTIONS(75),
    [anon_sym_LBRACE] = ACTIONS(77),
    [sym_return_statement] = ACTIONS(79),
    [sym_continue_statement] = ACTIONS(79),
    [sym_break_statement] = ACTIONS(79),
    [anon_sym_if] = ACTIONS(25),
    [anon_sym_end] = ACTIONS(105),
    [anon_sym_for] = ACTIONS(27),
    [anon_sym_parfor] = ACTIONS(29),
    [anon_sym_while] = ACTIONS(31),
    [anon_sym_switch] = ACTIONS(33),
    [anon_sym_global] = ACTIONS(35),
    [anon_sym_persistent] = ACTIONS(37),
    [anon_sym_function] = ACTIONS(87),
    [anon_sym_classdef] = ACTIONS(41),
    [anon_sym_catch] = ACTIONS(107),
    [anon_sym_try] = ACTIONS(43),
    [sym_number] = ACTIONS(89),
    [anon_sym_true] = ACTIONS(47),
    [anon_sym_false] = ACTIONS(47),
    [anon_sym_LF] = ACTIONS(103),
    [anon_sym_CR] = ACTIONS(103),
    [sym_comment] = ACTIONS(3),
    [sym_line_continuation] = ACTIONS(3),
    [sym_command_name] = ACTIONS(49),
    [sym__single_quote_string_start] = ACTIONS(51),
    [sym__double_quote_string_start] = ACTIONS(53),
    [sym__multioutput_variable_start] = ACTIONS(55),
  },
  [7] = {
    [aux_sym__block] = STATE(54),
    [sym_block] = STATE(1048),
    [sym__statement] = STATE(874),
    [sym__expression] = STATE(627),
    [sym_parenthesis] = STATE(411),
    [sym__binary_expression] = STATE(622),
    [sym_binary_operator] = STATE(422),
    [sym_unary_operator] = STATE(389),
    [sym_indirect_access] = STATE(994),
    [sym_field_expression] = STATE(485),
    [sym_not_operator] = STATE(477),
    [sym_metaclass_operator] = STATE(627),
    [sym_handle_operator] = STATE(627),
    [sym_comparison_operator] = STATE(446),
    [sym_boolean_operator] = STATE(446),
    [sym_postfix_operator] = STATE(411),
    [sym_string] = STATE(411),
    [sym_matrix] = STATE(411),
    [sym_cell] = STATE(423),
    [sym_ignored_argument] = STATE(1187),
    [sym_assignment] = STATE(874),
    [sym_multioutput_variable] = STATE(1187),
    [sym_function_call] = STATE(210),
    [sym_command] = STATE(874),
    [sym__range_element] = STATE(1181),
    [sym_range] = STATE(627),
    [sym_if_statement] = STATE(874),
    [sym_for_statement] = STATE(874),
    [sym_while_statement] = STATE(874),
    [sym_switch_statement] = STATE(874),
    [sym_lambda] = STATE(627),
    [sym_global_operator] = STATE(874),
    [sym_persistent_operator] = STATE(874),
    [sym__function_definition_with_end] = STATE(877),
    [sym_class_definition] = STATE(874),
    [sym_try_statement] = STATE(874),
    [sym_boolean] = STATE(205),
    [sym__end_of_line] = STATE(158),
    [aux_sym_elseif_clause_repeat1] = STATE(158),
    [sym_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(99),
    [anon_sym_COMMA] = ACTIONS(99),
    [anon_sym_LPAREN] = ACTIONS(59),
    [anon_sym_PLUS] = ACTIONS(61),
    [anon_sym_DASH] = ACTIONS(61),
    [anon_sym_TILDE] = ACTIONS(63),
    [anon_sym_QMARK] = ACTIONS(65),
    [anon_sym_AT] = ACTIONS(67),
    [anon_sym_LBRACK] = ACTIONS(75),
    [anon_sym_LBRACE] = ACTIONS(77),
    [sym_return_statement] = ACTIONS(79),
    [sym_continue_statement] = ACTIONS(79),
    [sym_break_statement] = ACTIONS(79),
    [anon_sym_if] = ACTIONS(25),
    [anon_sym_end] = ACTIONS(109),
    [anon_sym_for] = ACTIONS(27),
    [anon_sym_parfor] = ACTIONS(29),
    [anon_sym_while] = ACTIONS(31),
    [anon_sym_case] = ACTIONS(109),
    [anon_sym_otherwise] = ACTIONS(109),
    [anon_sym_switch] = ACTIONS(33),
    [anon_sym_global] = ACTIONS(35),
    [anon_sym_persistent] = ACTIONS(37),
    [anon_sym_function] = ACTIONS(87),
    [anon_sym_classdef] = ACTIONS(41),
    [anon_sym_try] = ACTIONS(43),
    [sym_number] = ACTIONS(89),
    [anon_sym_true] = ACTIONS(47),
    [anon_sym_false] = ACTIONS(47),
    [anon_sym_LF] = ACTIONS(99),
    [anon_sym_CR] = ACTIONS(99),
    [sym_comment] = ACTIONS(3),
    [sym_line_continuation] = ACTIONS(3),
    [sym_command_name] = ACTIONS(49),
    [sym__single_quote_string_start] = ACTIONS(51),
    [sym__double_quote_string_start] = ACTIONS(53),
    [sym__multioutput_variable_start] = ACTIONS(55),
  },
  [8] = {
    [aux_sym__block] = STATE(54),
    [sym_block] = STATE(1006),
    [sym__statement] = STATE(874),
    [sym__expression] = STATE(627),
    [sym_parenthesis] = STATE(411),
    [sym__binary_expression] = STATE(622),
    [sym_binary_operator] = STATE(422),
    [sym_unary_operator] = STATE(389),
    [sym_indirect_access] = STATE(994),
    [sym_field_expression] = STATE(485),
    [sym_not_operator] = STATE(477),
    [sym_metaclass_operator] = STATE(627),
    [sym_handle_operator] = STATE(627),
    [sym_comparison_operator] = STATE(446),
    [sym_boolean_operator] = STATE(446),
    [sym_postfix_operator] = STATE(411),
    [sym_string] = STATE(411),
    [sym_matrix] = STATE(411),
    [sym_cell] = STATE(423),
    [sym_ignored_argument] = STATE(1187),
    [sym_assignment] = STATE(874),
    [sym_multioutput_variable] = STATE(1187),
    [sym_function_call] = STATE(210),
    [sym_command] = STATE(874),
    [sym__range_element] = STATE(1181),
    [sym_range] = STATE(627),
    [sym_if_statement] = STATE(874),
    [sym_for_statement] = STATE(874),
    [sym_while_statement] = STATE(874),
    [sym_switch_statement] = STATE(874),
    [sym_lambda] = STATE(627),
    [sym_global_operator] = STATE(874),
    [sym_persistent_operator] = STATE(874),
    [sym__function_definition_with_end] = STATE(877),
    [sym_class_definition] = STATE(874),
    [sym_catch_clause] = STATE(1207),
    [sym_try_statement] = STATE(874),
    [sym_boolean] = STATE(205),
    [sym__end_of_line] = STATE(158),
    [aux_sym_elseif_clause_repeat1] = STATE(158),
    [sym_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(99),
    [anon_sym_COMMA] = ACTIONS(99),
    [anon_sym_LPAREN] = ACTIONS(59),
    [anon_sym_PLUS] = ACTIONS(61),
    [anon_sym_DASH] = ACTIONS(61),
    [anon_sym_TILDE] = ACTIONS(63),
    [anon_sym_QMARK] = ACTIONS(65),
    [anon_sym_AT] = ACTIONS(67),
    [anon_sym_LBRACK] = ACTIONS(75),
    [anon_sym_LBRACE] = ACTIONS(77),
    [sym_return_statement] = ACTIONS(79),
    [sym_continue_statement] = ACTIONS(79),
    [sym_break_statement] = ACTIONS(79),
    [anon_sym_if] = ACTIONS(25),
    [anon_sym_end] = ACTIONS(111),
    [anon_sym_for] = ACTIONS(27),
    [anon_sym_parfor] = ACTIONS(29),
    [anon_sym_while] = ACTIONS(31),
    [anon_sym_switch] = ACTIONS(33),
    [anon_sym_global] = ACTIONS(35),
    [anon_sym_persistent] = ACTIONS(37),
    [anon_sym_function] = ACTIONS(87),
    [anon_sym_classdef] = ACTIONS(41),
    [anon_sym_catch] = ACTIONS(107),
    [anon_sym_try] = ACTIONS(43),
    [sym_number] = ACTIONS(89),
    [anon_sym_true] = ACTIONS(47),
    [anon_sym_false] = ACTIONS(47),
    [anon_sym_LF] = ACTIONS(99),
    [anon_sym_CR] = ACTIONS(99),
    [sym_comment] = ACTIONS(3),
    [sym_line_continuation] = ACTIONS(3),
    [sym_command_name] = ACTIONS(49),
    [sym__single_quote_string_start] = ACTIONS(51),
    [sym__double_quote_string_start] = ACTIONS(53),
    [sym__multioutput_variable_start] = ACTIONS(55),
  },
  [9] = {
    [aux_sym__block] = STATE(54),
    [sym_block] = STATE(1058),
    [sym__statement] = STATE(874),
    [sym__expression] = STATE(627),
    [sym_parenthesis] = STATE(411),
    [sym__binary_expression] = STATE(622),
    [sym_binary_operator] = STATE(422),
    [sym_unary_operator] = STATE(389),
    [sym_indirect_access] = STATE(994),
    [sym_field_expression] = STATE(485),
    [sym_not_operator] = STATE(477),
    [sym_metaclass_operator] = STATE(627),
    [sym_handle_operator] = STATE(627),
    [sym_comparison_operator] = STATE(446),
    [sym_boolean_operator] = STATE(446),
    [sym_postfix_operator] = STATE(411),
    [sym_string] = STATE(411),
    [sym_matrix] = STATE(411),
    [sym_cell] = STATE(423),
    [sym_ignored_argument] = STATE(1187),
    [sym_assignment] = STATE(874),
    [sym_multioutput_variable] = STATE(1187),
    [sym_function_call] = STATE(210),
    [sym_command] = STATE(874),
    [sym__range_element] = STATE(1181),
    [sym_range] = STATE(627),
    [sym_if_statement] = STATE(874),
    [sym_for_statement] = STATE(874),
    [sym_while_statement] = STATE(874),
    [sym_switch_statement] = STATE(874),
    [sym_lambda] = STATE(627),
    [sym_global_operator] = STATE(874),
    [sym_persistent_operator] = STATE(874),
    [sym__function_definition_with_end] = STATE(877),
    [sym_class_definition] = STATE(874),
    [sym_try_statement] = STATE(874),
    [sym_boolean] = STATE(205),
    [sym__end_of_line] = STATE(158),
    [aux_sym_elseif_clause_repeat1] = STATE(158),
    [sym_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(99),
    [anon_sym_COMMA] = ACTIONS(99),
    [anon_sym_LPAREN] = ACTIONS(59),
    [anon_sym_PLUS] = ACTIONS(61),
    [anon_sym_DASH] = ACTIONS(61),
    [anon_sym_TILDE] = ACTIONS(63),
    [anon_sym_QMARK] = ACTIONS(65),
    [anon_sym_AT] = ACTIONS(67),
    [anon_sym_LBRACK] = ACTIONS(75),
    [anon_sym_LBRACE] = ACTIONS(77),
    [sym_return_statement] = ACTIONS(79),
    [sym_continue_statement] = ACTIONS(79),
    [sym_break_statement] = ACTIONS(79),
    [anon_sym_elseif] = ACTIONS(113),
    [anon_sym_else] = ACTIONS(113),
    [anon_sym_if] = ACTIONS(25),
    [anon_sym_end] = ACTIONS(113),
    [anon_sym_for] = ACTIONS(27),
    [anon_sym_parfor] = ACTIONS(29),
    [anon_sym_while] = ACTIONS(31),
    [anon_sym_switch] = ACTIONS(33),
    [anon_sym_global] = ACTIONS(35),
    [anon_sym_persistent] = ACTIONS(37),
    [anon_sym_function] = ACTIONS(87),
    [anon_sym_classdef] = ACTIONS(41),
    [anon_sym_try] = ACTIONS(43),
    [sym_number] = ACTIONS(89),
    [anon_sym_true] = ACTIONS(47),
    [anon_sym_false] = ACTIONS(47),
    [anon_sym_LF] = ACTIONS(99),
    [anon_sym_CR] = ACTIONS(99),
    [sym_comment] = ACTIONS(3),
    [sym_line_continuation] = ACTIONS(3),
    [sym_command_name] = ACTIONS(49),
    [sym__single_quote_string_start] = ACTIONS(51),
    [sym__double_quote_string_start] = ACTIONS(53),
    [sym__multioutput_variable_start] = ACTIONS(55),
  },
  [10] = {
    [aux_sym__block] = STATE(54),
    [sym_block] = STATE(1199),
    [sym__statement] = STATE(874),
    [sym__expression] = STATE(627),
    [sym_parenthesis] = STATE(411),
    [sym__binary_expression] = STATE(622),
    [sym_binary_operator] = STATE(422),
    [sym_unary_operator] = STATE(389),
    [sym_indirect_access] = STATE(994),
    [sym_field_expression] = STATE(485),
    [sym_not_operator] = STATE(477),
    [sym_metaclass_operator] = STATE(627),
    [sym_handle_operator] = STATE(627),
    [sym_comparison_operator] = STATE(446),
    [sym_boolean_operator] = STATE(446),
    [sym_postfix_operator] = STATE(411),
    [sym_string] = STATE(411),
    [sym_matrix] = STATE(411),
    [sym_cell] = STATE(423),
    [sym_ignored_argument] = STATE(1187),
    [sym_assignment] = STATE(874),
    [sym_multioutput_variable] = STATE(1187),
    [sym_function_call] = STATE(210),
    [sym_command] = STATE(874),
    [sym__range_element] = STATE(1181),
    [sym_range] = STATE(627),
    [sym_if_statement] = STATE(874),
    [sym_for_statement] = STATE(874),
    [sym_while_statement] = STATE(874),
    [sym_switch_statement] = STATE(874),
    [sym_lambda] = STATE(627),
    [sym_global_operator] = STATE(874),
    [sym_persistent_operator] = STATE(874),
    [sym__function_definition_with_end] = STATE(877),
    [sym_class_definition] = STATE(874),
    [sym_try_statement] = STATE(874),
    [sym_boolean] = STATE(205),
    [sym__end_of_line] = STATE(158),
    [aux_sym_elseif_clause_repeat1] = STATE(158),
    [sym_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(99),
    [anon_sym_COMMA] = ACTIONS(99),
    [anon_sym_LPAREN] = ACTIONS(59),
    [anon_sym_PLUS] = ACTIONS(61),
    [anon_sym_DASH] = ACTIONS(61),
    [anon_sym_TILDE] = ACTIONS(63),
    [anon_sym_QMARK] = ACTIONS(65),
    [anon_sym_AT] = ACTIONS(67),
    [anon_sym_LBRACK] = ACTIONS(75),
    [anon_sym_LBRACE] = ACTIONS(77),
    [sym_return_statement] = ACTIONS(79),
    [sym_continue_statement] = ACTIONS(79),
    [sym_break_statement] = ACTIONS(79),
    [anon_sym_if] = ACTIONS(25),
    [anon_sym_end] = ACTIONS(115),
    [anon_sym_for] = ACTIONS(27),
    [anon_sym_parfor] = ACTIONS(29),
    [anon_sym_while] = ACTIONS(31),
    [anon_sym_switch] = ACTIONS(33),
    [anon_sym_global] = ACTIONS(35),
    [anon_sym_persistent] = ACTIONS(37),
    [anon_sym_function] = ACTIONS(87),
    [anon_sym_classdef] = ACTIONS(41),
    [anon_sym_try] = ACTIONS(43),
    [sym_number] = ACTIONS(89),
    [anon_sym_true] = ACTIONS(47),
    [anon_sym_false] = ACTIONS(47),
    [anon_sym_LF] = ACTIONS(99),
    [anon_sym_CR] = ACTIONS(99),
    [sym_comment] = ACTIONS(3),
    [sym_line_continuation] = ACTIONS(3),
    [sym_command_name] = ACTIONS(49),
    [sym__single_quote_string_start] = ACTIONS(51),
    [sym__double_quote_string_start] = ACTIONS(53),
    [sym__multioutput_variable_start] = ACTIONS(55),
  },
  [11] = {
    [aux_sym__block] = STATE(54),
    [sym_block] = STATE(1178),
    [sym__statement] = STATE(874),
    [sym__expression] = STATE(627),
    [sym_parenthesis] = STATE(411),
    [sym__binary_expression] = STATE(622),
    [sym_binary_operator] = STATE(422),
    [sym_unary_operator] = STATE(389),
    [sym_indirect_access] = STATE(994),
    [sym_field_expression] = STATE(485),
    [sym_not_operator] = STATE(477),
    [sym_metaclass_operator] = STATE(627),
    [sym_handle_operator] = STATE(627),
    [sym_comparison_operator] = STATE(446),
    [sym_boolean_operator] = STATE(446),
    [sym_postfix_operator] = STATE(411),
    [sym_string] = STATE(411),
    [sym_matrix] = STATE(411),
    [sym_cell] = STATE(423),
    [sym_ignored_argument] = STATE(1187),
    [sym_assignment] = STATE(874),
    [sym_multioutput_variable] = STATE(1187),
    [sym_function_call] = STATE(210),
    [sym_command] = STATE(874),
    [sym__range_element] = STATE(1181),
    [sym_range] = STATE(627),
    [sym_if_statement] = STATE(874),
    [sym_for_statement] = STATE(874),
    [sym_while_statement] = STATE(874),
    [sym_switch_statement] = STATE(874),
    [sym_lambda] = STATE(627),
    [sym_global_operator] = STATE(874),
    [sym_persistent_operator] = STATE(874),
    [sym__function_definition_with_end] = STATE(877),
    [sym_class_definition] = STATE(874),
    [sym_try_statement] = STATE(874),
    [sym_boolean] = STATE(205),
    [sym__end_of_line] = STATE(158),
    [aux_sym_elseif_clause_repeat1] = STATE(158),
    [sym_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(99),
    [anon_sym_COMMA] = ACTIONS(99),
    [anon_sym_LPAREN] = ACTIONS(59),
    [anon_sym_PLUS] = ACTIONS(61),
    [anon_sym_DASH] = ACTIONS(61),
    [anon_sym_TILDE] = ACTIONS(63),
    [anon_sym_QMARK] = ACTIONS(65),
    [anon_sym_AT] = ACTIONS(67),
    [anon_sym_LBRACK] = ACTIONS(75),
    [anon_sym_LBRACE] = ACTIONS(77),
    [sym_return_statement] = ACTIONS(79),
    [sym_continue_statement] = ACTIONS(79),
    [sym_break_statement] = ACTIONS(79),
    [anon_sym_if] = ACTIONS(25),
    [anon_sym_end] = ACTIONS(117),
    [anon_sym_for] = ACTIONS(27),
    [anon_sym_parfor] = ACTIONS(29),
    [anon_sym_while] = ACTIONS(31),
    [anon_sym_switch] = ACTIONS(33),
    [anon_sym_global] = ACTIONS(35),
    [anon_sym_persistent] = ACTIONS(37),
    [anon_sym_function] = ACTIONS(87),
    [anon_sym_classdef] = ACTIONS(41),
    [anon_sym_try] = ACTIONS(43),
    [sym_number] = ACTIONS(89),
    [anon_sym_true] = ACTIONS(47),
    [anon_sym_false] = ACTIONS(47),
    [anon_sym_LF] = ACTIONS(99),
    [anon_sym_CR] = ACTIONS(99),
    [sym_comment] = ACTIONS(3),
    [sym_line_continuation] = ACTIONS(3),
    [sym_command_name] = ACTIONS(49),
    [sym__single_quote_string_start] = ACTIONS(51),
    [sym__double_quote_string_start] = ACTIONS(53),
    [sym__multioutput_variable_start] = ACTIONS(55),
  },
  [12] = {
    [aux_sym__block] = STATE(54),
    [sym_block] = STATE(1143),
    [sym__statement] = STATE(874),
    [sym__expression] = STATE(627),
    [sym_parenthesis] = STATE(411),
    [sym__binary_expression] = STATE(622),
    [sym_binary_operator] = STATE(422),
    [sym_unary_operator] = STATE(389),
    [sym_indirect_access] = STATE(994),
    [sym_field_expression] = STATE(485),
    [sym_not_operator] = STATE(477),
    [sym_metaclass_operator] = STATE(627),
    [sym_handle_operator] = STATE(627),
    [sym_comparison_operator] = STATE(446),
    [sym_boolean_operator] = STATE(446),
    [sym_postfix_operator] = STATE(411),
    [sym_string] = STATE(411),
    [sym_matrix] = STATE(411),
    [sym_cell] = STATE(423),
    [sym_ignored_argument] = STATE(1187),
    [sym_assignment] = STATE(874),
    [sym_multioutput_variable] = STATE(1187),
    [sym_function_call] = STATE(210),
    [sym_command] = STATE(874),
    [sym__range_element] = STATE(1181),
    [sym_range] = STATE(627),
    [sym_if_statement] = STATE(874),
    [sym_for_statement] = STATE(874),
    [sym_while_statement] = STATE(874),
    [sym_switch_statement] = STATE(874),
    [sym_lambda] = STATE(627),
    [sym_global_operator] = STATE(874),
    [sym_persistent_operator] = STATE(874),
    [sym__function_definition_with_end] = STATE(877),
    [sym_class_definition] = STATE(874),
    [sym_try_statement] = STATE(874),
    [sym_boolean] = STATE(205),
    [sym__end_of_line] = STATE(158),
    [aux_sym_elseif_clause_repeat1] = STATE(158),
    [sym_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(99),
    [anon_sym_COMMA] = ACTIONS(99),
    [anon_sym_LPAREN] = ACTIONS(59),
    [anon_sym_PLUS] = ACTIONS(61),
    [anon_sym_DASH] = ACTIONS(61),
    [anon_sym_TILDE] = ACTIONS(63),
    [anon_sym_QMARK] = ACTIONS(65),
    [anon_sym_AT] = ACTIONS(67),
    [anon_sym_LBRACK] = ACTIONS(75),
    [anon_sym_LBRACE] = ACTIONS(77),
    [sym_return_statement] = ACTIONS(79),
    [sym_continue_statement] = ACTIONS(79),
    [sym_break_statement] = ACTIONS(79),
    [anon_sym_if] = ACTIONS(25),
    [anon_sym_end] = ACTIONS(119),
    [anon_sym_for] = ACTIONS(27),
    [anon_sym_parfor] = ACTIONS(29),
    [anon_sym_while] = ACTIONS(31),
    [anon_sym_switch] = ACTIONS(33),
    [anon_sym_global] = ACTIONS(35),
    [anon_sym_persistent] = ACTIONS(37),
    [anon_sym_function] = ACTIONS(87),
    [anon_sym_classdef] = ACTIONS(41),
    [anon_sym_try] = ACTIONS(43),
    [sym_number] = ACTIONS(89),
    [anon_sym_true] = ACTIONS(47),
    [anon_sym_false] = ACTIONS(47),
    [anon_sym_LF] = ACTIONS(99),
    [anon_sym_CR] = ACTIONS(99),
    [sym_comment] = ACTIONS(3),
    [sym_line_continuation] = ACTIONS(3),
    [sym_command_name] = ACTIONS(49),
    [sym__single_quote_string_start] = ACTIONS(51),
    [sym__double_quote_string_start] = ACTIONS(53),
    [sym__multioutput_variable_start] = ACTIONS(55),
  },
  [13] = {
    [aux_sym__block] = STATE(54),
    [sym_block] = STATE(1192),
    [sym__statement] = STATE(874),
    [sym__expression] = STATE(627),
    [sym_parenthesis] = STATE(411),
    [sym__binary_expression] = STATE(622),
    [sym_binary_operator] = STATE(422),
    [sym_unary_operator] = STATE(389),
    [sym_indirect_access] = STATE(994),
    [sym_field_expression] = STATE(485),
    [sym_not_operator] = STATE(477),
    [sym_metaclass_operator] = STATE(627),
    [sym_handle_operator] = STATE(627),
    [sym_comparison_operator] = STATE(446),
    [sym_boolean_operator] = STATE(446),
    [sym_postfix_operator] = STATE(411),
    [sym_string] = STATE(411),
    [sym_matrix] = STATE(411),
    [sym_cell] = STATE(423),
    [sym_ignored_argument] = STATE(1187),
    [sym_assignment] = STATE(874),
    [sym_multioutput_variable] = STATE(1187),
    [sym_function_call] = STATE(210),
    [sym_command] = STATE(874),
    [sym__range_element] = STATE(1181),
    [sym_range] = STATE(627),
    [sym_if_statement] = STATE(874),
    [sym_for_statement] = STATE(874),
    [sym_while_statement] = STATE(874),
    [sym_switch_statement] = STATE(874),
    [sym_lambda] = STATE(627),
    [sym_global_operator] = STATE(874),
    [sym_persistent_operator] = STATE(874),
    [sym__function_definition_with_end] = STATE(877),
    [sym_class_definition] = STATE(874),
    [sym_try_statement] = STATE(874),
    [sym_boolean] = STATE(205),
    [sym__end_of_line] = STATE(158),
    [aux_sym_elseif_clause_repeat1] = STATE(158),
    [sym_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(99),
    [anon_sym_COMMA] = ACTIONS(99),
    [anon_sym_LPAREN] = ACTIONS(59),
    [anon_sym_PLUS] = ACTIONS(61),
    [anon_sym_DASH] = ACTIONS(61),
    [anon_sym_TILDE] = ACTIONS(63),
    [anon_sym_QMARK] = ACTIONS(65),
    [anon_sym_AT] = ACTIONS(67),
    [anon_sym_LBRACK] = ACTIONS(75),
    [anon_sym_LBRACE] = ACTIONS(77),
    [sym_return_statement] = ACTIONS(79),
    [sym_continue_statement] = ACTIONS(79),
    [sym_break_statement] = ACTIONS(79),
    [anon_sym_if] = ACTIONS(25),
    [anon_sym_end] = ACTIONS(121),
    [anon_sym_for] = ACTIONS(27),
    [anon_sym_parfor] = ACTIONS(29),
    [anon_sym_while] = ACTIONS(31),
    [anon_sym_switch] = ACTIONS(33),
    [anon_sym_global] = ACTIONS(35),
    [anon_sym_persistent] = ACTIONS(37),
    [anon_sym_function] = ACTIONS(87),
    [anon_sym_classdef] = ACTIONS(41),
    [anon_sym_try] = ACTIONS(43),
    [sym_number] = ACTIONS(89),
    [anon_sym_true] = ACTIONS(47),
    [anon_sym_false] = ACTIONS(47),
    [anon_sym_LF] = ACTIONS(99),
    [anon_sym_CR] = ACTIONS(99),
    [sym_comment] = ACTIONS(3),
    [sym_line_continuation] = ACTIONS(3),
    [sym_command_name] = ACTIONS(49),
    [sym__single_quote_string_start] = ACTIONS(51),
    [sym__double_quote_string_start] = ACTIONS(53),
    [sym__multioutput_variable_start] = ACTIONS(55),
  },
  [14] = {
    [aux_sym__block] = STATE(54),
    [sym_block] = STATE(1205),
    [sym__statement] = STATE(874),
    [sym__expression] = STATE(627),
    [sym_parenthesis] = STATE(411),
    [sym__binary_expression] = STATE(622),
    [sym_binary_operator] = STATE(422),
    [sym_unary_operator] = STATE(389),
    [sym_indirect_access] = STATE(994),
    [sym_field_expression] = STATE(485),
    [sym_not_operator] = STATE(477),
    [sym_metaclass_operator] = STATE(627),
    [sym_handle_operator] = STATE(627),
    [sym_comparison_operator] = STATE(446),
    [sym_boolean_operator] = STATE(446),
    [sym_postfix_operator] = STATE(411),
    [sym_string] = STATE(411),
    [sym_matrix] = STATE(411),
    [sym_cell] = STATE(423),
    [sym_ignored_argument] = STATE(1187),
    [sym_assignment] = STATE(874),
    [sym_multioutput_variable] = STATE(1187),
    [sym_function_call] = STATE(210),
    [sym_command] = STATE(874),
    [sym__range_element] = STATE(1181),
    [sym_range] = STATE(627),
    [sym_if_statement] = STATE(874),
    [sym_for_statement] = STATE(874),
    [sym_while_statement] = STATE(874),
    [sym_switch_statement] = STATE(874),
    [sym_lambda] = STATE(627),
    [sym_global_operator] = STATE(874),
    [sym_persistent_operator] = STATE(874),
    [sym__function_definition_with_end] = STATE(877),
    [sym_class_definition] = STATE(874),
    [sym_try_statement] = STATE(874),
    [sym_boolean] = STATE(205),
    [sym__end_of_line] = STATE(158),
    [aux_sym_elseif_clause_repeat1] = STATE(158),
    [sym_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(99),
    [anon_sym_COMMA] = ACTIONS(99),
    [anon_sym_LPAREN] = ACTIONS(59),
    [anon_sym_PLUS] = ACTIONS(61),
    [anon_sym_DASH] = ACTIONS(61),
    [anon_sym_TILDE] = ACTIONS(63),
    [anon_sym_QMARK] = ACTIONS(65),
    [anon_sym_AT] = ACTIONS(67),
    [anon_sym_LBRACK] = ACTIONS(75),
    [anon_sym_LBRACE] = ACTIONS(77),
    [sym_return_statement] = ACTIONS(79),
    [sym_continue_statement] = ACTIONS(79),
    [sym_break_statement] = ACTIONS(79),
    [anon_sym_if] = ACTIONS(25),
    [anon_sym_end] = ACTIONS(123),
    [anon_sym_for] = ACTIONS(27),
    [anon_sym_parfor] = ACTIONS(29),
    [anon_sym_while] = ACTIONS(31),
    [anon_sym_switch] = ACTIONS(33),
    [anon_sym_global] = ACTIONS(35),
    [anon_sym_persistent] = ACTIONS(37),
    [anon_sym_function] = ACTIONS(87),
    [anon_sym_classdef] = ACTIONS(41),
    [anon_sym_try] = ACTIONS(43),
    [sym_number] = ACTIONS(89),
    [anon_sym_true] = ACTIONS(47),
    [anon_sym_false] = ACTIONS(47),
    [anon_sym_LF] = ACTIONS(99),
    [anon_sym_CR] = ACTIONS(99),
    [sym_comment] = ACTIONS(3),
    [sym_line_continuation] = ACTIONS(3),
    [sym_command_name] = ACTIONS(49),
    [sym__single_quote_string_start] = ACTIONS(51),
    [sym__double_quote_string_start] = ACTIONS(53),
    [sym__multioutput_variable_start] = ACTIONS(55),
  },
  [15] = {
    [aux_sym__block] = STATE(54),
    [sym_block] = STATE(1163),
    [sym__statement] = STATE(874),
    [sym__expression] = STATE(627),
    [sym_parenthesis] = STATE(411),
    [sym__binary_expression] = STATE(622),
    [sym_binary_operator] = STATE(422),
    [sym_unary_operator] = STATE(389),
    [sym_indirect_access] = STATE(994),
    [sym_field_expression] = STATE(485),
    [sym_not_operator] = STATE(477),
    [sym_metaclass_operator] = STATE(627),
    [sym_handle_operator] = STATE(627),
    [sym_comparison_operator] = STATE(446),
    [sym_boolean_operator] = STATE(446),
    [sym_postfix_operator] = STATE(411),
    [sym_string] = STATE(411),
    [sym_matrix] = STATE(411),
    [sym_cell] = STATE(423),
    [sym_ignored_argument] = STATE(1187),
    [sym_assignment] = STATE(874),
    [sym_multioutput_variable] = STATE(1187),
    [sym_function_call] = STATE(210),
    [sym_command] = STATE(874),
    [sym__range_element] = STATE(1181),
    [sym_range] = STATE(627),
    [sym_if_statement] = STATE(874),
    [sym_for_statement] = STATE(874),
    [sym_while_statement] = STATE(874),
    [sym_switch_statement] = STATE(874),
    [sym_lambda] = STATE(627),
    [sym_global_operator] = STATE(874),
    [sym_persistent_operator] = STATE(874),
    [sym__function_definition_with_end] = STATE(877),
    [sym_class_definition] = STATE(874),
    [sym_try_statement] = STATE(874),
    [sym_boolean] = STATE(205),
    [sym__end_of_line] = STATE(14),
    [aux_sym_elseif_clause_repeat1] = STATE(14),
    [sym_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(125),
    [anon_sym_COMMA] = ACTIONS(125),
    [anon_sym_LPAREN] = ACTIONS(59),
    [anon_sym_PLUS] = ACTIONS(61),
    [anon_sym_DASH] = ACTIONS(61),
    [anon_sym_TILDE] = ACTIONS(63),
    [anon_sym_QMARK] = ACTIONS(65),
    [anon_sym_AT] = ACTIONS(67),
    [anon_sym_LBRACK] = ACTIONS(75),
    [anon_sym_LBRACE] = ACTIONS(77),
    [sym_return_statement] = ACTIONS(79),
    [sym_continue_statement] = ACTIONS(79),
    [sym_break_statement] = ACTIONS(79),
    [anon_sym_if] = ACTIONS(25),
    [anon_sym_end] = ACTIONS(127),
    [anon_sym_for] = ACTIONS(27),
    [anon_sym_parfor] = ACTIONS(29),
    [anon_sym_while] = ACTIONS(31),
    [anon_sym_switch] = ACTIONS(33),
    [anon_sym_global] = ACTIONS(35),
    [anon_sym_persistent] = ACTIONS(37),
    [anon_sym_function] = ACTIONS(87),
    [anon_sym_classdef] = ACTIONS(41),
    [anon_sym_try] = ACTIONS(43),
    [sym_number] = ACTIONS(89),
    [anon_sym_true] = ACTIONS(47),
    [anon_sym_false] = ACTIONS(47),
    [anon_sym_LF] = ACTIONS(125),
    [anon_sym_CR] = ACTIONS(125),
    [sym_comment] = ACTIONS(3),
    [sym_line_continuation] = ACTIONS(3),
    [sym_command_name] = ACTIONS(49),
    [sym__single_quote_string_start] = ACTIONS(51),
    [sym__double_quote_string_start] = ACTIONS(53),
    [sym__multioutput_variable_start] = ACTIONS(55),
  },
  [16] = {
    [aux_sym__block] = STATE(54),
    [sym_block] = STATE(1154),
    [sym__statement] = STATE(874),
    [sym__expression] = STATE(627),
    [sym_parenthesis] = STATE(411),
    [sym__binary_expression] = STATE(622),
    [sym_binary_operator] = STATE(422),
    [sym_unary_operator] = STATE(389),
    [sym_indirect_access] = STATE(994),
    [sym_field_expression] = STATE(485),
    [sym_not_operator] = STATE(477),
    [sym_metaclass_operator] = STATE(627),
    [sym_handle_operator] = STATE(627),
    [sym_comparison_operator] = STATE(446),
    [sym_boolean_operator] = STATE(446),
    [sym_postfix_operator] = STATE(411),
    [sym_string] = STATE(411),
    [sym_matrix] = STATE(411),
    [sym_cell] = STATE(423),
    [sym_ignored_argument] = STATE(1187),
    [sym_assignment] = STATE(874),
    [sym_multioutput_variable] = STATE(1187),
    [sym_function_call] = STATE(210),
    [sym_command] = STATE(874),
    [sym__range_element] = STATE(1181),
    [sym_range] = STATE(627),
    [sym_if_statement] = STATE(874),
    [sym_for_statement] = STATE(874),
    [sym_while_statement] = STATE(874),
    [sym_switch_statement] = STATE(874),
    [sym_lambda] = STATE(627),
    [sym_global_operator] = STATE(874),
    [sym_persistent_operator] = STATE(874),
    [sym__function_definition_with_end] = STATE(877),
    [sym_class_definition] = STATE(874),
    [sym_try_statement] = STATE(874),
    [sym_boolean] = STATE(205),
    [sym__end_of_line] = STATE(18),
    [aux_sym_elseif_clause_repeat1] = STATE(18),
    [sym_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(129),
    [anon_sym_COMMA] = ACTIONS(129),
    [anon_sym_LPAREN] = ACTIONS(59),
    [anon_sym_PLUS] = ACTIONS(61),
    [anon_sym_DASH] = ACTIONS(61),
    [anon_sym_TILDE] = ACTIONS(63),
    [anon_sym_QMARK] = ACTIONS(65),
    [anon_sym_AT] = ACTIONS(67),
    [anon_sym_LBRACK] = ACTIONS(75),
    [anon_sym_LBRACE] = ACTIONS(77),
    [sym_return_statement] = ACTIONS(79),
    [sym_continue_statement] = ACTIONS(79),
    [sym_break_statement] = ACTIONS(79),
    [anon_sym_if] = ACTIONS(25),
    [anon_sym_end] = ACTIONS(131),
    [anon_sym_for] = ACTIONS(27),
    [anon_sym_parfor] = ACTIONS(29),
    [anon_sym_while] = ACTIONS(31),
    [anon_sym_switch] = ACTIONS(33),
    [anon_sym_global] = ACTIONS(35),
    [anon_sym_persistent] = ACTIONS(37),
    [anon_sym_function] = ACTIONS(87),
    [anon_sym_classdef] = ACTIONS(41),
    [anon_sym_try] = ACTIONS(43),
    [sym_number] = ACTIONS(89),
    [anon_sym_true] = ACTIONS(47),
    [anon_sym_false] = ACTIONS(47),
    [anon_sym_LF] = ACTIONS(129),
    [anon_sym_CR] = ACTIONS(129),
    [sym_comment] = ACTIONS(3),
    [sym_line_continuation] = ACTIONS(3),
    [sym_command_name] = ACTIONS(49),
    [sym__single_quote_string_start] = ACTIONS(51),
    [sym__double_quote_string_start] = ACTIONS(53),
    [sym__multioutput_variable_start] = ACTIONS(55),
  },
  [17] = {
    [aux_sym__block] = STATE(54),
    [sym_block] = STATE(1216),
    [sym__statement] = STATE(874),
    [sym__expression] = STATE(627),
    [sym_parenthesis] = STATE(411),
    [sym__binary_expression] = STATE(622),
    [sym_binary_operator] = STATE(422),
    [sym_unary_operator] = STATE(389),
    [sym_indirect_access] = STATE(994),
    [sym_field_expression] = STATE(485),
    [sym_not_operator] = STATE(477),
    [sym_metaclass_operator] = STATE(627),
    [sym_handle_operator] = STATE(627),
    [sym_comparison_operator] = STATE(446),
    [sym_boolean_operator] = STATE(446),
    [sym_postfix_operator] = STATE(411),
    [sym_string] = STATE(411),
    [sym_matrix] = STATE(411),
    [sym_cell] = STATE(423),
    [sym_ignored_argument] = STATE(1187),
    [sym_assignment] = STATE(874),
    [sym_multioutput_variable] = STATE(1187),
    [sym_function_call] = STATE(210),
    [sym_command] = STATE(874),
    [sym__range_element] = STATE(1181),
    [sym_range] = STATE(627),
    [sym_if_statement] = STATE(874),
    [sym_for_statement] = STATE(874),
    [sym_while_statement] = STATE(874),
    [sym_switch_statement] = STATE(874),
    [sym_lambda] = STATE(627),
    [sym_global_operator] = STATE(874),
    [sym_persistent_operator] = STATE(874),
    [sym__function_definition_with_end] = STATE(877),
    [sym_class_definition] = STATE(874),
    [sym_try_statement] = STATE(874),
    [sym_boolean] = STATE(205),
    [sym__end_of_line] = STATE(158),
    [aux_sym_elseif_clause_repeat1] = STATE(158),
    [sym_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(99),
    [anon_sym_COMMA] = ACTIONS(99),
    [anon_sym_LPAREN] = ACTIONS(59),
    [anon_sym_PLUS] = ACTIONS(61),
    [anon_sym_DASH] = ACTIONS(61),
    [anon_sym_TILDE] = ACTIONS(63),
    [anon_sym_QMARK] = ACTIONS(65),
    [anon_sym_AT] = ACTIONS(67),
    [anon_sym_LBRACK] = ACTIONS(75),
    [anon_sym_LBRACE] = ACTIONS(77),
    [sym_return_statement] = ACTIONS(79),
    [sym_continue_statement] = ACTIONS(79),
    [sym_break_statement] = ACTIONS(79),
    [anon_sym_if] = ACTIONS(25),
    [anon_sym_end] = ACTIONS(133),
    [anon_sym_for] = ACTIONS(27),
    [anon_sym_parfor] = ACTIONS(29),
    [anon_sym_while] = ACTIONS(31),
    [anon_sym_switch] = ACTIONS(33),
    [anon_sym_global] = ACTIONS(35),
    [anon_sym_persistent] = ACTIONS(37),
    [anon_sym_function] = ACTIONS(87),
    [anon_sym_classdef] = ACTIONS(41),
    [anon_sym_try] = ACTIONS(43),
    [sym_number] = ACTIONS(89),
    [anon_sym_true] = ACTIONS(47),
    [anon_sym_false] = ACTIONS(47),
    [anon_sym_LF] = ACTIONS(99),
    [anon_sym_CR] = ACTIONS(99),
    [sym_comment] = ACTIONS(3),
    [sym_line_continuation] = ACTIONS(3),
    [sym_command_name] = ACTIONS(49),
    [sym__single_quote_string_start] = ACTIONS(51),
    [sym__double_quote_string_start] = ACTIONS(53),
    [sym__multioutput_variable_start] = ACTIONS(55),
  },
  [18] = {
    [aux_sym__block] = STATE(54),
    [sym_block] = STATE(1145),
    [sym__statement] = STATE(874),
    [sym__expression] = STATE(627),
    [sym_parenthesis] = STATE(411),
    [sym__binary_expression] = STATE(622),
    [sym_binary_operator] = STATE(422),
    [sym_unary_operator] = STATE(389),
    [sym_indirect_access] = STATE(994),
    [sym_field_expression] = STATE(485),
    [sym_not_operator] = STATE(477),
    [sym_metaclass_operator] = STATE(627),
    [sym_handle_operator] = STATE(627),
    [sym_comparison_operator] = STATE(446),
    [sym_boolean_operator] = STATE(446),
    [sym_postfix_operator] = STATE(411),
    [sym_string] = STATE(411),
    [sym_matrix] = STATE(411),
    [sym_cell] = STATE(423),
    [sym_ignored_argument] = STATE(1187),
    [sym_assignment] = STATE(874),
    [sym_multioutput_variable] = STATE(1187),
    [sym_function_call] = STATE(210),
    [sym_command] = STATE(874),
    [sym__range_element] = STATE(1181),
    [sym_range] = STATE(627),
    [sym_if_statement] = STATE(874),
    [sym_for_statement] = STATE(874),
    [sym_while_statement] = STATE(874),
    [sym_switch_statement] = STATE(874),
    [sym_lambda] = STATE(627),
    [sym_global_operator] = STATE(874),
    [sym_persistent_operator] = STATE(874),
    [sym__function_definition_with_end] = STATE(877),
    [sym_class_definition] = STATE(874),
    [sym_try_statement] = STATE(874),
    [sym_boolean] = STATE(205),
    [sym__end_of_line] = STATE(158),
    [aux_sym_elseif_clause_repeat1] = STATE(158),
    [sym_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(99),
    [anon_sym_COMMA] = ACTIONS(99),
    [anon_sym_LPAREN] = ACTIONS(59),
    [anon_sym_PLUS] = ACTIONS(61),
    [anon_sym_DASH] = ACTIONS(61),
    [anon_sym_TILDE] = ACTIONS(63),
    [anon_sym_QMARK] = ACTIONS(65),
    [anon_sym_AT] = ACTIONS(67),
    [anon_sym_LBRACK] = ACTIONS(75),
    [anon_sym_LBRACE] = ACTIONS(77),
    [sym_return_statement] = ACTIONS(79),
    [sym_continue_statement] = ACTIONS(79),
    [sym_break_statement] = ACTIONS(79),
    [anon_sym_if] = ACTIONS(25),
    [anon_sym_end] = ACTIONS(135),
    [anon_sym_for] = ACTIONS(27),
    [anon_sym_parfor] = ACTIONS(29),
    [anon_sym_while] = ACTIONS(31),
    [anon_sym_switch] = ACTIONS(33),
    [anon_sym_global] = ACTIONS(35),
    [anon_sym_persistent] = ACTIONS(37),
    [anon_sym_function] = ACTIONS(87),
    [anon_sym_classdef] = ACTIONS(41),
    [anon_sym_try] = ACTIONS(43),
    [sym_number] = ACTIONS(89),
    [anon_sym_true] = ACTIONS(47),
    [anon_sym_false] = ACTIONS(47),
    [anon_sym_LF] = ACTIONS(99),
    [anon_sym_CR] = ACTIONS(99),
    [sym_comment] = ACTIONS(3),
    [sym_line_continuation] = ACTIONS(3),
    [sym_command_name] = ACTIONS(49),
    [sym__single_quote_string_start] = ACTIONS(51),
    [sym__double_quote_string_start] = ACTIONS(53),
    [sym__multioutput_variable_start] = ACTIONS(55),
  },
  [19] = {
    [aux_sym__block] = STATE(54),
    [sym_block] = STATE(1212),
    [sym__statement] = STATE(874),
    [sym__expression] = STATE(627),
    [sym_parenthesis] = STATE(411),
    [sym__binary_expression] = STATE(622),
    [sym_binary_operator] = STATE(422),
    [sym_unary_operator] = STATE(389),
    [sym_indirect_access] = STATE(994),
    [sym_field_expression] = STATE(485),
    [sym_not_operator] = STATE(477),
    [sym_metaclass_operator] = STATE(627),
    [sym_handle_operator] = STATE(627),
    [sym_comparison_operator] = STATE(446),
    [sym_boolean_operator] = STATE(446),
    [sym_postfix_operator] = STATE(411),
    [sym_string] = STATE(411),
    [sym_matrix] = STATE(411),
    [sym_cell] = STATE(423),
    [sym_ignored_argument] = STATE(1187),
    [sym_assignment] = STATE(874),
    [sym_multioutput_variable] = STATE(1187),
    [sym_function_call] = STATE(210),
    [sym_command] = STATE(874),
    [sym__range_element] = STATE(1181),
    [sym_range] = STATE(627),
    [sym_if_statement] = STATE(874),
    [sym_for_statement] = STATE(874),
    [sym_while_statement] = STATE(874),
    [sym_switch_statement] = STATE(874),
    [sym_lambda] = STATE(627),
    [sym_global_operator] = STATE(874),
    [sym_persistent_operator] = STATE(874),
    [sym__function_definition_with_end] = STATE(877),
    [sym_class_definition] = STATE(874),
    [sym_try_statement] = STATE(874),
    [sym_boolean] = STATE(205),
    [sym__end_of_line] = STATE(10),
    [aux_sym_elseif_clause_repeat1] = STATE(10),
    [sym_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(137),
    [anon_sym_COMMA] = ACTIONS(137),
    [anon_sym_LPAREN] = ACTIONS(59),
    [anon_sym_PLUS] = ACTIONS(61),
    [anon_sym_DASH] = ACTIONS(61),
    [anon_sym_TILDE] = ACTIONS(63),
    [anon_sym_QMARK] = ACTIONS(65),
    [anon_sym_AT] = ACTIONS(67),
    [anon_sym_LBRACK] = ACTIONS(75),
    [anon_sym_LBRACE] = ACTIONS(77),
    [sym_return_statement] = ACTIONS(79),
    [sym_continue_statement] = ACTIONS(79),
    [sym_break_statement] = ACTIONS(79),
    [anon_sym_if] = ACTIONS(25),
    [anon_sym_end] = ACTIONS(139),
    [anon_sym_for] = ACTIONS(27),
    [anon_sym_parfor] = ACTIONS(29),
    [anon_sym_while] = ACTIONS(31),
    [anon_sym_switch] = ACTIONS(33),
    [anon_sym_global] = ACTIONS(35),
    [anon_sym_persistent] = ACTIONS(37),
    [anon_sym_function] = ACTIONS(87),
    [anon_sym_classdef] = ACTIONS(41),
    [anon_sym_try] = ACTIONS(43),
    [sym_number] = ACTIONS(89),
    [anon_sym_true] = ACTIONS(47),
    [anon_sym_false] = ACTIONS(47),
    [anon_sym_LF] = ACTIONS(137),
    [anon_sym_CR] = ACTIONS(137),
    [sym_comment] = ACTIONS(3),
    [sym_line_continuation] = ACTIONS(3),
    [sym_command_name] = ACTIONS(49),
    [sym__single_quote_string_start] = ACTIONS(51),
    [sym__double_quote_string_start] = ACTIONS(53),
    [sym__multioutput_variable_start] = ACTIONS(55),
  },
  [20] = {
    [aux_sym__block] = STATE(54),
    [sym_block] = STATE(1152),
    [sym__statement] = STATE(874),
    [sym__expression] = STATE(627),
    [sym_parenthesis] = STATE(411),
    [sym__binary_expression] = STATE(622),
    [sym_binary_operator] = STATE(422),
    [sym_unary_operator] = STATE(389),
    [sym_indirect_access] = STATE(994),
    [sym_field_expression] = STATE(485),
    [sym_not_operator] = STATE(477),
    [sym_metaclass_operator] = STATE(627),
    [sym_handle_operator] = STATE(627),
    [sym_comparison_operator] = STATE(446),
    [sym_boolean_operator] = STATE(446),
    [sym_postfix_operator] = STATE(411),
    [sym_string] = STATE(411),
    [sym_matrix] = STATE(411),
    [sym_cell] = STATE(423),
    [sym_ignored_argument] = STATE(1187),
    [sym_assignment] = STATE(874),
    [sym_multioutput_variable] = STATE(1187),
    [sym_function_call] = STATE(210),
    [sym_command] = STATE(874),
    [sym__range_element] = STATE(1181),
    [sym_range] = STATE(627),
    [sym_if_statement] = STATE(874),
    [sym_for_statement] = STATE(874),
    [sym_while_statement] = STATE(874),
    [sym_switch_statement] = STATE(874),
    [sym_lambda] = STATE(627),
    [sym_global_operator] = STATE(874),
    [sym_persistent_operator] = STATE(874),
    [sym__function_definition_with_end] = STATE(877),
    [sym_class_definition] = STATE(874),
    [sym_try_statement] = STATE(874),
    [sym_boolean] = STATE(205),
    [sym__end_of_line] = STATE(13),
    [aux_sym_elseif_clause_repeat1] = STATE(13),
    [sym_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(141),
    [anon_sym_COMMA] = ACTIONS(141),
    [anon_sym_LPAREN] = ACTIONS(59),
    [anon_sym_PLUS] = ACTIONS(61),
    [anon_sym_DASH] = ACTIONS(61),
    [anon_sym_TILDE] = ACTIONS(63),
    [anon_sym_QMARK] = ACTIONS(65),
    [anon_sym_AT] = ACTIONS(67),
    [anon_sym_LBRACK] = ACTIONS(75),
    [anon_sym_LBRACE] = ACTIONS(77),
    [sym_return_statement] = ACTIONS(79),
    [sym_continue_statement] = ACTIONS(79),
    [sym_break_statement] = ACTIONS(79),
    [anon_sym_if] = ACTIONS(25),
    [anon_sym_end] = ACTIONS(143),
    [anon_sym_for] = ACTIONS(27),
    [anon_sym_parfor] = ACTIONS(29),
    [anon_sym_while] = ACTIONS(31),
    [anon_sym_switch] = ACTIONS(33),
    [anon_sym_global] = ACTIONS(35),
    [anon_sym_persistent] = ACTIONS(37),
    [anon_sym_function] = ACTIONS(87),
    [anon_sym_classdef] = ACTIONS(41),
    [anon_sym_try] = ACTIONS(43),
    [sym_number] = ACTIONS(89),
    [anon_sym_true] = ACTIONS(47),
    [anon_sym_false] = ACTIONS(47),
    [anon_sym_LF] = ACTIONS(141),
    [anon_sym_CR] = ACTIONS(141),
    [sym_comment] = ACTIONS(3),
    [sym_line_continuation] = ACTIONS(3),
    [sym_command_name] = ACTIONS(49),
    [sym__single_quote_string_start] = ACTIONS(51),
    [sym__double_quote_string_start] = ACTIONS(53),
    [sym__multioutput_variable_start] = ACTIONS(55),
  },
  [21] = {
    [aux_sym__block] = STATE(73),
    [sym_block] = STATE(964),
    [sym__statement] = STATE(853),
    [sym__expression] = STATE(632),
    [sym_parenthesis] = STATE(411),
    [sym__binary_expression] = STATE(622),
    [sym_binary_operator] = STATE(422),
    [sym_unary_operator] = STATE(389),
    [sym_indirect_access] = STATE(994),
    [sym_field_expression] = STATE(485),
    [sym_not_operator] = STATE(477),
    [sym_metaclass_operator] = STATE(632),
    [sym_handle_operator] = STATE(632),
    [sym_comparison_operator] = STATE(446),
    [sym_boolean_operator] = STATE(446),
    [sym_postfix_operator] = STATE(411),
    [sym_string] = STATE(411),
    [sym_matrix] = STATE(411),
    [sym_cell] = STATE(423),
    [sym_ignored_argument] = STATE(1187),
    [sym_assignment] = STATE(853),
    [sym_multioutput_variable] = STATE(1187),
    [sym_function_call] = STATE(210),
    [sym_command] = STATE(853),
    [sym__range_element] = STATE(1181),
    [sym_range] = STATE(632),
    [sym_if_statement] = STATE(853),
    [sym_for_statement] = STATE(853),
    [sym_while_statement] = STATE(853),
    [sym_switch_statement] = STATE(853),
    [sym_lambda] = STATE(632),
    [sym_global_operator] = STATE(853),
    [sym_persistent_operator] = STATE(853),
    [sym_arguments_statement] = STATE(44),
    [sym__function_definition_with_end] = STATE(888),
    [sym_class_definition] = STATE(853),
    [sym_try_statement] = STATE(853),
    [sym_boolean] = STATE(205),
    [aux_sym_function_definition_repeat1] = STATE(44),
    [ts_builtin_sym_end] = ACTIONS(145),
    [sym_identifier] = ACTIONS(7),
    [anon_sym_LPAREN] = ACTIONS(9),
    [anon_sym_PLUS] = ACTIONS(11),
    [anon_sym_DASH] = ACTIONS(11),
    [anon_sym_TILDE] = ACTIONS(13),
    [anon_sym_QMARK] = ACTIONS(15),
    [anon_sym_AT] = ACTIONS(17),
    [anon_sym_LBRACK] = ACTIONS(19),
    [anon_sym_LBRACE] = ACTIONS(21),
    [sym_return_statement] = ACTIONS(147),
    [sym_continue_statement] = ACTIONS(147),
    [sym_break_statement] = ACTIONS(147),
    [anon_sym_if] = ACTIONS(25),
    [anon_sym_end] = ACTIONS(149),
    [anon_sym_for] = ACTIONS(27),
    [anon_sym_parfor] = ACTIONS(29),
    [anon_sym_while] = ACTIONS(31),
    [anon_sym_switch] = ACTIONS(33),
    [anon_sym_global] = ACTIONS(35),
    [anon_sym_persistent] = ACTIONS(37),
    [anon_sym_arguments] = ACTIONS(151),
    [anon_sym_function] = ACTIONS(153),
    [anon_sym_endfunction] = ACTIONS(149),
    [anon_sym_classdef] = ACTIONS(41),
    [anon_sym_try] = ACTIONS(43),
    [sym_number] = ACTIONS(45),
    [anon_sym_true] = ACTIONS(47),
    [anon_sym_false] = ACTIONS(47),
    [sym_comment] = ACTIONS(3),
    [sym_line_continuation] = ACTIONS(3),
    [sym_command_name] = ACTIONS(49),
    [sym__single_quote_string_start] = ACTIONS(51),
    [sym__double_quote_string_start] = ACTIONS(53),
    [sym__multioutput_variable_start] = ACTIONS(55),
  },
  [22] = {
    [aux_sym__block] = STATE(73),
    [sym_block] = STATE(961),
    [sym__statement] = STATE(853),
    [sym__expression] = STATE(632),
    [sym_parenthesis] = STATE(411),
    [sym__binary_expression] = STATE(622),
    [sym_binary_operator] = STATE(422),
    [sym_unary_operator] = STATE(389),
    [sym_indirect_access] = STATE(994),
    [sym_field_expression] = STATE(485),
    [sym_not_operator] = STATE(477),
    [sym_metaclass_operator] = STATE(632),
    [sym_handle_operator] = STATE(632),
    [sym_comparison_operator] = STATE(446),
    [sym_boolean_operator] = STATE(446),
    [sym_postfix_operator] = STATE(411),
    [sym_string] = STATE(411),
    [sym_matrix] = STATE(411),
    [sym_cell] = STATE(423),
    [sym_ignored_argument] = STATE(1187),
    [sym_assignment] = STATE(853),
    [sym_multioutput_variable] = STATE(1187),
    [sym_function_call] = STATE(210),
    [sym_command] = STATE(853),
    [sym__range_element] = STATE(1181),
    [sym_range] = STATE(632),
    [sym_if_statement] = STATE(853),
    [sym_for_statement] = STATE(853),
    [sym_while_statement] = STATE(853),
    [sym_switch_statement] = STATE(853),
    [sym_lambda] = STATE(632),
    [sym_global_operator] = STATE(853),
    [sym_persistent_operator] = STATE(853),
    [sym_arguments_statement] = STATE(341),
    [sym__function_definition_with_end] = STATE(888),
    [sym_class_definition] = STATE(853),
    [sym_try_statement] = STATE(853),
    [sym_boolean] = STATE(205),
    [aux_sym_function_definition_repeat1] = STATE(341),
    [ts_builtin_sym_end] = ACTIONS(156),
    [sym_identifier] = ACTIONS(7),
    [anon_sym_LPAREN] = ACTIONS(9),
    [anon_sym_PLUS] = ACTIONS(11),
    [anon_sym_DASH] = ACTIONS(11),
    [anon_sym_TILDE] = ACTIONS(13),
    [anon_sym_QMARK] = ACTIONS(15),
    [anon_sym_AT] = ACTIONS(17),
    [anon_sym_LBRACK] = ACTIONS(19),
    [anon_sym_LBRACE] = ACTIONS(21),
    [sym_return_statement] = ACTIONS(147),
    [sym_continue_statement] = ACTIONS(147),
    [sym_break_statement] = ACTIONS(147),
    [anon_sym_if] = ACTIONS(25),
    [anon_sym_end] = ACTIONS(158),
    [anon_sym_for] = ACTIONS(27),
    [anon_sym_parfor] = ACTIONS(29),
    [anon_sym_while] = ACTIONS(31),
    [anon_sym_switch] = ACTIONS(33),
    [anon_sym_global] = ACTIONS(35),
    [anon_sym_persistent] = ACTIONS(37),
    [anon_sym_arguments] = ACTIONS(151),
    [anon_sym_function] = ACTIONS(160),
    [anon_sym_endfunction] = ACTIONS(158),
    [anon_sym_classdef] = ACTIONS(41),
    [anon_sym_try] = ACTIONS(43),
    [sym_number] = ACTIONS(45),
    [anon_sym_true] = ACTIONS(47),
    [anon_sym_false] = ACTIONS(47),
    [sym_comment] = ACTIONS(3),
    [sym_line_continuation] = ACTIONS(3),
    [sym_command_name] = ACTIONS(49),
    [sym__single_quote_string_start] = ACTIONS(51),
    [sym__double_quote_string_start] = ACTIONS(53),
    [sym__multioutput_variable_start] = ACTIONS(55),
  },
  [23] = {
    [aux_sym__block] = STATE(73),
    [sym_block] = STATE(980),
    [sym__statement] = STATE(853),
    [sym__expression] = STATE(632),
    [sym_parenthesis] = STATE(411),
    [sym__binary_expression] = STATE(622),
    [sym_binary_operator] = STATE(422),
    [sym_unary_operator] = STATE(389),
    [sym_indirect_access] = STATE(994),
    [sym_field_expression] = STATE(485),
    [sym_not_operator] = STATE(477),
    [sym_metaclass_operator] = STATE(632),
    [sym_handle_operator] = STATE(632),
    [sym_comparison_operator] = STATE(446),
    [sym_boolean_operator] = STATE(446),
    [sym_postfix_operator] = STATE(411),
    [sym_string] = STATE(411),
    [sym_matrix] = STATE(411),
    [sym_cell] = STATE(423),
    [sym_ignored_argument] = STATE(1187),
    [sym_assignment] = STATE(853),
    [sym_multioutput_variable] = STATE(1187),
    [sym_function_call] = STATE(210),
    [sym_command] = STATE(853),
    [sym__range_element] = STATE(1181),
    [sym_range] = STATE(632),
    [sym_if_statement] = STATE(853),
    [sym_for_statement] = STATE(853),
    [sym_while_statement] = STATE(853),
    [sym_switch_statement] = STATE(853),
    [sym_lambda] = STATE(632),
    [sym_global_operator] = STATE(853),
    [sym_persistent_operator] = STATE(853),
    [sym_arguments_statement] = STATE(341),
    [sym__function_definition_with_end] = STATE(888),
    [sym_class_definition] = STATE(853),
    [sym_try_statement] = STATE(853),
    [sym_boolean] = STATE(205),
    [aux_sym_function_definition_repeat1] = STATE(341),
    [ts_builtin_sym_end] = ACTIONS(163),
    [sym_identifier] = ACTIONS(7),
    [anon_sym_LPAREN] = ACTIONS(9),
    [anon_sym_PLUS] = ACTIONS(11),
    [anon_sym_DASH] = ACTIONS(11),
    [anon_sym_TILDE] = ACTIONS(13),
    [anon_sym_QMARK] = ACTIONS(15),
    [anon_sym_AT] = ACTIONS(17),
    [anon_sym_LBRACK] = ACTIONS(19),
    [anon_sym_LBRACE] = ACTIONS(21),
    [sym_return_statement] = ACTIONS(147),
    [sym_continue_statement] = ACTIONS(147),
    [sym_break_statement] = ACTIONS(147),
    [anon_sym_if] = ACTIONS(25),
    [anon_sym_end] = ACTIONS(165),
    [anon_sym_for] = ACTIONS(27),
    [anon_sym_parfor] = ACTIONS(29),
    [anon_sym_while] = ACTIONS(31),
    [anon_sym_switch] = ACTIONS(33),
    [anon_sym_global] = ACTIONS(35),
    [anon_sym_persistent] = ACTIONS(37),
    [anon_sym_arguments] = ACTIONS(151),
    [anon_sym_function] = ACTIONS(167),
    [anon_sym_endfunction] = ACTIONS(165),
    [anon_sym_classdef] = ACTIONS(41),
    [anon_sym_try] = ACTIONS(43),
    [sym_number] = ACTIONS(45),
    [anon_sym_true] = ACTIONS(47),
    [anon_sym_false] = ACTIONS(47),
    [sym_comment] = ACTIONS(3),
    [sym_line_continuation] = ACTIONS(3),
    [sym_command_name] = ACTIONS(49),
    [sym__single_quote_string_start] = ACTIONS(51),
    [sym__double_quote_string_start] = ACTIONS(53),
    [sym__multioutput_variable_start] = ACTIONS(55),
  },
  [24] = {
    [aux_sym__block] = STATE(73),
    [sym_block] = STATE(899),
    [sym__statement] = STATE(853),
    [sym__expression] = STATE(632),
    [sym_parenthesis] = STATE(411),
    [sym__binary_expression] = STATE(622),
    [sym_binary_operator] = STATE(422),
    [sym_unary_operator] = STATE(389),
    [sym_indirect_access] = STATE(994),
    [sym_field_expression] = STATE(485),
    [sym_not_operator] = STATE(477),
    [sym_metaclass_operator] = STATE(632),
    [sym_handle_operator] = STATE(632),
    [sym_comparison_operator] = STATE(446),
    [sym_boolean_operator] = STATE(446),
    [sym_postfix_operator] = STATE(411),
    [sym_string] = STATE(411),
    [sym_matrix] = STATE(411),
    [sym_cell] = STATE(423),
    [sym_ignored_argument] = STATE(1187),
    [sym_assignment] = STATE(853),
    [sym_multioutput_variable] = STATE(1187),
    [sym_function_call] = STATE(210),
    [sym_command] = STATE(853),
    [sym__range_element] = STATE(1181),
    [sym_range] = STATE(632),
    [sym_if_statement] = STATE(853),
    [sym_for_statement] = STATE(853),
    [sym_while_statement] = STATE(853),
    [sym_switch_statement] = STATE(853),
    [sym_lambda] = STATE(632),
    [sym_global_operator] = STATE(853),
    [sym_persistent_operator] = STATE(853),
    [sym_arguments_statement] = STATE(33),
    [sym__function_definition_with_end] = STATE(888),
    [sym_class_definition] = STATE(853),
    [sym_try_statement] = STATE(853),
    [sym_boolean] = STATE(205),
    [aux_sym_function_definition_repeat1] = STATE(33),
    [ts_builtin_sym_end] = ACTIONS(156),
    [sym_identifier] = ACTIONS(7),
    [anon_sym_LPAREN] = ACTIONS(9),
    [anon_sym_PLUS] = ACTIONS(11),
    [anon_sym_DASH] = ACTIONS(11),
    [anon_sym_TILDE] = ACTIONS(13),
    [anon_sym_QMARK] = ACTIONS(15),
    [anon_sym_AT] = ACTIONS(17),
    [anon_sym_LBRACK] = ACTIONS(19),
    [anon_sym_LBRACE] = ACTIONS(21),
    [sym_return_statement] = ACTIONS(147),
    [sym_continue_statement] = ACTIONS(147),
    [sym_break_statement] = ACTIONS(147),
    [anon_sym_if] = ACTIONS(25),
    [anon_sym_end] = ACTIONS(170),
    [anon_sym_for] = ACTIONS(27),
    [anon_sym_parfor] = ACTIONS(29),
    [anon_sym_while] = ACTIONS(31),
    [anon_sym_switch] = ACTIONS(33),
    [anon_sym_global] = ACTIONS(35),
    [anon_sym_persistent] = ACTIONS(37),
    [anon_sym_arguments] = ACTIONS(151),
    [anon_sym_function] = ACTIONS(160),
    [anon_sym_endfunction] = ACTIONS(170),
    [anon_sym_classdef] = ACTIONS(41),
    [anon_sym_try] = ACTIONS(43),
    [sym_number] = ACTIONS(45),
    [anon_sym_true] = ACTIONS(47),
    [anon_sym_false] = ACTIONS(47),
    [sym_comment] = ACTIONS(3),
    [sym_line_continuation] = ACTIONS(3),
    [sym_command_name] = ACTIONS(49),
    [sym__single_quote_string_start] = ACTIONS(51),
    [sym__double_quote_string_start] = ACTIONS(53),
    [sym__multioutput_variable_start] = ACTIONS(55),
  },
  [25] = {
    [aux_sym__block] = STATE(73),
    [sym_block] = STATE(899),
    [sym__statement] = STATE(853),
    [sym__expression] = STATE(632),
    [sym_parenthesis] = STATE(411),
    [sym__binary_expression] = STATE(622),
    [sym_binary_operator] = STATE(422),
    [sym_unary_operator] = STATE(389),
    [sym_indirect_access] = STATE(994),
    [sym_field_expression] = STATE(485),
    [sym_not_operator] = STATE(477),
    [sym_metaclass_operator] = STATE(632),
    [sym_handle_operator] = STATE(632),
    [sym_comparison_operator] = STATE(446),
    [sym_boolean_operator] = STATE(446),
    [sym_postfix_operator] = STATE(411),
    [sym_string] = STATE(411),
    [sym_matrix] = STATE(411),
    [sym_cell] = STATE(423),
    [sym_ignored_argument] = STATE(1187),
    [sym_assignment] = STATE(853),
    [sym_multioutput_variable] = STATE(1187),
    [sym_function_call] = STATE(210),
    [sym_command] = STATE(853),
    [sym__range_element] = STATE(1181),
    [sym_range] = STATE(632),
    [sym_if_statement] = STATE(853),
    [sym_for_statement] = STATE(853),
    [sym_while_statement] = STATE(853),
    [sym_switch_statement] = STATE(853),
    [sym_lambda] = STATE(632),
    [sym_global_operator] = STATE(853),
    [sym_persistent_operator] = STATE(853),
    [sym_arguments_statement] = STATE(341),
    [sym__function_definition_with_end] = STATE(888),
    [sym_class_definition] = STATE(853),
    [sym_try_statement] = STATE(853),
    [sym_boolean] = STATE(205),
    [aux_sym_function_definition_repeat1] = STATE(341),
    [ts_builtin_sym_end] = ACTIONS(156),
    [sym_identifier] = ACTIONS(7),
    [anon_sym_LPAREN] = ACTIONS(9),
    [anon_sym_PLUS] = ACTIONS(11),
    [anon_sym_DASH] = ACTIONS(11),
    [anon_sym_TILDE] = ACTIONS(13),
    [anon_sym_QMARK] = ACTIONS(15),
    [anon_sym_AT] = ACTIONS(17),
    [anon_sym_LBRACK] = ACTIONS(19),
    [anon_sym_LBRACE] = ACTIONS(21),
    [sym_return_statement] = ACTIONS(147),
    [sym_continue_statement] = ACTIONS(147),
    [sym_break_statement] = ACTIONS(147),
    [anon_sym_if] = ACTIONS(25),
    [anon_sym_end] = ACTIONS(170),
    [anon_sym_for] = ACTIONS(27),
    [anon_sym_parfor] = ACTIONS(29),
    [anon_sym_while] = ACTIONS(31),
    [anon_sym_switch] = ACTIONS(33),
    [anon_sym_global] = ACTIONS(35),
    [anon_sym_persistent] = ACTIONS(37),
    [anon_sym_arguments] = ACTIONS(151),
    [anon_sym_function] = ACTIONS(160),
    [anon_sym_endfunction] = ACTIONS(170),
    [anon_sym_classdef] = ACTIONS(41),
    [anon_sym_try] = ACTIONS(43),
    [sym_number] = ACTIONS(45),
    [anon_sym_true] = ACTIONS(47),
    [anon_sym_false] = ACTIONS(47),
    [sym_comment] = ACTIONS(3),
    [sym_line_continuation] = ACTIONS(3),
    [sym_command_name] = ACTIONS(49),
    [sym__single_quote_string_start] = ACTIONS(51),
    [sym__double_quote_string_start] = ACTIONS(53),
    [sym__multioutput_variable_start] = ACTIONS(55),
  },
  [26] = {
    [aux_sym__block] = STATE(73),
    [sym_block] = STATE(962),
    [sym__statement] = STATE(853),
    [sym__expression] = STATE(632),
    [sym_parenthesis] = STATE(411),
    [sym__binary_expression] = STATE(622),
    [sym_binary_operator] = STATE(422),
    [sym_unary_operator] = STATE(389),
    [sym_indirect_access] = STATE(994),
    [sym_field_expression] = STATE(485),
    [sym_not_operator] = STATE(477),
    [sym_metaclass_operator] = STATE(632),
    [sym_handle_operator] = STATE(632),
    [sym_comparison_operator] = STATE(446),
    [sym_boolean_operator] = STATE(446),
    [sym_postfix_operator] = STATE(411),
    [sym_string] = STATE(411),
    [sym_matrix] = STATE(411),
    [sym_cell] = STATE(423),
    [sym_ignored_argument] = STATE(1187),
    [sym_assignment] = STATE(853),
    [sym_multioutput_variable] = STATE(1187),
    [sym_function_call] = STATE(210),
    [sym_command] = STATE(853),
    [sym__range_element] = STATE(1181),
    [sym_range] = STATE(632),
    [sym_if_statement] = STATE(853),
    [sym_for_statement] = STATE(853),
    [sym_while_statement] = STATE(853),
    [sym_switch_statement] = STATE(853),
    [sym_lambda] = STATE(632),
    [sym_global_operator] = STATE(853),
    [sym_persistent_operator] = STATE(853),
    [sym_arguments_statement] = STATE(36),
    [sym__function_definition_with_end] = STATE(888),
    [sym_class_definition] = STATE(853),
    [sym_try_statement] = STATE(853),
    [sym_boolean] = STATE(205),
    [aux_sym_function_definition_repeat1] = STATE(36),
    [ts_builtin_sym_end] = ACTIONS(172),
    [sym_identifier] = ACTIONS(7),
    [anon_sym_LPAREN] = ACTIONS(9),
    [anon_sym_PLUS] = ACTIONS(11),
    [anon_sym_DASH] = ACTIONS(11),
    [anon_sym_TILDE] = ACTIONS(13),
    [anon_sym_QMARK] = ACTIONS(15),
    [anon_sym_AT] = ACTIONS(17),
    [anon_sym_LBRACK] = ACTIONS(19),
    [anon_sym_LBRACE] = ACTIONS(21),
    [sym_return_statement] = ACTIONS(147),
    [sym_continue_statement] = ACTIONS(147),
    [sym_break_statement] = ACTIONS(147),
    [anon_sym_if] = ACTIONS(25),
    [anon_sym_end] = ACTIONS(174),
    [anon_sym_for] = ACTIONS(27),
    [anon_sym_parfor] = ACTIONS(29),
    [anon_sym_while] = ACTIONS(31),
    [anon_sym_switch] = ACTIONS(33),
    [anon_sym_global] = ACTIONS(35),
    [anon_sym_persistent] = ACTIONS(37),
    [anon_sym_arguments] = ACTIONS(151),
    [anon_sym_function] = ACTIONS(176),
    [anon_sym_endfunction] = ACTIONS(174),
    [anon_sym_classdef] = ACTIONS(41),
    [anon_sym_try] = ACTIONS(43),
    [sym_number] = ACTIONS(45),
    [anon_sym_true] = ACTIONS(47),
    [anon_sym_false] = ACTIONS(47),
    [sym_comment] = ACTIONS(3),
    [sym_line_continuation] = ACTIONS(3),
    [sym_command_name] = ACTIONS(49),
    [sym__single_quote_string_start] = ACTIONS(51),
    [sym__double_quote_string_start] = ACTIONS(53),
    [sym__multioutput_variable_start] = ACTIONS(55),
  },
  [27] = {
    [aux_sym__block] = STATE(73),
    [sym_block] = STATE(895),
    [sym__statement] = STATE(853),
    [sym__expression] = STATE(632),
    [sym_parenthesis] = STATE(411),
    [sym__binary_expression] = STATE(622),
    [sym_binary_operator] = STATE(422),
    [sym_unary_operator] = STATE(389),
    [sym_indirect_access] = STATE(994),
    [sym_field_expression] = STATE(485),
    [sym_not_operator] = STATE(477),
    [sym_metaclass_operator] = STATE(632),
    [sym_handle_operator] = STATE(632),
    [sym_comparison_operator] = STATE(446),
    [sym_boolean_operator] = STATE(446),
    [sym_postfix_operator] = STATE(411),
    [sym_string] = STATE(411),
    [sym_matrix] = STATE(411),
    [sym_cell] = STATE(423),
    [sym_ignored_argument] = STATE(1187),
    [sym_assignment] = STATE(853),
    [sym_multioutput_variable] = STATE(1187),
    [sym_function_call] = STATE(210),
    [sym_command] = STATE(853),
    [sym__range_element] = STATE(1181),
    [sym_range] = STATE(632),
    [sym_if_statement] = STATE(853),
    [sym_for_statement] = STATE(853),
    [sym_while_statement] = STATE(853),
    [sym_switch_statement] = STATE(853),
    [sym_lambda] = STATE(632),
    [sym_global_operator] = STATE(853),
    [sym_persistent_operator] = STATE(853),
    [sym_arguments_statement] = STATE(341),
    [sym__function_definition_with_end] = STATE(888),
    [sym_class_definition] = STATE(853),
    [sym_try_statement] = STATE(853),
    [sym_boolean] = STATE(205),
    [aux_sym_function_definition_repeat1] = STATE(341),
    [ts_builtin_sym_end] = ACTIONS(179),
    [sym_identifier] = ACTIONS(7),
    [anon_sym_LPAREN] = ACTIONS(9),
    [anon_sym_PLUS] = ACTIONS(11),
    [anon_sym_DASH] = ACTIONS(11),
    [anon_sym_TILDE] = ACTIONS(13),
    [anon_sym_QMARK] = ACTIONS(15),
    [anon_sym_AT] = ACTIONS(17),
    [anon_sym_LBRACK] = ACTIONS(19),
    [anon_sym_LBRACE] = ACTIONS(21),
    [sym_return_statement] = ACTIONS(147),
    [sym_continue_statement] = ACTIONS(147),
    [sym_break_statement] = ACTIONS(147),
    [anon_sym_if] = ACTIONS(25),
    [anon_sym_end] = ACTIONS(181),
    [anon_sym_for] = ACTIONS(27),
    [anon_sym_parfor] = ACTIONS(29),
    [anon_sym_while] = ACTIONS(31),
    [anon_sym_switch] = ACTIONS(33),
    [anon_sym_global] = ACTIONS(35),
    [anon_sym_persistent] = ACTIONS(37),
    [anon_sym_arguments] = ACTIONS(151),
    [anon_sym_function] = ACTIONS(183),
    [anon_sym_endfunction] = ACTIONS(181),
    [anon_sym_classdef] = ACTIONS(41),
    [anon_sym_try] = ACTIONS(43),
    [sym_number] = ACTIONS(45),
    [anon_sym_true] = ACTIONS(47),
    [anon_sym_false] = ACTIONS(47),
    [sym_comment] = ACTIONS(3),
    [sym_line_continuation] = ACTIONS(3),
    [sym_command_name] = ACTIONS(49),
    [sym__single_quote_string_start] = ACTIONS(51),
    [sym__double_quote_string_start] = ACTIONS(53),
    [sym__multioutput_variable_start] = ACTIONS(55),
  },
  [28] = {
    [aux_sym__block] = STATE(73),
    [sym_block] = STATE(898),
    [sym__statement] = STATE(853),
    [sym__expression] = STATE(632),
    [sym_parenthesis] = STATE(411),
    [sym__binary_expression] = STATE(622),
    [sym_binary_operator] = STATE(422),
    [sym_unary_operator] = STATE(389),
    [sym_indirect_access] = STATE(994),
    [sym_field_expression] = STATE(485),
    [sym_not_operator] = STATE(477),
    [sym_metaclass_operator] = STATE(632),
    [sym_handle_operator] = STATE(632),
    [sym_comparison_operator] = STATE(446),
    [sym_boolean_operator] = STATE(446),
    [sym_postfix_operator] = STATE(411),
    [sym_string] = STATE(411),
    [sym_matrix] = STATE(411),
    [sym_cell] = STATE(423),
    [sym_ignored_argument] = STATE(1187),
    [sym_assignment] = STATE(853),
    [sym_multioutput_variable] = STATE(1187),
    [sym_function_call] = STATE(210),
    [sym_command] = STATE(853),
    [sym__range_element] = STATE(1181),
    [sym_range] = STATE(632),
    [sym_if_statement] = STATE(853),
    [sym_for_statement] = STATE(853),
    [sym_while_statement] = STATE(853),
    [sym_switch_statement] = STATE(853),
    [sym_lambda] = STATE(632),
    [sym_global_operator] = STATE(853),
    [sym_persistent_operator] = STATE(853),
    [sym_arguments_statement] = STATE(35),
    [sym__function_definition_with_end] = STATE(888),
    [sym_class_definition] = STATE(853),
    [sym_try_statement] = STATE(853),
    [sym_boolean] = STATE(205),
    [aux_sym_function_definition_repeat1] = STATE(35),
    [ts_builtin_sym_end] = ACTIONS(145),
    [sym_identifier] = ACTIONS(7),
    [anon_sym_LPAREN] = ACTIONS(9),
    [anon_sym_PLUS] = ACTIONS(11),
    [anon_sym_DASH] = ACTIONS(11),
    [anon_sym_TILDE] = ACTIONS(13),
    [anon_sym_QMARK] = ACTIONS(15),
    [anon_sym_AT] = ACTIONS(17),
    [anon_sym_LBRACK] = ACTIONS(19),
    [anon_sym_LBRACE] = ACTIONS(21),
    [sym_return_statement] = ACTIONS(147),
    [sym_continue_statement] = ACTIONS(147),
    [sym_break_statement] = ACTIONS(147),
    [anon_sym_if] = ACTIONS(25),
    [anon_sym_end] = ACTIONS(186),
    [anon_sym_for] = ACTIONS(27),
    [anon_sym_parfor] = ACTIONS(29),
    [anon_sym_while] = ACTIONS(31),
    [anon_sym_switch] = ACTIONS(33),
    [anon_sym_global] = ACTIONS(35),
    [anon_sym_persistent] = ACTIONS(37),
    [anon_sym_arguments] = ACTIONS(151),
    [anon_sym_function] = ACTIONS(153),
    [anon_sym_endfunction] = ACTIONS(186),
    [anon_sym_classdef] = ACTIONS(41),
    [anon_sym_try] = ACTIONS(43),
    [sym_number] = ACTIONS(45),
    [anon_sym_true] = ACTIONS(47),
    [anon_sym_false] = ACTIONS(47),
    [sym_comment] = ACTIONS(3),
    [sym_line_continuation] = ACTIONS(3),
    [sym_command_name] = ACTIONS(49),
    [sym__single_quote_string_start] = ACTIONS(51),
    [sym__double_quote_string_start] = ACTIONS(53),
    [sym__multioutput_variable_start] = ACTIONS(55),
  },
  [29] = {
    [aux_sym__block] = STATE(73),
    [sym_block] = STATE(918),
    [sym__statement] = STATE(853),
    [sym__expression] = STATE(632),
    [sym_parenthesis] = STATE(411),
    [sym__binary_expression] = STATE(622),
    [sym_binary_operator] = STATE(422),
    [sym_unary_operator] = STATE(389),
    [sym_indirect_access] = STATE(994),
    [sym_field_expression] = STATE(485),
    [sym_not_operator] = STATE(477),
    [sym_metaclass_operator] = STATE(632),
    [sym_handle_operator] = STATE(632),
    [sym_comparison_operator] = STATE(446),
    [sym_boolean_operator] = STATE(446),
    [sym_postfix_operator] = STATE(411),
    [sym_string] = STATE(411),
    [sym_matrix] = STATE(411),
    [sym_cell] = STATE(423),
    [sym_ignored_argument] = STATE(1187),
    [sym_assignment] = STATE(853),
    [sym_multioutput_variable] = STATE(1187),
    [sym_function_call] = STATE(210),
    [sym_command] = STATE(853),
    [sym__range_element] = STATE(1181),
    [sym_range] = STATE(632),
    [sym_if_statement] = STATE(853),
    [sym_for_statement] = STATE(853),
    [sym_while_statement] = STATE(853),
    [sym_switch_statement] = STATE(853),
    [sym_lambda] = STATE(632),
    [sym_global_operator] = STATE(853),
    [sym_persistent_operator] = STATE(853),
    [sym_arguments_statement] = STATE(22),
    [sym__function_definition_with_end] = STATE(888),
    [sym_class_definition] = STATE(853),
    [sym_try_statement] = STATE(853),
    [sym_boolean] = STATE(205),
    [aux_sym_function_definition_repeat1] = STATE(22),
    [ts_builtin_sym_end] = ACTIONS(188),
    [sym_identifier] = ACTIONS(7),
    [anon_sym_LPAREN] = ACTIONS(9),
    [anon_sym_PLUS] = ACTIONS(11),
    [anon_sym_DASH] = ACTIONS(11),
    [anon_sym_TILDE] = ACTIONS(13),
    [anon_sym_QMARK] = ACTIONS(15),
    [anon_sym_AT] = ACTIONS(17),
    [anon_sym_LBRACK] = ACTIONS(19),
    [anon_sym_LBRACE] = ACTIONS(21),
    [sym_return_statement] = ACTIONS(147),
    [sym_continue_statement] = ACTIONS(147),
    [sym_break_statement] = ACTIONS(147),
    [anon_sym_if] = ACTIONS(25),
    [anon_sym_end] = ACTIONS(190),
    [anon_sym_for] = ACTIONS(27),
    [anon_sym_parfor] = ACTIONS(29),
    [anon_sym_while] = ACTIONS(31),
    [anon_sym_switch] = ACTIONS(33),
    [anon_sym_global] = ACTIONS(35),
    [anon_sym_persistent] = ACTIONS(37),
    [anon_sym_arguments] = ACTIONS(151),
    [anon_sym_function] = ACTIONS(192),
    [anon_sym_endfunction] = ACTIONS(190),
    [anon_sym_classdef] = ACTIONS(41),
    [anon_sym_try] = ACTIONS(43),
    [sym_number] = ACTIONS(45),
    [anon_sym_true] = ACTIONS(47),
    [anon_sym_false] = ACTIONS(47),
    [sym_comment] = ACTIONS(3),
    [sym_line_continuation] = ACTIONS(3),
    [sym_command_name] = ACTIONS(49),
    [sym__single_quote_string_start] = ACTIONS(51),
    [sym__double_quote_string_start] = ACTIONS(53),
    [sym__multioutput_variable_start] = ACTIONS(55),
  },
  [30] = {
    [aux_sym__block] = STATE(73),
    [sym_block] = STATE(921),
    [sym__statement] = STATE(853),
    [sym__expression] = STATE(632),
    [sym_parenthesis] = STATE(411),
    [sym__binary_expression] = STATE(622),
    [sym_binary_operator] = STATE(422),
    [sym_unary_operator] = STATE(389),
    [sym_indirect_access] = STATE(994),
    [sym_field_expression] = STATE(485),
    [sym_not_operator] = STATE(477),
    [sym_metaclass_operator] = STATE(632),
    [sym_handle_operator] = STATE(632),
    [sym_comparison_operator] = STATE(446),
    [sym_boolean_operator] = STATE(446),
    [sym_postfix_operator] = STATE(411),
    [sym_string] = STATE(411),
    [sym_matrix] = STATE(411),
    [sym_cell] = STATE(423),
    [sym_ignored_argument] = STATE(1187),
    [sym_assignment] = STATE(853),
    [sym_multioutput_variable] = STATE(1187),
    [sym_function_call] = STATE(210),
    [sym_command] = STATE(853),
    [sym__range_element] = STATE(1181),
    [sym_range] = STATE(632),
    [sym_if_statement] = STATE(853),
    [sym_for_statement] = STATE(853),
    [sym_while_statement] = STATE(853),
    [sym_switch_statement] = STATE(853),
    [sym_lambda] = STATE(632),
    [sym_global_operator] = STATE(853),
    [sym_persistent_operator] = STATE(853),
    [sym_arguments_statement] = STATE(42),
    [sym__function_definition_with_end] = STATE(888),
    [sym_class_definition] = STATE(853),
    [sym_try_statement] = STATE(853),
    [sym_boolean] = STATE(205),
    [aux_sym_function_definition_repeat1] = STATE(42),
    [ts_builtin_sym_end] = ACTIONS(195),
    [sym_identifier] = ACTIONS(7),
    [anon_sym_LPAREN] = ACTIONS(9),
    [anon_sym_PLUS] = ACTIONS(11),
    [anon_sym_DASH] = ACTIONS(11),
    [anon_sym_TILDE] = ACTIONS(13),
    [anon_sym_QMARK] = ACTIONS(15),
    [anon_sym_AT] = ACTIONS(17),
    [anon_sym_LBRACK] = ACTIONS(19),
    [anon_sym_LBRACE] = ACTIONS(21),
    [sym_return_statement] = ACTIONS(147),
    [sym_continue_statement] = ACTIONS(147),
    [sym_break_statement] = ACTIONS(147),
    [anon_sym_if] = ACTIONS(25),
    [anon_sym_end] = ACTIONS(197),
    [anon_sym_for] = ACTIONS(27),
    [anon_sym_parfor] = ACTIONS(29),
    [anon_sym_while] = ACTIONS(31),
    [anon_sym_switch] = ACTIONS(33),
    [anon_sym_global] = ACTIONS(35),
    [anon_sym_persistent] = ACTIONS(37),
    [anon_sym_arguments] = ACTIONS(151),
    [anon_sym_function] = ACTIONS(199),
    [anon_sym_endfunction] = ACTIONS(197),
    [anon_sym_classdef] = ACTIONS(41),
    [anon_sym_try] = ACTIONS(43),
    [sym_number] = ACTIONS(45),
    [anon_sym_true] = ACTIONS(47),
    [anon_sym_false] = ACTIONS(47),
    [sym_comment] = ACTIONS(3),
    [sym_line_continuation] = ACTIONS(3),
    [sym_command_name] = ACTIONS(49),
    [sym__single_quote_string_start] = ACTIONS(51),
    [sym__double_quote_string_start] = ACTIONS(53),
    [sym__multioutput_variable_start] = ACTIONS(55),
  },
  [31] = {
    [aux_sym__block] = STATE(73),
    [sym_block] = STATE(921),
    [sym__statement] = STATE(853),
    [sym__expression] = STATE(632),
    [sym_parenthesis] = STATE(411),
    [sym__binary_expression] = STATE(622),
    [sym_binary_operator] = STATE(422),
    [sym_unary_operator] = STATE(389),
    [sym_indirect_access] = STATE(994),
    [sym_field_expression] = STATE(485),
    [sym_not_operator] = STATE(477),
    [sym_metaclass_operator] = STATE(632),
    [sym_handle_operator] = STATE(632),
    [sym_comparison_operator] = STATE(446),
    [sym_boolean_operator] = STATE(446),
    [sym_postfix_operator] = STATE(411),
    [sym_string] = STATE(411),
    [sym_matrix] = STATE(411),
    [sym_cell] = STATE(423),
    [sym_ignored_argument] = STATE(1187),
    [sym_assignment] = STATE(853),
    [sym_multioutput_variable] = STATE(1187),
    [sym_function_call] = STATE(210),
    [sym_command] = STATE(853),
    [sym__range_element] = STATE(1181),
    [sym_range] = STATE(632),
    [sym_if_statement] = STATE(853),
    [sym_for_statement] = STATE(853),
    [sym_while_statement] = STATE(853),
    [sym_switch_statement] = STATE(853),
    [sym_lambda] = STATE(632),
    [sym_global_operator] = STATE(853),
    [sym_persistent_operator] = STATE(853),
    [sym_arguments_statement] = STATE(341),
    [sym__function_definition_with_end] = STATE(888),
    [sym_class_definition] = STATE(853),
    [sym_try_statement] = STATE(853),
    [sym_boolean] = STATE(205),
    [aux_sym_function_definition_repeat1] = STATE(341),
    [ts_builtin_sym_end] = ACTIONS(195),
    [sym_identifier] = ACTIONS(7),
    [anon_sym_LPAREN] = ACTIONS(9),
    [anon_sym_PLUS] = ACTIONS(11),
    [anon_sym_DASH] = ACTIONS(11),
    [anon_sym_TILDE] = ACTIONS(13),
    [anon_sym_QMARK] = ACTIONS(15),
    [anon_sym_AT] = ACTIONS(17),
    [anon_sym_LBRACK] = ACTIONS(19),
    [anon_sym_LBRACE] = ACTIONS(21),
    [sym_return_statement] = ACTIONS(147),
    [sym_continue_statement] = ACTIONS(147),
    [sym_break_statement] = ACTIONS(147),
    [anon_sym_if] = ACTIONS(25),
    [anon_sym_end] = ACTIONS(197),
    [anon_sym_for] = ACTIONS(27),
    [anon_sym_parfor] = ACTIONS(29),
    [anon_sym_while] = ACTIONS(31),
    [anon_sym_switch] = ACTIONS(33),
    [anon_sym_global] = ACTIONS(35),
    [anon_sym_persistent] = ACTIONS(37),
    [anon_sym_arguments] = ACTIONS(151),
    [anon_sym_function] = ACTIONS(199),
    [anon_sym_endfunction] = ACTIONS(197),
    [anon_sym_classdef] = ACTIONS(41),
    [anon_sym_try] = ACTIONS(43),
    [sym_number] = ACTIONS(45),
    [anon_sym_true] = ACTIONS(47),
    [anon_sym_false] = ACTIONS(47),
    [sym_comment] = ACTIONS(3),
    [sym_line_continuation] = ACTIONS(3),
    [sym_command_name] = ACTIONS(49),
    [sym__single_quote_string_start] = ACTIONS(51),
    [sym__double_quote_string_start] = ACTIONS(53),
    [sym__multioutput_variable_start] = ACTIONS(55),
  },
  [32] = {
    [aux_sym__block] = STATE(73),
    [sym_block] = STATE(901),
    [sym__statement] = STATE(853),
    [sym__expression] = STATE(632),
    [sym_parenthesis] = STATE(411),
    [sym__binary_expression] = STATE(622),
    [sym_binary_operator] = STATE(422),
    [sym_unary_operator] = STATE(389),
    [sym_indirect_access] = STATE(994),
    [sym_field_expression] = STATE(485),
    [sym_not_operator] = STATE(477),
    [sym_metaclass_operator] = STATE(632),
    [sym_handle_operator] = STATE(632),
    [sym_comparison_operator] = STATE(446),
    [sym_boolean_operator] = STATE(446),
    [sym_postfix_operator] = STATE(411),
    [sym_string] = STATE(411),
    [sym_matrix] = STATE(411),
    [sym_cell] = STATE(423),
    [sym_ignored_argument] = STATE(1187),
    [sym_assignment] = STATE(853),
    [sym_multioutput_variable] = STATE(1187),
    [sym_function_call] = STATE(210),
    [sym_command] = STATE(853),
    [sym__range_element] = STATE(1181),
    [sym_range] = STATE(632),
    [sym_if_statement] = STATE(853),
    [sym_for_statement] = STATE(853),
    [sym_while_statement] = STATE(853),
    [sym_switch_statement] = STATE(853),
    [sym_lambda] = STATE(632),
    [sym_global_operator] = STATE(853),
    [sym_persistent_operator] = STATE(853),
    [sym_arguments_statement] = STATE(31),
    [sym__function_definition_with_end] = STATE(888),
    [sym_class_definition] = STATE(853),
    [sym_try_statement] = STATE(853),
    [sym_boolean] = STATE(205),
    [aux_sym_function_definition_repeat1] = STATE(31),
    [ts_builtin_sym_end] = ACTIONS(172),
    [sym_identifier] = ACTIONS(7),
    [anon_sym_LPAREN] = ACTIONS(9),
    [anon_sym_PLUS] = ACTIONS(11),
    [anon_sym_DASH] = ACTIONS(11),
    [anon_sym_TILDE] = ACTIONS(13),
    [anon_sym_QMARK] = ACTIONS(15),
    [anon_sym_AT] = ACTIONS(17),
    [anon_sym_LBRACK] = ACTIONS(19),
    [anon_sym_LBRACE] = ACTIONS(21),
    [sym_return_statement] = ACTIONS(147),
    [sym_continue_statement] = ACTIONS(147),
    [sym_break_statement] = ACTIONS(147),
    [anon_sym_if] = ACTIONS(25),
    [anon_sym_end] = ACTIONS(202),
    [anon_sym_for] = ACTIONS(27),
    [anon_sym_parfor] = ACTIONS(29),
    [anon_sym_while] = ACTIONS(31),
    [anon_sym_switch] = ACTIONS(33),
    [anon_sym_global] = ACTIONS(35),
    [anon_sym_persistent] = ACTIONS(37),
    [anon_sym_arguments] = ACTIONS(151),
    [anon_sym_function] = ACTIONS(176),
    [anon_sym_endfunction] = ACTIONS(202),
    [anon_sym_classdef] = ACTIONS(41),
    [anon_sym_try] = ACTIONS(43),
    [sym_number] = ACTIONS(45),
    [anon_sym_true] = ACTIONS(47),
    [anon_sym_false] = ACTIONS(47),
    [sym_comment] = ACTIONS(3),
    [sym_line_continuation] = ACTIONS(3),
    [sym_command_name] = ACTIONS(49),
    [sym__single_quote_string_start] = ACTIONS(51),
    [sym__double_quote_string_start] = ACTIONS(53),
    [sym__multioutput_variable_start] = ACTIONS(55),
  },
  [33] = {
    [aux_sym__block] = STATE(73),
    [sym_block] = STATE(927),
    [sym__statement] = STATE(853),
    [sym__expression] = STATE(632),
    [sym_parenthesis] = STATE(411),
    [sym__binary_expression] = STATE(622),
    [sym_binary_operator] = STATE(422),
    [sym_unary_operator] = STATE(389),
    [sym_indirect_access] = STATE(994),
    [sym_field_expression] = STATE(485),
    [sym_not_operator] = STATE(477),
    [sym_metaclass_operator] = STATE(632),
    [sym_handle_operator] = STATE(632),
    [sym_comparison_operator] = STATE(446),
    [sym_boolean_operator] = STATE(446),
    [sym_postfix_operator] = STATE(411),
    [sym_string] = STATE(411),
    [sym_matrix] = STATE(411),
    [sym_cell] = STATE(423),
    [sym_ignored_argument] = STATE(1187),
    [sym_assignment] = STATE(853),
    [sym_multioutput_variable] = STATE(1187),
    [sym_function_call] = STATE(210),
    [sym_command] = STATE(853),
    [sym__range_element] = STATE(1181),
    [sym_range] = STATE(632),
    [sym_if_statement] = STATE(853),
    [sym_for_statement] = STATE(853),
    [sym_while_statement] = STATE(853),
    [sym_switch_statement] = STATE(853),
    [sym_lambda] = STATE(632),
    [sym_global_operator] = STATE(853),
    [sym_persistent_operator] = STATE(853),
    [sym_arguments_statement] = STATE(341),
    [sym__function_definition_with_end] = STATE(888),
    [sym_class_definition] = STATE(853),
    [sym_try_statement] = STATE(853),
    [sym_boolean] = STATE(205),
    [aux_sym_function_definition_repeat1] = STATE(341),
    [ts_builtin_sym_end] = ACTIONS(163),
    [sym_identifier] = ACTIONS(7),
    [anon_sym_LPAREN] = ACTIONS(9),
    [anon_sym_PLUS] = ACTIONS(11),
    [anon_sym_DASH] = ACTIONS(11),
    [anon_sym_TILDE] = ACTIONS(13),
    [anon_sym_QMARK] = ACTIONS(15),
    [anon_sym_AT] = ACTIONS(17),
    [anon_sym_LBRACK] = ACTIONS(19),
    [anon_sym_LBRACE] = ACTIONS(21),
    [sym_return_statement] = ACTIONS(147),
    [sym_continue_statement] = ACTIONS(147),
    [sym_break_statement] = ACTIONS(147),
    [anon_sym_if] = ACTIONS(25),
    [anon_sym_end] = ACTIONS(204),
    [anon_sym_for] = ACTIONS(27),
    [anon_sym_parfor] = ACTIONS(29),
    [anon_sym_while] = ACTIONS(31),
    [anon_sym_switch] = ACTIONS(33),
    [anon_sym_global] = ACTIONS(35),
    [anon_sym_persistent] = ACTIONS(37),
    [anon_sym_arguments] = ACTIONS(151),
    [anon_sym_function] = ACTIONS(167),
    [anon_sym_endfunction] = ACTIONS(204),
    [anon_sym_classdef] = ACTIONS(41),
    [anon_sym_try] = ACTIONS(43),
    [sym_number] = ACTIONS(45),
    [anon_sym_true] = ACTIONS(47),
    [anon_sym_false] = ACTIONS(47),
    [sym_comment] = ACTIONS(3),
    [sym_line_continuation] = ACTIONS(3),
    [sym_command_name] = ACTIONS(49),
    [sym__single_quote_string_start] = ACTIONS(51),
    [sym__double_quote_string_start] = ACTIONS(53),
    [sym__multioutput_variable_start] = ACTIONS(55),
  },
  [34] = {
    [aux_sym__block] = STATE(73),
    [sym_block] = STATE(934),
    [sym__statement] = STATE(853),
    [sym__expression] = STATE(632),
    [sym_parenthesis] = STATE(411),
    [sym__binary_expression] = STATE(622),
    [sym_binary_operator] = STATE(422),
    [sym_unary_operator] = STATE(389),
    [sym_indirect_access] = STATE(994),
    [sym_field_expression] = STATE(485),
    [sym_not_operator] = STATE(477),
    [sym_metaclass_operator] = STATE(632),
    [sym_handle_operator] = STATE(632),
    [sym_comparison_operator] = STATE(446),
    [sym_boolean_operator] = STATE(446),
    [sym_postfix_operator] = STATE(411),
    [sym_string] = STATE(411),
    [sym_matrix] = STATE(411),
    [sym_cell] = STATE(423),
    [sym_ignored_argument] = STATE(1187),
    [sym_assignment] = STATE(853),
    [sym_multioutput_variable] = STATE(1187),
    [sym_function_call] = STATE(210),
    [sym_command] = STATE(853),
    [sym__range_element] = STATE(1181),
    [sym_range] = STATE(632),
    [sym_if_statement] = STATE(853),
    [sym_for_statement] = STATE(853),
    [sym_while_statement] = STATE(853),
    [sym_switch_statement] = STATE(853),
    [sym_lambda] = STATE(632),
    [sym_global_operator] = STATE(853),
    [sym_persistent_operator] = STATE(853),
    [sym_arguments_statement] = STATE(37),
    [sym__function_definition_with_end] = STATE(888),
    [sym_class_definition] = STATE(853),
    [sym_try_statement] = STATE(853),
    [sym_boolean] = STATE(205),
    [aux_sym_function_definition_repeat1] = STATE(37),
    [ts_builtin_sym_end] = ACTIONS(206),
    [sym_identifier] = ACTIONS(7),
    [anon_sym_LPAREN] = ACTIONS(9),
    [anon_sym_PLUS] = ACTIONS(11),
    [anon_sym_DASH] = ACTIONS(11),
    [anon_sym_TILDE] = ACTIONS(13),
    [anon_sym_QMARK] = ACTIONS(15),
    [anon_sym_AT] = ACTIONS(17),
    [anon_sym_LBRACK] = ACTIONS(19),
    [anon_sym_LBRACE] = ACTIONS(21),
    [sym_return_statement] = ACTIONS(147),
    [sym_continue_statement] = ACTIONS(147),
    [sym_break_statement] = ACTIONS(147),
    [anon_sym_if] = ACTIONS(25),
    [anon_sym_end] = ACTIONS(208),
    [anon_sym_for] = ACTIONS(27),
    [anon_sym_parfor] = ACTIONS(29),
    [anon_sym_while] = ACTIONS(31),
    [anon_sym_switch] = ACTIONS(33),
    [anon_sym_global] = ACTIONS(35),
    [anon_sym_persistent] = ACTIONS(37),
    [anon_sym_arguments] = ACTIONS(151),
    [anon_sym_function] = ACTIONS(210),
    [anon_sym_endfunction] = ACTIONS(208),
    [anon_sym_classdef] = ACTIONS(41),
    [anon_sym_try] = ACTIONS(43),
    [sym_number] = ACTIONS(45),
    [anon_sym_true] = ACTIONS(47),
    [anon_sym_false] = ACTIONS(47),
    [sym_comment] = ACTIONS(3),
    [sym_line_continuation] = ACTIONS(3),
    [sym_command_name] = ACTIONS(49),
    [sym__single_quote_string_start] = ACTIONS(51),
    [sym__double_quote_string_start] = ACTIONS(53),
    [sym__multioutput_variable_start] = ACTIONS(55),
  },
  [35] = {
    [aux_sym__block] = STATE(73),
    [sym_block] = STATE(934),
    [sym__statement] = STATE(853),
    [sym__expression] = STATE(632),
    [sym_parenthesis] = STATE(411),
    [sym__binary_expression] = STATE(622),
    [sym_binary_operator] = STATE(422),
    [sym_unary_operator] = STATE(389),
    [sym_indirect_access] = STATE(994),
    [sym_field_expression] = STATE(485),
    [sym_not_operator] = STATE(477),
    [sym_metaclass_operator] = STATE(632),
    [sym_handle_operator] = STATE(632),
    [sym_comparison_operator] = STATE(446),
    [sym_boolean_operator] = STATE(446),
    [sym_postfix_operator] = STATE(411),
    [sym_string] = STATE(411),
    [sym_matrix] = STATE(411),
    [sym_cell] = STATE(423),
    [sym_ignored_argument] = STATE(1187),
    [sym_assignment] = STATE(853),
    [sym_multioutput_variable] = STATE(1187),
    [sym_function_call] = STATE(210),
    [sym_command] = STATE(853),
    [sym__range_element] = STATE(1181),
    [sym_range] = STATE(632),
    [sym_if_statement] = STATE(853),
    [sym_for_statement] = STATE(853),
    [sym_while_statement] = STATE(853),
    [sym_switch_statement] = STATE(853),
    [sym_lambda] = STATE(632),
    [sym_global_operator] = STATE(853),
    [sym_persistent_operator] = STATE(853),
    [sym_arguments_statement] = STATE(341),
    [sym__function_definition_with_end] = STATE(888),
    [sym_class_definition] = STATE(853),
    [sym_try_statement] = STATE(853),
    [sym_boolean] = STATE(205),
    [aux_sym_function_definition_repeat1] = STATE(341),
    [ts_builtin_sym_end] = ACTIONS(206),
    [sym_identifier] = ACTIONS(7),
    [anon_sym_LPAREN] = ACTIONS(9),
    [anon_sym_PLUS] = ACTIONS(11),
    [anon_sym_DASH] = ACTIONS(11),
    [anon_sym_TILDE] = ACTIONS(13),
    [anon_sym_QMARK] = ACTIONS(15),
    [anon_sym_AT] = ACTIONS(17),
    [anon_sym_LBRACK] = ACTIONS(19),
    [anon_sym_LBRACE] = ACTIONS(21),
    [sym_return_statement] = ACTIONS(147),
    [sym_continue_statement] = ACTIONS(147),
    [sym_break_statement] = ACTIONS(147),
    [anon_sym_if] = ACTIONS(25),
    [anon_sym_end] = ACTIONS(208),
    [anon_sym_for] = ACTIONS(27),
    [anon_sym_parfor] = ACTIONS(29),
    [anon_sym_while] = ACTIONS(31),
    [anon_sym_switch] = ACTIONS(33),
    [anon_sym_global] = ACTIONS(35),
    [anon_sym_persistent] = ACTIONS(37),
    [anon_sym_arguments] = ACTIONS(151),
    [anon_sym_function] = ACTIONS(210),
    [anon_sym_endfunction] = ACTIONS(208),
    [anon_sym_classdef] = ACTIONS(41),
    [anon_sym_try] = ACTIONS(43),
    [sym_number] = ACTIONS(45),
    [anon_sym_true] = ACTIONS(47),
    [anon_sym_false] = ACTIONS(47),
    [sym_comment] = ACTIONS(3),
    [sym_line_continuation] = ACTIONS(3),
    [sym_command_name] = ACTIONS(49),
    [sym__single_quote_string_start] = ACTIONS(51),
    [sym__double_quote_string_start] = ACTIONS(53),
    [sym__multioutput_variable_start] = ACTIONS(55),
  },
  [36] = {
    [aux_sym__block] = STATE(73),
    [sym_block] = STATE(920),
    [sym__statement] = STATE(853),
    [sym__expression] = STATE(632),
    [sym_parenthesis] = STATE(411),
    [sym__binary_expression] = STATE(622),
    [sym_binary_operator] = STATE(422),
    [sym_unary_operator] = STATE(389),
    [sym_indirect_access] = STATE(994),
    [sym_field_expression] = STATE(485),
    [sym_not_operator] = STATE(477),
    [sym_metaclass_operator] = STATE(632),
    [sym_handle_operator] = STATE(632),
    [sym_comparison_operator] = STATE(446),
    [sym_boolean_operator] = STATE(446),
    [sym_postfix_operator] = STATE(411),
    [sym_string] = STATE(411),
    [sym_matrix] = STATE(411),
    [sym_cell] = STATE(423),
    [sym_ignored_argument] = STATE(1187),
    [sym_assignment] = STATE(853),
    [sym_multioutput_variable] = STATE(1187),
    [sym_function_call] = STATE(210),
    [sym_command] = STATE(853),
    [sym__range_element] = STATE(1181),
    [sym_range] = STATE(632),
    [sym_if_statement] = STATE(853),
    [sym_for_statement] = STATE(853),
    [sym_while_statement] = STATE(853),
    [sym_switch_statement] = STATE(853),
    [sym_lambda] = STATE(632),
    [sym_global_operator] = STATE(853),
    [sym_persistent_operator] = STATE(853),
    [sym_arguments_statement] = STATE(341),
    [sym__function_definition_with_end] = STATE(888),
    [sym_class_definition] = STATE(853),
    [sym_try_statement] = STATE(853),
    [sym_boolean] = STATE(205),
    [aux_sym_function_definition_repeat1] = STATE(341),
    [ts_builtin_sym_end] = ACTIONS(195),
    [sym_identifier] = ACTIONS(7),
    [anon_sym_LPAREN] = ACTIONS(9),
    [anon_sym_PLUS] = ACTIONS(11),
    [anon_sym_DASH] = ACTIONS(11),
    [anon_sym_TILDE] = ACTIONS(13),
    [anon_sym_QMARK] = ACTIONS(15),
    [anon_sym_AT] = ACTIONS(17),
    [anon_sym_LBRACK] = ACTIONS(19),
    [anon_sym_LBRACE] = ACTIONS(21),
    [sym_return_statement] = ACTIONS(147),
    [sym_continue_statement] = ACTIONS(147),
    [sym_break_statement] = ACTIONS(147),
    [anon_sym_if] = ACTIONS(25),
    [anon_sym_end] = ACTIONS(213),
    [anon_sym_for] = ACTIONS(27),
    [anon_sym_parfor] = ACTIONS(29),
    [anon_sym_while] = ACTIONS(31),
    [anon_sym_switch] = ACTIONS(33),
    [anon_sym_global] = ACTIONS(35),
    [anon_sym_persistent] = ACTIONS(37),
    [anon_sym_arguments] = ACTIONS(151),
    [anon_sym_function] = ACTIONS(199),
    [anon_sym_endfunction] = ACTIONS(213),
    [anon_sym_classdef] = ACTIONS(41),
    [anon_sym_try] = ACTIONS(43),
    [sym_number] = ACTIONS(45),
    [anon_sym_true] = ACTIONS(47),
    [anon_sym_false] = ACTIONS(47),
    [sym_comment] = ACTIONS(3),
    [sym_line_continuation] = ACTIONS(3),
    [sym_command_name] = ACTIONS(49),
    [sym__single_quote_string_start] = ACTIONS(51),
    [sym__double_quote_string_start] = ACTIONS(53),
    [sym__multioutput_variable_start] = ACTIONS(55),
  },
  [37] = {
    [aux_sym__block] = STATE(73),
    [sym_block] = STATE(973),
    [sym__statement] = STATE(853),
    [sym__expression] = STATE(632),
    [sym_parenthesis] = STATE(411),
    [sym__binary_expression] = STATE(622),
    [sym_binary_operator] = STATE(422),
    [sym_unary_operator] = STATE(389),
    [sym_indirect_access] = STATE(994),
    [sym_field_expression] = STATE(485),
    [sym_not_operator] = STATE(477),
    [sym_metaclass_operator] = STATE(632),
    [sym_handle_operator] = STATE(632),
    [sym_comparison_operator] = STATE(446),
    [sym_boolean_operator] = STATE(446),
    [sym_postfix_operator] = STATE(411),
    [sym_string] = STATE(411),
    [sym_matrix] = STATE(411),
    [sym_cell] = STATE(423),
    [sym_ignored_argument] = STATE(1187),
    [sym_assignment] = STATE(853),
    [sym_multioutput_variable] = STATE(1187),
    [sym_function_call] = STATE(210),
    [sym_command] = STATE(853),
    [sym__range_element] = STATE(1181),
    [sym_range] = STATE(632),
    [sym_if_statement] = STATE(853),
    [sym_for_statement] = STATE(853),
    [sym_while_statement] = STATE(853),
    [sym_switch_statement] = STATE(853),
    [sym_lambda] = STATE(632),
    [sym_global_operator] = STATE(853),
    [sym_persistent_operator] = STATE(853),
    [sym_arguments_statement] = STATE(341),
    [sym__function_definition_with_end] = STATE(888),
    [sym_class_definition] = STATE(853),
    [sym_try_statement] = STATE(853),
    [sym_boolean] = STATE(205),
    [aux_sym_function_definition_repeat1] = STATE(341),
    [ts_builtin_sym_end] = ACTIONS(215),
    [sym_identifier] = ACTIONS(7),
    [anon_sym_LPAREN] = ACTIONS(9),
    [anon_sym_PLUS] = ACTIONS(11),
    [anon_sym_DASH] = ACTIONS(11),
    [anon_sym_TILDE] = ACTIONS(13),
    [anon_sym_QMARK] = ACTIONS(15),
    [anon_sym_AT] = ACTIONS(17),
    [anon_sym_LBRACK] = ACTIONS(19),
    [anon_sym_LBRACE] = ACTIONS(21),
    [sym_return_statement] = ACTIONS(147),
    [sym_continue_statement] = ACTIONS(147),
    [sym_break_statement] = ACTIONS(147),
    [anon_sym_if] = ACTIONS(25),
    [anon_sym_end] = ACTIONS(217),
    [anon_sym_for] = ACTIONS(27),
    [anon_sym_parfor] = ACTIONS(29),
    [anon_sym_while] = ACTIONS(31),
    [anon_sym_switch] = ACTIONS(33),
    [anon_sym_global] = ACTIONS(35),
    [anon_sym_persistent] = ACTIONS(37),
    [anon_sym_arguments] = ACTIONS(151),
    [anon_sym_function] = ACTIONS(219),
    [anon_sym_endfunction] = ACTIONS(217),
    [anon_sym_classdef] = ACTIONS(41),
    [anon_sym_try] = ACTIONS(43),
    [sym_number] = ACTIONS(45),
    [anon_sym_true] = ACTIONS(47),
    [anon_sym_false] = ACTIONS(47),
    [sym_comment] = ACTIONS(3),
    [sym_line_continuation] = ACTIONS(3),
    [sym_command_name] = ACTIONS(49),
    [sym__single_quote_string_start] = ACTIONS(51),
    [sym__double_quote_string_start] = ACTIONS(53),
    [sym__multioutput_variable_start] = ACTIONS(55),
  },
  [38] = {
    [aux_sym__block] = STATE(73),
    [sym_block] = STATE(920),
    [sym__statement] = STATE(853),
    [sym__expression] = STATE(632),
    [sym_parenthesis] = STATE(411),
    [sym__binary_expression] = STATE(622),
    [sym_binary_operator] = STATE(422),
    [sym_unary_operator] = STATE(389),
    [sym_indirect_access] = STATE(994),
    [sym_field_expression] = STATE(485),
    [sym_not_operator] = STATE(477),
    [sym_metaclass_operator] = STATE(632),
    [sym_handle_operator] = STATE(632),
    [sym_comparison_operator] = STATE(446),
    [sym_boolean_operator] = STATE(446),
    [sym_postfix_operator] = STATE(411),
    [sym_string] = STATE(411),
    [sym_matrix] = STATE(411),
    [sym_cell] = STATE(423),
    [sym_ignored_argument] = STATE(1187),
    [sym_assignment] = STATE(853),
    [sym_multioutput_variable] = STATE(1187),
    [sym_function_call] = STATE(210),
    [sym_command] = STATE(853),
    [sym__range_element] = STATE(1181),
    [sym_range] = STATE(632),
    [sym_if_statement] = STATE(853),
    [sym_for_statement] = STATE(853),
    [sym_while_statement] = STATE(853),
    [sym_switch_statement] = STATE(853),
    [sym_lambda] = STATE(632),
    [sym_global_operator] = STATE(853),
    [sym_persistent_operator] = STATE(853),
    [sym_arguments_statement] = STATE(27),
    [sym__function_definition_with_end] = STATE(888),
    [sym_class_definition] = STATE(853),
    [sym_try_statement] = STATE(853),
    [sym_boolean] = STATE(205),
    [aux_sym_function_definition_repeat1] = STATE(27),
    [ts_builtin_sym_end] = ACTIONS(195),
    [sym_identifier] = ACTIONS(7),
    [anon_sym_LPAREN] = ACTIONS(9),
    [anon_sym_PLUS] = ACTIONS(11),
    [anon_sym_DASH] = ACTIONS(11),
    [anon_sym_TILDE] = ACTIONS(13),
    [anon_sym_QMARK] = ACTIONS(15),
    [anon_sym_AT] = ACTIONS(17),
    [anon_sym_LBRACK] = ACTIONS(19),
    [anon_sym_LBRACE] = ACTIONS(21),
    [sym_return_statement] = ACTIONS(147),
    [sym_continue_statement] = ACTIONS(147),
    [sym_break_statement] = ACTIONS(147),
    [anon_sym_if] = ACTIONS(25),
    [anon_sym_end] = ACTIONS(213),
    [anon_sym_for] = ACTIONS(27),
    [anon_sym_parfor] = ACTIONS(29),
    [anon_sym_while] = ACTIONS(31),
    [anon_sym_switch] = ACTIONS(33),
    [anon_sym_global] = ACTIONS(35),
    [anon_sym_persistent] = ACTIONS(37),
    [anon_sym_arguments] = ACTIONS(151),
    [anon_sym_function] = ACTIONS(199),
    [anon_sym_endfunction] = ACTIONS(213),
    [anon_sym_classdef] = ACTIONS(41),
    [anon_sym_try] = ACTIONS(43),
    [sym_number] = ACTIONS(45),
    [anon_sym_true] = ACTIONS(47),
    [anon_sym_false] = ACTIONS(47),
    [sym_comment] = ACTIONS(3),
    [sym_line_continuation] = ACTIONS(3),
    [sym_command_name] = ACTIONS(49),
    [sym__single_quote_string_start] = ACTIONS(51),
    [sym__double_quote_string_start] = ACTIONS(53),
    [sym__multioutput_variable_start] = ACTIONS(55),
  },
  [39] = {
    [aux_sym__block] = STATE(73),
    [sym_block] = STATE(923),
    [sym__statement] = STATE(853),
    [sym__expression] = STATE(632),
    [sym_parenthesis] = STATE(411),
    [sym__binary_expression] = STATE(622),
    [sym_binary_operator] = STATE(422),
    [sym_unary_operator] = STATE(389),
    [sym_indirect_access] = STATE(994),
    [sym_field_expression] = STATE(485),
    [sym_not_operator] = STATE(477),
    [sym_metaclass_operator] = STATE(632),
    [sym_handle_operator] = STATE(632),
    [sym_comparison_operator] = STATE(446),
    [sym_boolean_operator] = STATE(446),
    [sym_postfix_operator] = STATE(411),
    [sym_string] = STATE(411),
    [sym_matrix] = STATE(411),
    [sym_cell] = STATE(423),
    [sym_ignored_argument] = STATE(1187),
    [sym_assignment] = STATE(853),
    [sym_multioutput_variable] = STATE(1187),
    [sym_function_call] = STATE(210),
    [sym_command] = STATE(853),
    [sym__range_element] = STATE(1181),
    [sym_range] = STATE(632),
    [sym_if_statement] = STATE(853),
    [sym_for_statement] = STATE(853),
    [sym_while_statement] = STATE(853),
    [sym_switch_statement] = STATE(853),
    [sym_lambda] = STATE(632),
    [sym_global_operator] = STATE(853),
    [sym_persistent_operator] = STATE(853),
    [sym_arguments_statement] = STATE(25),
    [sym__function_definition_with_end] = STATE(888),
    [sym_class_definition] = STATE(853),
    [sym_try_statement] = STATE(853),
    [sym_boolean] = STATE(205),
    [aux_sym_function_definition_repeat1] = STATE(25),
    [ts_builtin_sym_end] = ACTIONS(188),
    [sym_identifier] = ACTIONS(7),
    [anon_sym_LPAREN] = ACTIONS(9),
    [anon_sym_PLUS] = ACTIONS(11),
    [anon_sym_DASH] = ACTIONS(11),
    [anon_sym_TILDE] = ACTIONS(13),
    [anon_sym_QMARK] = ACTIONS(15),
    [anon_sym_AT] = ACTIONS(17),
    [anon_sym_LBRACK] = ACTIONS(19),
    [anon_sym_LBRACE] = ACTIONS(21),
    [sym_return_statement] = ACTIONS(147),
    [sym_continue_statement] = ACTIONS(147),
    [sym_break_statement] = ACTIONS(147),
    [anon_sym_if] = ACTIONS(25),
    [anon_sym_end] = ACTIONS(222),
    [anon_sym_for] = ACTIONS(27),
    [anon_sym_parfor] = ACTIONS(29),
    [anon_sym_while] = ACTIONS(31),
    [anon_sym_switch] = ACTIONS(33),
    [anon_sym_global] = ACTIONS(35),
    [anon_sym_persistent] = ACTIONS(37),
    [anon_sym_arguments] = ACTIONS(151),
    [anon_sym_function] = ACTIONS(192),
    [anon_sym_endfunction] = ACTIONS(222),
    [anon_sym_classdef] = ACTIONS(41),
    [anon_sym_try] = ACTIONS(43),
    [sym_number] = ACTIONS(45),
    [anon_sym_true] = ACTIONS(47),
    [anon_sym_false] = ACTIONS(47),
    [sym_comment] = ACTIONS(3),
    [sym_line_continuation] = ACTIONS(3),
    [sym_command_name] = ACTIONS(49),
    [sym__single_quote_string_start] = ACTIONS(51),
    [sym__double_quote_string_start] = ACTIONS(53),
    [sym__multioutput_variable_start] = ACTIONS(55),
  },
  [40] = {
    [aux_sym__block] = STATE(73),
    [sym_block] = STATE(983),
    [sym__statement] = STATE(853),
    [sym__expression] = STATE(632),
    [sym_parenthesis] = STATE(411),
    [sym__binary_expression] = STATE(622),
    [sym_binary_operator] = STATE(422),
    [sym_unary_operator] = STATE(389),
    [sym_indirect_access] = STATE(994),
    [sym_field_expression] = STATE(485),
    [sym_not_operator] = STATE(477),
    [sym_metaclass_operator] = STATE(632),
    [sym_handle_operator] = STATE(632),
    [sym_comparison_operator] = STATE(446),
    [sym_boolean_operator] = STATE(446),
    [sym_postfix_operator] = STATE(411),
    [sym_string] = STATE(411),
    [sym_matrix] = STATE(411),
    [sym_cell] = STATE(423),
    [sym_ignored_argument] = STATE(1187),
    [sym_assignment] = STATE(853),
    [sym_multioutput_variable] = STATE(1187),
    [sym_function_call] = STATE(210),
    [sym_command] = STATE(853),
    [sym__range_element] = STATE(1181),
    [sym_range] = STATE(632),
    [sym_if_statement] = STATE(853),
    [sym_for_statement] = STATE(853),
    [sym_while_statement] = STATE(853),
    [sym_switch_statement] = STATE(853),
    [sym_lambda] = STATE(632),
    [sym_global_operator] = STATE(853),
    [sym_persistent_operator] = STATE(853),
    [sym_arguments_statement] = STATE(41),
    [sym__function_definition_with_end] = STATE(888),
    [sym_class_definition] = STATE(853),
    [sym_try_statement] = STATE(853),
    [sym_boolean] = STATE(205),
    [aux_sym_function_definition_repeat1] = STATE(41),
    [ts_builtin_sym_end] = ACTIONS(206),
    [sym_identifier] = ACTIONS(7),
    [anon_sym_LPAREN] = ACTIONS(9),
    [anon_sym_PLUS] = ACTIONS(11),
    [anon_sym_DASH] = ACTIONS(11),
    [anon_sym_TILDE] = ACTIONS(13),
    [anon_sym_QMARK] = ACTIONS(15),
    [anon_sym_AT] = ACTIONS(17),
    [anon_sym_LBRACK] = ACTIONS(19),
    [anon_sym_LBRACE] = ACTIONS(21),
    [sym_return_statement] = ACTIONS(147),
    [sym_continue_statement] = ACTIONS(147),
    [sym_break_statement] = ACTIONS(147),
    [anon_sym_if] = ACTIONS(25),
    [anon_sym_end] = ACTIONS(224),
    [anon_sym_for] = ACTIONS(27),
    [anon_sym_parfor] = ACTIONS(29),
    [anon_sym_while] = ACTIONS(31),
    [anon_sym_switch] = ACTIONS(33),
    [anon_sym_global] = ACTIONS(35),
    [anon_sym_persistent] = ACTIONS(37),
    [anon_sym_arguments] = ACTIONS(151),
    [anon_sym_function] = ACTIONS(210),
    [anon_sym_endfunction] = ACTIONS(224),
    [anon_sym_classdef] = ACTIONS(41),
    [anon_sym_try] = ACTIONS(43),
    [sym_number] = ACTIONS(45),
    [anon_sym_true] = ACTIONS(47),
    [anon_sym_false] = ACTIONS(47),
    [sym_comment] = ACTIONS(3),
    [sym_line_continuation] = ACTIONS(3),
    [sym_command_name] = ACTIONS(49),
    [sym__single_quote_string_start] = ACTIONS(51),
    [sym__double_quote_string_start] = ACTIONS(53),
    [sym__multioutput_variable_start] = ACTIONS(55),
  },
  [41] = {
    [aux_sym__block] = STATE(73),
    [sym_block] = STATE(995),
    [sym__statement] = STATE(853),
    [sym__expression] = STATE(632),
    [sym_parenthesis] = STATE(411),
    [sym__binary_expression] = STATE(622),
    [sym_binary_operator] = STATE(422),
    [sym_unary_operator] = STATE(389),
    [sym_indirect_access] = STATE(994),
    [sym_field_expression] = STATE(485),
    [sym_not_operator] = STATE(477),
    [sym_metaclass_operator] = STATE(632),
    [sym_handle_operator] = STATE(632),
    [sym_comparison_operator] = STATE(446),
    [sym_boolean_operator] = STATE(446),
    [sym_postfix_operator] = STATE(411),
    [sym_string] = STATE(411),
    [sym_matrix] = STATE(411),
    [sym_cell] = STATE(423),
    [sym_ignored_argument] = STATE(1187),
    [sym_assignment] = STATE(853),
    [sym_multioutput_variable] = STATE(1187),
    [sym_function_call] = STATE(210),
    [sym_command] = STATE(853),
    [sym__range_element] = STATE(1181),
    [sym_range] = STATE(632),
    [sym_if_statement] = STATE(853),
    [sym_for_statement] = STATE(853),
    [sym_while_statement] = STATE(853),
    [sym_switch_statement] = STATE(853),
    [sym_lambda] = STATE(632),
    [sym_global_operator] = STATE(853),
    [sym_persistent_operator] = STATE(853),
    [sym_arguments_statement] = STATE(341),
    [sym__function_definition_with_end] = STATE(888),
    [sym_class_definition] = STATE(853),
    [sym_try_statement] = STATE(853),
    [sym_boolean] = STATE(205),
    [aux_sym_function_definition_repeat1] = STATE(341),
    [ts_builtin_sym_end] = ACTIONS(215),
    [sym_identifier] = ACTIONS(7),
    [anon_sym_LPAREN] = ACTIONS(9),
    [anon_sym_PLUS] = ACTIONS(11),
    [anon_sym_DASH] = ACTIONS(11),
    [anon_sym_TILDE] = ACTIONS(13),
    [anon_sym_QMARK] = ACTIONS(15),
    [anon_sym_AT] = ACTIONS(17),
    [anon_sym_LBRACK] = ACTIONS(19),
    [anon_sym_LBRACE] = ACTIONS(21),
    [sym_return_statement] = ACTIONS(147),
    [sym_continue_statement] = ACTIONS(147),
    [sym_break_statement] = ACTIONS(147),
    [anon_sym_if] = ACTIONS(25),
    [anon_sym_end] = ACTIONS(226),
    [anon_sym_for] = ACTIONS(27),
    [anon_sym_parfor] = ACTIONS(29),
    [anon_sym_while] = ACTIONS(31),
    [anon_sym_switch] = ACTIONS(33),
    [anon_sym_global] = ACTIONS(35),
    [anon_sym_persistent] = ACTIONS(37),
    [anon_sym_arguments] = ACTIONS(151),
    [anon_sym_function] = ACTIONS(219),
    [anon_sym_endfunction] = ACTIONS(226),
    [anon_sym_classdef] = ACTIONS(41),
    [anon_sym_try] = ACTIONS(43),
    [sym_number] = ACTIONS(45),
    [anon_sym_true] = ACTIONS(47),
    [anon_sym_false] = ACTIONS(47),
    [sym_comment] = ACTIONS(3),
    [sym_line_continuation] = ACTIONS(3),
    [sym_command_name] = ACTIONS(49),
    [sym__single_quote_string_start] = ACTIONS(51),
    [sym__double_quote_string_start] = ACTIONS(53),
    [sym__multioutput_variable_start] = ACTIONS(55),
  },
  [42] = {
    [aux_sym__block] = STATE(73),
    [sym_block] = STATE(963),
    [sym__statement] = STATE(853),
    [sym__expression] = STATE(632),
    [sym_parenthesis] = STATE(411),
    [sym__binary_expression] = STATE(622),
    [sym_binary_operator] = STATE(422),
    [sym_unary_operator] = STATE(389),
    [sym_indirect_access] = STATE(994),
    [sym_field_expression] = STATE(485),
    [sym_not_operator] = STATE(477),
    [sym_metaclass_operator] = STATE(632),
    [sym_handle_operator] = STATE(632),
    [sym_comparison_operator] = STATE(446),
    [sym_boolean_operator] = STATE(446),
    [sym_postfix_operator] = STATE(411),
    [sym_string] = STATE(411),
    [sym_matrix] = STATE(411),
    [sym_cell] = STATE(423),
    [sym_ignored_argument] = STATE(1187),
    [sym_assignment] = STATE(853),
    [sym_multioutput_variable] = STATE(1187),
    [sym_function_call] = STATE(210),
    [sym_command] = STATE(853),
    [sym__range_element] = STATE(1181),
    [sym_range] = STATE(632),
    [sym_if_statement] = STATE(853),
    [sym_for_statement] = STATE(853),
    [sym_while_statement] = STATE(853),
    [sym_switch_statement] = STATE(853),
    [sym_lambda] = STATE(632),
    [sym_global_operator] = STATE(853),
    [sym_persistent_operator] = STATE(853),
    [sym_arguments_statement] = STATE(341),
    [sym__function_definition_with_end] = STATE(888),
    [sym_class_definition] = STATE(853),
    [sym_try_statement] = STATE(853),
    [sym_boolean] = STATE(205),
    [aux_sym_function_definition_repeat1] = STATE(341),
    [ts_builtin_sym_end] = ACTIONS(179),
    [sym_identifier] = ACTIONS(7),
    [anon_sym_LPAREN] = ACTIONS(9),
    [anon_sym_PLUS] = ACTIONS(11),
    [anon_sym_DASH] = ACTIONS(11),
    [anon_sym_TILDE] = ACTIONS(13),
    [anon_sym_QMARK] = ACTIONS(15),
    [anon_sym_AT] = ACTIONS(17),
    [anon_sym_LBRACK] = ACTIONS(19),
    [anon_sym_LBRACE] = ACTIONS(21),
    [sym_return_statement] = ACTIONS(147),
    [sym_continue_statement] = ACTIONS(147),
    [sym_break_statement] = ACTIONS(147),
    [anon_sym_if] = ACTIONS(25),
    [anon_sym_end] = ACTIONS(228),
    [anon_sym_for] = ACTIONS(27),
    [anon_sym_parfor] = ACTIONS(29),
    [anon_sym_while] = ACTIONS(31),
    [anon_sym_switch] = ACTIONS(33),
    [anon_sym_global] = ACTIONS(35),
    [anon_sym_persistent] = ACTIONS(37),
    [anon_sym_arguments] = ACTIONS(151),
    [anon_sym_function] = ACTIONS(183),
    [anon_sym_endfunction] = ACTIONS(228),
    [anon_sym_classdef] = ACTIONS(41),
    [anon_sym_try] = ACTIONS(43),
    [sym_number] = ACTIONS(45),
    [anon_sym_true] = ACTIONS(47),
    [anon_sym_false] = ACTIONS(47),
    [sym_comment] = ACTIONS(3),
    [sym_line_continuation] = ACTIONS(3),
    [sym_command_name] = ACTIONS(49),
    [sym__single_quote_string_start] = ACTIONS(51),
    [sym__double_quote_string_start] = ACTIONS(53),
    [sym__multioutput_variable_start] = ACTIONS(55),
  },
  [43] = {
    [aux_sym__block] = STATE(73),
    [sym_block] = STATE(961),
    [sym__statement] = STATE(853),
    [sym__expression] = STATE(632),
    [sym_parenthesis] = STATE(411),
    [sym__binary_expression] = STATE(622),
    [sym_binary_operator] = STATE(422),
    [sym_unary_operator] = STATE(389),
    [sym_indirect_access] = STATE(994),
    [sym_field_expression] = STATE(485),
    [sym_not_operator] = STATE(477),
    [sym_metaclass_operator] = STATE(632),
    [sym_handle_operator] = STATE(632),
    [sym_comparison_operator] = STATE(446),
    [sym_boolean_operator] = STATE(446),
    [sym_postfix_operator] = STATE(411),
    [sym_string] = STATE(411),
    [sym_matrix] = STATE(411),
    [sym_cell] = STATE(423),
    [sym_ignored_argument] = STATE(1187),
    [sym_assignment] = STATE(853),
    [sym_multioutput_variable] = STATE(1187),
    [sym_function_call] = STATE(210),
    [sym_command] = STATE(853),
    [sym__range_element] = STATE(1181),
    [sym_range] = STATE(632),
    [sym_if_statement] = STATE(853),
    [sym_for_statement] = STATE(853),
    [sym_while_statement] = STATE(853),
    [sym_switch_statement] = STATE(853),
    [sym_lambda] = STATE(632),
    [sym_global_operator] = STATE(853),
    [sym_persistent_operator] = STATE(853),
    [sym_arguments_statement] = STATE(23),
    [sym__function_definition_with_end] = STATE(888),
    [sym_class_definition] = STATE(853),
    [sym_try_statement] = STATE(853),
    [sym_boolean] = STATE(205),
    [aux_sym_function_definition_repeat1] = STATE(23),
    [ts_builtin_sym_end] = ACTIONS(156),
    [sym_identifier] = ACTIONS(7),
    [anon_sym_LPAREN] = ACTIONS(9),
    [anon_sym_PLUS] = ACTIONS(11),
    [anon_sym_DASH] = ACTIONS(11),
    [anon_sym_TILDE] = ACTIONS(13),
    [anon_sym_QMARK] = ACTIONS(15),
    [anon_sym_AT] = ACTIONS(17),
    [anon_sym_LBRACK] = ACTIONS(19),
    [anon_sym_LBRACE] = ACTIONS(21),
    [sym_return_statement] = ACTIONS(147),
    [sym_continue_statement] = ACTIONS(147),
    [sym_break_statement] = ACTIONS(147),
    [anon_sym_if] = ACTIONS(25),
    [anon_sym_end] = ACTIONS(158),
    [anon_sym_for] = ACTIONS(27),
    [anon_sym_parfor] = ACTIONS(29),
    [anon_sym_while] = ACTIONS(31),
    [anon_sym_switch] = ACTIONS(33),
    [anon_sym_global] = ACTIONS(35),
    [anon_sym_persistent] = ACTIONS(37),
    [anon_sym_arguments] = ACTIONS(151),
    [anon_sym_function] = ACTIONS(160),
    [anon_sym_endfunction] = ACTIONS(158),
    [anon_sym_classdef] = ACTIONS(41),
    [anon_sym_try] = ACTIONS(43),
    [sym_number] = ACTIONS(45),
    [anon_sym_true] = ACTIONS(47),
    [anon_sym_false] = ACTIONS(47),
    [sym_comment] = ACTIONS(3),
    [sym_line_continuation] = ACTIONS(3),
    [sym_command_name] = ACTIONS(49),
    [sym__single_quote_string_start] = ACTIONS(51),
    [sym__double_quote_string_start] = ACTIONS(53),
    [sym__multioutput_variable_start] = ACTIONS(55),
  },
  [44] = {
    [aux_sym__block] = STATE(73),
    [sym_block] = STATE(983),
    [sym__statement] = STATE(853),
    [sym__expression] = STATE(632),
    [sym_parenthesis] = STATE(411),
    [sym__binary_expression] = STATE(622),
    [sym_binary_operator] = STATE(422),
    [sym_unary_operator] = STATE(389),
    [sym_indirect_access] = STATE(994),
    [sym_field_expression] = STATE(485),
    [sym_not_operator] = STATE(477),
    [sym_metaclass_operator] = STATE(632),
    [sym_handle_operator] = STATE(632),
    [sym_comparison_operator] = STATE(446),
    [sym_boolean_operator] = STATE(446),
    [sym_postfix_operator] = STATE(411),
    [sym_string] = STATE(411),
    [sym_matrix] = STATE(411),
    [sym_cell] = STATE(423),
    [sym_ignored_argument] = STATE(1187),
    [sym_assignment] = STATE(853),
    [sym_multioutput_variable] = STATE(1187),
    [sym_function_call] = STATE(210),
    [sym_command] = STATE(853),
    [sym__range_element] = STATE(1181),
    [sym_range] = STATE(632),
    [sym_if_statement] = STATE(853),
    [sym_for_statement] = STATE(853),
    [sym_while_statement] = STATE(853),
    [sym_switch_statement] = STATE(853),
    [sym_lambda] = STATE(632),
    [sym_global_operator] = STATE(853),
    [sym_persistent_operator] = STATE(853),
    [sym_arguments_statement] = STATE(341),
    [sym__function_definition_with_end] = STATE(888),
    [sym_class_definition] = STATE(853),
    [sym_try_statement] = STATE(853),
    [sym_boolean] = STATE(205),
    [aux_sym_function_definition_repeat1] = STATE(341),
    [ts_builtin_sym_end] = ACTIONS(206),
    [sym_identifier] = ACTIONS(7),
    [anon_sym_LPAREN] = ACTIONS(9),
    [anon_sym_PLUS] = ACTIONS(11),
    [anon_sym_DASH] = ACTIONS(11),
    [anon_sym_TILDE] = ACTIONS(13),
    [anon_sym_QMARK] = ACTIONS(15),
    [anon_sym_AT] = ACTIONS(17),
    [anon_sym_LBRACK] = ACTIONS(19),
    [anon_sym_LBRACE] = ACTIONS(21),
    [sym_return_statement] = ACTIONS(147),
    [sym_continue_statement] = ACTIONS(147),
    [sym_break_statement] = ACTIONS(147),
    [anon_sym_if] = ACTIONS(25),
    [anon_sym_end] = ACTIONS(224),
    [anon_sym_for] = ACTIONS(27),
    [anon_sym_parfor] = ACTIONS(29),
    [anon_sym_while] = ACTIONS(31),
    [anon_sym_switch] = ACTIONS(33),
    [anon_sym_global] = ACTIONS(35),
    [anon_sym_persistent] = ACTIONS(37),
    [anon_sym_arguments] = ACTIONS(151),
    [anon_sym_function] = ACTIONS(210),
    [anon_sym_endfunction] = ACTIONS(224),
    [anon_sym_classdef] = ACTIONS(41),
    [anon_sym_try] = ACTIONS(43),
    [sym_number] = ACTIONS(45),
    [anon_sym_true] = ACTIONS(47),
    [anon_sym_false] = ACTIONS(47),
    [sym_comment] = ACTIONS(3),
    [sym_line_continuation] = ACTIONS(3),
    [sym_command_name] = ACTIONS(49),
    [sym__single_quote_string_start] = ACTIONS(51),
    [sym__double_quote_string_start] = ACTIONS(53),
    [sym__multioutput_variable_start] = ACTIONS(55),
  },
  [45] = {
    [aux_sym__block] = STATE(74),
    [sym_block] = STATE(1068),
    [sym__statement] = STATE(853),
    [sym__expression] = STATE(632),
    [sym_parenthesis] = STATE(411),
    [sym__binary_expression] = STATE(622),
    [sym_binary_operator] = STATE(422),
    [sym_unary_operator] = STATE(389),
    [sym_indirect_access] = STATE(994),
    [sym_field_expression] = STATE(485),
    [sym_not_operator] = STATE(477),
    [sym_metaclass_operator] = STATE(632),
    [sym_handle_operator] = STATE(632),
    [sym_comparison_operator] = STATE(446),
    [sym_boolean_operator] = STATE(446),
    [sym_postfix_operator] = STATE(411),
    [sym_string] = STATE(411),
    [sym_matrix] = STATE(411),
    [sym_cell] = STATE(423),
    [sym_ignored_argument] = STATE(1187),
    [sym_assignment] = STATE(853),
    [sym_multioutput_variable] = STATE(1187),
    [sym_function_call] = STATE(210),
    [sym_command] = STATE(853),
    [sym__range_element] = STATE(1181),
    [sym_range] = STATE(632),
    [sym_if_statement] = STATE(853),
    [sym_for_statement] = STATE(853),
    [sym_while_statement] = STATE(853),
    [sym_switch_statement] = STATE(853),
    [sym_lambda] = STATE(632),
    [sym_global_operator] = STATE(853),
    [sym_persistent_operator] = STATE(853),
    [sym_arguments_statement] = STATE(341),
    [sym__function_definition_with_end] = STATE(888),
    [sym_class_definition] = STATE(853),
    [sym_try_statement] = STATE(853),
    [sym_boolean] = STATE(205),
    [aux_sym_function_definition_repeat1] = STATE(341),
    [sym_identifier] = ACTIONS(7),
    [anon_sym_LPAREN] = ACTIONS(9),
    [anon_sym_PLUS] = ACTIONS(11),
    [anon_sym_DASH] = ACTIONS(11),
    [anon_sym_TILDE] = ACTIONS(13),
    [anon_sym_QMARK] = ACTIONS(15),
    [anon_sym_AT] = ACTIONS(17),
    [anon_sym_LBRACK] = ACTIONS(19),
    [anon_sym_LBRACE] = ACTIONS(21),
    [sym_return_statement] = ACTIONS(147),
    [sym_continue_statement] = ACTIONS(147),
    [sym_break_statement] = ACTIONS(147),
    [anon_sym_if] = ACTIONS(25),
    [anon_sym_end] = ACTIONS(230),
    [anon_sym_for] = ACTIONS(27),
    [anon_sym_parfor] = ACTIONS(29),
    [anon_sym_while] = ACTIONS(31),
    [anon_sym_switch] = ACTIONS(33),
    [anon_sym_global] = ACTIONS(35),
    [anon_sym_persistent] = ACTIONS(37),
    [anon_sym_arguments] = ACTIONS(151),
    [anon_sym_function] = ACTIONS(87),
    [anon_sym_endfunction] = ACTIONS(230),
    [anon_sym_classdef] = ACTIONS(41),
    [anon_sym_try] = ACTIONS(43),
    [sym_number] = ACTIONS(45),
    [anon_sym_true] = ACTIONS(47),
    [anon_sym_false] = ACTIONS(47),
    [sym_comment] = ACTIONS(3),
    [sym_line_continuation] = ACTIONS(3),
    [sym_command_name] = ACTIONS(49),
    [sym__single_quote_string_start] = ACTIONS(51),
    [sym__double_quote_string_start] = ACTIONS(53),
    [sym__multioutput_variable_start] = ACTIONS(55),
  },
  [46] = {
    [aux_sym__block] = STATE(74),
    [sym_block] = STATE(1132),
    [sym__statement] = STATE(853),
    [sym__expression] = STATE(632),
    [sym_parenthesis] = STATE(411),
    [sym__binary_expression] = STATE(622),
    [sym_binary_operator] = STATE(422),
    [sym_unary_operator] = STATE(389),
    [sym_indirect_access] = STATE(994),
    [sym_field_expression] = STATE(485),
    [sym_not_operator] = STATE(477),
    [sym_metaclass_operator] = STATE(632),
    [sym_handle_operator] = STATE(632),
    [sym_comparison_operator] = STATE(446),
    [sym_boolean_operator] = STATE(446),
    [sym_postfix_operator] = STATE(411),
    [sym_string] = STATE(411),
    [sym_matrix] = STATE(411),
    [sym_cell] = STATE(423),
    [sym_ignored_argument] = STATE(1187),
    [sym_assignment] = STATE(853),
    [sym_multioutput_variable] = STATE(1187),
    [sym_function_call] = STATE(210),
    [sym_command] = STATE(853),
    [sym__range_element] = STATE(1181),
    [sym_range] = STATE(632),
    [sym_if_statement] = STATE(853),
    [sym_for_statement] = STATE(853),
    [sym_while_statement] = STATE(853),
    [sym_switch_statement] = STATE(853),
    [sym_lambda] = STATE(632),
    [sym_global_operator] = STATE(853),
    [sym_persistent_operator] = STATE(853),
    [sym_arguments_statement] = STATE(53),
    [sym__function_definition_with_end] = STATE(888),
    [sym_class_definition] = STATE(853),
    [sym_try_statement] = STATE(853),
    [sym_boolean] = STATE(205),
    [aux_sym_function_definition_repeat1] = STATE(53),
    [sym_identifier] = ACTIONS(7),
    [anon_sym_LPAREN] = ACTIONS(9),
    [anon_sym_PLUS] = ACTIONS(11),
    [anon_sym_DASH] = ACTIONS(11),
    [anon_sym_TILDE] = ACTIONS(13),
    [anon_sym_QMARK] = ACTIONS(15),
    [anon_sym_AT] = ACTIONS(17),
    [anon_sym_LBRACK] = ACTIONS(19),
    [anon_sym_LBRACE] = ACTIONS(21),
    [sym_return_statement] = ACTIONS(147),
    [sym_continue_statement] = ACTIONS(147),
    [sym_break_statement] = ACTIONS(147),
    [anon_sym_if] = ACTIONS(25),
    [anon_sym_end] = ACTIONS(232),
    [anon_sym_for] = ACTIONS(27),
    [anon_sym_parfor] = ACTIONS(29),
    [anon_sym_while] = ACTIONS(31),
    [anon_sym_switch] = ACTIONS(33),
    [anon_sym_global] = ACTIONS(35),
    [anon_sym_persistent] = ACTIONS(37),
    [anon_sym_arguments] = ACTIONS(151),
    [anon_sym_function] = ACTIONS(87),
    [anon_sym_endfunction] = ACTIONS(232),
    [anon_sym_classdef] = ACTIONS(41),
    [anon_sym_try] = ACTIONS(43),
    [sym_number] = ACTIONS(45),
    [anon_sym_true] = ACTIONS(47),
    [anon_sym_false] = ACTIONS(47),
    [sym_comment] = ACTIONS(3),
    [sym_line_continuation] = ACTIONS(3),
    [sym_command_name] = ACTIONS(49),
    [sym__single_quote_string_start] = ACTIONS(51),
    [sym__double_quote_string_start] = ACTIONS(53),
    [sym__multioutput_variable_start] = ACTIONS(55),
  },
  [47] = {
    [aux_sym__block] = STATE(74),
    [sym_block] = STATE(1072),
    [sym__statement] = STATE(853),
    [sym__expression] = STATE(632),
    [sym_parenthesis] = STATE(411),
    [sym__binary_expression] = STATE(622),
    [sym_binary_operator] = STATE(422),
    [sym_unary_operator] = STATE(389),
    [sym_indirect_access] = STATE(994),
    [sym_field_expression] = STATE(485),
    [sym_not_operator] = STATE(477),
    [sym_metaclass_operator] = STATE(632),
    [sym_handle_operator] = STATE(632),
    [sym_comparison_operator] = STATE(446),
    [sym_boolean_operator] = STATE(446),
    [sym_postfix_operator] = STATE(411),
    [sym_string] = STATE(411),
    [sym_matrix] = STATE(411),
    [sym_cell] = STATE(423),
    [sym_ignored_argument] = STATE(1187),
    [sym_assignment] = STATE(853),
    [sym_multioutput_variable] = STATE(1187),
    [sym_function_call] = STATE(210),
    [sym_command] = STATE(853),
    [sym__range_element] = STATE(1181),
    [sym_range] = STATE(632),
    [sym_if_statement] = STATE(853),
    [sym_for_statement] = STATE(853),
    [sym_while_statement] = STATE(853),
    [sym_switch_statement] = STATE(853),
    [sym_lambda] = STATE(632),
    [sym_global_operator] = STATE(853),
    [sym_persistent_operator] = STATE(853),
    [sym_arguments_statement] = STATE(341),
    [sym__function_definition_with_end] = STATE(888),
    [sym_class_definition] = STATE(853),
    [sym_try_statement] = STATE(853),
    [sym_boolean] = STATE(205),
    [aux_sym_function_definition_repeat1] = STATE(341),
    [sym_identifier] = ACTIONS(7),
    [anon_sym_LPAREN] = ACTIONS(9),
    [anon_sym_PLUS] = ACTIONS(11),
    [anon_sym_DASH] = ACTIONS(11),
    [anon_sym_TILDE] = ACTIONS(13),
    [anon_sym_QMARK] = ACTIONS(15),
    [anon_sym_AT] = ACTIONS(17),
    [anon_sym_LBRACK] = ACTIONS(19),
    [anon_sym_LBRACE] = ACTIONS(21),
    [sym_return_statement] = ACTIONS(147),
    [sym_continue_statement] = ACTIONS(147),
    [sym_break_statement] = ACTIONS(147),
    [anon_sym_if] = ACTIONS(25),
    [anon_sym_end] = ACTIONS(234),
    [anon_sym_for] = ACTIONS(27),
    [anon_sym_parfor] = ACTIONS(29),
    [anon_sym_while] = ACTIONS(31),
    [anon_sym_switch] = ACTIONS(33),
    [anon_sym_global] = ACTIONS(35),
    [anon_sym_persistent] = ACTIONS(37),
    [anon_sym_arguments] = ACTIONS(151),
    [anon_sym_function] = ACTIONS(87),
    [anon_sym_endfunction] = ACTIONS(234),
    [anon_sym_classdef] = ACTIONS(41),
    [anon_sym_try] = ACTIONS(43),
    [sym_number] = ACTIONS(45),
    [anon_sym_true] = ACTIONS(47),
    [anon_sym_false] = ACTIONS(47),
    [sym_comment] = ACTIONS(3),
    [sym_line_continuation] = ACTIONS(3),
    [sym_command_name] = ACTIONS(49),
    [sym__single_quote_string_start] = ACTIONS(51),
    [sym__double_quote_string_start] = ACTIONS(53),
    [sym__multioutput_variable_start] = ACTIONS(55),
  },
  [48] = {
    [aux_sym__block] = STATE(74),
    [sym_block] = STATE(1109),
    [sym__statement] = STATE(853),
    [sym__expression] = STATE(632),
    [sym_parenthesis] = STATE(411),
    [sym__binary_expression] = STATE(622),
    [sym_binary_operator] = STATE(422),
    [sym_unary_operator] = STATE(389),
    [sym_indirect_access] = STATE(994),
    [sym_field_expression] = STATE(485),
    [sym_not_operator] = STATE(477),
    [sym_metaclass_operator] = STATE(632),
    [sym_handle_operator] = STATE(632),
    [sym_comparison_operator] = STATE(446),
    [sym_boolean_operator] = STATE(446),
    [sym_postfix_operator] = STATE(411),
    [sym_string] = STATE(411),
    [sym_matrix] = STATE(411),
    [sym_cell] = STATE(423),
    [sym_ignored_argument] = STATE(1187),
    [sym_assignment] = STATE(853),
    [sym_multioutput_variable] = STATE(1187),
    [sym_function_call] = STATE(210),
    [sym_command] = STATE(853),
    [sym__range_element] = STATE(1181),
    [sym_range] = STATE(632),
    [sym_if_statement] = STATE(853),
    [sym_for_statement] = STATE(853),
    [sym_while_statement] = STATE(853),
    [sym_switch_statement] = STATE(853),
    [sym_lambda] = STATE(632),
    [sym_global_operator] = STATE(853),
    [sym_persistent_operator] = STATE(853),
    [sym_arguments_statement] = STATE(341),
    [sym__function_definition_with_end] = STATE(888),
    [sym_class_definition] = STATE(853),
    [sym_try_statement] = STATE(853),
    [sym_boolean] = STATE(205),
    [aux_sym_function_definition_repeat1] = STATE(341),
    [sym_identifier] = ACTIONS(7),
    [anon_sym_LPAREN] = ACTIONS(9),
    [anon_sym_PLUS] = ACTIONS(11),
    [anon_sym_DASH] = ACTIONS(11),
    [anon_sym_TILDE] = ACTIONS(13),
    [anon_sym_QMARK] = ACTIONS(15),
    [anon_sym_AT] = ACTIONS(17),
    [anon_sym_LBRACK] = ACTIONS(19),
    [anon_sym_LBRACE] = ACTIONS(21),
    [sym_return_statement] = ACTIONS(147),
    [sym_continue_statement] = ACTIONS(147),
    [sym_break_statement] = ACTIONS(147),
    [anon_sym_if] = ACTIONS(25),
    [anon_sym_end] = ACTIONS(236),
    [anon_sym_for] = ACTIONS(27),
    [anon_sym_parfor] = ACTIONS(29),
    [anon_sym_while] = ACTIONS(31),
    [anon_sym_switch] = ACTIONS(33),
    [anon_sym_global] = ACTIONS(35),
    [anon_sym_persistent] = ACTIONS(37),
    [anon_sym_arguments] = ACTIONS(151),
    [anon_sym_function] = ACTIONS(87),
    [anon_sym_endfunction] = ACTIONS(236),
    [anon_sym_classdef] = ACTIONS(41),
    [anon_sym_try] = ACTIONS(43),
    [sym_number] = ACTIONS(45),
    [anon_sym_true] = ACTIONS(47),
    [anon_sym_false] = ACTIONS(47),
    [sym_comment] = ACTIONS(3),
    [sym_line_continuation] = ACTIONS(3),
    [sym_command_name] = ACTIONS(49),
    [sym__single_quote_string_start] = ACTIONS(51),
    [sym__double_quote_string_start] = ACTIONS(53),
    [sym__multioutput_variable_start] = ACTIONS(55),
  },
  [49] = {
    [aux_sym__block] = STATE(74),
    [sym_block] = STATE(1073),
    [sym__statement] = STATE(853),
    [sym__expression] = STATE(632),
    [sym_parenthesis] = STATE(411),
    [sym__binary_expression] = STATE(622),
    [sym_binary_operator] = STATE(422),
    [sym_unary_operator] = STATE(389),
    [sym_indirect_access] = STATE(994),
    [sym_field_expression] = STATE(485),
    [sym_not_operator] = STATE(477),
    [sym_metaclass_operator] = STATE(632),
    [sym_handle_operator] = STATE(632),
    [sym_comparison_operator] = STATE(446),
    [sym_boolean_operator] = STATE(446),
    [sym_postfix_operator] = STATE(411),
    [sym_string] = STATE(411),
    [sym_matrix] = STATE(411),
    [sym_cell] = STATE(423),
    [sym_ignored_argument] = STATE(1187),
    [sym_assignment] = STATE(853),
    [sym_multioutput_variable] = STATE(1187),
    [sym_function_call] = STATE(210),
    [sym_command] = STATE(853),
    [sym__range_element] = STATE(1181),
    [sym_range] = STATE(632),
    [sym_if_statement] = STATE(853),
    [sym_for_statement] = STATE(853),
    [sym_while_statement] = STATE(853),
    [sym_switch_statement] = STATE(853),
    [sym_lambda] = STATE(632),
    [sym_global_operator] = STATE(853),
    [sym_persistent_operator] = STATE(853),
    [sym_arguments_statement] = STATE(52),
    [sym__function_definition_with_end] = STATE(888),
    [sym_class_definition] = STATE(853),
    [sym_try_statement] = STATE(853),
    [sym_boolean] = STATE(205),
    [aux_sym_function_definition_repeat1] = STATE(52),
    [sym_identifier] = ACTIONS(7),
    [anon_sym_LPAREN] = ACTIONS(9),
    [anon_sym_PLUS] = ACTIONS(11),
    [anon_sym_DASH] = ACTIONS(11),
    [anon_sym_TILDE] = ACTIONS(13),
    [anon_sym_QMARK] = ACTIONS(15),
    [anon_sym_AT] = ACTIONS(17),
    [anon_sym_LBRACK] = ACTIONS(19),
    [anon_sym_LBRACE] = ACTIONS(21),
    [sym_return_statement] = ACTIONS(147),
    [sym_continue_statement] = ACTIONS(147),
    [sym_break_statement] = ACTIONS(147),
    [anon_sym_if] = ACTIONS(25),
    [anon_sym_end] = ACTIONS(238),
    [anon_sym_for] = ACTIONS(27),
    [anon_sym_parfor] = ACTIONS(29),
    [anon_sym_while] = ACTIONS(31),
    [anon_sym_switch] = ACTIONS(33),
    [anon_sym_global] = ACTIONS(35),
    [anon_sym_persistent] = ACTIONS(37),
    [anon_sym_arguments] = ACTIONS(151),
    [anon_sym_function] = ACTIONS(87),
    [anon_sym_endfunction] = ACTIONS(238),
    [anon_sym_classdef] = ACTIONS(41),
    [anon_sym_try] = ACTIONS(43),
    [sym_number] = ACTIONS(45),
    [anon_sym_true] = ACTIONS(47),
    [anon_sym_false] = ACTIONS(47),
    [sym_comment] = ACTIONS(3),
    [sym_line_continuation] = ACTIONS(3),
    [sym_command_name] = ACTIONS(49),
    [sym__single_quote_string_start] = ACTIONS(51),
    [sym__double_quote_string_start] = ACTIONS(53),
    [sym__multioutput_variable_start] = ACTIONS(55),
  },
  [50] = {
    [aux_sym__block] = STATE(74),
    [sym_block] = STATE(1088),
    [sym__statement] = STATE(853),
    [sym__expression] = STATE(632),
    [sym_parenthesis] = STATE(411),
    [sym__binary_expression] = STATE(622),
    [sym_binary_operator] = STATE(422),
    [sym_unary_operator] = STATE(389),
    [sym_indirect_access] = STATE(994),
    [sym_field_expression] = STATE(485),
    [sym_not_operator] = STATE(477),
    [sym_metaclass_operator] = STATE(632),
    [sym_handle_operator] = STATE(632),
    [sym_comparison_operator] = STATE(446),
    [sym_boolean_operator] = STATE(446),
    [sym_postfix_operator] = STATE(411),
    [sym_string] = STATE(411),
    [sym_matrix] = STATE(411),
    [sym_cell] = STATE(423),
    [sym_ignored_argument] = STATE(1187),
    [sym_assignment] = STATE(853),
    [sym_multioutput_variable] = STATE(1187),
    [sym_function_call] = STATE(210),
    [sym_command] = STATE(853),
    [sym__range_element] = STATE(1181),
    [sym_range] = STATE(632),
    [sym_if_statement] = STATE(853),
    [sym_for_statement] = STATE(853),
    [sym_while_statement] = STATE(853),
    [sym_switch_statement] = STATE(853),
    [sym_lambda] = STATE(632),
    [sym_global_operator] = STATE(853),
    [sym_persistent_operator] = STATE(853),
    [sym_arguments_statement] = STATE(341),
    [sym__function_definition_with_end] = STATE(888),
    [sym_class_definition] = STATE(853),
    [sym_try_statement] = STATE(853),
    [sym_boolean] = STATE(205),
    [aux_sym_function_definition_repeat1] = STATE(341),
    [sym_identifier] = ACTIONS(7),
    [anon_sym_LPAREN] = ACTIONS(9),
    [anon_sym_PLUS] = ACTIONS(11),
    [anon_sym_DASH] = ACTIONS(11),
    [anon_sym_TILDE] = ACTIONS(13),
    [anon_sym_QMARK] = ACTIONS(15),
    [anon_sym_AT] = ACTIONS(17),
    [anon_sym_LBRACK] = ACTIONS(19),
    [anon_sym_LBRACE] = ACTIONS(21),
    [sym_return_statement] = ACTIONS(147),
    [sym_continue_statement] = ACTIONS(147),
    [sym_break_statement] = ACTIONS(147),
    [anon_sym_if] = ACTIONS(25),
    [anon_sym_end] = ACTIONS(240),
    [anon_sym_for] = ACTIONS(27),
    [anon_sym_parfor] = ACTIONS(29),
    [anon_sym_while] = ACTIONS(31),
    [anon_sym_switch] = ACTIONS(33),
    [anon_sym_global] = ACTIONS(35),
    [anon_sym_persistent] = ACTIONS(37),
    [anon_sym_arguments] = ACTIONS(151),
    [anon_sym_function] = ACTIONS(87),
    [anon_sym_endfunction] = ACTIONS(240),
    [anon_sym_classdef] = ACTIONS(41),
    [anon_sym_try] = ACTIONS(43),
    [sym_number] = ACTIONS(45),
    [anon_sym_true] = ACTIONS(47),
    [anon_sym_false] = ACTIONS(47),
    [sym_comment] = ACTIONS(3),
    [sym_line_continuation] = ACTIONS(3),
    [sym_command_name] = ACTIONS(49),
    [sym__single_quote_string_start] = ACTIONS(51),
    [sym__double_quote_string_start] = ACTIONS(53),
    [sym__multioutput_variable_start] = ACTIONS(55),
  },
  [51] = {
    [aux_sym__block] = STATE(74),
    [sym_block] = STATE(1073),
    [sym__statement] = STATE(853),
    [sym__expression] = STATE(632),
    [sym_parenthesis] = STATE(411),
    [sym__binary_expression] = STATE(622),
    [sym_binary_operator] = STATE(422),
    [sym_unary_operator] = STATE(389),
    [sym_indirect_access] = STATE(994),
    [sym_field_expression] = STATE(485),
    [sym_not_operator] = STATE(477),
    [sym_metaclass_operator] = STATE(632),
    [sym_handle_operator] = STATE(632),
    [sym_comparison_operator] = STATE(446),
    [sym_boolean_operator] = STATE(446),
    [sym_postfix_operator] = STATE(411),
    [sym_string] = STATE(411),
    [sym_matrix] = STATE(411),
    [sym_cell] = STATE(423),
    [sym_ignored_argument] = STATE(1187),
    [sym_assignment] = STATE(853),
    [sym_multioutput_variable] = STATE(1187),
    [sym_function_call] = STATE(210),
    [sym_command] = STATE(853),
    [sym__range_element] = STATE(1181),
    [sym_range] = STATE(632),
    [sym_if_statement] = STATE(853),
    [sym_for_statement] = STATE(853),
    [sym_while_statement] = STATE(853),
    [sym_switch_statement] = STATE(853),
    [sym_lambda] = STATE(632),
    [sym_global_operator] = STATE(853),
    [sym_persistent_operator] = STATE(853),
    [sym_arguments_statement] = STATE(341),
    [sym__function_definition_with_end] = STATE(888),
    [sym_class_definition] = STATE(853),
    [sym_try_statement] = STATE(853),
    [sym_boolean] = STATE(205),
    [aux_sym_function_definition_repeat1] = STATE(341),
    [sym_identifier] = ACTIONS(7),
    [anon_sym_LPAREN] = ACTIONS(9),
    [anon_sym_PLUS] = ACTIONS(11),
    [anon_sym_DASH] = ACTIONS(11),
    [anon_sym_TILDE] = ACTIONS(13),
    [anon_sym_QMARK] = ACTIONS(15),
    [anon_sym_AT] = ACTIONS(17),
    [anon_sym_LBRACK] = ACTIONS(19),
    [anon_sym_LBRACE] = ACTIONS(21),
    [sym_return_statement] = ACTIONS(147),
    [sym_continue_statement] = ACTIONS(147),
    [sym_break_statement] = ACTIONS(147),
    [anon_sym_if] = ACTIONS(25),
    [anon_sym_end] = ACTIONS(238),
    [anon_sym_for] = ACTIONS(27),
    [anon_sym_parfor] = ACTIONS(29),
    [anon_sym_while] = ACTIONS(31),
    [anon_sym_switch] = ACTIONS(33),
    [anon_sym_global] = ACTIONS(35),
    [anon_sym_persistent] = ACTIONS(37),
    [anon_sym_arguments] = ACTIONS(151),
    [anon_sym_function] = ACTIONS(87),
    [anon_sym_endfunction] = ACTIONS(238),
    [anon_sym_classdef] = ACTIONS(41),
    [anon_sym_try] = ACTIONS(43),
    [sym_number] = ACTIONS(45),
    [anon_sym_true] = ACTIONS(47),
    [anon_sym_false] = ACTIONS(47),
    [sym_comment] = ACTIONS(3),
    [sym_line_continuation] = ACTIONS(3),
    [sym_command_name] = ACTIONS(49),
    [sym__single_quote_string_start] = ACTIONS(51),
    [sym__double_quote_string_start] = ACTIONS(53),
    [sym__multioutput_variable_start] = ACTIONS(55),
  },
  [52] = {
    [aux_sym__block] = STATE(74),
    [sym_block] = STATE(1075),
    [sym__statement] = STATE(853),
    [sym__expression] = STATE(632),
    [sym_parenthesis] = STATE(411),
    [sym__binary_expression] = STATE(622),
    [sym_binary_operator] = STATE(422),
    [sym_unary_operator] = STATE(389),
    [sym_indirect_access] = STATE(994),
    [sym_field_expression] = STATE(485),
    [sym_not_operator] = STATE(477),
    [sym_metaclass_operator] = STATE(632),
    [sym_handle_operator] = STATE(632),
    [sym_comparison_operator] = STATE(446),
    [sym_boolean_operator] = STATE(446),
    [sym_postfix_operator] = STATE(411),
    [sym_string] = STATE(411),
    [sym_matrix] = STATE(411),
    [sym_cell] = STATE(423),
    [sym_ignored_argument] = STATE(1187),
    [sym_assignment] = STATE(853),
    [sym_multioutput_variable] = STATE(1187),
    [sym_function_call] = STATE(210),
    [sym_command] = STATE(853),
    [sym__range_element] = STATE(1181),
    [sym_range] = STATE(632),
    [sym_if_statement] = STATE(853),
    [sym_for_statement] = STATE(853),
    [sym_while_statement] = STATE(853),
    [sym_switch_statement] = STATE(853),
    [sym_lambda] = STATE(632),
    [sym_global_operator] = STATE(853),
    [sym_persistent_operator] = STATE(853),
    [sym_arguments_statement] = STATE(341),
    [sym__function_definition_with_end] = STATE(888),
    [sym_class_definition] = STATE(853),
    [sym_try_statement] = STATE(853),
    [sym_boolean] = STATE(205),
    [aux_sym_function_definition_repeat1] = STATE(341),
    [sym_identifier] = ACTIONS(7),
    [anon_sym_LPAREN] = ACTIONS(9),
    [anon_sym_PLUS] = ACTIONS(11),
    [anon_sym_DASH] = ACTIONS(11),
    [anon_sym_TILDE] = ACTIONS(13),
    [anon_sym_QMARK] = ACTIONS(15),
    [anon_sym_AT] = ACTIONS(17),
    [anon_sym_LBRACK] = ACTIONS(19),
    [anon_sym_LBRACE] = ACTIONS(21),
    [sym_return_statement] = ACTIONS(147),
    [sym_continue_statement] = ACTIONS(147),
    [sym_break_statement] = ACTIONS(147),
    [anon_sym_if] = ACTIONS(25),
    [anon_sym_end] = ACTIONS(242),
    [anon_sym_for] = ACTIONS(27),
    [anon_sym_parfor] = ACTIONS(29),
    [anon_sym_while] = ACTIONS(31),
    [anon_sym_switch] = ACTIONS(33),
    [anon_sym_global] = ACTIONS(35),
    [anon_sym_persistent] = ACTIONS(37),
    [anon_sym_arguments] = ACTIONS(151),
    [anon_sym_function] = ACTIONS(87),
    [anon_sym_endfunction] = ACTIONS(242),
    [anon_sym_classdef] = ACTIONS(41),
    [anon_sym_try] = ACTIONS(43),
    [sym_number] = ACTIONS(45),
    [anon_sym_true] = ACTIONS(47),
    [anon_sym_false] = ACTIONS(47),
    [sym_comment] = ACTIONS(3),
    [sym_line_continuation] = ACTIONS(3),
    [sym_command_name] = ACTIONS(49),
    [sym__single_quote_string_start] = ACTIONS(51),
    [sym__double_quote_string_start] = ACTIONS(53),
    [sym__multioutput_variable_start] = ACTIONS(55),
  },
  [53] = {
    [aux_sym__block] = STATE(74),
    [sym_block] = STATE(1112),
    [sym__statement] = STATE(853),
    [sym__expression] = STATE(632),
    [sym_parenthesis] = STATE(411),
    [sym__binary_expression] = STATE(622),
    [sym_binary_operator] = STATE(422),
    [sym_unary_operator] = STATE(389),
    [sym_indirect_access] = STATE(994),
    [sym_field_expression] = STATE(485),
    [sym_not_operator] = STATE(477),
    [sym_metaclass_operator] = STATE(632),
    [sym_handle_operator] = STATE(632),
    [sym_comparison_operator] = STATE(446),
    [sym_boolean_operator] = STATE(446),
    [sym_postfix_operator] = STATE(411),
    [sym_string] = STATE(411),
    [sym_matrix] = STATE(411),
    [sym_cell] = STATE(423),
    [sym_ignored_argument] = STATE(1187),
    [sym_assignment] = STATE(853),
    [sym_multioutput_variable] = STATE(1187),
    [sym_function_call] = STATE(210),
    [sym_command] = STATE(853),
    [sym__range_element] = STATE(1181),
    [sym_range] = STATE(632),
    [sym_if_statement] = STATE(853),
    [sym_for_statement] = STATE(853),
    [sym_while_statement] = STATE(853),
    [sym_switch_statement] = STATE(853),
    [sym_lambda] = STATE(632),
    [sym_global_operator] = STATE(853),
    [sym_persistent_operator] = STATE(853),
    [sym_arguments_statement] = STATE(341),
    [sym__function_definition_with_end] = STATE(888),
    [sym_class_definition] = STATE(853),
    [sym_try_statement] = STATE(853),
    [sym_boolean] = STATE(205),
    [aux_sym_function_definition_repeat1] = STATE(341),
    [sym_identifier] = ACTIONS(7),
    [anon_sym_LPAREN] = ACTIONS(9),
    [anon_sym_PLUS] = ACTIONS(11),
    [anon_sym_DASH] = ACTIONS(11),
    [anon_sym_TILDE] = ACTIONS(13),
    [anon_sym_QMARK] = ACTIONS(15),
    [anon_sym_AT] = ACTIONS(17),
    [anon_sym_LBRACK] = ACTIONS(19),
    [anon_sym_LBRACE] = ACTIONS(21),
    [sym_return_statement] = ACTIONS(147),
    [sym_continue_statement] = ACTIONS(147),
    [sym_break_statement] = ACTIONS(147),
    [anon_sym_if] = ACTIONS(25),
    [anon_sym_end] = ACTIONS(244),
    [anon_sym_for] = ACTIONS(27),
    [anon_sym_parfor] = ACTIONS(29),
    [anon_sym_while] = ACTIONS(31),
    [anon_sym_switch] = ACTIONS(33),
    [anon_sym_global] = ACTIONS(35),
    [anon_sym_persistent] = ACTIONS(37),
    [anon_sym_arguments] = ACTIONS(151),
    [anon_sym_function] = ACTIONS(87),
    [anon_sym_endfunction] = ACTIONS(244),
    [anon_sym_classdef] = ACTIONS(41),
    [anon_sym_try] = ACTIONS(43),
    [sym_number] = ACTIONS(45),
    [anon_sym_true] = ACTIONS(47),
    [anon_sym_false] = ACTIONS(47),
    [sym_comment] = ACTIONS(3),
    [sym_line_continuation] = ACTIONS(3),
    [sym_command_name] = ACTIONS(49),
    [sym__single_quote_string_start] = ACTIONS(51),
    [sym__double_quote_string_start] = ACTIONS(53),
    [sym__multioutput_variable_start] = ACTIONS(55),
  },
  [54] = {
    [aux_sym__block] = STATE(59),
    [sym__statement] = STATE(874),
    [sym__expression] = STATE(627),
    [sym_parenthesis] = STATE(411),
    [sym__binary_expression] = STATE(622),
    [sym_binary_operator] = STATE(422),
    [sym_unary_operator] = STATE(389),
    [sym_indirect_access] = STATE(994),
    [sym_field_expression] = STATE(485),
    [sym_not_operator] = STATE(477),
    [sym_metaclass_operator] = STATE(627),
    [sym_handle_operator] = STATE(627),
    [sym_comparison_operator] = STATE(446),
    [sym_boolean_operator] = STATE(446),
    [sym_postfix_operator] = STATE(411),
    [sym_string] = STATE(411),
    [sym_matrix] = STATE(411),
    [sym_cell] = STATE(423),
    [sym_ignored_argument] = STATE(1187),
    [sym_assignment] = STATE(874),
    [sym_multioutput_variable] = STATE(1187),
    [sym_function_call] = STATE(210),
    [sym_command] = STATE(874),
    [sym__range_element] = STATE(1181),
    [sym_range] = STATE(627),
    [sym_if_statement] = STATE(874),
    [sym_for_statement] = STATE(874),
    [sym_while_statement] = STATE(874),
    [sym_switch_statement] = STATE(874),
    [sym_lambda] = STATE(627),
    [sym_global_operator] = STATE(874),
    [sym_persistent_operator] = STATE(874),
    [sym__function_definition_with_end] = STATE(877),
    [sym_class_definition] = STATE(874),
    [sym_try_statement] = STATE(874),
    [sym_boolean] = STATE(205),
    [sym_identifier] = ACTIONS(7),
    [anon_sym_LPAREN] = ACTIONS(9),
    [anon_sym_PLUS] = ACTIONS(11),
    [anon_sym_DASH] = ACTIONS(11),
    [anon_sym_TILDE] = ACTIONS(13),
    [anon_sym_QMARK] = ACTIONS(15),
    [anon_sym_AT] = ACTIONS(17),
    [anon_sym_LBRACK] = ACTIONS(19),
    [anon_sym_LBRACE] = ACTIONS(21),
    [sym_return_statement] = ACTIONS(79),
    [sym_continue_statement] = ACTIONS(79),
    [sym_break_statement] = ACTIONS(79),
    [anon_sym_elseif] = ACTIONS(246),
    [anon_sym_else] = ACTIONS(246),
    [anon_sym_if] = ACTIONS(25),
    [anon_sym_end] = ACTIONS(246),
    [anon_sym_for] = ACTIONS(27),
    [anon_sym_parfor] = ACTIONS(29),
    [anon_sym_while] = ACTIONS(31),
    [anon_sym_case] = ACTIONS(246),
    [anon_sym_otherwise] = ACTIONS(246),
    [anon_sym_switch] = ACTIONS(33),
    [anon_sym_global] = ACTIONS(35),
    [anon_sym_persistent] = ACTIONS(37),
    [anon_sym_function] = ACTIONS(87),
    [anon_sym_classdef] = ACTIONS(41),
    [anon_sym_catch] = ACTIONS(246),
    [anon_sym_try] = ACTIONS(43),
    [sym_number] = ACTIONS(45),
    [anon_sym_true] = ACTIONS(47),
    [anon_sym_false] = ACTIONS(47),
    [sym_comment] = ACTIONS(3),
    [sym_line_continuation] = ACTIONS(3),
    [sym_command_name] = ACTIONS(49),
    [sym__single_quote_string_start] = ACTIONS(51),
    [sym__double_quote_string_start] = ACTIONS(53),
    [sym__multioutput_variable_start] = ACTIONS(55),
  },
  [55] = {
    [aux_sym__block] = STATE(74),
    [sym_block] = STATE(1125),
    [sym__statement] = STATE(853),
    [sym__expression] = STATE(632),
    [sym_parenthesis] = STATE(411),
    [sym__binary_expression] = STATE(622),
    [sym_binary_operator] = STATE(422),
    [sym_unary_operator] = STATE(389),
    [sym_indirect_access] = STATE(994),
    [sym_field_expression] = STATE(485),
    [sym_not_operator] = STATE(477),
    [sym_metaclass_operator] = STATE(632),
    [sym_handle_operator] = STATE(632),
    [sym_comparison_operator] = STATE(446),
    [sym_boolean_operator] = STATE(446),
    [sym_postfix_operator] = STATE(411),
    [sym_string] = STATE(411),
    [sym_matrix] = STATE(411),
    [sym_cell] = STATE(423),
    [sym_ignored_argument] = STATE(1187),
    [sym_assignment] = STATE(853),
    [sym_multioutput_variable] = STATE(1187),
    [sym_function_call] = STATE(210),
    [sym_command] = STATE(853),
    [sym__range_element] = STATE(1181),
    [sym_range] = STATE(632),
    [sym_if_statement] = STATE(853),
    [sym_for_statement] = STATE(853),
    [sym_while_statement] = STATE(853),
    [sym_switch_statement] = STATE(853),
    [sym_lambda] = STATE(632),
    [sym_global_operator] = STATE(853),
    [sym_persistent_operator] = STATE(853),
    [sym_arguments_statement] = STATE(48),
    [sym__function_definition_with_end] = STATE(888),
    [sym_class_definition] = STATE(853),
    [sym_try_statement] = STATE(853),
    [sym_boolean] = STATE(205),
    [aux_sym_function_definition_repeat1] = STATE(48),
    [sym_identifier] = ACTIONS(7),
    [anon_sym_LPAREN] = ACTIONS(9),
    [anon_sym_PLUS] = ACTIONS(11),
    [anon_sym_DASH] = ACTIONS(11),
    [anon_sym_TILDE] = ACTIONS(13),
    [anon_sym_QMARK] = ACTIONS(15),
    [anon_sym_AT] = ACTIONS(17),
    [anon_sym_LBRACK] = ACTIONS(19),
    [anon_sym_LBRACE] = ACTIONS(21),
    [sym_return_statement] = ACTIONS(147),
    [sym_continue_statement] = ACTIONS(147),
    [sym_break_statement] = ACTIONS(147),
    [anon_sym_if] = ACTIONS(25),
    [anon_sym_end] = ACTIONS(248),
    [anon_sym_for] = ACTIONS(27),
    [anon_sym_parfor] = ACTIONS(29),
    [anon_sym_while] = ACTIONS(31),
    [anon_sym_switch] = ACTIONS(33),
    [anon_sym_global] = ACTIONS(35),
    [anon_sym_persistent] = ACTIONS(37),
    [anon_sym_arguments] = ACTIONS(151),
    [anon_sym_function] = ACTIONS(87),
    [anon_sym_endfunction] = ACTIONS(248),
    [anon_sym_classdef] = ACTIONS(41),
    [anon_sym_try] = ACTIONS(43),
    [sym_number] = ACTIONS(45),
    [anon_sym_true] = ACTIONS(47),
    [anon_sym_false] = ACTIONS(47),
    [sym_comment] = ACTIONS(3),
    [sym_line_continuation] = ACTIONS(3),
    [sym_command_name] = ACTIONS(49),
    [sym__single_quote_string_start] = ACTIONS(51),
    [sym__double_quote_string_start] = ACTIONS(53),
    [sym__multioutput_variable_start] = ACTIONS(55),
  },
  [56] = {
    [aux_sym__block] = STATE(74),
    [sym_block] = STATE(1129),
    [sym__statement] = STATE(853),
    [sym__expression] = STATE(632),
    [sym_parenthesis] = STATE(411),
    [sym__binary_expression] = STATE(622),
    [sym_binary_operator] = STATE(422),
    [sym_unary_operator] = STATE(389),
    [sym_indirect_access] = STATE(994),
    [sym_field_expression] = STATE(485),
    [sym_not_operator] = STATE(477),
    [sym_metaclass_operator] = STATE(632),
    [sym_handle_operator] = STATE(632),
    [sym_comparison_operator] = STATE(446),
    [sym_boolean_operator] = STATE(446),
    [sym_postfix_operator] = STATE(411),
    [sym_string] = STATE(411),
    [sym_matrix] = STATE(411),
    [sym_cell] = STATE(423),
    [sym_ignored_argument] = STATE(1187),
    [sym_assignment] = STATE(853),
    [sym_multioutput_variable] = STATE(1187),
    [sym_function_call] = STATE(210),
    [sym_command] = STATE(853),
    [sym__range_element] = STATE(1181),
    [sym_range] = STATE(632),
    [sym_if_statement] = STATE(853),
    [sym_for_statement] = STATE(853),
    [sym_while_statement] = STATE(853),
    [sym_switch_statement] = STATE(853),
    [sym_lambda] = STATE(632),
    [sym_global_operator] = STATE(853),
    [sym_persistent_operator] = STATE(853),
    [sym_arguments_statement] = STATE(341),
    [sym__function_definition_with_end] = STATE(888),
    [sym_class_definition] = STATE(853),
    [sym_try_statement] = STATE(853),
    [sym_boolean] = STATE(205),
    [aux_sym_function_definition_repeat1] = STATE(341),
    [sym_identifier] = ACTIONS(7),
    [anon_sym_LPAREN] = ACTIONS(9),
    [anon_sym_PLUS] = ACTIONS(11),
    [anon_sym_DASH] = ACTIONS(11),
    [anon_sym_TILDE] = ACTIONS(13),
    [anon_sym_QMARK] = ACTIONS(15),
    [anon_sym_AT] = ACTIONS(17),
    [anon_sym_LBRACK] = ACTIONS(19),
    [anon_sym_LBRACE] = ACTIONS(21),
    [sym_return_statement] = ACTIONS(147),
    [sym_continue_statement] = ACTIONS(147),
    [sym_break_statement] = ACTIONS(147),
    [anon_sym_if] = ACTIONS(25),
    [anon_sym_end] = ACTIONS(250),
    [anon_sym_for] = ACTIONS(27),
    [anon_sym_parfor] = ACTIONS(29),
    [anon_sym_while] = ACTIONS(31),
    [anon_sym_switch] = ACTIONS(33),
    [anon_sym_global] = ACTIONS(35),
    [anon_sym_persistent] = ACTIONS(37),
    [anon_sym_arguments] = ACTIONS(151),
    [anon_sym_function] = ACTIONS(87),
    [anon_sym_endfunction] = ACTIONS(250),
    [anon_sym_classdef] = ACTIONS(41),
    [anon_sym_try] = ACTIONS(43),
    [sym_number] = ACTIONS(45),
    [anon_sym_true] = ACTIONS(47),
    [anon_sym_false] = ACTIONS(47),
    [sym_comment] = ACTIONS(3),
    [sym_line_continuation] = ACTIONS(3),
    [sym_command_name] = ACTIONS(49),
    [sym__single_quote_string_start] = ACTIONS(51),
    [sym__double_quote_string_start] = ACTIONS(53),
    [sym__multioutput_variable_start] = ACTIONS(55),
  },
  [57] = {
    [aux_sym__block] = STATE(74),
    [sym_block] = STATE(1109),
    [sym__statement] = STATE(853),
    [sym__expression] = STATE(632),
    [sym_parenthesis] = STATE(411),
    [sym__binary_expression] = STATE(622),
    [sym_binary_operator] = STATE(422),
    [sym_unary_operator] = STATE(389),
    [sym_indirect_access] = STATE(994),
    [sym_field_expression] = STATE(485),
    [sym_not_operator] = STATE(477),
    [sym_metaclass_operator] = STATE(632),
    [sym_handle_operator] = STATE(632),
    [sym_comparison_operator] = STATE(446),
    [sym_boolean_operator] = STATE(446),
    [sym_postfix_operator] = STATE(411),
    [sym_string] = STATE(411),
    [sym_matrix] = STATE(411),
    [sym_cell] = STATE(423),
    [sym_ignored_argument] = STATE(1187),
    [sym_assignment] = STATE(853),
    [sym_multioutput_variable] = STATE(1187),
    [sym_function_call] = STATE(210),
    [sym_command] = STATE(853),
    [sym__range_element] = STATE(1181),
    [sym_range] = STATE(632),
    [sym_if_statement] = STATE(853),
    [sym_for_statement] = STATE(853),
    [sym_while_statement] = STATE(853),
    [sym_switch_statement] = STATE(853),
    [sym_lambda] = STATE(632),
    [sym_global_operator] = STATE(853),
    [sym_persistent_operator] = STATE(853),
    [sym_arguments_statement] = STATE(50),
    [sym__function_definition_with_end] = STATE(888),
    [sym_class_definition] = STATE(853),
    [sym_try_statement] = STATE(853),
    [sym_boolean] = STATE(205),
    [aux_sym_function_definition_repeat1] = STATE(50),
    [sym_identifier] = ACTIONS(7),
    [anon_sym_LPAREN] = ACTIONS(9),
    [anon_sym_PLUS] = ACTIONS(11),
    [anon_sym_DASH] = ACTIONS(11),
    [anon_sym_TILDE] = ACTIONS(13),
    [anon_sym_QMARK] = ACTIONS(15),
    [anon_sym_AT] = ACTIONS(17),
    [anon_sym_LBRACK] = ACTIONS(19),
    [anon_sym_LBRACE] = ACTIONS(21),
    [sym_return_statement] = ACTIONS(147),
    [sym_continue_statement] = ACTIONS(147),
    [sym_break_statement] = ACTIONS(147),
    [anon_sym_if] = ACTIONS(25),
    [anon_sym_end] = ACTIONS(236),
    [anon_sym_for] = ACTIONS(27),
    [anon_sym_parfor] = ACTIONS(29),
    [anon_sym_while] = ACTIONS(31),
    [anon_sym_switch] = ACTIONS(33),
    [anon_sym_global] = ACTIONS(35),
    [anon_sym_persistent] = ACTIONS(37),
    [anon_sym_arguments] = ACTIONS(151),
    [anon_sym_function] = ACTIONS(87),
    [anon_sym_endfunction] = ACTIONS(236),
    [anon_sym_classdef] = ACTIONS(41),
    [anon_sym_try] = ACTIONS(43),
    [sym_number] = ACTIONS(45),
    [anon_sym_true] = ACTIONS(47),
    [anon_sym_false] = ACTIONS(47),
    [sym_comment] = ACTIONS(3),
    [sym_line_continuation] = ACTIONS(3),
    [sym_command_name] = ACTIONS(49),
    [sym__single_quote_string_start] = ACTIONS(51),
    [sym__double_quote_string_start] = ACTIONS(53),
    [sym__multioutput_variable_start] = ACTIONS(55),
  },
  [58] = {
    [aux_sym__block] = STATE(74),
    [sym_block] = STATE(1132),
    [sym__statement] = STATE(853),
    [sym__expression] = STATE(632),
    [sym_parenthesis] = STATE(411),
    [sym__binary_expression] = STATE(622),
    [sym_binary_operator] = STATE(422),
    [sym_unary_operator] = STATE(389),
    [sym_indirect_access] = STATE(994),
    [sym_field_expression] = STATE(485),
    [sym_not_operator] = STATE(477),
    [sym_metaclass_operator] = STATE(632),
    [sym_handle_operator] = STATE(632),
    [sym_comparison_operator] = STATE(446),
    [sym_boolean_operator] = STATE(446),
    [sym_postfix_operator] = STATE(411),
    [sym_string] = STATE(411),
    [sym_matrix] = STATE(411),
    [sym_cell] = STATE(423),
    [sym_ignored_argument] = STATE(1187),
    [sym_assignment] = STATE(853),
    [sym_multioutput_variable] = STATE(1187),
    [sym_function_call] = STATE(210),
    [sym_command] = STATE(853),
    [sym__range_element] = STATE(1181),
    [sym_range] = STATE(632),
    [sym_if_statement] = STATE(853),
    [sym_for_statement] = STATE(853),
    [sym_while_statement] = STATE(853),
    [sym_switch_statement] = STATE(853),
    [sym_lambda] = STATE(632),
    [sym_global_operator] = STATE(853),
    [sym_persistent_operator] = STATE(853),
    [sym_arguments_statement] = STATE(341),
    [sym__function_definition_with_end] = STATE(888),
    [sym_class_definition] = STATE(853),
    [sym_try_statement] = STATE(853),
    [sym_boolean] = STATE(205),
    [aux_sym_function_definition_repeat1] = STATE(341),
    [sym_identifier] = ACTIONS(7),
    [anon_sym_LPAREN] = ACTIONS(9),
    [anon_sym_PLUS] = ACTIONS(11),
    [anon_sym_DASH] = ACTIONS(11),
    [anon_sym_TILDE] = ACTIONS(13),
    [anon_sym_QMARK] = ACTIONS(15),
    [anon_sym_AT] = ACTIONS(17),
    [anon_sym_LBRACK] = ACTIONS(19),
    [anon_sym_LBRACE] = ACTIONS(21),
    [sym_return_statement] = ACTIONS(147),
    [sym_continue_statement] = ACTIONS(147),
    [sym_break_statement] = ACTIONS(147),
    [anon_sym_if] = ACTIONS(25),
    [anon_sym_end] = ACTIONS(232),
    [anon_sym_for] = ACTIONS(27),
    [anon_sym_parfor] = ACTIONS(29),
    [anon_sym_while] = ACTIONS(31),
    [anon_sym_switch] = ACTIONS(33),
    [anon_sym_global] = ACTIONS(35),
    [anon_sym_persistent] = ACTIONS(37),
    [anon_sym_arguments] = ACTIONS(151),
    [anon_sym_function] = ACTIONS(87),
    [anon_sym_endfunction] = ACTIONS(232),
    [anon_sym_classdef] = ACTIONS(41),
    [anon_sym_try] = ACTIONS(43),
    [sym_number] = ACTIONS(45),
    [anon_sym_true] = ACTIONS(47),
    [anon_sym_false] = ACTIONS(47),
    [sym_comment] = ACTIONS(3),
    [sym_line_continuation] = ACTIONS(3),
    [sym_command_name] = ACTIONS(49),
    [sym__single_quote_string_start] = ACTIONS(51),
    [sym__double_quote_string_start] = ACTIONS(53),
    [sym__multioutput_variable_start] = ACTIONS(55),
  },
  [59] = {
    [aux_sym__block] = STATE(59),
    [sym__statement] = STATE(874),
    [sym__expression] = STATE(627),
    [sym_parenthesis] = STATE(411),
    [sym__binary_expression] = STATE(622),
    [sym_binary_operator] = STATE(422),
    [sym_unary_operator] = STATE(389),
    [sym_indirect_access] = STATE(994),
    [sym_field_expression] = STATE(485),
    [sym_not_operator] = STATE(477),
    [sym_metaclass_operator] = STATE(627),
    [sym_handle_operator] = STATE(627),
    [sym_comparison_operator] = STATE(446),
    [sym_boolean_operator] = STATE(446),
    [sym_postfix_operator] = STATE(411),
    [sym_string] = STATE(411),
    [sym_matrix] = STATE(411),
    [sym_cell] = STATE(423),
    [sym_ignored_argument] = STATE(1187),
    [sym_assignment] = STATE(874),
    [sym_multioutput_variable] = STATE(1187),
    [sym_function_call] = STATE(210),
    [sym_command] = STATE(874),
    [sym__range_element] = STATE(1181),
    [sym_range] = STATE(627),
    [sym_if_statement] = STATE(874),
    [sym_for_statement] = STATE(874),
    [sym_while_statement] = STATE(874),
    [sym_switch_statement] = STATE(874),
    [sym_lambda] = STATE(627),
    [sym_global_operator] = STATE(874),
    [sym_persistent_operator] = STATE(874),
    [sym__function_definition_with_end] = STATE(877),
    [sym_class_definition] = STATE(874),
    [sym_try_statement] = STATE(874),
    [sym_boolean] = STATE(205),
    [sym_identifier] = ACTIONS(252),
    [anon_sym_LPAREN] = ACTIONS(255),
    [anon_sym_PLUS] = ACTIONS(258),
    [anon_sym_DASH] = ACTIONS(258),
    [anon_sym_TILDE] = ACTIONS(261),
    [anon_sym_QMARK] = ACTIONS(264),
    [anon_sym_AT] = ACTIONS(267),
    [anon_sym_LBRACK] = ACTIONS(270),
    [anon_sym_LBRACE] = ACTIONS(273),
    [sym_return_statement] = ACTIONS(276),
    [sym_continue_statement] = ACTIONS(276),
    [sym_break_statement] = ACTIONS(276),
    [anon_sym_elseif] = ACTIONS(279),
    [anon_sym_else] = ACTIONS(279),
    [anon_sym_if] = ACTIONS(281),
    [anon_sym_end] = ACTIONS(279),
    [anon_sym_for] = ACTIONS(284),
    [anon_sym_parfor] = ACTIONS(287),
    [anon_sym_while] = ACTIONS(290),
    [anon_sym_case] = ACTIONS(279),
    [anon_sym_otherwise] = ACTIONS(279),
    [anon_sym_switch] = ACTIONS(293),
    [anon_sym_global] = ACTIONS(296),
    [anon_sym_persistent] = ACTIONS(299),
    [anon_sym_function] = ACTIONS(302),
    [anon_sym_classdef] = ACTIONS(305),
    [anon_sym_catch] = ACTIONS(279),
    [anon_sym_try] = ACTIONS(308),
    [sym_number] = ACTIONS(311),
    [anon_sym_true] = ACTIONS(314),
    [anon_sym_false] = ACTIONS(314),
    [sym_comment] = ACTIONS(3),
    [sym_line_continuation] = ACTIONS(3),
    [sym_command_name] = ACTIONS(317),
    [sym__single_quote_string_start] = ACTIONS(320),
    [sym__double_quote_string_start] = ACTIONS(323),
    [sym__multioutput_variable_start] = ACTIONS(326),
  },
  [60] = {
    [aux_sym__block] = STATE(74),
    [sym_block] = STATE(1063),
    [sym__statement] = STATE(853),
    [sym__expression] = STATE(632),
    [sym_parenthesis] = STATE(411),
    [sym__binary_expression] = STATE(622),
    [sym_binary_operator] = STATE(422),
    [sym_unary_operator] = STATE(389),
    [sym_indirect_access] = STATE(994),
    [sym_field_expression] = STATE(485),
    [sym_not_operator] = STATE(477),
    [sym_metaclass_operator] = STATE(632),
    [sym_handle_operator] = STATE(632),
    [sym_comparison_operator] = STATE(446),
    [sym_boolean_operator] = STATE(446),
    [sym_postfix_operator] = STATE(411),
    [sym_string] = STATE(411),
    [sym_matrix] = STATE(411),
    [sym_cell] = STATE(423),
    [sym_ignored_argument] = STATE(1187),
    [sym_assignment] = STATE(853),
    [sym_multioutput_variable] = STATE(1187),
    [sym_function_call] = STATE(210),
    [sym_command] = STATE(853),
    [sym__range_element] = STATE(1181),
    [sym_range] = STATE(632),
    [sym_if_statement] = STATE(853),
    [sym_for_statement] = STATE(853),
    [sym_while_statement] = STATE(853),
    [sym_switch_statement] = STATE(853),
    [sym_lambda] = STATE(632),
    [sym_global_operator] = STATE(853),
    [sym_persistent_operator] = STATE(853),
    [sym_arguments_statement] = STATE(45),
    [sym__function_definition_with_end] = STATE(888),
    [sym_class_definition] = STATE(853),
    [sym_try_statement] = STATE(853),
    [sym_boolean] = STATE(205),
    [aux_sym_function_definition_repeat1] = STATE(45),
    [sym_identifier] = ACTIONS(7),
    [anon_sym_LPAREN] = ACTIONS(9),
    [anon_sym_PLUS] = ACTIONS(11),
    [anon_sym_DASH] = ACTIONS(11),
    [anon_sym_TILDE] = ACTIONS(13),
    [anon_sym_QMARK] = ACTIONS(15),
    [anon_sym_AT] = ACTIONS(17),
    [anon_sym_LBRACK] = ACTIONS(19),
    [anon_sym_LBRACE] = ACTIONS(21),
    [sym_return_statement] = ACTIONS(147),
    [sym_continue_statement] = ACTIONS(147),
    [sym_break_statement] = ACTIONS(147),
    [anon_sym_if] = ACTIONS(25),
    [anon_sym_end] = ACTIONS(329),
    [anon_sym_for] = ACTIONS(27),
    [anon_sym_parfor] = ACTIONS(29),
    [anon_sym_while] = ACTIONS(31),
    [anon_sym_switch] = ACTIONS(33),
    [anon_sym_global] = ACTIONS(35),
    [anon_sym_persistent] = ACTIONS(37),
    [anon_sym_arguments] = ACTIONS(151),
    [anon_sym_function] = ACTIONS(87),
    [anon_sym_endfunction] = ACTIONS(329),
    [anon_sym_classdef] = ACTIONS(41),
    [anon_sym_try] = ACTIONS(43),
    [sym_number] = ACTIONS(45),
    [anon_sym_true] = ACTIONS(47),
    [anon_sym_false] = ACTIONS(47),
    [sym_comment] = ACTIONS(3),
    [sym_line_continuation] = ACTIONS(3),
    [sym_command_name] = ACTIONS(49),
    [sym__single_quote_string_start] = ACTIONS(51),
    [sym__double_quote_string_start] = ACTIONS(53),
    [sym__multioutput_variable_start] = ACTIONS(55),
  },
  [61] = {
    [aux_sym__block] = STATE(74),
    [sym_block] = STATE(1094),
    [sym__statement] = STATE(853),
    [sym__expression] = STATE(632),
    [sym_parenthesis] = STATE(411),
    [sym__binary_expression] = STATE(622),
    [sym_binary_operator] = STATE(422),
    [sym_unary_operator] = STATE(389),
    [sym_indirect_access] = STATE(994),
    [sym_field_expression] = STATE(485),
    [sym_not_operator] = STATE(477),
    [sym_metaclass_operator] = STATE(632),
    [sym_handle_operator] = STATE(632),
    [sym_comparison_operator] = STATE(446),
    [sym_boolean_operator] = STATE(446),
    [sym_postfix_operator] = STATE(411),
    [sym_string] = STATE(411),
    [sym_matrix] = STATE(411),
    [sym_cell] = STATE(423),
    [sym_ignored_argument] = STATE(1187),
    [sym_assignment] = STATE(853),
    [sym_multioutput_variable] = STATE(1187),
    [sym_function_call] = STATE(210),
    [sym_command] = STATE(853),
    [sym__range_element] = STATE(1181),
    [sym_range] = STATE(632),
    [sym_if_statement] = STATE(853),
    [sym_for_statement] = STATE(853),
    [sym_while_statement] = STATE(853),
    [sym_switch_statement] = STATE(853),
    [sym_lambda] = STATE(632),
    [sym_global_operator] = STATE(853),
    [sym_persistent_operator] = STATE(853),
    [sym_arguments_statement] = STATE(66),
    [sym__function_definition_with_end] = STATE(888),
    [sym_class_definition] = STATE(853),
    [sym_try_statement] = STATE(853),
    [sym_boolean] = STATE(205),
    [aux_sym_function_definition_repeat1] = STATE(66),
    [sym_identifier] = ACTIONS(7),
    [anon_sym_LPAREN] = ACTIONS(9),
    [anon_sym_PLUS] = ACTIONS(11),
    [anon_sym_DASH] = ACTIONS(11),
    [anon_sym_TILDE] = ACTIONS(13),
    [anon_sym_QMARK] = ACTIONS(15),
    [anon_sym_AT] = ACTIONS(17),
    [anon_sym_LBRACK] = ACTIONS(19),
    [anon_sym_LBRACE] = ACTIONS(21),
    [sym_return_statement] = ACTIONS(147),
    [sym_continue_statement] = ACTIONS(147),
    [sym_break_statement] = ACTIONS(147),
    [anon_sym_if] = ACTIONS(25),
    [anon_sym_end] = ACTIONS(331),
    [anon_sym_for] = ACTIONS(27),
    [anon_sym_parfor] = ACTIONS(29),
    [anon_sym_while] = ACTIONS(31),
    [anon_sym_switch] = ACTIONS(33),
    [anon_sym_global] = ACTIONS(35),
    [anon_sym_persistent] = ACTIONS(37),
    [anon_sym_arguments] = ACTIONS(151),
    [anon_sym_function] = ACTIONS(87),
    [anon_sym_endfunction] = ACTIONS(331),
    [anon_sym_classdef] = ACTIONS(41),
    [anon_sym_try] = ACTIONS(43),
    [sym_number] = ACTIONS(45),
    [anon_sym_true] = ACTIONS(47),
    [anon_sym_false] = ACTIONS(47),
    [sym_comment] = ACTIONS(3),
    [sym_line_continuation] = ACTIONS(3),
    [sym_command_name] = ACTIONS(49),
    [sym__single_quote_string_start] = ACTIONS(51),
    [sym__double_quote_string_start] = ACTIONS(53),
    [sym__multioutput_variable_start] = ACTIONS(55),
  },
  [62] = {
    [aux_sym__block] = STATE(74),
    [sym_block] = STATE(1127),
    [sym__statement] = STATE(853),
    [sym__expression] = STATE(632),
    [sym_parenthesis] = STATE(411),
    [sym__binary_expression] = STATE(622),
    [sym_binary_operator] = STATE(422),
    [sym_unary_operator] = STATE(389),
    [sym_indirect_access] = STATE(994),
    [sym_field_expression] = STATE(485),
    [sym_not_operator] = STATE(477),
    [sym_metaclass_operator] = STATE(632),
    [sym_handle_operator] = STATE(632),
    [sym_comparison_operator] = STATE(446),
    [sym_boolean_operator] = STATE(446),
    [sym_postfix_operator] = STATE(411),
    [sym_string] = STATE(411),
    [sym_matrix] = STATE(411),
    [sym_cell] = STATE(423),
    [sym_ignored_argument] = STATE(1187),
    [sym_assignment] = STATE(853),
    [sym_multioutput_variable] = STATE(1187),
    [sym_function_call] = STATE(210),
    [sym_command] = STATE(853),
    [sym__range_element] = STATE(1181),
    [sym_range] = STATE(632),
    [sym_if_statement] = STATE(853),
    [sym_for_statement] = STATE(853),
    [sym_while_statement] = STATE(853),
    [sym_switch_statement] = STATE(853),
    [sym_lambda] = STATE(632),
    [sym_global_operator] = STATE(853),
    [sym_persistent_operator] = STATE(853),
    [sym_arguments_statement] = STATE(69),
    [sym__function_definition_with_end] = STATE(888),
    [sym_class_definition] = STATE(853),
    [sym_try_statement] = STATE(853),
    [sym_boolean] = STATE(205),
    [aux_sym_function_definition_repeat1] = STATE(69),
    [sym_identifier] = ACTIONS(7),
    [anon_sym_LPAREN] = ACTIONS(9),
    [anon_sym_PLUS] = ACTIONS(11),
    [anon_sym_DASH] = ACTIONS(11),
    [anon_sym_TILDE] = ACTIONS(13),
    [anon_sym_QMARK] = ACTIONS(15),
    [anon_sym_AT] = ACTIONS(17),
    [anon_sym_LBRACK] = ACTIONS(19),
    [anon_sym_LBRACE] = ACTIONS(21),
    [sym_return_statement] = ACTIONS(147),
    [sym_continue_statement] = ACTIONS(147),
    [sym_break_statement] = ACTIONS(147),
    [anon_sym_if] = ACTIONS(25),
    [anon_sym_end] = ACTIONS(333),
    [anon_sym_for] = ACTIONS(27),
    [anon_sym_parfor] = ACTIONS(29),
    [anon_sym_while] = ACTIONS(31),
    [anon_sym_switch] = ACTIONS(33),
    [anon_sym_global] = ACTIONS(35),
    [anon_sym_persistent] = ACTIONS(37),
    [anon_sym_arguments] = ACTIONS(151),
    [anon_sym_function] = ACTIONS(87),
    [anon_sym_endfunction] = ACTIONS(333),
    [anon_sym_classdef] = ACTIONS(41),
    [anon_sym_try] = ACTIONS(43),
    [sym_number] = ACTIONS(45),
    [anon_sym_true] = ACTIONS(47),
    [anon_sym_false] = ACTIONS(47),
    [sym_comment] = ACTIONS(3),
    [sym_line_continuation] = ACTIONS(3),
    [sym_command_name] = ACTIONS(49),
    [sym__single_quote_string_start] = ACTIONS(51),
    [sym__double_quote_string_start] = ACTIONS(53),
    [sym__multioutput_variable_start] = ACTIONS(55),
  },
  [63] = {
    [aux_sym__block] = STATE(74),
    [sym_block] = STATE(1107),
    [sym__statement] = STATE(853),
    [sym__expression] = STATE(632),
    [sym_parenthesis] = STATE(411),
    [sym__binary_expression] = STATE(622),
    [sym_binary_operator] = STATE(422),
    [sym_unary_operator] = STATE(389),
    [sym_indirect_access] = STATE(994),
    [sym_field_expression] = STATE(485),
    [sym_not_operator] = STATE(477),
    [sym_metaclass_operator] = STATE(632),
    [sym_handle_operator] = STATE(632),
    [sym_comparison_operator] = STATE(446),
    [sym_boolean_operator] = STATE(446),
    [sym_postfix_operator] = STATE(411),
    [sym_string] = STATE(411),
    [sym_matrix] = STATE(411),
    [sym_cell] = STATE(423),
    [sym_ignored_argument] = STATE(1187),
    [sym_assignment] = STATE(853),
    [sym_multioutput_variable] = STATE(1187),
    [sym_function_call] = STATE(210),
    [sym_command] = STATE(853),
    [sym__range_element] = STATE(1181),
    [sym_range] = STATE(632),
    [sym_if_statement] = STATE(853),
    [sym_for_statement] = STATE(853),
    [sym_while_statement] = STATE(853),
    [sym_switch_statement] = STATE(853),
    [sym_lambda] = STATE(632),
    [sym_global_operator] = STATE(853),
    [sym_persistent_operator] = STATE(853),
    [sym_arguments_statement] = STATE(58),
    [sym__function_definition_with_end] = STATE(888),
    [sym_class_definition] = STATE(853),
    [sym_try_statement] = STATE(853),
    [sym_boolean] = STATE(205),
    [aux_sym_function_definition_repeat1] = STATE(58),
    [sym_identifier] = ACTIONS(7),
    [anon_sym_LPAREN] = ACTIONS(9),
    [anon_sym_PLUS] = ACTIONS(11),
    [anon_sym_DASH] = ACTIONS(11),
    [anon_sym_TILDE] = ACTIONS(13),
    [anon_sym_QMARK] = ACTIONS(15),
    [anon_sym_AT] = ACTIONS(17),
    [anon_sym_LBRACK] = ACTIONS(19),
    [anon_sym_LBRACE] = ACTIONS(21),
    [sym_return_statement] = ACTIONS(147),
    [sym_continue_statement] = ACTIONS(147),
    [sym_break_statement] = ACTIONS(147),
    [anon_sym_if] = ACTIONS(25),
    [anon_sym_end] = ACTIONS(335),
    [anon_sym_for] = ACTIONS(27),
    [anon_sym_parfor] = ACTIONS(29),
    [anon_sym_while] = ACTIONS(31),
    [anon_sym_switch] = ACTIONS(33),
    [anon_sym_global] = ACTIONS(35),
    [anon_sym_persistent] = ACTIONS(37),
    [anon_sym_arguments] = ACTIONS(151),
    [anon_sym_function] = ACTIONS(87),
    [anon_sym_endfunction] = ACTIONS(335),
    [anon_sym_classdef] = ACTIONS(41),
    [anon_sym_try] = ACTIONS(43),
    [sym_number] = ACTIONS(45),
    [anon_sym_true] = ACTIONS(47),
    [anon_sym_false] = ACTIONS(47),
    [sym_comment] = ACTIONS(3),
    [sym_line_continuation] = ACTIONS(3),
    [sym_command_name] = ACTIONS(49),
    [sym__single_quote_string_start] = ACTIONS(51),
    [sym__double_quote_string_start] = ACTIONS(53),
    [sym__multioutput_variable_start] = ACTIONS(55),
  },
  [64] = {
    [aux_sym__block] = STATE(74),
    [sym_block] = STATE(1108),
    [sym__statement] = STATE(853),
    [sym__expression] = STATE(632),
    [sym_parenthesis] = STATE(411),
    [sym__binary_expression] = STATE(622),
    [sym_binary_operator] = STATE(422),
    [sym_unary_operator] = STATE(389),
    [sym_indirect_access] = STATE(994),
    [sym_field_expression] = STATE(485),
    [sym_not_operator] = STATE(477),
    [sym_metaclass_operator] = STATE(632),
    [sym_handle_operator] = STATE(632),
    [sym_comparison_operator] = STATE(446),
    [sym_boolean_operator] = STATE(446),
    [sym_postfix_operator] = STATE(411),
    [sym_string] = STATE(411),
    [sym_matrix] = STATE(411),
    [sym_cell] = STATE(423),
    [sym_ignored_argument] = STATE(1187),
    [sym_assignment] = STATE(853),
    [sym_multioutput_variable] = STATE(1187),
    [sym_function_call] = STATE(210),
    [sym_command] = STATE(853),
    [sym__range_element] = STATE(1181),
    [sym_range] = STATE(632),
    [sym_if_statement] = STATE(853),
    [sym_for_statement] = STATE(853),
    [sym_while_statement] = STATE(853),
    [sym_switch_statement] = STATE(853),
    [sym_lambda] = STATE(632),
    [sym_global_operator] = STATE(853),
    [sym_persistent_operator] = STATE(853),
    [sym_arguments_statement] = STATE(56),
    [sym__function_definition_with_end] = STATE(888),
    [sym_class_definition] = STATE(853),
    [sym_try_statement] = STATE(853),
    [sym_boolean] = STATE(205),
    [aux_sym_function_definition_repeat1] = STATE(56),
    [sym_identifier] = ACTIONS(7),
    [anon_sym_LPAREN] = ACTIONS(9),
    [anon_sym_PLUS] = ACTIONS(11),
    [anon_sym_DASH] = ACTIONS(11),
    [anon_sym_TILDE] = ACTIONS(13),
    [anon_sym_QMARK] = ACTIONS(15),
    [anon_sym_AT] = ACTIONS(17),
    [anon_sym_LBRACK] = ACTIONS(19),
    [anon_sym_LBRACE] = ACTIONS(21),
    [sym_return_statement] = ACTIONS(147),
    [sym_continue_statement] = ACTIONS(147),
    [sym_break_statement] = ACTIONS(147),
    [anon_sym_if] = ACTIONS(25),
    [anon_sym_end] = ACTIONS(337),
    [anon_sym_for] = ACTIONS(27),
    [anon_sym_parfor] = ACTIONS(29),
    [anon_sym_while] = ACTIONS(31),
    [anon_sym_switch] = ACTIONS(33),
    [anon_sym_global] = ACTIONS(35),
    [anon_sym_persistent] = ACTIONS(37),
    [anon_sym_arguments] = ACTIONS(151),
    [anon_sym_function] = ACTIONS(87),
    [anon_sym_endfunction] = ACTIONS(337),
    [anon_sym_classdef] = ACTIONS(41),
    [anon_sym_try] = ACTIONS(43),
    [sym_number] = ACTIONS(45),
    [anon_sym_true] = ACTIONS(47),
    [anon_sym_false] = ACTIONS(47),
    [sym_comment] = ACTIONS(3),
    [sym_line_continuation] = ACTIONS(3),
    [sym_command_name] = ACTIONS(49),
    [sym__single_quote_string_start] = ACTIONS(51),
    [sym__double_quote_string_start] = ACTIONS(53),
    [sym__multioutput_variable_start] = ACTIONS(55),
  },
  [65] = {
    [aux_sym__block] = STATE(74),
    [sym_block] = STATE(1066),
    [sym__statement] = STATE(853),
    [sym__expression] = STATE(632),
    [sym_parenthesis] = STATE(411),
    [sym__binary_expression] = STATE(622),
    [sym_binary_operator] = STATE(422),
    [sym_unary_operator] = STATE(389),
    [sym_indirect_access] = STATE(994),
    [sym_field_expression] = STATE(485),
    [sym_not_operator] = STATE(477),
    [sym_metaclass_operator] = STATE(632),
    [sym_handle_operator] = STATE(632),
    [sym_comparison_operator] = STATE(446),
    [sym_boolean_operator] = STATE(446),
    [sym_postfix_operator] = STATE(411),
    [sym_string] = STATE(411),
    [sym_matrix] = STATE(411),
    [sym_cell] = STATE(423),
    [sym_ignored_argument] = STATE(1187),
    [sym_assignment] = STATE(853),
    [sym_multioutput_variable] = STATE(1187),
    [sym_function_call] = STATE(210),
    [sym_command] = STATE(853),
    [sym__range_element] = STATE(1181),
    [sym_range] = STATE(632),
    [sym_if_statement] = STATE(853),
    [sym_for_statement] = STATE(853),
    [sym_while_statement] = STATE(853),
    [sym_switch_statement] = STATE(853),
    [sym_lambda] = STATE(632),
    [sym_global_operator] = STATE(853),
    [sym_persistent_operator] = STATE(853),
    [sym_arguments_statement] = STATE(341),
    [sym__function_definition_with_end] = STATE(888),
    [sym_class_definition] = STATE(853),
    [sym_try_statement] = STATE(853),
    [sym_boolean] = STATE(205),
    [aux_sym_function_definition_repeat1] = STATE(341),
    [sym_identifier] = ACTIONS(7),
    [anon_sym_LPAREN] = ACTIONS(9),
    [anon_sym_PLUS] = ACTIONS(11),
    [anon_sym_DASH] = ACTIONS(11),
    [anon_sym_TILDE] = ACTIONS(13),
    [anon_sym_QMARK] = ACTIONS(15),
    [anon_sym_AT] = ACTIONS(17),
    [anon_sym_LBRACK] = ACTIONS(19),
    [anon_sym_LBRACE] = ACTIONS(21),
    [sym_return_statement] = ACTIONS(147),
    [sym_continue_statement] = ACTIONS(147),
    [sym_break_statement] = ACTIONS(147),
    [anon_sym_if] = ACTIONS(25),
    [anon_sym_end] = ACTIONS(339),
    [anon_sym_for] = ACTIONS(27),
    [anon_sym_parfor] = ACTIONS(29),
    [anon_sym_while] = ACTIONS(31),
    [anon_sym_switch] = ACTIONS(33),
    [anon_sym_global] = ACTIONS(35),
    [anon_sym_persistent] = ACTIONS(37),
    [anon_sym_arguments] = ACTIONS(151),
    [anon_sym_function] = ACTIONS(87),
    [anon_sym_endfunction] = ACTIONS(339),
    [anon_sym_classdef] = ACTIONS(41),
    [anon_sym_try] = ACTIONS(43),
    [sym_number] = ACTIONS(45),
    [anon_sym_true] = ACTIONS(47),
    [anon_sym_false] = ACTIONS(47),
    [sym_comment] = ACTIONS(3),
    [sym_line_continuation] = ACTIONS(3),
    [sym_command_name] = ACTIONS(49),
    [sym__single_quote_string_start] = ACTIONS(51),
    [sym__double_quote_string_start] = ACTIONS(53),
    [sym__multioutput_variable_start] = ACTIONS(55),
  },
  [66] = {
    [aux_sym__block] = STATE(74),
    [sym_block] = STATE(1108),
    [sym__statement] = STATE(853),
    [sym__expression] = STATE(632),
    [sym_parenthesis] = STATE(411),
    [sym__binary_expression] = STATE(622),
    [sym_binary_operator] = STATE(422),
    [sym_unary_operator] = STATE(389),
    [sym_indirect_access] = STATE(994),
    [sym_field_expression] = STATE(485),
    [sym_not_operator] = STATE(477),
    [sym_metaclass_operator] = STATE(632),
    [sym_handle_operator] = STATE(632),
    [sym_comparison_operator] = STATE(446),
    [sym_boolean_operator] = STATE(446),
    [sym_postfix_operator] = STATE(411),
    [sym_string] = STATE(411),
    [sym_matrix] = STATE(411),
    [sym_cell] = STATE(423),
    [sym_ignored_argument] = STATE(1187),
    [sym_assignment] = STATE(853),
    [sym_multioutput_variable] = STATE(1187),
    [sym_function_call] = STATE(210),
    [sym_command] = STATE(853),
    [sym__range_element] = STATE(1181),
    [sym_range] = STATE(632),
    [sym_if_statement] = STATE(853),
    [sym_for_statement] = STATE(853),
    [sym_while_statement] = STATE(853),
    [sym_switch_statement] = STATE(853),
    [sym_lambda] = STATE(632),
    [sym_global_operator] = STATE(853),
    [sym_persistent_operator] = STATE(853),
    [sym_arguments_statement] = STATE(341),
    [sym__function_definition_with_end] = STATE(888),
    [sym_class_definition] = STATE(853),
    [sym_try_statement] = STATE(853),
    [sym_boolean] = STATE(205),
    [aux_sym_function_definition_repeat1] = STATE(341),
    [sym_identifier] = ACTIONS(7),
    [anon_sym_LPAREN] = ACTIONS(9),
    [anon_sym_PLUS] = ACTIONS(11),
    [anon_sym_DASH] = ACTIONS(11),
    [anon_sym_TILDE] = ACTIONS(13),
    [anon_sym_QMARK] = ACTIONS(15),
    [anon_sym_AT] = ACTIONS(17),
    [anon_sym_LBRACK] = ACTIONS(19),
    [anon_sym_LBRACE] = ACTIONS(21),
    [sym_return_statement] = ACTIONS(147),
    [sym_continue_statement] = ACTIONS(147),
    [sym_break_statement] = ACTIONS(147),
    [anon_sym_if] = ACTIONS(25),
    [anon_sym_end] = ACTIONS(337),
    [anon_sym_for] = ACTIONS(27),
    [anon_sym_parfor] = ACTIONS(29),
    [anon_sym_while] = ACTIONS(31),
    [anon_sym_switch] = ACTIONS(33),
    [anon_sym_global] = ACTIONS(35),
    [anon_sym_persistent] = ACTIONS(37),
    [anon_sym_arguments] = ACTIONS(151),
    [anon_sym_function] = ACTIONS(87),
    [anon_sym_endfunction] = ACTIONS(337),
    [anon_sym_classdef] = ACTIONS(41),
    [anon_sym_try] = ACTIONS(43),
    [sym_number] = ACTIONS(45),
    [anon_sym_true] = ACTIONS(47),
    [anon_sym_false] = ACTIONS(47),
    [sym_comment] = ACTIONS(3),
    [sym_line_continuation] = ACTIONS(3),
    [sym_command_name] = ACTIONS(49),
    [sym__single_quote_string_start] = ACTIONS(51),
    [sym__double_quote_string_start] = ACTIONS(53),
    [sym__multioutput_variable_start] = ACTIONS(55),
  },
  [67] = {
    [aux_sym__block] = STATE(74),
    [sym_block] = STATE(1070),
    [sym__statement] = STATE(853),
    [sym__expression] = STATE(632),
    [sym_parenthesis] = STATE(411),
    [sym__binary_expression] = STATE(622),
    [sym_binary_operator] = STATE(422),
    [sym_unary_operator] = STATE(389),
    [sym_indirect_access] = STATE(994),
    [sym_field_expression] = STATE(485),
    [sym_not_operator] = STATE(477),
    [sym_metaclass_operator] = STATE(632),
    [sym_handle_operator] = STATE(632),
    [sym_comparison_operator] = STATE(446),
    [sym_boolean_operator] = STATE(446),
    [sym_postfix_operator] = STATE(411),
    [sym_string] = STATE(411),
    [sym_matrix] = STATE(411),
    [sym_cell] = STATE(423),
    [sym_ignored_argument] = STATE(1187),
    [sym_assignment] = STATE(853),
    [sym_multioutput_variable] = STATE(1187),
    [sym_function_call] = STATE(210),
    [sym_command] = STATE(853),
    [sym__range_element] = STATE(1181),
    [sym_range] = STATE(632),
    [sym_if_statement] = STATE(853),
    [sym_for_statement] = STATE(853),
    [sym_while_statement] = STATE(853),
    [sym_switch_statement] = STATE(853),
    [sym_lambda] = STATE(632),
    [sym_global_operator] = STATE(853),
    [sym_persistent_operator] = STATE(853),
    [sym_arguments_statement] = STATE(51),
    [sym__function_definition_with_end] = STATE(888),
    [sym_class_definition] = STATE(853),
    [sym_try_statement] = STATE(853),
    [sym_boolean] = STATE(205),
    [aux_sym_function_definition_repeat1] = STATE(51),
    [sym_identifier] = ACTIONS(7),
    [anon_sym_LPAREN] = ACTIONS(9),
    [anon_sym_PLUS] = ACTIONS(11),
    [anon_sym_DASH] = ACTIONS(11),
    [anon_sym_TILDE] = ACTIONS(13),
    [anon_sym_QMARK] = ACTIONS(15),
    [anon_sym_AT] = ACTIONS(17),
    [anon_sym_LBRACK] = ACTIONS(19),
    [anon_sym_LBRACE] = ACTIONS(21),
    [sym_return_statement] = ACTIONS(147),
    [sym_continue_statement] = ACTIONS(147),
    [sym_break_statement] = ACTIONS(147),
    [anon_sym_if] = ACTIONS(25),
    [anon_sym_end] = ACTIONS(341),
    [anon_sym_for] = ACTIONS(27),
    [anon_sym_parfor] = ACTIONS(29),
    [anon_sym_while] = ACTIONS(31),
    [anon_sym_switch] = ACTIONS(33),
    [anon_sym_global] = ACTIONS(35),
    [anon_sym_persistent] = ACTIONS(37),
    [anon_sym_arguments] = ACTIONS(151),
    [anon_sym_function] = ACTIONS(87),
    [anon_sym_endfunction] = ACTIONS(341),
    [anon_sym_classdef] = ACTIONS(41),
    [anon_sym_try] = ACTIONS(43),
    [sym_number] = ACTIONS(45),
    [anon_sym_true] = ACTIONS(47),
    [anon_sym_false] = ACTIONS(47),
    [sym_comment] = ACTIONS(3),
    [sym_line_continuation] = ACTIONS(3),
    [sym_command_name] = ACTIONS(49),
    [sym__single_quote_string_start] = ACTIONS(51),
    [sym__double_quote_string_start] = ACTIONS(53),
    [sym__multioutput_variable_start] = ACTIONS(55),
  },
  [68] = {
    [aux_sym__block] = STATE(74),
    [sym_block] = STATE(1066),
    [sym__statement] = STATE(853),
    [sym__expression] = STATE(632),
    [sym_parenthesis] = STATE(411),
    [sym__binary_expression] = STATE(622),
    [sym_binary_operator] = STATE(422),
    [sym_unary_operator] = STATE(389),
    [sym_indirect_access] = STATE(994),
    [sym_field_expression] = STATE(485),
    [sym_not_operator] = STATE(477),
    [sym_metaclass_operator] = STATE(632),
    [sym_handle_operator] = STATE(632),
    [sym_comparison_operator] = STATE(446),
    [sym_boolean_operator] = STATE(446),
    [sym_postfix_operator] = STATE(411),
    [sym_string] = STATE(411),
    [sym_matrix] = STATE(411),
    [sym_cell] = STATE(423),
    [sym_ignored_argument] = STATE(1187),
    [sym_assignment] = STATE(853),
    [sym_multioutput_variable] = STATE(1187),
    [sym_function_call] = STATE(210),
    [sym_command] = STATE(853),
    [sym__range_element] = STATE(1181),
    [sym_range] = STATE(632),
    [sym_if_statement] = STATE(853),
    [sym_for_statement] = STATE(853),
    [sym_while_statement] = STATE(853),
    [sym_switch_statement] = STATE(853),
    [sym_lambda] = STATE(632),
    [sym_global_operator] = STATE(853),
    [sym_persistent_operator] = STATE(853),
    [sym_arguments_statement] = STATE(47),
    [sym__function_definition_with_end] = STATE(888),
    [sym_class_definition] = STATE(853),
    [sym_try_statement] = STATE(853),
    [sym_boolean] = STATE(205),
    [aux_sym_function_definition_repeat1] = STATE(47),
    [sym_identifier] = ACTIONS(7),
    [anon_sym_LPAREN] = ACTIONS(9),
    [anon_sym_PLUS] = ACTIONS(11),
    [anon_sym_DASH] = ACTIONS(11),
    [anon_sym_TILDE] = ACTIONS(13),
    [anon_sym_QMARK] = ACTIONS(15),
    [anon_sym_AT] = ACTIONS(17),
    [anon_sym_LBRACK] = ACTIONS(19),
    [anon_sym_LBRACE] = ACTIONS(21),
    [sym_return_statement] = ACTIONS(147),
    [sym_continue_statement] = ACTIONS(147),
    [sym_break_statement] = ACTIONS(147),
    [anon_sym_if] = ACTIONS(25),
    [anon_sym_end] = ACTIONS(339),
    [anon_sym_for] = ACTIONS(27),
    [anon_sym_parfor] = ACTIONS(29),
    [anon_sym_while] = ACTIONS(31),
    [anon_sym_switch] = ACTIONS(33),
    [anon_sym_global] = ACTIONS(35),
    [anon_sym_persistent] = ACTIONS(37),
    [anon_sym_arguments] = ACTIONS(151),
    [anon_sym_function] = ACTIONS(87),
    [anon_sym_endfunction] = ACTIONS(339),
    [anon_sym_classdef] = ACTIONS(41),
    [anon_sym_try] = ACTIONS(43),
    [sym_number] = ACTIONS(45),
    [anon_sym_true] = ACTIONS(47),
    [anon_sym_false] = ACTIONS(47),
    [sym_comment] = ACTIONS(3),
    [sym_line_continuation] = ACTIONS(3),
    [sym_command_name] = ACTIONS(49),
    [sym__single_quote_string_start] = ACTIONS(51),
    [sym__double_quote_string_start] = ACTIONS(53),
    [sym__multioutput_variable_start] = ACTIONS(55),
  },
  [69] = {
    [aux_sym__block] = STATE(74),
    [sym_block] = STATE(1063),
    [sym__statement] = STATE(853),
    [sym__expression] = STATE(632),
    [sym_parenthesis] = STATE(411),
    [sym__binary_expression] = STATE(622),
    [sym_binary_operator] = STATE(422),
    [sym_unary_operator] = STATE(389),
    [sym_indirect_access] = STATE(994),
    [sym_field_expression] = STATE(485),
    [sym_not_operator] = STATE(477),
    [sym_metaclass_operator] = STATE(632),
    [sym_handle_operator] = STATE(632),
    [sym_comparison_operator] = STATE(446),
    [sym_boolean_operator] = STATE(446),
    [sym_postfix_operator] = STATE(411),
    [sym_string] = STATE(411),
    [sym_matrix] = STATE(411),
    [sym_cell] = STATE(423),
    [sym_ignored_argument] = STATE(1187),
    [sym_assignment] = STATE(853),
    [sym_multioutput_variable] = STATE(1187),
    [sym_function_call] = STATE(210),
    [sym_command] = STATE(853),
    [sym__range_element] = STATE(1181),
    [sym_range] = STATE(632),
    [sym_if_statement] = STATE(853),
    [sym_for_statement] = STATE(853),
    [sym_while_statement] = STATE(853),
    [sym_switch_statement] = STATE(853),
    [sym_lambda] = STATE(632),
    [sym_global_operator] = STATE(853),
    [sym_persistent_operator] = STATE(853),
    [sym_arguments_statement] = STATE(341),
    [sym__function_definition_with_end] = STATE(888),
    [sym_class_definition] = STATE(853),
    [sym_try_statement] = STATE(853),
    [sym_boolean] = STATE(205),
    [aux_sym_function_definition_repeat1] = STATE(341),
    [sym_identifier] = ACTIONS(7),
    [anon_sym_LPAREN] = ACTIONS(9),
    [anon_sym_PLUS] = ACTIONS(11),
    [anon_sym_DASH] = ACTIONS(11),
    [anon_sym_TILDE] = ACTIONS(13),
    [anon_sym_QMARK] = ACTIONS(15),
    [anon_sym_AT] = ACTIONS(17),
    [anon_sym_LBRACK] = ACTIONS(19),
    [anon_sym_LBRACE] = ACTIONS(21),
    [sym_return_statement] = ACTIONS(147),
    [sym_continue_statement] = ACTIONS(147),
    [sym_break_statement] = ACTIONS(147),
    [anon_sym_if] = ACTIONS(25),
    [anon_sym_end] = ACTIONS(329),
    [anon_sym_for] = ACTIONS(27),
    [anon_sym_parfor] = ACTIONS(29),
    [anon_sym_while] = ACTIONS(31),
    [anon_sym_switch] = ACTIONS(33),
    [anon_sym_global] = ACTIONS(35),
    [anon_sym_persistent] = ACTIONS(37),
    [anon_sym_arguments] = ACTIONS(151),
    [anon_sym_function] = ACTIONS(87),
    [anon_sym_endfunction] = ACTIONS(329),
    [anon_sym_classdef] = ACTIONS(41),
    [anon_sym_try] = ACTIONS(43),
    [sym_number] = ACTIONS(45),
    [anon_sym_true] = ACTIONS(47),
    [anon_sym_false] = ACTIONS(47),
    [sym_comment] = ACTIONS(3),
    [sym_line_continuation] = ACTIONS(3),
    [sym_command_name] = ACTIONS(49),
    [sym__single_quote_string_start] = ACTIONS(51),
    [sym__double_quote_string_start] = ACTIONS(53),
    [sym__multioutput_variable_start] = ACTIONS(55),
  },
  [70] = {
    [aux_sym__block] = STATE(74),
    [sym_block] = STATE(1095),
    [sym__statement] = STATE(853),
    [sym__expression] = STATE(632),
    [sym_parenthesis] = STATE(411),
    [sym__binary_expression] = STATE(622),
    [sym_binary_operator] = STATE(422),
    [sym_unary_operator] = STATE(389),
    [sym_indirect_access] = STATE(994),
    [sym_field_expression] = STATE(485),
    [sym_not_operator] = STATE(477),
    [sym_metaclass_operator] = STATE(632),
    [sym_handle_operator] = STATE(632),
    [sym_comparison_operator] = STATE(446),
    [sym_boolean_operator] = STATE(446),
    [sym_postfix_operator] = STATE(411),
    [sym_string] = STATE(411),
    [sym_matrix] = STATE(411),
    [sym_cell] = STATE(423),
    [sym_ignored_argument] = STATE(1187),
    [sym_assignment] = STATE(853),
    [sym_multioutput_variable] = STATE(1187),
    [sym_function_call] = STATE(210),
    [sym_command] = STATE(853),
    [sym__range_element] = STATE(1181),
    [sym_range] = STATE(632),
    [sym_if_statement] = STATE(853),
    [sym_for_statement] = STATE(853),
    [sym_while_statement] = STATE(853),
    [sym_switch_statement] = STATE(853),
    [sym_lambda] = STATE(632),
    [sym_global_operator] = STATE(853),
    [sym_persistent_operator] = STATE(853),
    [sym_arguments_statement] = STATE(65),
    [sym__function_definition_with_end] = STATE(888),
    [sym_class_definition] = STATE(853),
    [sym_try_statement] = STATE(853),
    [sym_boolean] = STATE(205),
    [aux_sym_function_definition_repeat1] = STATE(65),
    [sym_identifier] = ACTIONS(7),
    [anon_sym_LPAREN] = ACTIONS(9),
    [anon_sym_PLUS] = ACTIONS(11),
    [anon_sym_DASH] = ACTIONS(11),
    [anon_sym_TILDE] = ACTIONS(13),
    [anon_sym_QMARK] = ACTIONS(15),
    [anon_sym_AT] = ACTIONS(17),
    [anon_sym_LBRACK] = ACTIONS(19),
    [anon_sym_LBRACE] = ACTIONS(21),
    [sym_return_statement] = ACTIONS(147),
    [sym_continue_statement] = ACTIONS(147),
    [sym_break_statement] = ACTIONS(147),
    [anon_sym_if] = ACTIONS(25),
    [anon_sym_end] = ACTIONS(343),
    [anon_sym_for] = ACTIONS(27),
    [anon_sym_parfor] = ACTIONS(29),
    [anon_sym_while] = ACTIONS(31),
    [anon_sym_switch] = ACTIONS(33),
    [anon_sym_global] = ACTIONS(35),
    [anon_sym_persistent] = ACTIONS(37),
    [anon_sym_arguments] = ACTIONS(151),
    [anon_sym_function] = ACTIONS(87),
    [anon_sym_endfunction] = ACTIONS(343),
    [anon_sym_classdef] = ACTIONS(41),
    [anon_sym_try] = ACTIONS(43),
    [sym_number] = ACTIONS(45),
    [anon_sym_true] = ACTIONS(47),
    [anon_sym_false] = ACTIONS(47),
    [sym_comment] = ACTIONS(3),
    [sym_line_continuation] = ACTIONS(3),
    [sym_command_name] = ACTIONS(49),
    [sym__single_quote_string_start] = ACTIONS(51),
    [sym__double_quote_string_start] = ACTIONS(53),
    [sym__multioutput_variable_start] = ACTIONS(55),
  },
  [71] = {
    [aux_sym__block] = STATE(75),
    [sym__statement] = STATE(817),
    [sym__expression] = STATE(630),
    [sym_parenthesis] = STATE(411),
    [sym__binary_expression] = STATE(622),
    [sym_binary_operator] = STATE(422),
    [sym_unary_operator] = STATE(389),
    [sym_indirect_access] = STATE(994),
    [sym_field_expression] = STATE(485),
    [sym_not_operator] = STATE(477),
    [sym_metaclass_operator] = STATE(630),
    [sym_handle_operator] = STATE(630),
    [sym_comparison_operator] = STATE(446),
    [sym_boolean_operator] = STATE(446),
    [sym_postfix_operator] = STATE(411),
    [sym_string] = STATE(411),
    [sym_matrix] = STATE(411),
    [sym_cell] = STATE(423),
    [sym_ignored_argument] = STATE(1187),
    [sym_assignment] = STATE(817),
    [sym_multioutput_variable] = STATE(1187),
    [sym_function_call] = STATE(210),
    [sym_command] = STATE(817),
    [sym__range_element] = STATE(1181),
    [sym_range] = STATE(630),
    [sym_if_statement] = STATE(817),
    [sym_for_statement] = STATE(817),
    [sym_while_statement] = STATE(817),
    [sym_switch_statement] = STATE(817),
    [sym_lambda] = STATE(630),
    [sym_global_operator] = STATE(817),
    [sym_persistent_operator] = STATE(817),
    [sym_function_definition] = STATE(929),
    [sym__function_definition_with_end] = STATE(860),
    [sym_class_definition] = STATE(817),
    [sym_try_statement] = STATE(817),
    [sym_boolean] = STATE(205),
    [aux_sym_source_file_repeat1] = STATE(929),
    [ts_builtin_sym_end] = ACTIONS(345),
    [sym_identifier] = ACTIONS(7),
    [anon_sym_LPAREN] = ACTIONS(9),
    [anon_sym_PLUS] = ACTIONS(11),
    [anon_sym_DASH] = ACTIONS(11),
    [anon_sym_TILDE] = ACTIONS(13),
    [anon_sym_QMARK] = ACTIONS(15),
    [anon_sym_AT] = ACTIONS(17),
    [anon_sym_LBRACK] = ACTIONS(19),
    [anon_sym_LBRACE] = ACTIONS(21),
    [sym_return_statement] = ACTIONS(23),
    [sym_continue_statement] = ACTIONS(23),
    [sym_break_statement] = ACTIONS(23),
    [anon_sym_if] = ACTIONS(25),
    [anon_sym_for] = ACTIONS(27),
    [anon_sym_parfor] = ACTIONS(29),
    [anon_sym_while] = ACTIONS(31),
    [anon_sym_switch] = ACTIONS(33),
    [anon_sym_global] = ACTIONS(35),
    [anon_sym_persistent] = ACTIONS(37),
    [anon_sym_function] = ACTIONS(39),
    [anon_sym_classdef] = ACTIONS(41),
    [anon_sym_try] = ACTIONS(43),
    [sym_number] = ACTIONS(45),
    [anon_sym_true] = ACTIONS(47),
    [anon_sym_false] = ACTIONS(47),
    [sym_comment] = ACTIONS(3),
    [sym_line_continuation] = ACTIONS(3),
    [sym_command_name] = ACTIONS(49),
    [sym__single_quote_string_start] = ACTIONS(51),
    [sym__double_quote_string_start] = ACTIONS(53),
    [sym__multioutput_variable_start] = ACTIONS(55),
  },
  [72] = {
    [aux_sym__block] = STATE(72),
    [sym__statement] = STATE(853),
    [sym__expression] = STATE(632),
    [sym_parenthesis] = STATE(411),
    [sym__binary_expression] = STATE(622),
    [sym_binary_operator] = STATE(422),
    [sym_unary_operator] = STATE(389),
    [sym_indirect_access] = STATE(994),
    [sym_field_expression] = STATE(485),
    [sym_not_operator] = STATE(477),
    [sym_metaclass_operator] = STATE(632),
    [sym_handle_operator] = STATE(632),
    [sym_comparison_operator] = STATE(446),
    [sym_boolean_operator] = STATE(446),
    [sym_postfix_operator] = STATE(411),
    [sym_string] = STATE(411),
    [sym_matrix] = STATE(411),
    [sym_cell] = STATE(423),
    [sym_ignored_argument] = STATE(1187),
    [sym_assignment] = STATE(853),
    [sym_multioutput_variable] = STATE(1187),
    [sym_function_call] = STATE(210),
    [sym_command] = STATE(853),
    [sym__range_element] = STATE(1181),
    [sym_range] = STATE(632),
    [sym_if_statement] = STATE(853),
    [sym_for_statement] = STATE(853),
    [sym_while_statement] = STATE(853),
    [sym_switch_statement] = STATE(853),
    [sym_lambda] = STATE(632),
    [sym_global_operator] = STATE(853),
    [sym_persistent_operator] = STATE(853),
    [sym__function_definition_with_end] = STATE(888),
    [sym_class_definition] = STATE(853),
    [sym_try_statement] = STATE(853),
    [sym_boolean] = STATE(205),
    [ts_builtin_sym_end] = ACTIONS(347),
    [sym_identifier] = ACTIONS(252),
    [anon_sym_LPAREN] = ACTIONS(255),
    [anon_sym_PLUS] = ACTIONS(258),
    [anon_sym_DASH] = ACTIONS(258),
    [anon_sym_TILDE] = ACTIONS(261),
    [anon_sym_QMARK] = ACTIONS(264),
    [anon_sym_AT] = ACTIONS(267),
    [anon_sym_LBRACK] = ACTIONS(270),
    [anon_sym_LBRACE] = ACTIONS(273),
    [sym_return_statement] = ACTIONS(349),
    [sym_continue_statement] = ACTIONS(349),
    [sym_break_statement] = ACTIONS(349),
    [anon_sym_if] = ACTIONS(281),
    [anon_sym_end] = ACTIONS(279),
    [anon_sym_for] = ACTIONS(284),
    [anon_sym_parfor] = ACTIONS(287),
    [anon_sym_while] = ACTIONS(290),
    [anon_sym_switch] = ACTIONS(293),
    [anon_sym_global] = ACTIONS(296),
    [anon_sym_persistent] = ACTIONS(299),
    [anon_sym_function] = ACTIONS(302),
    [anon_sym_endfunction] = ACTIONS(279),
    [anon_sym_classdef] = ACTIONS(305),
    [anon_sym_try] = ACTIONS(308),
    [sym_number] = ACTIONS(311),
    [anon_sym_true] = ACTIONS(314),
    [anon_sym_false] = ACTIONS(314),
    [sym_comment] = ACTIONS(3),
    [sym_line_continuation] = ACTIONS(3),
    [sym_command_name] = ACTIONS(317),
    [sym__single_quote_string_start] = ACTIONS(320),
    [sym__double_quote_string_start] = ACTIONS(323),
    [sym__multioutput_variable_start] = ACTIONS(326),
  },
  [73] = {
    [aux_sym__block] = STATE(72),
    [sym__statement] = STATE(853),
    [sym__expression] = STATE(632),
    [sym_parenthesis] = STATE(411),
    [sym__binary_expression] = STATE(622),
    [sym_binary_operator] = STATE(422),
    [sym_unary_operator] = STATE(389),
    [sym_indirect_access] = STATE(994),
    [sym_field_expression] = STATE(485),
    [sym_not_operator] = STATE(477),
    [sym_metaclass_operator] = STATE(632),
    [sym_handle_operator] = STATE(632),
    [sym_comparison_operator] = STATE(446),
    [sym_boolean_operator] = STATE(446),
    [sym_postfix_operator] = STATE(411),
    [sym_string] = STATE(411),
    [sym_matrix] = STATE(411),
    [sym_cell] = STATE(423),
    [sym_ignored_argument] = STATE(1187),
    [sym_assignment] = STATE(853),
    [sym_multioutput_variable] = STATE(1187),
    [sym_function_call] = STATE(210),
    [sym_command] = STATE(853),
    [sym__range_element] = STATE(1181),
    [sym_range] = STATE(632),
    [sym_if_statement] = STATE(853),
    [sym_for_statement] = STATE(853),
    [sym_while_statement] = STATE(853),
    [sym_switch_statement] = STATE(853),
    [sym_lambda] = STATE(632),
    [sym_global_operator] = STATE(853),
    [sym_persistent_operator] = STATE(853),
    [sym__function_definition_with_end] = STATE(888),
    [sym_class_definition] = STATE(853),
    [sym_try_statement] = STATE(853),
    [sym_boolean] = STATE(205),
    [ts_builtin_sym_end] = ACTIONS(352),
    [sym_identifier] = ACTIONS(7),
    [anon_sym_LPAREN] = ACTIONS(9),
    [anon_sym_PLUS] = ACTIONS(11),
    [anon_sym_DASH] = ACTIONS(11),
    [anon_sym_TILDE] = ACTIONS(13),
    [anon_sym_QMARK] = ACTIONS(15),
    [anon_sym_AT] = ACTIONS(17),
    [anon_sym_LBRACK] = ACTIONS(19),
    [anon_sym_LBRACE] = ACTIONS(21),
    [sym_return_statement] = ACTIONS(147),
    [sym_continue_statement] = ACTIONS(147),
    [sym_break_statement] = ACTIONS(147),
    [anon_sym_if] = ACTIONS(25),
    [anon_sym_end] = ACTIONS(246),
    [anon_sym_for] = ACTIONS(27),
    [anon_sym_parfor] = ACTIONS(29),
    [anon_sym_while] = ACTIONS(31),
    [anon_sym_switch] = ACTIONS(33),
    [anon_sym_global] = ACTIONS(35),
    [anon_sym_persistent] = ACTIONS(37),
    [anon_sym_function] = ACTIONS(354),
    [anon_sym_endfunction] = ACTIONS(246),
    [anon_sym_classdef] = ACTIONS(41),
    [anon_sym_try] = ACTIONS(43),
    [sym_number] = ACTIONS(45),
    [anon_sym_true] = ACTIONS(47),
    [anon_sym_false] = ACTIONS(47),
    [sym_comment] = ACTIONS(3),
    [sym_line_continuation] = ACTIONS(3),
    [sym_command_name] = ACTIONS(49),
    [sym__single_quote_string_start] = ACTIONS(51),
    [sym__double_quote_string_start] = ACTIONS(53),
    [sym__multioutput_variable_start] = ACTIONS(55),
  },
  [74] = {
    [aux_sym__block] = STATE(72),
    [sym__statement] = STATE(853),
    [sym__expression] = STATE(632),
    [sym_parenthesis] = STATE(411),
    [sym__binary_expression] = STATE(622),
    [sym_binary_operator] = STATE(422),
    [sym_unary_operator] = STATE(389),
    [sym_indirect_access] = STATE(994),
    [sym_field_expression] = STATE(485),
    [sym_not_operator] = STATE(477),
    [sym_metaclass_operator] = STATE(632),
    [sym_handle_operator] = STATE(632),
    [sym_comparison_operator] = STATE(446),
    [sym_boolean_operator] = STATE(446),
    [sym_postfix_operator] = STATE(411),
    [sym_string] = STATE(411),
    [sym_matrix] = STATE(411),
    [sym_cell] = STATE(423),
    [sym_ignored_argument] = STATE(1187),
    [sym_assignment] = STATE(853),
    [sym_multioutput_variable] = STATE(1187),
    [sym_function_call] = STATE(210),
    [sym_command] = STATE(853),
    [sym__range_element] = STATE(1181),
    [sym_range] = STATE(632),
    [sym_if_statement] = STATE(853),
    [sym_for_statement] = STATE(853),
    [sym_while_statement] = STATE(853),
    [sym_switch_statement] = STATE(853),
    [sym_lambda] = STATE(632),
    [sym_global_operator] = STATE(853),
    [sym_persistent_operator] = STATE(853),
    [sym__function_definition_with_end] = STATE(888),
    [sym_class_definition] = STATE(853),
    [sym_try_statement] = STATE(853),
    [sym_boolean] = STATE(205),
    [sym_identifier] = ACTIONS(7),
    [anon_sym_LPAREN] = ACTIONS(9),
    [anon_sym_PLUS] = ACTIONS(11),
    [anon_sym_DASH] = ACTIONS(11),
    [anon_sym_TILDE] = ACTIONS(13),
    [anon_sym_QMARK] = ACTIONS(15),
    [anon_sym_AT] = ACTIONS(17),
    [anon_sym_LBRACK] = ACTIONS(19),
    [anon_sym_LBRACE] = ACTIONS(21),
    [sym_return_statement] = ACTIONS(147),
    [sym_continue_statement] = ACTIONS(147),
    [sym_break_statement] = ACTIONS(147),
    [anon_sym_if] = ACTIONS(25),
    [anon_sym_end] = ACTIONS(246),
    [anon_sym_for] = ACTIONS(27),
    [anon_sym_parfor] = ACTIONS(29),
    [anon_sym_while] = ACTIONS(31),
    [anon_sym_switch] = ACTIONS(33),
    [anon_sym_global] = ACTIONS(35),
    [anon_sym_persistent] = ACTIONS(37),
    [anon_sym_function] = ACTIONS(87),
    [anon_sym_endfunction] = ACTIONS(246),
    [anon_sym_classdef] = ACTIONS(41),
    [anon_sym_try] = ACTIONS(43),
    [sym_number] = ACTIONS(45),
    [anon_sym_true] = ACTIONS(47),
    [anon_sym_false] = ACTIONS(47),
    [sym_comment] = ACTIONS(3),
    [sym_line_continuation] = ACTIONS(3),
    [sym_command_name] = ACTIONS(49),
    [sym__single_quote_string_start] = ACTIONS(51),
    [sym__double_quote_string_start] = ACTIONS(53),
    [sym__multioutput_variable_start] = ACTIONS(55),
  },
  [75] = {
    [aux_sym__block] = STATE(75),
    [sym__statement] = STATE(817),
    [sym__expression] = STATE(630),
    [sym_parenthesis] = STATE(411),
    [sym__binary_expression] = STATE(622),
    [sym_binary_operator] = STATE(422),
    [sym_unary_operator] = STATE(389),
    [sym_indirect_access] = STATE(994),
    [sym_field_expression] = STATE(485),
    [sym_not_operator] = STATE(477),
    [sym_metaclass_operator] = STATE(630),
    [sym_handle_operator] = STATE(630),
    [sym_comparison_operator] = STATE(446),
    [sym_boolean_operator] = STATE(446),
    [sym_postfix_operator] = STATE(411),
    [sym_string] = STATE(411),
    [sym_matrix] = STATE(411),
    [sym_cell] = STATE(423),
    [sym_ignored_argument] = STATE(1187),
    [sym_assignment] = STATE(817),
    [sym_multioutput_variable] = STATE(1187),
    [sym_function_call] = STATE(210),
    [sym_command] = STATE(817),
    [sym__range_element] = STATE(1181),
    [sym_range] = STATE(630),
    [sym_if_statement] = STATE(817),
    [sym_for_statement] = STATE(817),
    [sym_while_statement] = STATE(817),
    [sym_switch_statement] = STATE(817),
    [sym_lambda] = STATE(630),
    [sym_global_operator] = STATE(817),
    [sym_persistent_operator] = STATE(817),
    [sym__function_definition_with_end] = STATE(860),
    [sym_class_definition] = STATE(817),
    [sym_try_statement] = STATE(817),
    [sym_boolean] = STATE(205),
    [ts_builtin_sym_end] = ACTIONS(347),
    [sym_identifier] = ACTIONS(252),
    [anon_sym_LPAREN] = ACTIONS(255),
    [anon_sym_PLUS] = ACTIONS(258),
    [anon_sym_DASH] = ACTIONS(258),
    [anon_sym_TILDE] = ACTIONS(261),
    [anon_sym_QMARK] = ACTIONS(264),
    [anon_sym_AT] = ACTIONS(267),
    [anon_sym_LBRACK] = ACTIONS(270),
    [anon_sym_LBRACE] = ACTIONS(273),
    [sym_return_statement] = ACTIONS(357),
    [sym_continue_statement] = ACTIONS(357),
    [sym_break_statement] = ACTIONS(357),
    [anon_sym_if] = ACTIONS(281),
    [anon_sym_for] = ACTIONS(284),
    [anon_sym_parfor] = ACTIONS(287),
    [anon_sym_while] = ACTIONS(290),
    [anon_sym_switch] = ACTIONS(293),
    [anon_sym_global] = ACTIONS(296),
    [anon_sym_persistent] = ACTIONS(299),
    [anon_sym_function] = ACTIONS(302),
    [anon_sym_classdef] = ACTIONS(305),
    [anon_sym_try] = ACTIONS(308),
    [sym_number] = ACTIONS(311),
    [anon_sym_true] = ACTIONS(314),
    [anon_sym_false] = ACTIONS(314),
    [sym_comment] = ACTIONS(3),
    [sym_line_continuation] = ACTIONS(3),
    [sym_command_name] = ACTIONS(317),
    [sym__single_quote_string_start] = ACTIONS(320),
    [sym__double_quote_string_start] = ACTIONS(323),
    [sym__multioutput_variable_start] = ACTIONS(326),
  },
};

static const uint16_t ts_small_parse_table[] = {
  [0] = 12,
    ACTIONS(362), 1,
      anon_sym_LPAREN,
    ACTIONS(366), 1,
      anon_sym_DOT,
    ACTIONS(368), 1,
      anon_sym_AT,
    ACTIONS(372), 1,
      anon_sym_LBRACE,
    ACTIONS(374), 1,
      anon_sym_COLON,
    STATE(81), 1,
      aux_sym_field_expression_repeat1,
    STATE(90), 1,
      sym__args,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(370), 2,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(376), 4,
      sym_command_name,
      sym__single_quote_string_start,
      sym__double_quote_string_start,
      sym__multioutput_variable_start,
    ACTIONS(364), 14,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
    ACTIONS(360), 35,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_LBRACK,
      sym_return_statement,
      sym_continue_statement,
      sym_break_statement,
      anon_sym_elseif,
      anon_sym_else,
      anon_sym_if,
      anon_sym_end,
      anon_sym_for,
      anon_sym_parfor,
      anon_sym_while,
      anon_sym_switch,
      anon_sym_global,
      anon_sym_persistent,
      anon_sym_function,
      anon_sym_classdef,
      anon_sym_try,
      sym_number,
      anon_sym_true,
      anon_sym_false,
      sym_identifier,
      anon_sym_LF,
      anon_sym_CR,
  [89] = 12,
    ACTIONS(362), 1,
      anon_sym_LPAREN,
    ACTIONS(366), 1,
      anon_sym_DOT,
    ACTIONS(368), 1,
      anon_sym_AT,
    ACTIONS(372), 1,
      anon_sym_LBRACE,
    STATE(81), 1,
      aux_sym_field_expression_repeat1,
    STATE(90), 1,
      sym__args,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(370), 2,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(381), 4,
      sym_command_name,
      sym__single_quote_string_start,
      sym__double_quote_string_start,
      sym__multioutput_variable_start,
    ACTIONS(378), 8,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
    ACTIONS(364), 14,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
    ACTIONS(374), 28,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LBRACK,
      anon_sym_COLON,
      sym_return_statement,
      sym_continue_statement,
      sym_break_statement,
      anon_sym_elseif,
      anon_sym_else,
      anon_sym_if,
      anon_sym_end,
      anon_sym_for,
      anon_sym_parfor,
      anon_sym_while,
      anon_sym_switch,
      anon_sym_global,
      anon_sym_persistent,
      anon_sym_function,
      anon_sym_classdef,
      anon_sym_try,
      sym_number,
      anon_sym_true,
      anon_sym_false,
      sym_identifier,
      anon_sym_LF,
      anon_sym_CR,
  [178] = 10,
    ACTIONS(362), 1,
      anon_sym_LPAREN,
    ACTIONS(366), 1,
      anon_sym_DOT,
    ACTIONS(368), 1,
      anon_sym_AT,
    ACTIONS(372), 1,
      anon_sym_LBRACE,
    STATE(81), 1,
      aux_sym_field_expression_repeat1,
    STATE(90), 1,
      sym__args,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(370), 2,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(385), 4,
      sym_command_name,
      sym__single_quote_string_start,
      sym__double_quote_string_start,
      sym__multioutput_variable_start,
    ACTIONS(383), 50,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_LBRACK,
      anon_sym_COLON,
      sym_return_statement,
      sym_continue_statement,
      sym_break_statement,
      anon_sym_elseif,
      anon_sym_else,
      anon_sym_if,
      anon_sym_end,
      anon_sym_for,
      anon_sym_parfor,
      anon_sym_while,
      anon_sym_switch,
      anon_sym_global,
      anon_sym_persistent,
      anon_sym_function,
      anon_sym_classdef,
      anon_sym_try,
      sym_number,
      anon_sym_true,
      anon_sym_false,
      sym_identifier,
      anon_sym_LF,
      anon_sym_CR,
  [263] = 10,
    ACTIONS(362), 1,
      anon_sym_LPAREN,
    ACTIONS(366), 1,
      anon_sym_DOT,
    ACTIONS(368), 1,
      anon_sym_AT,
    ACTIONS(372), 1,
      anon_sym_LBRACE,
    STATE(81), 1,
      aux_sym_field_expression_repeat1,
    STATE(90), 1,
      sym__args,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(370), 2,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(387), 4,
      sym_command_name,
      sym__single_quote_string_start,
      sym__double_quote_string_start,
      sym__multioutput_variable_start,
    ACTIONS(364), 50,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_LBRACK,
      anon_sym_COLON,
      sym_return_statement,
      sym_continue_statement,
      sym_break_statement,
      anon_sym_elseif,
      anon_sym_else,
      anon_sym_if,
      anon_sym_end,
      anon_sym_for,
      anon_sym_parfor,
      anon_sym_while,
      anon_sym_switch,
      anon_sym_global,
      anon_sym_persistent,
      anon_sym_function,
      anon_sym_classdef,
      anon_sym_try,
      sym_number,
      anon_sym_true,
      anon_sym_false,
      sym_identifier,
      anon_sym_LF,
      anon_sym_CR,
  [348] = 12,
    ACTIONS(362), 1,
      anon_sym_LPAREN,
    ACTIONS(366), 1,
      anon_sym_DOT,
    ACTIONS(368), 1,
      anon_sym_AT,
    ACTIONS(372), 1,
      anon_sym_LBRACE,
    ACTIONS(378), 1,
      anon_sym_COLON,
    STATE(81), 1,
      aux_sym_field_expression_repeat1,
    STATE(90), 1,
      sym__args,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(370), 2,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(376), 4,
      sym_command_name,
      sym__single_quote_string_start,
      sym__double_quote_string_start,
      sym__multioutput_variable_start,
    ACTIONS(364), 14,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
    ACTIONS(360), 35,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_LBRACK,
      sym_return_statement,
      sym_continue_statement,
      sym_break_statement,
      anon_sym_elseif,
      anon_sym_else,
      anon_sym_if,
      anon_sym_end,
      anon_sym_for,
      anon_sym_parfor,
      anon_sym_while,
      anon_sym_switch,
      anon_sym_global,
      anon_sym_persistent,
      anon_sym_function,
      anon_sym_classdef,
      anon_sym_try,
      sym_number,
      anon_sym_true,
      anon_sym_false,
      sym_identifier,
      anon_sym_LF,
      anon_sym_CR,
  [437] = 5,
    ACTIONS(366), 1,
      anon_sym_DOT,
    STATE(83), 1,
      aux_sym_field_expression_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(391), 4,
      sym_command_name,
      sym__single_quote_string_start,
      sym__double_quote_string_start,
      sym__multioutput_variable_start,
    ACTIONS(389), 55,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_AT,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_LBRACK,
      anon_sym_LBRACE,
      anon_sym_COLON,
      sym_return_statement,
      sym_continue_statement,
      sym_break_statement,
      anon_sym_elseif,
      anon_sym_else,
      anon_sym_if,
      anon_sym_end,
      anon_sym_for,
      anon_sym_parfor,
      anon_sym_while,
      anon_sym_switch,
      anon_sym_global,
      anon_sym_persistent,
      anon_sym_function,
      anon_sym_classdef,
      anon_sym_try,
      sym_number,
      anon_sym_true,
      anon_sym_false,
      sym_identifier,
      anon_sym_LF,
      anon_sym_CR,
  [511] = 5,
    ACTIONS(395), 1,
      anon_sym_DOT,
    STATE(85), 1,
      aux_sym_handle_operator_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(397), 4,
      sym_command_name,
      sym__single_quote_string_start,
      sym__double_quote_string_start,
      sym__multioutput_variable_start,
    ACTIONS(393), 55,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_AT,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_LBRACK,
      anon_sym_LBRACE,
      anon_sym_COLON,
      sym_return_statement,
      sym_continue_statement,
      sym_break_statement,
      anon_sym_elseif,
      anon_sym_else,
      anon_sym_if,
      anon_sym_end,
      anon_sym_for,
      anon_sym_parfor,
      anon_sym_while,
      anon_sym_switch,
      anon_sym_global,
      anon_sym_persistent,
      anon_sym_function,
      anon_sym_classdef,
      anon_sym_try,
      sym_number,
      anon_sym_true,
      anon_sym_false,
      sym_identifier,
      anon_sym_LF,
      anon_sym_CR,
  [585] = 5,
    ACTIONS(401), 1,
      anon_sym_DOT,
    STATE(83), 1,
      aux_sym_field_expression_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(404), 4,
      sym_command_name,
      sym__single_quote_string_start,
      sym__double_quote_string_start,
      sym__multioutput_variable_start,
    ACTIONS(399), 55,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_AT,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_LBRACK,
      anon_sym_LBRACE,
      anon_sym_COLON,
      sym_return_statement,
      sym_continue_statement,
      sym_break_statement,
      anon_sym_elseif,
      anon_sym_else,
      anon_sym_if,
      anon_sym_end,
      anon_sym_for,
      anon_sym_parfor,
      anon_sym_while,
      anon_sym_switch,
      anon_sym_global,
      anon_sym_persistent,
      anon_sym_function,
      anon_sym_classdef,
      anon_sym_try,
      sym_number,
      anon_sym_true,
      anon_sym_false,
      sym_identifier,
      anon_sym_LF,
      anon_sym_CR,
  [659] = 7,
    ACTIONS(362), 1,
      anon_sym_LPAREN,
    ACTIONS(368), 1,
      anon_sym_AT,
    ACTIONS(372), 1,
      anon_sym_LBRACE,
    STATE(90), 1,
      sym__args,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(408), 4,
      sym_command_name,
      sym__single_quote_string_start,
      sym__double_quote_string_start,
      sym__multioutput_variable_start,
    ACTIONS(406), 53,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_DOT,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_LBRACK,
      anon_sym_COLON,
      sym_return_statement,
      sym_continue_statement,
      sym_break_statement,
      anon_sym_elseif,
      anon_sym_else,
      anon_sym_if,
      anon_sym_end,
      anon_sym_for,
      anon_sym_parfor,
      anon_sym_while,
      anon_sym_switch,
      anon_sym_global,
      anon_sym_persistent,
      anon_sym_function,
      anon_sym_classdef,
      anon_sym_try,
      sym_number,
      anon_sym_true,
      anon_sym_false,
      sym_identifier,
      anon_sym_LF,
      anon_sym_CR,
  [737] = 5,
    ACTIONS(412), 1,
      anon_sym_DOT,
    STATE(85), 1,
      aux_sym_handle_operator_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(415), 4,
      sym_command_name,
      sym__single_quote_string_start,
      sym__double_quote_string_start,
      sym__multioutput_variable_start,
    ACTIONS(410), 55,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_AT,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_LBRACK,
      anon_sym_LBRACE,
      anon_sym_COLON,
      sym_return_statement,
      sym_continue_statement,
      sym_break_statement,
      anon_sym_elseif,
      anon_sym_else,
      anon_sym_if,
      anon_sym_end,
      anon_sym_for,
      anon_sym_parfor,
      anon_sym_while,
      anon_sym_switch,
      anon_sym_global,
      anon_sym_persistent,
      anon_sym_function,
      anon_sym_classdef,
      anon_sym_try,
      sym_number,
      anon_sym_true,
      anon_sym_false,
      sym_identifier,
      anon_sym_LF,
      anon_sym_CR,
  [811] = 5,
    ACTIONS(395), 1,
      anon_sym_DOT,
    STATE(82), 1,
      aux_sym_handle_operator_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(419), 4,
      sym_command_name,
      sym__single_quote_string_start,
      sym__double_quote_string_start,
      sym__multioutput_variable_start,
    ACTIONS(417), 55,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_AT,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_LBRACK,
      anon_sym_LBRACE,
      anon_sym_COLON,
      sym_return_statement,
      sym_continue_statement,
      sym_break_statement,
      anon_sym_elseif,
      anon_sym_else,
      anon_sym_if,
      anon_sym_end,
      anon_sym_for,
      anon_sym_parfor,
      anon_sym_while,
      anon_sym_switch,
      anon_sym_global,
      anon_sym_persistent,
      anon_sym_function,
      anon_sym_classdef,
      anon_sym_try,
      sym_number,
      anon_sym_true,
      anon_sym_false,
      sym_identifier,
      anon_sym_LF,
      anon_sym_CR,
  [885] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(423), 4,
      sym_command_name,
      sym__single_quote_string_start,
      sym__double_quote_string_start,
      sym__multioutput_variable_start,
    ACTIONS(421), 56,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_DOT,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_AT,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_LBRACK,
      anon_sym_LBRACE,
      anon_sym_COLON,
      sym_return_statement,
      sym_continue_statement,
      sym_break_statement,
      anon_sym_elseif,
      anon_sym_else,
      anon_sym_if,
      anon_sym_end,
      anon_sym_for,
      anon_sym_parfor,
      anon_sym_while,
      anon_sym_switch,
      anon_sym_global,
      anon_sym_persistent,
      anon_sym_function,
      anon_sym_classdef,
      anon_sym_try,
      sym_number,
      anon_sym_true,
      anon_sym_false,
      sym_identifier,
      anon_sym_LF,
      anon_sym_CR,
  [954] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(427), 4,
      sym_command_name,
      sym__single_quote_string_start,
      sym__double_quote_string_start,
      sym__multioutput_variable_start,
    ACTIONS(425), 56,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_DOT,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_AT,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_LBRACK,
      anon_sym_LBRACE,
      anon_sym_COLON,
      sym_return_statement,
      sym_continue_statement,
      sym_break_statement,
      anon_sym_elseif,
      anon_sym_else,
      anon_sym_if,
      anon_sym_end,
      anon_sym_for,
      anon_sym_parfor,
      anon_sym_while,
      anon_sym_switch,
      anon_sym_global,
      anon_sym_persistent,
      anon_sym_function,
      anon_sym_classdef,
      anon_sym_try,
      sym_number,
      anon_sym_true,
      anon_sym_false,
      sym_identifier,
      anon_sym_LF,
      anon_sym_CR,
  [1023] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(415), 4,
      sym_command_name,
      sym__single_quote_string_start,
      sym__double_quote_string_start,
      sym__multioutput_variable_start,
    ACTIONS(410), 56,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_DOT,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_AT,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_LBRACK,
      anon_sym_LBRACE,
      anon_sym_COLON,
      sym_return_statement,
      sym_continue_statement,
      sym_break_statement,
      anon_sym_elseif,
      anon_sym_else,
      anon_sym_if,
      anon_sym_end,
      anon_sym_for,
      anon_sym_parfor,
      anon_sym_while,
      anon_sym_switch,
      anon_sym_global,
      anon_sym_persistent,
      anon_sym_function,
      anon_sym_classdef,
      anon_sym_try,
      sym_number,
      anon_sym_true,
      anon_sym_false,
      sym_identifier,
      anon_sym_LF,
      anon_sym_CR,
  [1092] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(431), 4,
      sym_command_name,
      sym__single_quote_string_start,
      sym__double_quote_string_start,
      sym__multioutput_variable_start,
    ACTIONS(429), 56,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_DOT,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_AT,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_LBRACK,
      anon_sym_LBRACE,
      anon_sym_COLON,
      sym_return_statement,
      sym_continue_statement,
      sym_break_statement,
      anon_sym_elseif,
      anon_sym_else,
      anon_sym_if,
      anon_sym_end,
      anon_sym_for,
      anon_sym_parfor,
      anon_sym_while,
      anon_sym_switch,
      anon_sym_global,
      anon_sym_persistent,
      anon_sym_function,
      anon_sym_classdef,
      anon_sym_try,
      sym_number,
      anon_sym_true,
      anon_sym_false,
      sym_identifier,
      anon_sym_LF,
      anon_sym_CR,
  [1161] = 10,
    ACTIONS(362), 1,
      anon_sym_LPAREN,
    ACTIONS(372), 1,
      anon_sym_LBRACE,
    ACTIONS(374), 1,
      anon_sym_COLON,
    ACTIONS(433), 1,
      anon_sym_AT,
    STATE(88), 1,
      sym__args,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(370), 2,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(376), 4,
      sym_command_name,
      sym__single_quote_string_start,
      sym__double_quote_string_start,
      sym__multioutput_variable_start,
    ACTIONS(364), 14,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
    ACTIONS(360), 35,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_LBRACK,
      sym_return_statement,
      sym_continue_statement,
      sym_break_statement,
      anon_sym_elseif,
      anon_sym_else,
      anon_sym_if,
      anon_sym_end,
      anon_sym_for,
      anon_sym_parfor,
      anon_sym_while,
      anon_sym_switch,
      anon_sym_global,
      anon_sym_persistent,
      anon_sym_function,
      anon_sym_classdef,
      anon_sym_try,
      sym_number,
      anon_sym_true,
      anon_sym_false,
      sym_identifier,
      anon_sym_LF,
      anon_sym_CR,
  [1244] = 8,
    ACTIONS(362), 1,
      anon_sym_LPAREN,
    ACTIONS(372), 1,
      anon_sym_LBRACE,
    ACTIONS(433), 1,
      anon_sym_AT,
    STATE(88), 1,
      sym__args,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(370), 2,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(385), 4,
      sym_command_name,
      sym__single_quote_string_start,
      sym__double_quote_string_start,
      sym__multioutput_variable_start,
    ACTIONS(383), 50,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_LBRACK,
      anon_sym_COLON,
      sym_return_statement,
      sym_continue_statement,
      sym_break_statement,
      anon_sym_elseif,
      anon_sym_else,
      anon_sym_if,
      anon_sym_end,
      anon_sym_for,
      anon_sym_parfor,
      anon_sym_while,
      anon_sym_switch,
      anon_sym_global,
      anon_sym_persistent,
      anon_sym_function,
      anon_sym_classdef,
      anon_sym_try,
      sym_number,
      anon_sym_true,
      anon_sym_false,
      sym_identifier,
      anon_sym_LF,
      anon_sym_CR,
  [1323] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(437), 4,
      sym_command_name,
      sym__single_quote_string_start,
      sym__double_quote_string_start,
      sym__multioutput_variable_start,
    ACTIONS(435), 56,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_DOT,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_AT,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_LBRACK,
      anon_sym_LBRACE,
      anon_sym_COLON,
      sym_return_statement,
      sym_continue_statement,
      sym_break_statement,
      anon_sym_elseif,
      anon_sym_else,
      anon_sym_if,
      anon_sym_end,
      anon_sym_for,
      anon_sym_parfor,
      anon_sym_while,
      anon_sym_switch,
      anon_sym_global,
      anon_sym_persistent,
      anon_sym_function,
      anon_sym_classdef,
      anon_sym_try,
      sym_number,
      anon_sym_true,
      anon_sym_false,
      sym_identifier,
      anon_sym_LF,
      anon_sym_CR,
  [1392] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(441), 4,
      sym_command_name,
      sym__single_quote_string_start,
      sym__double_quote_string_start,
      sym__multioutput_variable_start,
    ACTIONS(439), 56,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_DOT,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_AT,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_LBRACK,
      anon_sym_LBRACE,
      anon_sym_COLON,
      sym_return_statement,
      sym_continue_statement,
      sym_break_statement,
      anon_sym_elseif,
      anon_sym_else,
      anon_sym_if,
      anon_sym_end,
      anon_sym_for,
      anon_sym_parfor,
      anon_sym_while,
      anon_sym_switch,
      anon_sym_global,
      anon_sym_persistent,
      anon_sym_function,
      anon_sym_classdef,
      anon_sym_try,
      sym_number,
      anon_sym_true,
      anon_sym_false,
      sym_identifier,
      anon_sym_LF,
      anon_sym_CR,
  [1461] = 8,
    ACTIONS(362), 1,
      anon_sym_LPAREN,
    ACTIONS(372), 1,
      anon_sym_LBRACE,
    ACTIONS(433), 1,
      anon_sym_AT,
    STATE(88), 1,
      sym__args,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(370), 2,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(387), 4,
      sym_command_name,
      sym__single_quote_string_start,
      sym__double_quote_string_start,
      sym__multioutput_variable_start,
    ACTIONS(364), 50,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_LBRACK,
      anon_sym_COLON,
      sym_return_statement,
      sym_continue_statement,
      sym_break_statement,
      anon_sym_elseif,
      anon_sym_else,
      anon_sym_if,
      anon_sym_end,
      anon_sym_for,
      anon_sym_parfor,
      anon_sym_while,
      anon_sym_switch,
      anon_sym_global,
      anon_sym_persistent,
      anon_sym_function,
      anon_sym_classdef,
      anon_sym_try,
      sym_number,
      anon_sym_true,
      anon_sym_false,
      sym_identifier,
      anon_sym_LF,
      anon_sym_CR,
  [1540] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(445), 4,
      sym_command_name,
      sym__single_quote_string_start,
      sym__double_quote_string_start,
      sym__multioutput_variable_start,
    ACTIONS(443), 56,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_DOT,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_AT,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_LBRACK,
      anon_sym_LBRACE,
      anon_sym_COLON,
      sym_return_statement,
      sym_continue_statement,
      sym_break_statement,
      anon_sym_elseif,
      anon_sym_else,
      anon_sym_if,
      anon_sym_end,
      anon_sym_for,
      anon_sym_parfor,
      anon_sym_while,
      anon_sym_switch,
      anon_sym_global,
      anon_sym_persistent,
      anon_sym_function,
      anon_sym_classdef,
      anon_sym_try,
      sym_number,
      anon_sym_true,
      anon_sym_false,
      sym_identifier,
      anon_sym_LF,
      anon_sym_CR,
  [1609] = 10,
    ACTIONS(362), 1,
      anon_sym_LPAREN,
    ACTIONS(372), 1,
      anon_sym_LBRACE,
    ACTIONS(433), 1,
      anon_sym_AT,
    STATE(88), 1,
      sym__args,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(370), 2,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(381), 4,
      sym_command_name,
      sym__single_quote_string_start,
      sym__double_quote_string_start,
      sym__multioutput_variable_start,
    ACTIONS(378), 8,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
    ACTIONS(364), 14,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
    ACTIONS(374), 28,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LBRACK,
      anon_sym_COLON,
      sym_return_statement,
      sym_continue_statement,
      sym_break_statement,
      anon_sym_elseif,
      anon_sym_else,
      anon_sym_if,
      anon_sym_end,
      anon_sym_for,
      anon_sym_parfor,
      anon_sym_while,
      anon_sym_switch,
      anon_sym_global,
      anon_sym_persistent,
      anon_sym_function,
      anon_sym_classdef,
      anon_sym_try,
      sym_number,
      anon_sym_true,
      anon_sym_false,
      sym_identifier,
      anon_sym_LF,
      anon_sym_CR,
  [1692] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(449), 4,
      sym_command_name,
      sym__single_quote_string_start,
      sym__double_quote_string_start,
      sym__multioutput_variable_start,
    ACTIONS(447), 56,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_DOT,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_AT,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_LBRACK,
      anon_sym_LBRACE,
      anon_sym_COLON,
      sym_return_statement,
      sym_continue_statement,
      sym_break_statement,
      anon_sym_elseif,
      anon_sym_else,
      anon_sym_if,
      anon_sym_end,
      anon_sym_for,
      anon_sym_parfor,
      anon_sym_while,
      anon_sym_switch,
      anon_sym_global,
      anon_sym_persistent,
      anon_sym_function,
      anon_sym_classdef,
      anon_sym_try,
      sym_number,
      anon_sym_true,
      anon_sym_false,
      sym_identifier,
      anon_sym_LF,
      anon_sym_CR,
  [1761] = 10,
    ACTIONS(362), 1,
      anon_sym_LPAREN,
    ACTIONS(372), 1,
      anon_sym_LBRACE,
    ACTIONS(378), 1,
      anon_sym_COLON,
    ACTIONS(433), 1,
      anon_sym_AT,
    STATE(88), 1,
      sym__args,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(370), 2,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(376), 4,
      sym_command_name,
      sym__single_quote_string_start,
      sym__double_quote_string_start,
      sym__multioutput_variable_start,
    ACTIONS(364), 14,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
    ACTIONS(360), 35,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_LBRACK,
      sym_return_statement,
      sym_continue_statement,
      sym_break_statement,
      anon_sym_elseif,
      anon_sym_else,
      anon_sym_if,
      anon_sym_end,
      anon_sym_for,
      anon_sym_parfor,
      anon_sym_while,
      anon_sym_switch,
      anon_sym_global,
      anon_sym_persistent,
      anon_sym_function,
      anon_sym_classdef,
      anon_sym_try,
      sym_number,
      anon_sym_true,
      anon_sym_false,
      sym_identifier,
      anon_sym_LF,
      anon_sym_CR,
  [1844] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(453), 4,
      sym_command_name,
      sym__single_quote_string_start,
      sym__double_quote_string_start,
      sym__multioutput_variable_start,
    ACTIONS(451), 55,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_AT,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_LBRACK,
      anon_sym_LBRACE,
      anon_sym_COLON,
      sym_return_statement,
      sym_continue_statement,
      sym_break_statement,
      anon_sym_elseif,
      anon_sym_else,
      anon_sym_if,
      anon_sym_end,
      anon_sym_for,
      anon_sym_parfor,
      anon_sym_while,
      anon_sym_switch,
      anon_sym_global,
      anon_sym_persistent,
      anon_sym_function,
      anon_sym_classdef,
      anon_sym_try,
      sym_number,
      anon_sym_true,
      anon_sym_false,
      sym_identifier,
      anon_sym_LF,
      anon_sym_CR,
  [1912] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(457), 4,
      sym_command_name,
      sym__single_quote_string_start,
      sym__double_quote_string_start,
      sym__multioutput_variable_start,
    ACTIONS(455), 55,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_AT,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_LBRACK,
      anon_sym_LBRACE,
      anon_sym_COLON,
      sym_return_statement,
      sym_continue_statement,
      sym_break_statement,
      anon_sym_elseif,
      anon_sym_else,
      anon_sym_if,
      anon_sym_end,
      anon_sym_for,
      anon_sym_parfor,
      anon_sym_while,
      anon_sym_switch,
      anon_sym_global,
      anon_sym_persistent,
      anon_sym_function,
      anon_sym_classdef,
      anon_sym_try,
      sym_number,
      anon_sym_true,
      anon_sym_false,
      sym_identifier,
      anon_sym_LF,
      anon_sym_CR,
  [1980] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(461), 4,
      sym_command_name,
      sym__single_quote_string_start,
      sym__double_quote_string_start,
      sym__multioutput_variable_start,
    ACTIONS(459), 55,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_AT,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_LBRACK,
      anon_sym_LBRACE,
      anon_sym_COLON,
      sym_return_statement,
      sym_continue_statement,
      sym_break_statement,
      anon_sym_elseif,
      anon_sym_else,
      anon_sym_if,
      anon_sym_end,
      anon_sym_for,
      anon_sym_parfor,
      anon_sym_while,
      anon_sym_switch,
      anon_sym_global,
      anon_sym_persistent,
      anon_sym_function,
      anon_sym_classdef,
      anon_sym_try,
      sym_number,
      anon_sym_true,
      anon_sym_false,
      sym_identifier,
      anon_sym_LF,
      anon_sym_CR,
  [2048] = 4,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(370), 2,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(387), 4,
      sym_command_name,
      sym__single_quote_string_start,
      sym__double_quote_string_start,
      sym__multioutput_variable_start,
    ACTIONS(364), 53,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_AT,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_LBRACK,
      anon_sym_LBRACE,
      anon_sym_COLON,
      sym_return_statement,
      sym_continue_statement,
      sym_break_statement,
      anon_sym_elseif,
      anon_sym_else,
      anon_sym_if,
      anon_sym_end,
      anon_sym_for,
      anon_sym_parfor,
      anon_sym_while,
      anon_sym_switch,
      anon_sym_global,
      anon_sym_persistent,
      anon_sym_function,
      anon_sym_classdef,
      anon_sym_try,
      sym_number,
      anon_sym_true,
      anon_sym_false,
      sym_identifier,
      anon_sym_LF,
      anon_sym_CR,
  [2118] = 6,
    ACTIONS(378), 1,
      anon_sym_COLON,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(370), 2,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(376), 4,
      sym_command_name,
      sym__single_quote_string_start,
      sym__double_quote_string_start,
      sym__multioutput_variable_start,
    ACTIONS(364), 14,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
    ACTIONS(360), 38,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_AT,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_LBRACK,
      anon_sym_LBRACE,
      sym_return_statement,
      sym_continue_statement,
      sym_break_statement,
      anon_sym_elseif,
      anon_sym_else,
      anon_sym_if,
      anon_sym_end,
      anon_sym_for,
      anon_sym_parfor,
      anon_sym_while,
      anon_sym_switch,
      anon_sym_global,
      anon_sym_persistent,
      anon_sym_function,
      anon_sym_classdef,
      anon_sym_try,
      sym_number,
      anon_sym_true,
      anon_sym_false,
      sym_identifier,
      anon_sym_LF,
      anon_sym_CR,
  [2192] = 6,
    ACTIONS(463), 1,
      anon_sym_COLON,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(370), 2,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(376), 4,
      sym_command_name,
      sym__single_quote_string_start,
      sym__double_quote_string_start,
      sym__multioutput_variable_start,
    ACTIONS(364), 14,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
    ACTIONS(360), 38,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_AT,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_LBRACK,
      anon_sym_LBRACE,
      sym_return_statement,
      sym_continue_statement,
      sym_break_statement,
      anon_sym_elseif,
      anon_sym_else,
      anon_sym_if,
      anon_sym_end,
      anon_sym_for,
      anon_sym_parfor,
      anon_sym_while,
      anon_sym_switch,
      anon_sym_global,
      anon_sym_persistent,
      anon_sym_function,
      anon_sym_classdef,
      anon_sym_try,
      sym_number,
      anon_sym_true,
      anon_sym_false,
      sym_identifier,
      anon_sym_LF,
      anon_sym_CR,
  [2266] = 4,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(370), 2,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(385), 4,
      sym_command_name,
      sym__single_quote_string_start,
      sym__double_quote_string_start,
      sym__multioutput_variable_start,
    ACTIONS(383), 53,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_AT,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_LBRACK,
      anon_sym_LBRACE,
      anon_sym_COLON,
      sym_return_statement,
      sym_continue_statement,
      sym_break_statement,
      anon_sym_elseif,
      anon_sym_else,
      anon_sym_if,
      anon_sym_end,
      anon_sym_for,
      anon_sym_parfor,
      anon_sym_while,
      anon_sym_switch,
      anon_sym_global,
      anon_sym_persistent,
      anon_sym_function,
      anon_sym_classdef,
      anon_sym_try,
      sym_number,
      anon_sym_true,
      anon_sym_false,
      sym_identifier,
      anon_sym_LF,
      anon_sym_CR,
  [2336] = 6,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(370), 2,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(471), 4,
      sym_command_name,
      sym__single_quote_string_start,
      sym__double_quote_string_start,
      sym__multioutput_variable_start,
    ACTIONS(468), 8,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
    ACTIONS(364), 14,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
    ACTIONS(466), 31,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_AT,
      anon_sym_LBRACK,
      anon_sym_LBRACE,
      anon_sym_COLON,
      sym_return_statement,
      sym_continue_statement,
      sym_break_statement,
      anon_sym_elseif,
      anon_sym_else,
      anon_sym_if,
      anon_sym_end,
      anon_sym_for,
      anon_sym_parfor,
      anon_sym_while,
      anon_sym_switch,
      anon_sym_global,
      anon_sym_persistent,
      anon_sym_function,
      anon_sym_classdef,
      anon_sym_try,
      sym_number,
      anon_sym_true,
      anon_sym_false,
      sym_identifier,
      anon_sym_LF,
      anon_sym_CR,
  [2410] = 4,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(370), 2,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(385), 4,
      sym_command_name,
      sym__single_quote_string_start,
      sym__double_quote_string_start,
      sym__multioutput_variable_start,
    ACTIONS(383), 53,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_AT,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_LBRACK,
      anon_sym_LBRACE,
      anon_sym_COLON,
      sym_return_statement,
      sym_continue_statement,
      sym_break_statement,
      anon_sym_elseif,
      anon_sym_else,
      anon_sym_if,
      anon_sym_end,
      anon_sym_for,
      anon_sym_parfor,
      anon_sym_while,
      anon_sym_switch,
      anon_sym_global,
      anon_sym_persistent,
      anon_sym_function,
      anon_sym_classdef,
      anon_sym_try,
      sym_number,
      anon_sym_true,
      anon_sym_false,
      sym_identifier,
      anon_sym_LF,
      anon_sym_CR,
  [2480] = 5,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(370), 2,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(376), 4,
      sym_command_name,
      sym__single_quote_string_start,
      sym__double_quote_string_start,
      sym__multioutput_variable_start,
    ACTIONS(364), 14,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
    ACTIONS(360), 39,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_AT,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_LBRACK,
      anon_sym_LBRACE,
      anon_sym_COLON,
      sym_return_statement,
      sym_continue_statement,
      sym_break_statement,
      anon_sym_elseif,
      anon_sym_else,
      anon_sym_if,
      anon_sym_end,
      anon_sym_for,
      anon_sym_parfor,
      anon_sym_while,
      anon_sym_switch,
      anon_sym_global,
      anon_sym_persistent,
      anon_sym_function,
      anon_sym_classdef,
      anon_sym_try,
      sym_number,
      anon_sym_true,
      anon_sym_false,
      sym_identifier,
      anon_sym_LF,
      anon_sym_CR,
  [2552] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(385), 4,
      sym_command_name,
      sym__single_quote_string_start,
      sym__double_quote_string_start,
      sym__multioutput_variable_start,
    ACTIONS(383), 55,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_AT,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_LBRACK,
      anon_sym_LBRACE,
      anon_sym_COLON,
      sym_return_statement,
      sym_continue_statement,
      sym_break_statement,
      anon_sym_elseif,
      anon_sym_else,
      anon_sym_if,
      anon_sym_end,
      anon_sym_for,
      anon_sym_parfor,
      anon_sym_while,
      anon_sym_switch,
      anon_sym_global,
      anon_sym_persistent,
      anon_sym_function,
      anon_sym_classdef,
      anon_sym_try,
      sym_number,
      anon_sym_true,
      anon_sym_false,
      sym_identifier,
      anon_sym_LF,
      anon_sym_CR,
  [2620] = 4,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(477), 4,
      sym_command_name,
      sym__single_quote_string_start,
      sym__double_quote_string_start,
      sym__multioutput_variable_start,
    ACTIONS(475), 6,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
    ACTIONS(473), 49,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_AT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_LBRACK,
      anon_sym_LBRACE,
      anon_sym_COLON,
      sym_return_statement,
      sym_continue_statement,
      sym_break_statement,
      anon_sym_elseif,
      anon_sym_else,
      anon_sym_if,
      anon_sym_end,
      anon_sym_for,
      anon_sym_parfor,
      anon_sym_while,
      anon_sym_switch,
      anon_sym_global,
      anon_sym_persistent,
      anon_sym_function,
      anon_sym_classdef,
      anon_sym_try,
      sym_number,
      anon_sym_true,
      anon_sym_false,
      sym_identifier,
      anon_sym_LF,
      anon_sym_CR,
  [2690] = 5,
    ACTIONS(479), 1,
      anon_sym_AMP_AMP,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(477), 4,
      sym_command_name,
      sym__single_quote_string_start,
      sym__double_quote_string_start,
      sym__multioutput_variable_start,
    ACTIONS(475), 6,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
    ACTIONS(473), 48,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_AT,
      anon_sym_PIPE_PIPE,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_LBRACK,
      anon_sym_LBRACE,
      anon_sym_COLON,
      sym_return_statement,
      sym_continue_statement,
      sym_break_statement,
      anon_sym_elseif,
      anon_sym_else,
      anon_sym_if,
      anon_sym_end,
      anon_sym_for,
      anon_sym_parfor,
      anon_sym_while,
      anon_sym_switch,
      anon_sym_global,
      anon_sym_persistent,
      anon_sym_function,
      anon_sym_classdef,
      anon_sym_try,
      sym_number,
      anon_sym_true,
      anon_sym_false,
      sym_identifier,
      anon_sym_LF,
      anon_sym_CR,
  [2762] = 6,
    ACTIONS(479), 1,
      anon_sym_AMP_AMP,
    ACTIONS(483), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(485), 4,
      sym_command_name,
      sym__single_quote_string_start,
      sym__double_quote_string_start,
      sym__multioutput_variable_start,
    ACTIONS(475), 6,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
    ACTIONS(481), 47,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_AT,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_LBRACK,
      anon_sym_LBRACE,
      anon_sym_COLON,
      sym_return_statement,
      sym_continue_statement,
      sym_break_statement,
      anon_sym_elseif,
      anon_sym_else,
      anon_sym_if,
      anon_sym_end,
      anon_sym_for,
      anon_sym_parfor,
      anon_sym_while,
      anon_sym_switch,
      anon_sym_global,
      anon_sym_persistent,
      anon_sym_function,
      anon_sym_classdef,
      anon_sym_try,
      sym_number,
      anon_sym_true,
      anon_sym_false,
      sym_identifier,
      anon_sym_LF,
      anon_sym_CR,
  [2836] = 4,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(376), 4,
      sym_command_name,
      sym__single_quote_string_start,
      sym__double_quote_string_start,
      sym__multioutput_variable_start,
    ACTIONS(364), 14,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
    ACTIONS(360), 41,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_AT,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_LBRACK,
      anon_sym_LBRACE,
      anon_sym_COLON,
      sym_return_statement,
      sym_continue_statement,
      sym_break_statement,
      anon_sym_elseif,
      anon_sym_else,
      anon_sym_if,
      anon_sym_end,
      anon_sym_for,
      anon_sym_parfor,
      anon_sym_while,
      anon_sym_switch,
      anon_sym_global,
      anon_sym_persistent,
      anon_sym_function,
      anon_sym_classdef,
      anon_sym_try,
      sym_number,
      anon_sym_true,
      anon_sym_false,
      sym_identifier,
      anon_sym_LF,
      anon_sym_CR,
  [2906] = 4,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(370), 2,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(385), 4,
      sym_command_name,
      sym__single_quote_string_start,
      sym__double_quote_string_start,
      sym__multioutput_variable_start,
    ACTIONS(383), 53,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_AT,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_LBRACK,
      anon_sym_LBRACE,
      anon_sym_COLON,
      sym_return_statement,
      sym_continue_statement,
      sym_break_statement,
      anon_sym_elseif,
      anon_sym_else,
      anon_sym_if,
      anon_sym_end,
      anon_sym_for,
      anon_sym_parfor,
      anon_sym_while,
      anon_sym_switch,
      anon_sym_global,
      anon_sym_persistent,
      anon_sym_function,
      anon_sym_classdef,
      anon_sym_try,
      sym_number,
      anon_sym_true,
      anon_sym_false,
      sym_identifier,
      anon_sym_LF,
      anon_sym_CR,
  [2976] = 4,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(489), 4,
      sym_command_name,
      sym__single_quote_string_start,
      sym__double_quote_string_start,
      sym__multioutput_variable_start,
    ACTIONS(475), 6,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
    ACTIONS(487), 49,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_AT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_LBRACK,
      anon_sym_LBRACE,
      anon_sym_COLON,
      sym_return_statement,
      sym_continue_statement,
      sym_break_statement,
      anon_sym_elseif,
      anon_sym_else,
      anon_sym_if,
      anon_sym_end,
      anon_sym_for,
      anon_sym_parfor,
      anon_sym_while,
      anon_sym_switch,
      anon_sym_global,
      anon_sym_persistent,
      anon_sym_function,
      anon_sym_classdef,
      anon_sym_try,
      sym_number,
      anon_sym_true,
      anon_sym_false,
      sym_identifier,
      anon_sym_LF,
      anon_sym_CR,
  [3046] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(493), 4,
      sym_command_name,
      sym__single_quote_string_start,
      sym__double_quote_string_start,
      sym__multioutput_variable_start,
    ACTIONS(491), 55,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_AT,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_LBRACK,
      anon_sym_LBRACE,
      anon_sym_COLON,
      sym_return_statement,
      sym_continue_statement,
      sym_break_statement,
      anon_sym_elseif,
      anon_sym_else,
      anon_sym_if,
      anon_sym_end,
      anon_sym_for,
      anon_sym_parfor,
      anon_sym_while,
      anon_sym_switch,
      anon_sym_global,
      anon_sym_persistent,
      anon_sym_function,
      anon_sym_classdef,
      anon_sym_try,
      sym_number,
      anon_sym_true,
      anon_sym_false,
      sym_identifier,
      anon_sym_LF,
      anon_sym_CR,
  [3114] = 6,
    ACTIONS(479), 1,
      anon_sym_AMP_AMP,
    ACTIONS(483), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(497), 4,
      sym_command_name,
      sym__single_quote_string_start,
      sym__double_quote_string_start,
      sym__multioutput_variable_start,
    ACTIONS(475), 6,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
    ACTIONS(495), 47,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_AT,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_LBRACK,
      anon_sym_LBRACE,
      anon_sym_COLON,
      sym_return_statement,
      sym_continue_statement,
      sym_break_statement,
      anon_sym_elseif,
      anon_sym_else,
      anon_sym_if,
      anon_sym_end,
      anon_sym_for,
      anon_sym_parfor,
      anon_sym_while,
      anon_sym_switch,
      anon_sym_global,
      anon_sym_persistent,
      anon_sym_function,
      anon_sym_classdef,
      anon_sym_try,
      sym_number,
      anon_sym_true,
      anon_sym_false,
      sym_identifier,
      anon_sym_LF,
      anon_sym_CR,
  [3188] = 4,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(370), 2,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(387), 4,
      sym_command_name,
      sym__single_quote_string_start,
      sym__double_quote_string_start,
      sym__multioutput_variable_start,
    ACTIONS(364), 53,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_AT,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_LBRACK,
      anon_sym_LBRACE,
      anon_sym_COLON,
      sym_return_statement,
      sym_continue_statement,
      sym_break_statement,
      anon_sym_elseif,
      anon_sym_else,
      anon_sym_if,
      anon_sym_end,
      anon_sym_for,
      anon_sym_parfor,
      anon_sym_while,
      anon_sym_switch,
      anon_sym_global,
      anon_sym_persistent,
      anon_sym_function,
      anon_sym_classdef,
      anon_sym_try,
      sym_number,
      anon_sym_true,
      anon_sym_false,
      sym_identifier,
      anon_sym_LF,
      anon_sym_CR,
  [3258] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(501), 4,
      sym_command_name,
      sym__single_quote_string_start,
      sym__double_quote_string_start,
      sym__multioutput_variable_start,
    ACTIONS(499), 55,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_AT,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_LBRACK,
      anon_sym_LBRACE,
      anon_sym_COLON,
      sym_return_statement,
      sym_continue_statement,
      sym_break_statement,
      anon_sym_elseif,
      anon_sym_else,
      anon_sym_if,
      anon_sym_end,
      anon_sym_for,
      anon_sym_parfor,
      anon_sym_while,
      anon_sym_switch,
      anon_sym_global,
      anon_sym_persistent,
      anon_sym_function,
      anon_sym_classdef,
      anon_sym_try,
      sym_number,
      anon_sym_true,
      anon_sym_false,
      sym_identifier,
      anon_sym_LF,
      anon_sym_CR,
  [3326] = 6,
    ACTIONS(468), 1,
      anon_sym_COLON,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(370), 2,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(376), 4,
      sym_command_name,
      sym__single_quote_string_start,
      sym__double_quote_string_start,
      sym__multioutput_variable_start,
    ACTIONS(364), 14,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
    ACTIONS(360), 38,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_AT,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_LBRACK,
      anon_sym_LBRACE,
      sym_return_statement,
      sym_continue_statement,
      sym_break_statement,
      anon_sym_elseif,
      anon_sym_else,
      anon_sym_if,
      anon_sym_end,
      anon_sym_for,
      anon_sym_parfor,
      anon_sym_while,
      anon_sym_switch,
      anon_sym_global,
      anon_sym_persistent,
      anon_sym_function,
      anon_sym_classdef,
      anon_sym_try,
      sym_number,
      anon_sym_true,
      anon_sym_false,
      sym_identifier,
      anon_sym_LF,
      anon_sym_CR,
  [3400] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(505), 4,
      sym_command_name,
      sym__single_quote_string_start,
      sym__double_quote_string_start,
      sym__multioutput_variable_start,
    ACTIONS(503), 55,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_AT,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_LBRACK,
      anon_sym_LBRACE,
      anon_sym_COLON,
      sym_return_statement,
      sym_continue_statement,
      sym_break_statement,
      anon_sym_elseif,
      anon_sym_else,
      anon_sym_if,
      anon_sym_end,
      anon_sym_for,
      anon_sym_parfor,
      anon_sym_while,
      anon_sym_switch,
      anon_sym_global,
      anon_sym_persistent,
      anon_sym_function,
      anon_sym_classdef,
      anon_sym_try,
      sym_number,
      anon_sym_true,
      anon_sym_false,
      sym_identifier,
      anon_sym_LF,
      anon_sym_CR,
  [3468] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(509), 4,
      sym_command_name,
      sym__single_quote_string_start,
      sym__double_quote_string_start,
      sym__multioutput_variable_start,
    ACTIONS(507), 55,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_AT,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_LBRACK,
      anon_sym_LBRACE,
      anon_sym_COLON,
      sym_return_statement,
      sym_continue_statement,
      sym_break_statement,
      anon_sym_elseif,
      anon_sym_else,
      anon_sym_if,
      anon_sym_end,
      anon_sym_for,
      anon_sym_parfor,
      anon_sym_while,
      anon_sym_switch,
      anon_sym_global,
      anon_sym_persistent,
      anon_sym_function,
      anon_sym_classdef,
      anon_sym_try,
      sym_number,
      anon_sym_true,
      anon_sym_false,
      sym_identifier,
      anon_sym_LF,
      anon_sym_CR,
  [3536] = 6,
    ACTIONS(466), 1,
      anon_sym_COLON,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(370), 2,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(376), 4,
      sym_command_name,
      sym__single_quote_string_start,
      sym__double_quote_string_start,
      sym__multioutput_variable_start,
    ACTIONS(364), 14,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
    ACTIONS(360), 38,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_AT,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_LBRACK,
      anon_sym_LBRACE,
      sym_return_statement,
      sym_continue_statement,
      sym_break_statement,
      anon_sym_elseif,
      anon_sym_else,
      anon_sym_if,
      anon_sym_end,
      anon_sym_for,
      anon_sym_parfor,
      anon_sym_while,
      anon_sym_switch,
      anon_sym_global,
      anon_sym_persistent,
      anon_sym_function,
      anon_sym_classdef,
      anon_sym_try,
      sym_number,
      anon_sym_true,
      anon_sym_false,
      sym_identifier,
      anon_sym_LF,
      anon_sym_CR,
  [3610] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(513), 4,
      sym_command_name,
      sym__single_quote_string_start,
      sym__double_quote_string_start,
      sym__multioutput_variable_start,
    ACTIONS(511), 55,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_AT,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_LBRACK,
      anon_sym_LBRACE,
      anon_sym_COLON,
      sym_return_statement,
      sym_continue_statement,
      sym_break_statement,
      anon_sym_elseif,
      anon_sym_else,
      anon_sym_if,
      anon_sym_end,
      anon_sym_for,
      anon_sym_parfor,
      anon_sym_while,
      anon_sym_switch,
      anon_sym_global,
      anon_sym_persistent,
      anon_sym_function,
      anon_sym_classdef,
      anon_sym_try,
      sym_number,
      anon_sym_true,
      anon_sym_false,
      sym_identifier,
      anon_sym_LF,
      anon_sym_CR,
  [3678] = 6,
    ACTIONS(515), 1,
      anon_sym_COLON,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(370), 2,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(376), 4,
      sym_command_name,
      sym__single_quote_string_start,
      sym__double_quote_string_start,
      sym__multioutput_variable_start,
    ACTIONS(364), 14,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
    ACTIONS(360), 38,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_AT,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_LBRACK,
      anon_sym_LBRACE,
      sym_return_statement,
      sym_continue_statement,
      sym_break_statement,
      anon_sym_elseif,
      anon_sym_else,
      anon_sym_if,
      anon_sym_end,
      anon_sym_for,
      anon_sym_parfor,
      anon_sym_while,
      anon_sym_switch,
      anon_sym_global,
      anon_sym_persistent,
      anon_sym_function,
      anon_sym_classdef,
      anon_sym_try,
      sym_number,
      anon_sym_true,
      anon_sym_false,
      sym_identifier,
      anon_sym_LF,
      anon_sym_CR,
  [3752] = 6,
    ACTIONS(374), 1,
      anon_sym_COLON,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(370), 2,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(376), 4,
      sym_command_name,
      sym__single_quote_string_start,
      sym__double_quote_string_start,
      sym__multioutput_variable_start,
    ACTIONS(364), 14,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
    ACTIONS(360), 38,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_AT,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_LBRACK,
      anon_sym_LBRACE,
      sym_return_statement,
      sym_continue_statement,
      sym_break_statement,
      anon_sym_elseif,
      anon_sym_else,
      anon_sym_if,
      anon_sym_end,
      anon_sym_for,
      anon_sym_parfor,
      anon_sym_while,
      anon_sym_switch,
      anon_sym_global,
      anon_sym_persistent,
      anon_sym_function,
      anon_sym_classdef,
      anon_sym_try,
      sym_number,
      anon_sym_true,
      anon_sym_false,
      sym_identifier,
      anon_sym_LF,
      anon_sym_CR,
  [3826] = 4,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(370), 2,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(387), 4,
      sym_command_name,
      sym__single_quote_string_start,
      sym__double_quote_string_start,
      sym__multioutput_variable_start,
    ACTIONS(364), 53,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_AT,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_LBRACK,
      anon_sym_LBRACE,
      anon_sym_COLON,
      sym_return_statement,
      sym_continue_statement,
      sym_break_statement,
      anon_sym_elseif,
      anon_sym_else,
      anon_sym_if,
      anon_sym_end,
      anon_sym_for,
      anon_sym_parfor,
      anon_sym_while,
      anon_sym_switch,
      anon_sym_global,
      anon_sym_persistent,
      anon_sym_function,
      anon_sym_classdef,
      anon_sym_try,
      sym_number,
      anon_sym_true,
      anon_sym_false,
      sym_identifier,
      anon_sym_LF,
      anon_sym_CR,
  [3896] = 4,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(370), 2,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(387), 4,
      sym_command_name,
      sym__single_quote_string_start,
      sym__double_quote_string_start,
      sym__multioutput_variable_start,
    ACTIONS(364), 53,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_AT,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_LBRACK,
      anon_sym_LBRACE,
      anon_sym_COLON,
      sym_return_statement,
      sym_continue_statement,
      sym_break_statement,
      anon_sym_elseif,
      anon_sym_else,
      anon_sym_if,
      anon_sym_end,
      anon_sym_for,
      anon_sym_parfor,
      anon_sym_while,
      anon_sym_switch,
      anon_sym_global,
      anon_sym_persistent,
      anon_sym_function,
      anon_sym_classdef,
      anon_sym_try,
      sym_number,
      anon_sym_true,
      anon_sym_false,
      sym_identifier,
      anon_sym_LF,
      anon_sym_CR,
  [3966] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(519), 4,
      sym_command_name,
      sym__single_quote_string_start,
      sym__double_quote_string_start,
      sym__multioutput_variable_start,
    ACTIONS(517), 55,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_AT,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_LBRACK,
      anon_sym_LBRACE,
      anon_sym_COLON,
      sym_return_statement,
      sym_continue_statement,
      sym_break_statement,
      anon_sym_elseif,
      anon_sym_else,
      anon_sym_if,
      anon_sym_end,
      anon_sym_for,
      anon_sym_parfor,
      anon_sym_while,
      anon_sym_switch,
      anon_sym_global,
      anon_sym_persistent,
      anon_sym_function,
      anon_sym_classdef,
      anon_sym_try,
      sym_number,
      anon_sym_true,
      anon_sym_false,
      sym_identifier,
      anon_sym_LF,
      anon_sym_CR,
  [4034] = 5,
    ACTIONS(526), 1,
      anon_sym_COLON,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(528), 4,
      sym_command_name,
      sym__single_quote_string_start,
      sym__double_quote_string_start,
      sym__multioutput_variable_start,
    ACTIONS(523), 8,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
    ACTIONS(521), 46,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_AT,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_LBRACK,
      anon_sym_LBRACE,
      sym_return_statement,
      sym_continue_statement,
      sym_break_statement,
      anon_sym_elseif,
      anon_sym_else,
      anon_sym_if,
      anon_sym_end,
      anon_sym_for,
      anon_sym_parfor,
      anon_sym_while,
      anon_sym_switch,
      anon_sym_global,
      anon_sym_persistent,
      anon_sym_function,
      anon_sym_classdef,
      anon_sym_try,
      sym_number,
      anon_sym_true,
      anon_sym_false,
      sym_identifier,
      anon_sym_LF,
      anon_sym_CR,
  [4106] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(532), 4,
      sym_command_name,
      sym__single_quote_string_start,
      sym__double_quote_string_start,
      sym__multioutput_variable_start,
    ACTIONS(530), 55,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_AT,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_LBRACK,
      anon_sym_LBRACE,
      anon_sym_COLON,
      sym_return_statement,
      sym_continue_statement,
      sym_break_statement,
      anon_sym_elseif,
      anon_sym_else,
      anon_sym_if,
      anon_sym_end,
      anon_sym_for,
      anon_sym_parfor,
      anon_sym_while,
      anon_sym_switch,
      anon_sym_global,
      anon_sym_persistent,
      anon_sym_function,
      anon_sym_classdef,
      anon_sym_try,
      sym_number,
      anon_sym_true,
      anon_sym_false,
      sym_identifier,
      anon_sym_LF,
      anon_sym_CR,
  [4174] = 6,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(370), 2,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(381), 4,
      sym_command_name,
      sym__single_quote_string_start,
      sym__double_quote_string_start,
      sym__multioutput_variable_start,
    ACTIONS(378), 8,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
    ACTIONS(364), 14,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
    ACTIONS(374), 31,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_AT,
      anon_sym_LBRACK,
      anon_sym_LBRACE,
      anon_sym_COLON,
      sym_return_statement,
      sym_continue_statement,
      sym_break_statement,
      anon_sym_elseif,
      anon_sym_else,
      anon_sym_if,
      anon_sym_end,
      anon_sym_for,
      anon_sym_parfor,
      anon_sym_while,
      anon_sym_switch,
      anon_sym_global,
      anon_sym_persistent,
      anon_sym_function,
      anon_sym_classdef,
      anon_sym_try,
      sym_number,
      anon_sym_true,
      anon_sym_false,
      sym_identifier,
      anon_sym_LF,
      anon_sym_CR,
  [4248] = 6,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(370), 2,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(534), 4,
      sym_command_name,
      sym__single_quote_string_start,
      sym__double_quote_string_start,
      sym__multioutput_variable_start,
    ACTIONS(463), 8,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
    ACTIONS(364), 14,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
    ACTIONS(515), 31,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_AT,
      anon_sym_LBRACK,
      anon_sym_LBRACE,
      anon_sym_COLON,
      sym_return_statement,
      sym_continue_statement,
      sym_break_statement,
      anon_sym_elseif,
      anon_sym_else,
      anon_sym_if,
      anon_sym_end,
      anon_sym_for,
      anon_sym_parfor,
      anon_sym_while,
      anon_sym_switch,
      anon_sym_global,
      anon_sym_persistent,
      anon_sym_function,
      anon_sym_classdef,
      anon_sym_try,
      sym_number,
      anon_sym_true,
      anon_sym_false,
      sym_identifier,
      anon_sym_LF,
      anon_sym_CR,
  [4322] = 6,
    ACTIONS(479), 1,
      anon_sym_AMP_AMP,
    ACTIONS(483), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(538), 4,
      sym_command_name,
      sym__single_quote_string_start,
      sym__double_quote_string_start,
      sym__multioutput_variable_start,
    ACTIONS(475), 6,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
    ACTIONS(536), 47,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_AT,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_LBRACK,
      anon_sym_LBRACE,
      anon_sym_COLON,
      sym_return_statement,
      sym_continue_statement,
      sym_break_statement,
      anon_sym_elseif,
      anon_sym_else,
      anon_sym_if,
      anon_sym_end,
      anon_sym_for,
      anon_sym_parfor,
      anon_sym_while,
      anon_sym_switch,
      anon_sym_global,
      anon_sym_persistent,
      anon_sym_function,
      anon_sym_classdef,
      anon_sym_try,
      sym_number,
      anon_sym_true,
      anon_sym_false,
      sym_identifier,
      anon_sym_LF,
      anon_sym_CR,
  [4396] = 5,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(381), 4,
      sym_command_name,
      sym__single_quote_string_start,
      sym__double_quote_string_start,
      sym__multioutput_variable_start,
    ACTIONS(378), 8,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
    ACTIONS(364), 14,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
    ACTIONS(374), 33,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_AT,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_LBRACK,
      anon_sym_LBRACE,
      anon_sym_COLON,
      sym_return_statement,
      sym_continue_statement,
      sym_break_statement,
      anon_sym_elseif,
      anon_sym_else,
      anon_sym_if,
      anon_sym_end,
      anon_sym_for,
      anon_sym_parfor,
      anon_sym_while,
      anon_sym_switch,
      anon_sym_global,
      anon_sym_persistent,
      anon_sym_function,
      anon_sym_classdef,
      anon_sym_try,
      sym_number,
      anon_sym_true,
      anon_sym_false,
      sym_identifier,
      anon_sym_LF,
      anon_sym_CR,
  [4468] = 4,
    ACTIONS(542), 1,
      anon_sym_COLON,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(544), 4,
      sym_command_name,
      sym__single_quote_string_start,
      sym__double_quote_string_start,
      sym__multioutput_variable_start,
    ACTIONS(540), 54,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_AT,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_LBRACK,
      anon_sym_LBRACE,
      sym_return_statement,
      sym_continue_statement,
      sym_break_statement,
      anon_sym_elseif,
      anon_sym_else,
      anon_sym_if,
      anon_sym_end,
      anon_sym_for,
      anon_sym_parfor,
      anon_sym_while,
      anon_sym_switch,
      anon_sym_global,
      anon_sym_persistent,
      anon_sym_function,
      anon_sym_classdef,
      anon_sym_try,
      sym_number,
      anon_sym_true,
      anon_sym_false,
      sym_identifier,
      anon_sym_LF,
      anon_sym_CR,
  [4538] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(548), 4,
      sym_command_name,
      sym__single_quote_string_start,
      sym__double_quote_string_start,
      sym__multioutput_variable_start,
    ACTIONS(546), 55,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_AT,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_LBRACK,
      anon_sym_LBRACE,
      anon_sym_COLON,
      sym_return_statement,
      sym_continue_statement,
      sym_break_statement,
      anon_sym_elseif,
      anon_sym_else,
      anon_sym_if,
      anon_sym_end,
      anon_sym_for,
      anon_sym_parfor,
      anon_sym_while,
      anon_sym_switch,
      anon_sym_global,
      anon_sym_persistent,
      anon_sym_function,
      anon_sym_classdef,
      anon_sym_try,
      sym_number,
      anon_sym_true,
      anon_sym_false,
      sym_identifier,
      anon_sym_LF,
      anon_sym_CR,
  [4606] = 5,
    ACTIONS(378), 1,
      anon_sym_COLON,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(376), 4,
      sym_command_name,
      sym__single_quote_string_start,
      sym__double_quote_string_start,
      sym__multioutput_variable_start,
    ACTIONS(364), 14,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
    ACTIONS(360), 40,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_AT,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_LBRACK,
      anon_sym_LBRACE,
      sym_return_statement,
      sym_continue_statement,
      sym_break_statement,
      anon_sym_elseif,
      anon_sym_else,
      anon_sym_if,
      anon_sym_end,
      anon_sym_for,
      anon_sym_parfor,
      anon_sym_while,
      anon_sym_switch,
      anon_sym_global,
      anon_sym_persistent,
      anon_sym_function,
      anon_sym_classdef,
      anon_sym_try,
      sym_number,
      anon_sym_true,
      anon_sym_false,
      sym_identifier,
      anon_sym_LF,
      anon_sym_CR,
  [4678] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(552), 4,
      sym_command_name,
      sym__single_quote_string_start,
      sym__double_quote_string_start,
      sym__multioutput_variable_start,
    ACTIONS(550), 55,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_AT,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_LBRACK,
      anon_sym_LBRACE,
      anon_sym_COLON,
      sym_return_statement,
      sym_continue_statement,
      sym_break_statement,
      anon_sym_elseif,
      anon_sym_else,
      anon_sym_if,
      anon_sym_end,
      anon_sym_for,
      anon_sym_parfor,
      anon_sym_while,
      anon_sym_switch,
      anon_sym_global,
      anon_sym_persistent,
      anon_sym_function,
      anon_sym_classdef,
      anon_sym_try,
      sym_number,
      anon_sym_true,
      anon_sym_false,
      sym_identifier,
      anon_sym_LF,
      anon_sym_CR,
  [4746] = 6,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(560), 2,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
    ACTIONS(556), 4,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
    ACTIONS(562), 4,
      sym_command_name,
      sym__single_quote_string_start,
      sym__double_quote_string_start,
      sym__multioutput_variable_start,
    ACTIONS(558), 6,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
    ACTIONS(554), 43,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_AT,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_LBRACK,
      anon_sym_LBRACE,
      anon_sym_COLON,
      sym_return_statement,
      sym_continue_statement,
      sym_break_statement,
      anon_sym_elseif,
      anon_sym_else,
      anon_sym_if,
      anon_sym_end,
      anon_sym_for,
      anon_sym_parfor,
      anon_sym_while,
      anon_sym_switch,
      anon_sym_global,
      anon_sym_persistent,
      anon_sym_function,
      anon_sym_classdef,
      anon_sym_try,
      sym_number,
      anon_sym_true,
      anon_sym_false,
      sym_identifier,
      anon_sym_LF,
      anon_sym_CR,
  [4820] = 7,
    ACTIONS(564), 1,
      anon_sym_AMP,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(560), 2,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
    ACTIONS(556), 4,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
    ACTIONS(562), 4,
      sym_command_name,
      sym__single_quote_string_start,
      sym__double_quote_string_start,
      sym__multioutput_variable_start,
    ACTIONS(558), 6,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
    ACTIONS(554), 42,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_PIPE,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_AT,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_LBRACK,
      anon_sym_LBRACE,
      anon_sym_COLON,
      sym_return_statement,
      sym_continue_statement,
      sym_break_statement,
      anon_sym_elseif,
      anon_sym_else,
      anon_sym_if,
      anon_sym_end,
      anon_sym_for,
      anon_sym_parfor,
      anon_sym_while,
      anon_sym_switch,
      anon_sym_global,
      anon_sym_persistent,
      anon_sym_function,
      anon_sym_classdef,
      anon_sym_try,
      sym_number,
      anon_sym_true,
      anon_sym_false,
      sym_identifier,
      anon_sym_LF,
      anon_sym_CR,
  [4896] = 4,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(560), 2,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
    ACTIONS(562), 4,
      sym_command_name,
      sym__single_quote_string_start,
      sym__double_quote_string_start,
      sym__multioutput_variable_start,
    ACTIONS(554), 53,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_AT,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_LBRACK,
      anon_sym_LBRACE,
      anon_sym_COLON,
      sym_return_statement,
      sym_continue_statement,
      sym_break_statement,
      anon_sym_elseif,
      anon_sym_else,
      anon_sym_if,
      anon_sym_end,
      anon_sym_for,
      anon_sym_parfor,
      anon_sym_while,
      anon_sym_switch,
      anon_sym_global,
      anon_sym_persistent,
      anon_sym_function,
      anon_sym_classdef,
      anon_sym_try,
      sym_number,
      anon_sym_true,
      anon_sym_false,
      sym_identifier,
      anon_sym_LF,
      anon_sym_CR,
  [4966] = 4,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(560), 2,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
    ACTIONS(562), 4,
      sym_command_name,
      sym__single_quote_string_start,
      sym__double_quote_string_start,
      sym__multioutput_variable_start,
    ACTIONS(554), 53,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_AT,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_LBRACK,
      anon_sym_LBRACE,
      anon_sym_COLON,
      sym_return_statement,
      sym_continue_statement,
      sym_break_statement,
      anon_sym_elseif,
      anon_sym_else,
      anon_sym_if,
      anon_sym_end,
      anon_sym_for,
      anon_sym_parfor,
      anon_sym_while,
      anon_sym_switch,
      anon_sym_global,
      anon_sym_persistent,
      anon_sym_function,
      anon_sym_classdef,
      anon_sym_try,
      sym_number,
      anon_sym_true,
      anon_sym_false,
      sym_identifier,
      anon_sym_LF,
      anon_sym_CR,
  [5036] = 5,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(560), 2,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
    ACTIONS(562), 4,
      sym_command_name,
      sym__single_quote_string_start,
      sym__double_quote_string_start,
      sym__multioutput_variable_start,
    ACTIONS(558), 6,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
    ACTIONS(554), 47,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_AT,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_LBRACK,
      anon_sym_LBRACE,
      anon_sym_COLON,
      sym_return_statement,
      sym_continue_statement,
      sym_break_statement,
      anon_sym_elseif,
      anon_sym_else,
      anon_sym_if,
      anon_sym_end,
      anon_sym_for,
      anon_sym_parfor,
      anon_sym_while,
      anon_sym_switch,
      anon_sym_global,
      anon_sym_persistent,
      anon_sym_function,
      anon_sym_classdef,
      anon_sym_try,
      sym_number,
      anon_sym_true,
      anon_sym_false,
      sym_identifier,
      anon_sym_LF,
      anon_sym_CR,
  [5108] = 5,
    ACTIONS(374), 1,
      anon_sym_COLON,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(376), 4,
      sym_command_name,
      sym__single_quote_string_start,
      sym__double_quote_string_start,
      sym__multioutput_variable_start,
    ACTIONS(364), 14,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
    ACTIONS(360), 38,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_AT,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_LBRACK,
      anon_sym_LBRACE,
      sym_return_statement,
      sym_continue_statement,
      sym_break_statement,
      anon_sym_elseif,
      anon_sym_else,
      anon_sym_if,
      anon_sym_end,
      anon_sym_for,
      anon_sym_parfor,
      anon_sym_while,
      anon_sym_switch,
      anon_sym_global,
      anon_sym_persistent,
      anon_sym_function,
      anon_sym_classdef,
      anon_sym_try,
      sym_number,
      anon_sym_true,
      anon_sym_false,
      sym_identifier,
      anon_sym_LF,
      anon_sym_CR,
  [5178] = 4,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(477), 4,
      sym_command_name,
      sym__single_quote_string_start,
      sym__double_quote_string_start,
      sym__multioutput_variable_start,
    ACTIONS(69), 6,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
    ACTIONS(473), 46,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_AT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_LBRACK,
      anon_sym_LBRACE,
      sym_return_statement,
      sym_continue_statement,
      sym_break_statement,
      anon_sym_elseif,
      anon_sym_else,
      anon_sym_if,
      anon_sym_end,
      anon_sym_for,
      anon_sym_parfor,
      anon_sym_while,
      anon_sym_switch,
      anon_sym_global,
      anon_sym_persistent,
      anon_sym_function,
      anon_sym_classdef,
      anon_sym_try,
      sym_number,
      anon_sym_true,
      anon_sym_false,
      sym_identifier,
      anon_sym_LF,
      anon_sym_CR,
  [5245] = 6,
    ACTIONS(71), 1,
      anon_sym_AMP_AMP,
    ACTIONS(73), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(538), 4,
      sym_command_name,
      sym__single_quote_string_start,
      sym__double_quote_string_start,
      sym__multioutput_variable_start,
    ACTIONS(69), 6,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
    ACTIONS(536), 44,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_AT,
      anon_sym_LBRACK,
      anon_sym_LBRACE,
      sym_return_statement,
      sym_continue_statement,
      sym_break_statement,
      anon_sym_elseif,
      anon_sym_else,
      anon_sym_if,
      anon_sym_end,
      anon_sym_for,
      anon_sym_parfor,
      anon_sym_while,
      anon_sym_switch,
      anon_sym_global,
      anon_sym_persistent,
      anon_sym_function,
      anon_sym_classdef,
      anon_sym_try,
      sym_number,
      anon_sym_true,
      anon_sym_false,
      sym_identifier,
      anon_sym_LF,
      anon_sym_CR,
  [5316] = 5,
    ACTIONS(71), 1,
      anon_sym_AMP_AMP,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(477), 4,
      sym_command_name,
      sym__single_quote_string_start,
      sym__double_quote_string_start,
      sym__multioutput_variable_start,
    ACTIONS(69), 6,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
    ACTIONS(473), 45,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_AT,
      anon_sym_PIPE_PIPE,
      anon_sym_LBRACK,
      anon_sym_LBRACE,
      sym_return_statement,
      sym_continue_statement,
      sym_break_statement,
      anon_sym_elseif,
      anon_sym_else,
      anon_sym_if,
      anon_sym_end,
      anon_sym_for,
      anon_sym_parfor,
      anon_sym_while,
      anon_sym_switch,
      anon_sym_global,
      anon_sym_persistent,
      anon_sym_function,
      anon_sym_classdef,
      anon_sym_try,
      sym_number,
      anon_sym_true,
      anon_sym_false,
      sym_identifier,
      anon_sym_LF,
      anon_sym_CR,
  [5385] = 6,
    ACTIONS(71), 1,
      anon_sym_AMP_AMP,
    ACTIONS(73), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(485), 4,
      sym_command_name,
      sym__single_quote_string_start,
      sym__double_quote_string_start,
      sym__multioutput_variable_start,
    ACTIONS(69), 6,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
    ACTIONS(481), 44,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_AT,
      anon_sym_LBRACK,
      anon_sym_LBRACE,
      sym_return_statement,
      sym_continue_statement,
      sym_break_statement,
      anon_sym_elseif,
      anon_sym_else,
      anon_sym_if,
      anon_sym_end,
      anon_sym_for,
      anon_sym_parfor,
      anon_sym_while,
      anon_sym_switch,
      anon_sym_global,
      anon_sym_persistent,
      anon_sym_function,
      anon_sym_classdef,
      anon_sym_try,
      sym_number,
      anon_sym_true,
      anon_sym_false,
      sym_identifier,
      anon_sym_LF,
      anon_sym_CR,
  [5456] = 6,
    ACTIONS(71), 1,
      anon_sym_AMP_AMP,
    ACTIONS(73), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(497), 4,
      sym_command_name,
      sym__single_quote_string_start,
      sym__double_quote_string_start,
      sym__multioutput_variable_start,
    ACTIONS(69), 6,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
    ACTIONS(495), 44,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_AT,
      anon_sym_LBRACK,
      anon_sym_LBRACE,
      sym_return_statement,
      sym_continue_statement,
      sym_break_statement,
      anon_sym_elseif,
      anon_sym_else,
      anon_sym_if,
      anon_sym_end,
      anon_sym_for,
      anon_sym_parfor,
      anon_sym_while,
      anon_sym_switch,
      anon_sym_global,
      anon_sym_persistent,
      anon_sym_function,
      anon_sym_classdef,
      anon_sym_try,
      sym_number,
      anon_sym_true,
      anon_sym_false,
      sym_identifier,
      anon_sym_LF,
      anon_sym_CR,
  [5527] = 5,
    ACTIONS(566), 1,
      anon_sym_DOT,
    STATE(153), 1,
      aux_sym_handle_operator_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(419), 4,
      sym_command_name,
      sym__single_quote_string_start,
      sym__double_quote_string_start,
      sym__multioutput_variable_start,
    ACTIONS(417), 40,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_AT,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_LBRACK,
      anon_sym_LBRACE,
      sym_return_statement,
      sym_continue_statement,
      sym_break_statement,
      anon_sym_elseif,
      anon_sym_else,
      anon_sym_if,
      anon_sym_end,
      anon_sym_for,
      anon_sym_parfor,
      anon_sym_while,
      anon_sym_switch,
      anon_sym_global,
      anon_sym_persistent,
      anon_sym_function,
      anon_sym_classdef,
      anon_sym_try,
      sym_number,
      anon_sym_true,
      anon_sym_false,
      sym_identifier,
      anon_sym_LF,
      anon_sym_CR,
  [5586] = 5,
    ACTIONS(566), 1,
      anon_sym_DOT,
    STATE(154), 1,
      aux_sym_handle_operator_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(397), 4,
      sym_command_name,
      sym__single_quote_string_start,
      sym__double_quote_string_start,
      sym__multioutput_variable_start,
    ACTIONS(393), 40,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_AT,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_LBRACK,
      anon_sym_LBRACE,
      sym_return_statement,
      sym_continue_statement,
      sym_break_statement,
      anon_sym_elseif,
      anon_sym_else,
      anon_sym_if,
      anon_sym_end,
      anon_sym_for,
      anon_sym_parfor,
      anon_sym_while,
      anon_sym_switch,
      anon_sym_global,
      anon_sym_persistent,
      anon_sym_function,
      anon_sym_classdef,
      anon_sym_try,
      sym_number,
      anon_sym_true,
      anon_sym_false,
      sym_identifier,
      anon_sym_LF,
      anon_sym_CR,
  [5645] = 5,
    ACTIONS(568), 1,
      anon_sym_DOT,
    STATE(154), 1,
      aux_sym_handle_operator_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(415), 4,
      sym_command_name,
      sym__single_quote_string_start,
      sym__double_quote_string_start,
      sym__multioutput_variable_start,
    ACTIONS(410), 40,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_AT,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_LBRACK,
      anon_sym_LBRACE,
      sym_return_statement,
      sym_continue_statement,
      sym_break_statement,
      anon_sym_elseif,
      anon_sym_else,
      anon_sym_if,
      anon_sym_end,
      anon_sym_for,
      anon_sym_parfor,
      anon_sym_while,
      anon_sym_switch,
      anon_sym_global,
      anon_sym_persistent,
      anon_sym_function,
      anon_sym_classdef,
      anon_sym_try,
      sym_number,
      anon_sym_true,
      anon_sym_false,
      sym_identifier,
      anon_sym_LF,
      anon_sym_CR,
  [5704] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(415), 4,
      sym_command_name,
      sym__single_quote_string_start,
      sym__double_quote_string_start,
      sym__multioutput_variable_start,
    ACTIONS(410), 41,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_DOT,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_AT,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_LBRACK,
      anon_sym_LBRACE,
      sym_return_statement,
      sym_continue_statement,
      sym_break_statement,
      anon_sym_elseif,
      anon_sym_else,
      anon_sym_if,
      anon_sym_end,
      anon_sym_for,
      anon_sym_parfor,
      anon_sym_while,
      anon_sym_switch,
      anon_sym_global,
      anon_sym_persistent,
      anon_sym_function,
      anon_sym_classdef,
      anon_sym_try,
      sym_number,
      anon_sym_true,
      anon_sym_false,
      sym_identifier,
      anon_sym_LF,
      anon_sym_CR,
  [5758] = 30,
    ACTIONS(571), 1,
      sym_identifier,
    ACTIONS(575), 1,
      anon_sym_COMMA,
    ACTIONS(577), 1,
      anon_sym_LPAREN,
    ACTIONS(581), 1,
      anon_sym_TILDE,
    ACTIONS(583), 1,
      anon_sym_QMARK,
    ACTIONS(585), 1,
      anon_sym_AT,
    ACTIONS(587), 1,
      anon_sym_LBRACK,
    ACTIONS(589), 1,
      aux_sym_matrix_token1,
    ACTIONS(591), 1,
      anon_sym_LBRACE,
    ACTIONS(593), 1,
      sym_number,
    ACTIONS(597), 1,
      sym__single_quote_string_start,
    ACTIONS(599), 1,
      sym__double_quote_string_start,
    STATE(216), 1,
      sym_function_call,
    STATE(363), 1,
      sym_boolean,
    STATE(508), 1,
      sym_unary_operator,
    STATE(509), 1,
      sym_binary_operator,
    STATE(510), 1,
      sym_cell,
    STATE(525), 1,
      sym_not_operator,
    STATE(615), 1,
      sym__binary_expression,
    STATE(796), 1,
      sym_ignored_argument,
    STATE(919), 1,
      sym_indirect_access,
    STATE(976), 1,
      sym_row,
    STATE(1179), 1,
      sym__range_element,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(579), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(595), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(511), 2,
      sym_comparison_operator,
      sym_boolean_operator,
    ACTIONS(573), 3,
      anon_sym_SEMI,
      anon_sym_RBRACK,
      anon_sym_RBRACE,
    STATE(507), 5,
      sym_parenthesis,
      sym_field_expression,
      sym_postfix_operator,
      sym_string,
      sym_matrix,
    STATE(616), 5,
      sym__expression,
      sym_metaclass_operator,
      sym_handle_operator,
      sym_range,
      sym_lambda,
  [5863] = 6,
    ACTIONS(71), 1,
      anon_sym_AMP_AMP,
    ACTIONS(73), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(603), 4,
      sym_command_name,
      sym__single_quote_string_start,
      sym__double_quote_string_start,
      sym__multioutput_variable_start,
    ACTIONS(69), 6,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
    ACTIONS(601), 30,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_AT,
      anon_sym_LBRACK,
      anon_sym_LBRACE,
      sym_return_statement,
      sym_continue_statement,
      sym_break_statement,
      anon_sym_if,
      anon_sym_end,
      anon_sym_for,
      anon_sym_parfor,
      anon_sym_while,
      anon_sym_switch,
      anon_sym_global,
      anon_sym_persistent,
      anon_sym_function,
      anon_sym_classdef,
      anon_sym_try,
      sym_number,
      anon_sym_true,
      anon_sym_false,
      sym_identifier,
      anon_sym_LF,
      anon_sym_CR,
  [5920] = 5,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    STATE(158), 2,
      sym__end_of_line,
      aux_sym_elseif_clause_repeat1,
    ACTIONS(607), 4,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_CR,
    ACTIONS(610), 4,
      sym_command_name,
      sym__single_quote_string_start,
      sym__double_quote_string_start,
      sym__multioutput_variable_start,
    ACTIONS(605), 31,
      anon_sym_LPAREN,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_AT,
      anon_sym_LBRACK,
      anon_sym_LBRACE,
      sym_return_statement,
      sym_continue_statement,
      sym_break_statement,
      anon_sym_elseif,
      anon_sym_else,
      anon_sym_if,
      anon_sym_end,
      anon_sym_for,
      anon_sym_parfor,
      anon_sym_while,
      anon_sym_case,
      anon_sym_otherwise,
      anon_sym_switch,
      anon_sym_global,
      anon_sym_persistent,
      anon_sym_function,
      anon_sym_classdef,
      anon_sym_catch,
      anon_sym_try,
      sym_number,
      anon_sym_true,
      anon_sym_false,
      sym_identifier,
  [5974] = 28,
    ACTIONS(571), 1,
      sym_identifier,
    ACTIONS(577), 1,
      anon_sym_LPAREN,
    ACTIONS(581), 1,
      anon_sym_TILDE,
    ACTIONS(583), 1,
      anon_sym_QMARK,
    ACTIONS(585), 1,
      anon_sym_AT,
    ACTIONS(587), 1,
      anon_sym_LBRACK,
    ACTIONS(591), 1,
      anon_sym_LBRACE,
    ACTIONS(593), 1,
      sym_number,
    ACTIONS(597), 1,
      sym__single_quote_string_start,
    ACTIONS(599), 1,
      sym__double_quote_string_start,
    ACTIONS(614), 1,
      aux_sym_matrix_token1,
    STATE(216), 1,
      sym_function_call,
    STATE(363), 1,
      sym_boolean,
    STATE(508), 1,
      sym_unary_operator,
    STATE(509), 1,
      sym_binary_operator,
    STATE(510), 1,
      sym_cell,
    STATE(525), 1,
      sym_not_operator,
    STATE(615), 1,
      sym__binary_expression,
    STATE(847), 1,
      sym_ignored_argument,
    STATE(919), 1,
      sym_indirect_access,
    STATE(1179), 1,
      sym__range_element,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(579), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(595), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(511), 2,
      sym_comparison_operator,
      sym_boolean_operator,
    ACTIONS(612), 3,
      anon_sym_SEMI,
      anon_sym_RBRACK,
      anon_sym_RBRACE,
    STATE(507), 5,
      sym_parenthesis,
      sym_field_expression,
      sym_postfix_operator,
      sym_string,
      sym_matrix,
    STATE(624), 5,
      sym__expression,
      sym_metaclass_operator,
      sym_handle_operator,
      sym_range,
      sym_lambda,
  [6073] = 28,
    ACTIONS(571), 1,
      sym_identifier,
    ACTIONS(577), 1,
      anon_sym_LPAREN,
    ACTIONS(581), 1,
      anon_sym_TILDE,
    ACTIONS(583), 1,
      anon_sym_QMARK,
    ACTIONS(585), 1,
      anon_sym_AT,
    ACTIONS(587), 1,
      anon_sym_LBRACK,
    ACTIONS(591), 1,
      anon_sym_LBRACE,
    ACTIONS(593), 1,
      sym_number,
    ACTIONS(597), 1,
      sym__single_quote_string_start,
    ACTIONS(599), 1,
      sym__double_quote_string_start,
    ACTIONS(618), 1,
      aux_sym_matrix_token1,
    STATE(216), 1,
      sym_function_call,
    STATE(363), 1,
      sym_boolean,
    STATE(508), 1,
      sym_unary_operator,
    STATE(509), 1,
      sym_binary_operator,
    STATE(510), 1,
      sym_cell,
    STATE(525), 1,
      sym_not_operator,
    STATE(615), 1,
      sym__binary_expression,
    STATE(847), 1,
      sym_ignored_argument,
    STATE(919), 1,
      sym_indirect_access,
    STATE(1179), 1,
      sym__range_element,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(579), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(595), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(511), 2,
      sym_comparison_operator,
      sym_boolean_operator,
    ACTIONS(616), 3,
      anon_sym_SEMI,
      anon_sym_RBRACK,
      anon_sym_RBRACE,
    STATE(507), 5,
      sym_parenthesis,
      sym_field_expression,
      sym_postfix_operator,
      sym_string,
      sym_matrix,
    STATE(624), 5,
      sym__expression,
      sym_metaclass_operator,
      sym_handle_operator,
      sym_range,
      sym_lambda,
  [6172] = 27,
    ACTIONS(577), 1,
      anon_sym_LPAREN,
    ACTIONS(587), 1,
      anon_sym_LBRACK,
    ACTIONS(591), 1,
      anon_sym_LBRACE,
    ACTIONS(597), 1,
      sym__single_quote_string_start,
    ACTIONS(599), 1,
      sym__double_quote_string_start,
    ACTIONS(620), 1,
      sym_identifier,
    ACTIONS(624), 1,
      anon_sym_TILDE,
    ACTIONS(626), 1,
      anon_sym_QMARK,
    ACTIONS(628), 1,
      anon_sym_AT,
    ACTIONS(632), 1,
      sym_number,
    STATE(207), 1,
      sym_function_call,
    STATE(359), 1,
      sym_boolean,
    STATE(466), 1,
      sym_unary_operator,
    STATE(469), 1,
      sym_not_operator,
    STATE(499), 1,
      sym_binary_operator,
    STATE(510), 1,
      sym_cell,
    STATE(615), 1,
      sym__binary_expression,
    STATE(919), 1,
      sym_indirect_access,
    STATE(1179), 1,
      sym__range_element,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(579), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(595), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(630), 2,
      sym__entry_delimiter,
      aux_sym_matrix_token1,
    STATE(511), 2,
      sym_comparison_operator,
      sym_boolean_operator,
    ACTIONS(622), 3,
      anon_sym_SEMI,
      anon_sym_RBRACK,
      anon_sym_RBRACE,
    STATE(463), 5,
      sym_parenthesis,
      sym_field_expression,
      sym_postfix_operator,
      sym_string,
      sym_matrix,
    STATE(494), 5,
      sym__expression,
      sym_metaclass_operator,
      sym_handle_operator,
      sym_range,
      sym_lambda,
  [6269] = 28,
    ACTIONS(571), 1,
      sym_identifier,
    ACTIONS(577), 1,
      anon_sym_LPAREN,
    ACTIONS(581), 1,
      anon_sym_TILDE,
    ACTIONS(583), 1,
      anon_sym_QMARK,
    ACTIONS(585), 1,
      anon_sym_AT,
    ACTIONS(587), 1,
      anon_sym_LBRACK,
    ACTIONS(591), 1,
      anon_sym_LBRACE,
    ACTIONS(593), 1,
      sym_number,
    ACTIONS(597), 1,
      sym__single_quote_string_start,
    ACTIONS(599), 1,
      sym__double_quote_string_start,
    ACTIONS(636), 1,
      aux_sym_matrix_token1,
    STATE(216), 1,
      sym_function_call,
    STATE(363), 1,
      sym_boolean,
    STATE(508), 1,
      sym_unary_operator,
    STATE(509), 1,
      sym_binary_operator,
    STATE(510), 1,
      sym_cell,
    STATE(525), 1,
      sym_not_operator,
    STATE(615), 1,
      sym__binary_expression,
    STATE(847), 1,
      sym_ignored_argument,
    STATE(919), 1,
      sym_indirect_access,
    STATE(1179), 1,
      sym__range_element,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(579), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(595), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(511), 2,
      sym_comparison_operator,
      sym_boolean_operator,
    ACTIONS(634), 3,
      anon_sym_SEMI,
      anon_sym_RBRACK,
      anon_sym_RBRACE,
    STATE(507), 5,
      sym_parenthesis,
      sym_field_expression,
      sym_postfix_operator,
      sym_string,
      sym_matrix,
    STATE(624), 5,
      sym__expression,
      sym_metaclass_operator,
      sym_handle_operator,
      sym_range,
      sym_lambda,
  [6368] = 29,
    ACTIONS(638), 1,
      sym_identifier,
    ACTIONS(640), 1,
      anon_sym_LPAREN,
    ACTIONS(644), 1,
      anon_sym_TILDE,
    ACTIONS(646), 1,
      anon_sym_QMARK,
    ACTIONS(648), 1,
      anon_sym_AT,
    ACTIONS(650), 1,
      anon_sym_LBRACK,
    ACTIONS(652), 1,
      anon_sym_LBRACE,
    ACTIONS(654), 1,
      anon_sym_RBRACE,
    ACTIONS(656), 1,
      anon_sym_COLON,
    ACTIONS(658), 1,
      sym_number,
    ACTIONS(662), 1,
      sym__single_quote_string_start,
    ACTIONS(664), 1,
      sym__double_quote_string_start,
    STATE(367), 1,
      sym_function_call,
    STATE(402), 1,
      sym_boolean,
    STATE(518), 1,
      sym_cell,
    STATE(530), 1,
      sym_binary_operator,
    STATE(542), 1,
      sym_unary_operator,
    STATE(586), 1,
      sym_not_operator,
    STATE(614), 1,
      sym__binary_expression,
    STATE(905), 1,
      sym_indirect_access,
    STATE(984), 1,
      sym_spread_operator,
    STATE(1141), 1,
      sym_arguments,
    STATE(1196), 1,
      sym__range_element,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(642), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(660), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(520), 2,
      sym_comparison_operator,
      sym_boolean_operator,
    STATE(521), 5,
      sym_parenthesis,
      sym_field_expression,
      sym_postfix_operator,
      sym_string,
      sym_matrix,
    STATE(634), 5,
      sym__expression,
      sym_metaclass_operator,
      sym_handle_operator,
      sym_range,
      sym_lambda,
  [6468] = 29,
    ACTIONS(638), 1,
      sym_identifier,
    ACTIONS(640), 1,
      anon_sym_LPAREN,
    ACTIONS(644), 1,
      anon_sym_TILDE,
    ACTIONS(646), 1,
      anon_sym_QMARK,
    ACTIONS(648), 1,
      anon_sym_AT,
    ACTIONS(650), 1,
      anon_sym_LBRACK,
    ACTIONS(652), 1,
      anon_sym_LBRACE,
    ACTIONS(656), 1,
      anon_sym_COLON,
    ACTIONS(658), 1,
      sym_number,
    ACTIONS(662), 1,
      sym__single_quote_string_start,
    ACTIONS(664), 1,
      sym__double_quote_string_start,
    ACTIONS(666), 1,
      anon_sym_RBRACE,
    STATE(367), 1,
      sym_function_call,
    STATE(402), 1,
      sym_boolean,
    STATE(518), 1,
      sym_cell,
    STATE(530), 1,
      sym_binary_operator,
    STATE(542), 1,
      sym_unary_operator,
    STATE(586), 1,
      sym_not_operator,
    STATE(614), 1,
      sym__binary_expression,
    STATE(905), 1,
      sym_indirect_access,
    STATE(984), 1,
      sym_spread_operator,
    STATE(1151), 1,
      sym_arguments,
    STATE(1196), 1,
      sym__range_element,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(642), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(660), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(520), 2,
      sym_comparison_operator,
      sym_boolean_operator,
    STATE(521), 5,
      sym_parenthesis,
      sym_field_expression,
      sym_postfix_operator,
      sym_string,
      sym_matrix,
    STATE(634), 5,
      sym__expression,
      sym_metaclass_operator,
      sym_handle_operator,
      sym_range,
      sym_lambda,
  [6568] = 29,
    ACTIONS(638), 1,
      sym_identifier,
    ACTIONS(640), 1,
      anon_sym_LPAREN,
    ACTIONS(644), 1,
      anon_sym_TILDE,
    ACTIONS(646), 1,
      anon_sym_QMARK,
    ACTIONS(648), 1,
      anon_sym_AT,
    ACTIONS(650), 1,
      anon_sym_LBRACK,
    ACTIONS(652), 1,
      anon_sym_LBRACE,
    ACTIONS(656), 1,
      anon_sym_COLON,
    ACTIONS(658), 1,
      sym_number,
    ACTIONS(662), 1,
      sym__single_quote_string_start,
    ACTIONS(664), 1,
      sym__double_quote_string_start,
    ACTIONS(668), 1,
      anon_sym_RBRACE,
    STATE(367), 1,
      sym_function_call,
    STATE(402), 1,
      sym_boolean,
    STATE(518), 1,
      sym_cell,
    STATE(530), 1,
      sym_binary_operator,
    STATE(542), 1,
      sym_unary_operator,
    STATE(586), 1,
      sym_not_operator,
    STATE(614), 1,
      sym__binary_expression,
    STATE(905), 1,
      sym_indirect_access,
    STATE(984), 1,
      sym_spread_operator,
    STATE(1168), 1,
      sym_arguments,
    STATE(1196), 1,
      sym__range_element,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(642), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(660), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(520), 2,
      sym_comparison_operator,
      sym_boolean_operator,
    STATE(521), 5,
      sym_parenthesis,
      sym_field_expression,
      sym_postfix_operator,
      sym_string,
      sym_matrix,
    STATE(634), 5,
      sym__expression,
      sym_metaclass_operator,
      sym_handle_operator,
      sym_range,
      sym_lambda,
  [6668] = 29,
    ACTIONS(571), 1,
      sym_identifier,
    ACTIONS(597), 1,
      sym__single_quote_string_start,
    ACTIONS(599), 1,
      sym__double_quote_string_start,
    ACTIONS(670), 1,
      anon_sym_COMMA,
    ACTIONS(672), 1,
      anon_sym_LPAREN,
    ACTIONS(676), 1,
      anon_sym_TILDE,
    ACTIONS(678), 1,
      anon_sym_QMARK,
    ACTIONS(680), 1,
      anon_sym_AT,
    ACTIONS(682), 1,
      anon_sym_LBRACK,
    ACTIONS(684), 1,
      anon_sym_RBRACK,
    ACTIONS(686), 1,
      anon_sym_LBRACE,
    ACTIONS(688), 1,
      sym_number,
    STATE(216), 1,
      sym_function_call,
    STATE(363), 1,
      sym_boolean,
    STATE(508), 1,
      sym_unary_operator,
    STATE(509), 1,
      sym_binary_operator,
    STATE(510), 1,
      sym_cell,
    STATE(525), 1,
      sym_not_operator,
    STATE(615), 1,
      sym__binary_expression,
    STATE(796), 1,
      sym_ignored_argument,
    STATE(919), 1,
      sym_indirect_access,
    STATE(939), 1,
      sym_row,
    STATE(1179), 1,
      sym__range_element,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(595), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(674), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    STATE(511), 2,
      sym_comparison_operator,
      sym_boolean_operator,
    STATE(507), 5,
      sym_parenthesis,
      sym_field_expression,
      sym_postfix_operator,
      sym_string,
      sym_matrix,
    STATE(616), 5,
      sym__expression,
      sym_metaclass_operator,
      sym_handle_operator,
      sym_range,
      sym_lambda,
  [6768] = 29,
    ACTIONS(640), 1,
      anon_sym_LPAREN,
    ACTIONS(644), 1,
      anon_sym_TILDE,
    ACTIONS(646), 1,
      anon_sym_QMARK,
    ACTIONS(648), 1,
      anon_sym_AT,
    ACTIONS(650), 1,
      anon_sym_LBRACK,
    ACTIONS(652), 1,
      anon_sym_LBRACE,
    ACTIONS(654), 1,
      anon_sym_RPAREN,
    ACTIONS(656), 1,
      anon_sym_COLON,
    ACTIONS(658), 1,
      sym_number,
    ACTIONS(662), 1,
      sym__single_quote_string_start,
    ACTIONS(664), 1,
      sym__double_quote_string_start,
    ACTIONS(690), 1,
      sym_identifier,
    STATE(380), 1,
      sym_function_call,
    STATE(402), 1,
      sym_boolean,
    STATE(518), 1,
      sym_cell,
    STATE(564), 1,
      sym_binary_operator,
    STATE(565), 1,
      sym_unary_operator,
    STATE(586), 1,
      sym_not_operator,
    STATE(614), 1,
      sym__binary_expression,
    STATE(905), 1,
      sym_indirect_access,
    STATE(984), 1,
      sym_spread_operator,
    STATE(1150), 1,
      sym_arguments,
    STATE(1196), 1,
      sym__range_element,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(642), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(660), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(520), 2,
      sym_comparison_operator,
      sym_boolean_operator,
    STATE(570), 5,
      sym_parenthesis,
      sym_field_expression,
      sym_postfix_operator,
      sym_string,
      sym_matrix,
    STATE(634), 5,
      sym__expression,
      sym_metaclass_operator,
      sym_handle_operator,
      sym_range,
      sym_lambda,
  [6868] = 5,
    STATE(170), 1,
      aux_sym__block_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(696), 2,
      anon_sym_SEMI,
      anon_sym_COMMA,
    ACTIONS(692), 14,
      sym_command_name,
      sym__single_quote_string_start,
      sym__double_quote_string_start,
      sym__multioutput_variable_start,
      ts_builtin_sym_end,
      anon_sym_LPAREN,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_AT,
      anon_sym_LBRACK,
      anon_sym_LBRACE,
      sym_number,
    ACTIONS(694), 22,
      sym_return_statement,
      sym_continue_statement,
      sym_break_statement,
      anon_sym_elseif,
      anon_sym_else,
      anon_sym_if,
      anon_sym_end,
      anon_sym_for,
      anon_sym_parfor,
      anon_sym_while,
      anon_sym_case,
      anon_sym_otherwise,
      anon_sym_switch,
      anon_sym_global,
      anon_sym_persistent,
      anon_sym_function,
      anon_sym_classdef,
      anon_sym_catch,
      anon_sym_try,
      anon_sym_true,
      anon_sym_false,
      sym_identifier,
  [6920] = 29,
    ACTIONS(571), 1,
      sym_identifier,
    ACTIONS(597), 1,
      sym__single_quote_string_start,
    ACTIONS(599), 1,
      sym__double_quote_string_start,
    ACTIONS(670), 1,
      anon_sym_COMMA,
    ACTIONS(672), 1,
      anon_sym_LPAREN,
    ACTIONS(676), 1,
      anon_sym_TILDE,
    ACTIONS(678), 1,
      anon_sym_QMARK,
    ACTIONS(680), 1,
      anon_sym_AT,
    ACTIONS(682), 1,
      anon_sym_LBRACK,
    ACTIONS(686), 1,
      anon_sym_LBRACE,
    ACTIONS(688), 1,
      sym_number,
    ACTIONS(698), 1,
      anon_sym_RBRACK,
    STATE(216), 1,
      sym_function_call,
    STATE(363), 1,
      sym_boolean,
    STATE(508), 1,
      sym_unary_operator,
    STATE(509), 1,
      sym_binary_operator,
    STATE(510), 1,
      sym_cell,
    STATE(525), 1,
      sym_not_operator,
    STATE(615), 1,
      sym__binary_expression,
    STATE(796), 1,
      sym_ignored_argument,
    STATE(919), 1,
      sym_indirect_access,
    STATE(996), 1,
      sym_row,
    STATE(1179), 1,
      sym__range_element,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(595), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(674), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    STATE(511), 2,
      sym_comparison_operator,
      sym_boolean_operator,
    STATE(507), 5,
      sym_parenthesis,
      sym_field_expression,
      sym_postfix_operator,
      sym_string,
      sym_matrix,
    STATE(616), 5,
      sym__expression,
      sym_metaclass_operator,
      sym_handle_operator,
      sym_range,
      sym_lambda,
  [7020] = 5,
    STATE(175), 1,
      aux_sym__block_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(704), 2,
      anon_sym_SEMI,
      anon_sym_COMMA,
    ACTIONS(700), 14,
      sym_command_name,
      sym__single_quote_string_start,
      sym__double_quote_string_start,
      sym__multioutput_variable_start,
      ts_builtin_sym_end,
      anon_sym_LPAREN,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_AT,
      anon_sym_LBRACK,
      anon_sym_LBRACE,
      sym_number,
    ACTIONS(702), 22,
      sym_return_statement,
      sym_continue_statement,
      sym_break_statement,
      anon_sym_elseif,
      anon_sym_else,
      anon_sym_if,
      anon_sym_end,
      anon_sym_for,
      anon_sym_parfor,
      anon_sym_while,
      anon_sym_case,
      anon_sym_otherwise,
      anon_sym_switch,
      anon_sym_global,
      anon_sym_persistent,
      anon_sym_function,
      anon_sym_classdef,
      anon_sym_catch,
      anon_sym_try,
      anon_sym_true,
      anon_sym_false,
      sym_identifier,
  [7072] = 29,
    ACTIONS(571), 1,
      sym_identifier,
    ACTIONS(597), 1,
      sym__single_quote_string_start,
    ACTIONS(599), 1,
      sym__double_quote_string_start,
    ACTIONS(670), 1,
      anon_sym_COMMA,
    ACTIONS(672), 1,
      anon_sym_LPAREN,
    ACTIONS(676), 1,
      anon_sym_TILDE,
    ACTIONS(678), 1,
      anon_sym_QMARK,
    ACTIONS(680), 1,
      anon_sym_AT,
    ACTIONS(682), 1,
      anon_sym_LBRACK,
    ACTIONS(686), 1,
      anon_sym_LBRACE,
    ACTIONS(688), 1,
      sym_number,
    ACTIONS(706), 1,
      anon_sym_RBRACE,
    STATE(216), 1,
      sym_function_call,
    STATE(363), 1,
      sym_boolean,
    STATE(508), 1,
      sym_unary_operator,
    STATE(509), 1,
      sym_binary_operator,
    STATE(510), 1,
      sym_cell,
    STATE(525), 1,
      sym_not_operator,
    STATE(615), 1,
      sym__binary_expression,
    STATE(796), 1,
      sym_ignored_argument,
    STATE(904), 1,
      sym_row,
    STATE(919), 1,
      sym_indirect_access,
    STATE(1179), 1,
      sym__range_element,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(595), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(674), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    STATE(511), 2,
      sym_comparison_operator,
      sym_boolean_operator,
    STATE(507), 5,
      sym_parenthesis,
      sym_field_expression,
      sym_postfix_operator,
      sym_string,
      sym_matrix,
    STATE(616), 5,
      sym__expression,
      sym_metaclass_operator,
      sym_handle_operator,
      sym_range,
      sym_lambda,
  [7172] = 29,
    ACTIONS(571), 1,
      sym_identifier,
    ACTIONS(597), 1,
      sym__single_quote_string_start,
    ACTIONS(599), 1,
      sym__double_quote_string_start,
    ACTIONS(670), 1,
      anon_sym_COMMA,
    ACTIONS(672), 1,
      anon_sym_LPAREN,
    ACTIONS(676), 1,
      anon_sym_TILDE,
    ACTIONS(678), 1,
      anon_sym_QMARK,
    ACTIONS(680), 1,
      anon_sym_AT,
    ACTIONS(682), 1,
      anon_sym_LBRACK,
    ACTIONS(686), 1,
      anon_sym_LBRACE,
    ACTIONS(688), 1,
      sym_number,
    ACTIONS(708), 1,
      anon_sym_RBRACK,
    STATE(216), 1,
      sym_function_call,
    STATE(363), 1,
      sym_boolean,
    STATE(508), 1,
      sym_unary_operator,
    STATE(509), 1,
      sym_binary_operator,
    STATE(510), 1,
      sym_cell,
    STATE(525), 1,
      sym_not_operator,
    STATE(615), 1,
      sym__binary_expression,
    STATE(796), 1,
      sym_ignored_argument,
    STATE(919), 1,
      sym_indirect_access,
    STATE(967), 1,
      sym_row,
    STATE(1179), 1,
      sym__range_element,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(595), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(674), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    STATE(511), 2,
      sym_comparison_operator,
      sym_boolean_operator,
    STATE(507), 5,
      sym_parenthesis,
      sym_field_expression,
      sym_postfix_operator,
      sym_string,
      sym_matrix,
    STATE(616), 5,
      sym__expression,
      sym_metaclass_operator,
      sym_handle_operator,
      sym_range,
      sym_lambda,
  [7272] = 29,
    ACTIONS(571), 1,
      sym_identifier,
    ACTIONS(597), 1,
      sym__single_quote_string_start,
    ACTIONS(599), 1,
      sym__double_quote_string_start,
    ACTIONS(670), 1,
      anon_sym_COMMA,
    ACTIONS(672), 1,
      anon_sym_LPAREN,
    ACTIONS(676), 1,
      anon_sym_TILDE,
    ACTIONS(678), 1,
      anon_sym_QMARK,
    ACTIONS(680), 1,
      anon_sym_AT,
    ACTIONS(682), 1,
      anon_sym_LBRACK,
    ACTIONS(686), 1,
      anon_sym_LBRACE,
    ACTIONS(688), 1,
      sym_number,
    ACTIONS(710), 1,
      anon_sym_RBRACE,
    STATE(216), 1,
      sym_function_call,
    STATE(363), 1,
      sym_boolean,
    STATE(508), 1,
      sym_unary_operator,
    STATE(509), 1,
      sym_binary_operator,
    STATE(510), 1,
      sym_cell,
    STATE(525), 1,
      sym_not_operator,
    STATE(615), 1,
      sym__binary_expression,
    STATE(796), 1,
      sym_ignored_argument,
    STATE(919), 1,
      sym_indirect_access,
    STATE(957), 1,
      sym_row,
    STATE(1179), 1,
      sym__range_element,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(595), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(674), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    STATE(511), 2,
      sym_comparison_operator,
      sym_boolean_operator,
    STATE(507), 5,
      sym_parenthesis,
      sym_field_expression,
      sym_postfix_operator,
      sym_string,
      sym_matrix,
    STATE(616), 5,
      sym__expression,
      sym_metaclass_operator,
      sym_handle_operator,
      sym_range,
      sym_lambda,
  [7372] = 29,
    ACTIONS(571), 1,
      sym_identifier,
    ACTIONS(597), 1,
      sym__single_quote_string_start,
    ACTIONS(599), 1,
      sym__double_quote_string_start,
    ACTIONS(670), 1,
      anon_sym_COMMA,
    ACTIONS(672), 1,
      anon_sym_LPAREN,
    ACTIONS(676), 1,
      anon_sym_TILDE,
    ACTIONS(678), 1,
      anon_sym_QMARK,
    ACTIONS(680), 1,
      anon_sym_AT,
    ACTIONS(682), 1,
      anon_sym_LBRACK,
    ACTIONS(686), 1,
      anon_sym_LBRACE,
    ACTIONS(688), 1,
      sym_number,
    ACTIONS(712), 1,
      anon_sym_RBRACK,
    STATE(216), 1,
      sym_function_call,
    STATE(363), 1,
      sym_boolean,
    STATE(508), 1,
      sym_unary_operator,
    STATE(509), 1,
      sym_binary_operator,
    STATE(510), 1,
      sym_cell,
    STATE(525), 1,
      sym_not_operator,
    STATE(615), 1,
      sym__binary_expression,
    STATE(796), 1,
      sym_ignored_argument,
    STATE(893), 1,
      sym_row,
    STATE(919), 1,
      sym_indirect_access,
    STATE(1179), 1,
      sym__range_element,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(595), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(674), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    STATE(511), 2,
      sym_comparison_operator,
      sym_boolean_operator,
    STATE(507), 5,
      sym_parenthesis,
      sym_field_expression,
      sym_postfix_operator,
      sym_string,
      sym_matrix,
    STATE(616), 5,
      sym__expression,
      sym_metaclass_operator,
      sym_handle_operator,
      sym_range,
      sym_lambda,
  [7472] = 5,
    STATE(175), 1,
      aux_sym__block_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(718), 2,
      anon_sym_SEMI,
      anon_sym_COMMA,
    ACTIONS(714), 14,
      sym_command_name,
      sym__single_quote_string_start,
      sym__double_quote_string_start,
      sym__multioutput_variable_start,
      ts_builtin_sym_end,
      anon_sym_LPAREN,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_AT,
      anon_sym_LBRACK,
      anon_sym_LBRACE,
      sym_number,
    ACTIONS(716), 22,
      sym_return_statement,
      sym_continue_statement,
      sym_break_statement,
      anon_sym_elseif,
      anon_sym_else,
      anon_sym_if,
      anon_sym_end,
      anon_sym_for,
      anon_sym_parfor,
      anon_sym_while,
      anon_sym_case,
      anon_sym_otherwise,
      anon_sym_switch,
      anon_sym_global,
      anon_sym_persistent,
      anon_sym_function,
      anon_sym_classdef,
      anon_sym_catch,
      anon_sym_try,
      anon_sym_true,
      anon_sym_false,
      sym_identifier,
  [7524] = 29,
    ACTIONS(638), 1,
      sym_identifier,
    ACTIONS(640), 1,
      anon_sym_LPAREN,
    ACTIONS(644), 1,
      anon_sym_TILDE,
    ACTIONS(646), 1,
      anon_sym_QMARK,
    ACTIONS(648), 1,
      anon_sym_AT,
    ACTIONS(650), 1,
      anon_sym_LBRACK,
    ACTIONS(652), 1,
      anon_sym_LBRACE,
    ACTIONS(654), 1,
      anon_sym_RPAREN,
    ACTIONS(656), 1,
      anon_sym_COLON,
    ACTIONS(658), 1,
      sym_number,
    ACTIONS(662), 1,
      sym__single_quote_string_start,
    ACTIONS(664), 1,
      sym__double_quote_string_start,
    STATE(367), 1,
      sym_function_call,
    STATE(402), 1,
      sym_boolean,
    STATE(518), 1,
      sym_cell,
    STATE(530), 1,
      sym_binary_operator,
    STATE(542), 1,
      sym_unary_operator,
    STATE(586), 1,
      sym_not_operator,
    STATE(614), 1,
      sym__binary_expression,
    STATE(905), 1,
      sym_indirect_access,
    STATE(984), 1,
      sym_spread_operator,
    STATE(1150), 1,
      sym_arguments,
    STATE(1196), 1,
      sym__range_element,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(642), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(660), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(520), 2,
      sym_comparison_operator,
      sym_boolean_operator,
    STATE(521), 5,
      sym_parenthesis,
      sym_field_expression,
      sym_postfix_operator,
      sym_string,
      sym_matrix,
    STATE(634), 5,
      sym__expression,
      sym_metaclass_operator,
      sym_handle_operator,
      sym_range,
      sym_lambda,
  [7624] = 5,
    STATE(175), 1,
      aux_sym__block_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(704), 2,
      anon_sym_SEMI,
      anon_sym_COMMA,
    ACTIONS(721), 14,
      sym_command_name,
      sym__single_quote_string_start,
      sym__double_quote_string_start,
      sym__multioutput_variable_start,
      ts_builtin_sym_end,
      anon_sym_LPAREN,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_AT,
      anon_sym_LBRACK,
      anon_sym_LBRACE,
      sym_number,
    ACTIONS(723), 22,
      sym_return_statement,
      sym_continue_statement,
      sym_break_statement,
      anon_sym_elseif,
      anon_sym_else,
      anon_sym_if,
      anon_sym_end,
      anon_sym_for,
      anon_sym_parfor,
      anon_sym_while,
      anon_sym_case,
      anon_sym_otherwise,
      anon_sym_switch,
      anon_sym_global,
      anon_sym_persistent,
      anon_sym_function,
      anon_sym_classdef,
      anon_sym_catch,
      anon_sym_try,
      anon_sym_true,
      anon_sym_false,
      sym_identifier,
  [7676] = 29,
    ACTIONS(638), 1,
      sym_identifier,
    ACTIONS(640), 1,
      anon_sym_LPAREN,
    ACTIONS(644), 1,
      anon_sym_TILDE,
    ACTIONS(646), 1,
      anon_sym_QMARK,
    ACTIONS(648), 1,
      anon_sym_AT,
    ACTIONS(650), 1,
      anon_sym_LBRACK,
    ACTIONS(652), 1,
      anon_sym_LBRACE,
    ACTIONS(656), 1,
      anon_sym_COLON,
    ACTIONS(658), 1,
      sym_number,
    ACTIONS(662), 1,
      sym__single_quote_string_start,
    ACTIONS(664), 1,
      sym__double_quote_string_start,
    ACTIONS(668), 1,
      anon_sym_RPAREN,
    STATE(367), 1,
      sym_function_call,
    STATE(402), 1,
      sym_boolean,
    STATE(518), 1,
      sym_cell,
    STATE(530), 1,
      sym_binary_operator,
    STATE(542), 1,
      sym_unary_operator,
    STATE(586), 1,
      sym_not_operator,
    STATE(614), 1,
      sym__binary_expression,
    STATE(905), 1,
      sym_indirect_access,
    STATE(984), 1,
      sym_spread_operator,
    STATE(1169), 1,
      sym_arguments,
    STATE(1196), 1,
      sym__range_element,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(642), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(660), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(520), 2,
      sym_comparison_operator,
      sym_boolean_operator,
    STATE(521), 5,
      sym_parenthesis,
      sym_field_expression,
      sym_postfix_operator,
      sym_string,
      sym_matrix,
    STATE(634), 5,
      sym__expression,
      sym_metaclass_operator,
      sym_handle_operator,
      sym_range,
      sym_lambda,
  [7776] = 5,
    STATE(177), 1,
      aux_sym__block_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(725), 2,
      anon_sym_SEMI,
      anon_sym_COMMA,
    ACTIONS(347), 14,
      sym_command_name,
      sym__single_quote_string_start,
      sym__double_quote_string_start,
      sym__multioutput_variable_start,
      ts_builtin_sym_end,
      anon_sym_LPAREN,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_AT,
      anon_sym_LBRACK,
      anon_sym_LBRACE,
      sym_number,
    ACTIONS(279), 22,
      sym_return_statement,
      sym_continue_statement,
      sym_break_statement,
      anon_sym_elseif,
      anon_sym_else,
      anon_sym_if,
      anon_sym_end,
      anon_sym_for,
      anon_sym_parfor,
      anon_sym_while,
      anon_sym_case,
      anon_sym_otherwise,
      anon_sym_switch,
      anon_sym_global,
      anon_sym_persistent,
      anon_sym_function,
      anon_sym_classdef,
      anon_sym_catch,
      anon_sym_try,
      anon_sym_true,
      anon_sym_false,
      sym_identifier,
  [7828] = 29,
    ACTIONS(571), 1,
      sym_identifier,
    ACTIONS(597), 1,
      sym__single_quote_string_start,
    ACTIONS(599), 1,
      sym__double_quote_string_start,
    ACTIONS(670), 1,
      anon_sym_COMMA,
    ACTIONS(672), 1,
      anon_sym_LPAREN,
    ACTIONS(676), 1,
      anon_sym_TILDE,
    ACTIONS(678), 1,
      anon_sym_QMARK,
    ACTIONS(680), 1,
      anon_sym_AT,
    ACTIONS(682), 1,
      anon_sym_LBRACK,
    ACTIONS(686), 1,
      anon_sym_LBRACE,
    ACTIONS(688), 1,
      sym_number,
    ACTIONS(727), 1,
      anon_sym_RBRACE,
    STATE(216), 1,
      sym_function_call,
    STATE(363), 1,
      sym_boolean,
    STATE(508), 1,
      sym_unary_operator,
    STATE(509), 1,
      sym_binary_operator,
    STATE(510), 1,
      sym_cell,
    STATE(525), 1,
      sym_not_operator,
    STATE(615), 1,
      sym__binary_expression,
    STATE(796), 1,
      sym_ignored_argument,
    STATE(919), 1,
      sym_indirect_access,
    STATE(997), 1,
      sym_row,
    STATE(1179), 1,
      sym__range_element,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(595), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(674), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    STATE(511), 2,
      sym_comparison_operator,
      sym_boolean_operator,
    STATE(507), 5,
      sym_parenthesis,
      sym_field_expression,
      sym_postfix_operator,
      sym_string,
      sym_matrix,
    STATE(616), 5,
      sym__expression,
      sym_metaclass_operator,
      sym_handle_operator,
      sym_range,
      sym_lambda,
  [7928] = 29,
    ACTIONS(638), 1,
      sym_identifier,
    ACTIONS(640), 1,
      anon_sym_LPAREN,
    ACTIONS(644), 1,
      anon_sym_TILDE,
    ACTIONS(646), 1,
      anon_sym_QMARK,
    ACTIONS(648), 1,
      anon_sym_AT,
    ACTIONS(650), 1,
      anon_sym_LBRACK,
    ACTIONS(652), 1,
      anon_sym_LBRACE,
    ACTIONS(656), 1,
      anon_sym_COLON,
    ACTIONS(658), 1,
      sym_number,
    ACTIONS(662), 1,
      sym__single_quote_string_start,
    ACTIONS(664), 1,
      sym__double_quote_string_start,
    ACTIONS(729), 1,
      anon_sym_RBRACE,
    STATE(367), 1,
      sym_function_call,
    STATE(402), 1,
      sym_boolean,
    STATE(518), 1,
      sym_cell,
    STATE(530), 1,
      sym_binary_operator,
    STATE(542), 1,
      sym_unary_operator,
    STATE(586), 1,
      sym_not_operator,
    STATE(614), 1,
      sym__binary_expression,
    STATE(905), 1,
      sym_indirect_access,
    STATE(984), 1,
      sym_spread_operator,
    STATE(1182), 1,
      sym_arguments,
    STATE(1196), 1,
      sym__range_element,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(642), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(660), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(520), 2,
      sym_comparison_operator,
      sym_boolean_operator,
    STATE(521), 5,
      sym_parenthesis,
      sym_field_expression,
      sym_postfix_operator,
      sym_string,
      sym_matrix,
    STATE(634), 5,
      sym__expression,
      sym_metaclass_operator,
      sym_handle_operator,
      sym_range,
      sym_lambda,
  [8028] = 29,
    ACTIONS(571), 1,
      sym_identifier,
    ACTIONS(597), 1,
      sym__single_quote_string_start,
    ACTIONS(599), 1,
      sym__double_quote_string_start,
    ACTIONS(670), 1,
      anon_sym_COMMA,
    ACTIONS(672), 1,
      anon_sym_LPAREN,
    ACTIONS(676), 1,
      anon_sym_TILDE,
    ACTIONS(678), 1,
      anon_sym_QMARK,
    ACTIONS(680), 1,
      anon_sym_AT,
    ACTIONS(682), 1,
      anon_sym_LBRACK,
    ACTIONS(686), 1,
      anon_sym_LBRACE,
    ACTIONS(688), 1,
      sym_number,
    ACTIONS(731), 1,
      anon_sym_RBRACE,
    STATE(216), 1,
      sym_function_call,
    STATE(363), 1,
      sym_boolean,
    STATE(508), 1,
      sym_unary_operator,
    STATE(509), 1,
      sym_binary_operator,
    STATE(510), 1,
      sym_cell,
    STATE(525), 1,
      sym_not_operator,
    STATE(615), 1,
      sym__binary_expression,
    STATE(796), 1,
      sym_ignored_argument,
    STATE(919), 1,
      sym_indirect_access,
    STATE(940), 1,
      sym_row,
    STATE(1179), 1,
      sym__range_element,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(595), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(674), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    STATE(511), 2,
      sym_comparison_operator,
      sym_boolean_operator,
    STATE(507), 5,
      sym_parenthesis,
      sym_field_expression,
      sym_postfix_operator,
      sym_string,
      sym_matrix,
    STATE(616), 5,
      sym__expression,
      sym_metaclass_operator,
      sym_handle_operator,
      sym_range,
      sym_lambda,
  [8128] = 29,
    ACTIONS(638), 1,
      sym_identifier,
    ACTIONS(640), 1,
      anon_sym_LPAREN,
    ACTIONS(644), 1,
      anon_sym_TILDE,
    ACTIONS(646), 1,
      anon_sym_QMARK,
    ACTIONS(648), 1,
      anon_sym_AT,
    ACTIONS(650), 1,
      anon_sym_LBRACK,
    ACTIONS(652), 1,
      anon_sym_LBRACE,
    ACTIONS(656), 1,
      anon_sym_COLON,
    ACTIONS(658), 1,
      sym_number,
    ACTIONS(662), 1,
      sym__single_quote_string_start,
    ACTIONS(664), 1,
      sym__double_quote_string_start,
    ACTIONS(666), 1,
      anon_sym_RPAREN,
    STATE(367), 1,
      sym_function_call,
    STATE(402), 1,
      sym_boolean,
    STATE(518), 1,
      sym_cell,
    STATE(530), 1,
      sym_binary_operator,
    STATE(542), 1,
      sym_unary_operator,
    STATE(586), 1,
      sym_not_operator,
    STATE(614), 1,
      sym__binary_expression,
    STATE(905), 1,
      sym_indirect_access,
    STATE(984), 1,
      sym_spread_operator,
    STATE(1149), 1,
      sym_arguments,
    STATE(1196), 1,
      sym__range_element,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(642), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(660), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(520), 2,
      sym_comparison_operator,
      sym_boolean_operator,
    STATE(521), 5,
      sym_parenthesis,
      sym_field_expression,
      sym_postfix_operator,
      sym_string,
      sym_matrix,
    STATE(634), 5,
      sym__expression,
      sym_metaclass_operator,
      sym_handle_operator,
      sym_range,
      sym_lambda,
  [8228] = 29,
    ACTIONS(638), 1,
      sym_identifier,
    ACTIONS(640), 1,
      anon_sym_LPAREN,
    ACTIONS(644), 1,
      anon_sym_TILDE,
    ACTIONS(646), 1,
      anon_sym_QMARK,
    ACTIONS(648), 1,
      anon_sym_AT,
    ACTIONS(650), 1,
      anon_sym_LBRACK,
    ACTIONS(652), 1,
      anon_sym_LBRACE,
    ACTIONS(656), 1,
      anon_sym_COLON,
    ACTIONS(658), 1,
      sym_number,
    ACTIONS(662), 1,
      sym__single_quote_string_start,
    ACTIONS(664), 1,
      sym__double_quote_string_start,
    ACTIONS(729), 1,
      anon_sym_RPAREN,
    STATE(367), 1,
      sym_function_call,
    STATE(402), 1,
      sym_boolean,
    STATE(518), 1,
      sym_cell,
    STATE(530), 1,
      sym_binary_operator,
    STATE(542), 1,
      sym_unary_operator,
    STATE(586), 1,
      sym_not_operator,
    STATE(614), 1,
      sym__binary_expression,
    STATE(905), 1,
      sym_indirect_access,
    STATE(984), 1,
      sym_spread_operator,
    STATE(1136), 1,
      sym_arguments,
    STATE(1196), 1,
      sym__range_element,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(642), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(660), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(520), 2,
      sym_comparison_operator,
      sym_boolean_operator,
    STATE(521), 5,
      sym_parenthesis,
      sym_field_expression,
      sym_postfix_operator,
      sym_string,
      sym_matrix,
    STATE(634), 5,
      sym__expression,
      sym_metaclass_operator,
      sym_handle_operator,
      sym_range,
      sym_lambda,
  [8328] = 29,
    ACTIONS(638), 1,
      sym_identifier,
    ACTIONS(640), 1,
      anon_sym_LPAREN,
    ACTIONS(644), 1,
      anon_sym_TILDE,
    ACTIONS(646), 1,
      anon_sym_QMARK,
    ACTIONS(648), 1,
      anon_sym_AT,
    ACTIONS(650), 1,
      anon_sym_LBRACK,
    ACTIONS(652), 1,
      anon_sym_LBRACE,
    ACTIONS(656), 1,
      anon_sym_COLON,
    ACTIONS(658), 1,
      sym_number,
    ACTIONS(662), 1,
      sym__single_quote_string_start,
    ACTIONS(664), 1,
      sym__double_quote_string_start,
    ACTIONS(733), 1,
      anon_sym_RBRACE,
    STATE(367), 1,
      sym_function_call,
    STATE(402), 1,
      sym_boolean,
    STATE(518), 1,
      sym_cell,
    STATE(530), 1,
      sym_binary_operator,
    STATE(542), 1,
      sym_unary_operator,
    STATE(586), 1,
      sym_not_operator,
    STATE(614), 1,
      sym__binary_expression,
    STATE(905), 1,
      sym_indirect_access,
    STATE(984), 1,
      sym_spread_operator,
    STATE(1135), 1,
      sym_arguments,
    STATE(1196), 1,
      sym__range_element,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(642), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(660), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(520), 2,
      sym_comparison_operator,
      sym_boolean_operator,
    STATE(521), 5,
      sym_parenthesis,
      sym_field_expression,
      sym_postfix_operator,
      sym_string,
      sym_matrix,
    STATE(634), 5,
      sym__expression,
      sym_metaclass_operator,
      sym_handle_operator,
      sym_range,
      sym_lambda,
  [8428] = 29,
    ACTIONS(638), 1,
      sym_identifier,
    ACTIONS(640), 1,
      anon_sym_LPAREN,
    ACTIONS(644), 1,
      anon_sym_TILDE,
    ACTIONS(646), 1,
      anon_sym_QMARK,
    ACTIONS(648), 1,
      anon_sym_AT,
    ACTIONS(650), 1,
      anon_sym_LBRACK,
    ACTIONS(652), 1,
      anon_sym_LBRACE,
    ACTIONS(656), 1,
      anon_sym_COLON,
    ACTIONS(658), 1,
      sym_number,
    ACTIONS(662), 1,
      sym__single_quote_string_start,
    ACTIONS(664), 1,
      sym__double_quote_string_start,
    ACTIONS(733), 1,
      anon_sym_RPAREN,
    STATE(367), 1,
      sym_function_call,
    STATE(402), 1,
      sym_boolean,
    STATE(518), 1,
      sym_cell,
    STATE(530), 1,
      sym_binary_operator,
    STATE(542), 1,
      sym_unary_operator,
    STATE(586), 1,
      sym_not_operator,
    STATE(614), 1,
      sym__binary_expression,
    STATE(905), 1,
      sym_indirect_access,
    STATE(984), 1,
      sym_spread_operator,
    STATE(1155), 1,
      sym_arguments,
    STATE(1196), 1,
      sym__range_element,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(642), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(660), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(520), 2,
      sym_comparison_operator,
      sym_boolean_operator,
    STATE(521), 5,
      sym_parenthesis,
      sym_field_expression,
      sym_postfix_operator,
      sym_string,
      sym_matrix,
    STATE(634), 5,
      sym__expression,
      sym_metaclass_operator,
      sym_handle_operator,
      sym_range,
      sym_lambda,
  [8528] = 11,
    ACTIONS(378), 1,
      anon_sym_COLON,
    ACTIONS(735), 1,
      anon_sym_LPAREN,
    ACTIONS(737), 1,
      anon_sym_DOT,
    ACTIONS(739), 1,
      anon_sym_AT,
    ACTIONS(743), 1,
      anon_sym_LBRACE,
    STATE(201), 1,
      sym__args,
    STATE(310), 1,
      aux_sym_field_expression_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(741), 2,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(364), 14,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
    ACTIONS(360), 15,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_end,
      anon_sym_case,
      anon_sym_otherwise,
      anon_sym_LF,
      anon_sym_CR,
  [8591] = 9,
    ACTIONS(735), 1,
      anon_sym_LPAREN,
    ACTIONS(737), 1,
      anon_sym_DOT,
    ACTIONS(739), 1,
      anon_sym_AT,
    ACTIONS(743), 1,
      anon_sym_LBRACE,
    STATE(201), 1,
      sym__args,
    STATE(310), 1,
      aux_sym_field_expression_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(741), 2,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(383), 30,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_case,
      anon_sym_otherwise,
      anon_sym_LF,
      anon_sym_CR,
  [8650] = 11,
    ACTIONS(735), 1,
      anon_sym_LPAREN,
    ACTIONS(737), 1,
      anon_sym_DOT,
    ACTIONS(739), 1,
      anon_sym_AT,
    ACTIONS(743), 1,
      anon_sym_LBRACE,
    STATE(201), 1,
      sym__args,
    STATE(310), 1,
      aux_sym_field_expression_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(741), 2,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(374), 8,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_case,
      anon_sym_otherwise,
      anon_sym_LF,
      anon_sym_CR,
    ACTIONS(378), 8,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
    ACTIONS(364), 14,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
  [8713] = 11,
    ACTIONS(374), 1,
      anon_sym_COLON,
    ACTIONS(735), 1,
      anon_sym_LPAREN,
    ACTIONS(737), 1,
      anon_sym_DOT,
    ACTIONS(739), 1,
      anon_sym_AT,
    ACTIONS(743), 1,
      anon_sym_LBRACE,
    STATE(201), 1,
      sym__args,
    STATE(310), 1,
      aux_sym_field_expression_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(741), 2,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(364), 14,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
    ACTIONS(360), 15,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_end,
      anon_sym_case,
      anon_sym_otherwise,
      anon_sym_LF,
      anon_sym_CR,
  [8776] = 6,
    ACTIONS(735), 1,
      anon_sym_LPAREN,
    ACTIONS(739), 1,
      anon_sym_AT,
    ACTIONS(743), 1,
      anon_sym_LBRACE,
    STATE(201), 1,
      sym__args,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(406), 34,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_DOT,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_case,
      anon_sym_otherwise,
      anon_sym_LF,
      anon_sym_CR,
  [8829] = 9,
    ACTIONS(735), 1,
      anon_sym_LPAREN,
    ACTIONS(737), 1,
      anon_sym_DOT,
    ACTIONS(739), 1,
      anon_sym_AT,
    ACTIONS(743), 1,
      anon_sym_LBRACE,
    STATE(201), 1,
      sym__args,
    STATE(310), 1,
      aux_sym_field_expression_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(741), 2,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(364), 30,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_case,
      anon_sym_otherwise,
      anon_sym_LF,
      anon_sym_CR,
  [8888] = 27,
    ACTIONS(640), 1,
      anon_sym_LPAREN,
    ACTIONS(644), 1,
      anon_sym_TILDE,
    ACTIONS(646), 1,
      anon_sym_QMARK,
    ACTIONS(648), 1,
      anon_sym_AT,
    ACTIONS(650), 1,
      anon_sym_LBRACK,
    ACTIONS(652), 1,
      anon_sym_LBRACE,
    ACTIONS(656), 1,
      anon_sym_COLON,
    ACTIONS(658), 1,
      sym_number,
    ACTIONS(662), 1,
      sym__single_quote_string_start,
    ACTIONS(664), 1,
      sym__double_quote_string_start,
    ACTIONS(745), 1,
      sym_identifier,
    STATE(367), 1,
      sym_function_call,
    STATE(402), 1,
      sym_boolean,
    STATE(518), 1,
      sym_cell,
    STATE(530), 1,
      sym_binary_operator,
    STATE(542), 1,
      sym_unary_operator,
    STATE(586), 1,
      sym_not_operator,
    STATE(614), 1,
      sym__binary_expression,
    STATE(905), 1,
      sym_indirect_access,
    STATE(1042), 1,
      sym_spread_operator,
    STATE(1196), 1,
      sym__range_element,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(642), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(660), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(520), 2,
      sym_comparison_operator,
      sym_boolean_operator,
    STATE(521), 5,
      sym_parenthesis,
      sym_field_expression,
      sym_postfix_operator,
      sym_string,
      sym_matrix,
    STATE(656), 5,
      sym__expression,
      sym_metaclass_operator,
      sym_handle_operator,
      sym_range,
      sym_lambda,
  [8982] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(443), 37,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_DOT,
      anon_sym_AT,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_LBRACE,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_case,
      anon_sym_otherwise,
      anon_sym_LF,
      anon_sym_CR,
  [9026] = 27,
    ACTIONS(640), 1,
      anon_sym_LPAREN,
    ACTIONS(644), 1,
      anon_sym_TILDE,
    ACTIONS(646), 1,
      anon_sym_QMARK,
    ACTIONS(648), 1,
      anon_sym_AT,
    ACTIONS(650), 1,
      anon_sym_LBRACK,
    ACTIONS(652), 1,
      anon_sym_LBRACE,
    ACTIONS(656), 1,
      anon_sym_COLON,
    ACTIONS(658), 1,
      sym_number,
    ACTIONS(662), 1,
      sym__single_quote_string_start,
    ACTIONS(664), 1,
      sym__double_quote_string_start,
    ACTIONS(747), 1,
      sym_identifier,
    STATE(367), 1,
      sym_function_call,
    STATE(402), 1,
      sym_boolean,
    STATE(518), 1,
      sym_cell,
    STATE(530), 1,
      sym_binary_operator,
    STATE(542), 1,
      sym_unary_operator,
    STATE(586), 1,
      sym_not_operator,
    STATE(614), 1,
      sym__binary_expression,
    STATE(905), 1,
      sym_indirect_access,
    STATE(1042), 1,
      sym_spread_operator,
    STATE(1196), 1,
      sym__range_element,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(642), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(660), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(520), 2,
      sym_comparison_operator,
      sym_boolean_operator,
    STATE(521), 5,
      sym_parenthesis,
      sym_field_expression,
      sym_postfix_operator,
      sym_string,
      sym_matrix,
    STATE(656), 5,
      sym__expression,
      sym_metaclass_operator,
      sym_handle_operator,
      sym_range,
      sym_lambda,
  [9120] = 27,
    ACTIONS(640), 1,
      anon_sym_LPAREN,
    ACTIONS(644), 1,
      anon_sym_TILDE,
    ACTIONS(646), 1,
      anon_sym_QMARK,
    ACTIONS(648), 1,
      anon_sym_AT,
    ACTIONS(650), 1,
      anon_sym_LBRACK,
    ACTIONS(652), 1,
      anon_sym_LBRACE,
    ACTIONS(656), 1,
      anon_sym_COLON,
    ACTIONS(658), 1,
      sym_number,
    ACTIONS(662), 1,
      sym__single_quote_string_start,
    ACTIONS(664), 1,
      sym__double_quote_string_start,
    ACTIONS(749), 1,
      sym_identifier,
    STATE(367), 1,
      sym_function_call,
    STATE(402), 1,
      sym_boolean,
    STATE(518), 1,
      sym_cell,
    STATE(530), 1,
      sym_binary_operator,
    STATE(542), 1,
      sym_unary_operator,
    STATE(586), 1,
      sym_not_operator,
    STATE(614), 1,
      sym__binary_expression,
    STATE(905), 1,
      sym_indirect_access,
    STATE(1042), 1,
      sym_spread_operator,
    STATE(1196), 1,
      sym__range_element,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(642), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(660), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(520), 2,
      sym_comparison_operator,
      sym_boolean_operator,
    STATE(521), 5,
      sym_parenthesis,
      sym_field_expression,
      sym_postfix_operator,
      sym_string,
      sym_matrix,
    STATE(656), 5,
      sym__expression,
      sym_metaclass_operator,
      sym_handle_operator,
      sym_range,
      sym_lambda,
  [9214] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(435), 37,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_DOT,
      anon_sym_AT,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_LBRACE,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_case,
      anon_sym_otherwise,
      anon_sym_LF,
      anon_sym_CR,
  [9258] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(439), 37,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_DOT,
      anon_sym_AT,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_LBRACE,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_case,
      anon_sym_otherwise,
      anon_sym_LF,
      anon_sym_CR,
  [9302] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(447), 37,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_DOT,
      anon_sym_AT,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_LBRACE,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_case,
      anon_sym_otherwise,
      anon_sym_LF,
      anon_sym_CR,
  [9346] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(425), 37,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_DOT,
      anon_sym_AT,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_LBRACE,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_case,
      anon_sym_otherwise,
      anon_sym_LF,
      anon_sym_CR,
  [9390] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(429), 37,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_DOT,
      anon_sym_AT,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_LBRACE,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_case,
      anon_sym_otherwise,
      anon_sym_LF,
      anon_sym_CR,
  [9434] = 27,
    ACTIONS(640), 1,
      anon_sym_LPAREN,
    ACTIONS(644), 1,
      anon_sym_TILDE,
    ACTIONS(646), 1,
      anon_sym_QMARK,
    ACTIONS(648), 1,
      anon_sym_AT,
    ACTIONS(650), 1,
      anon_sym_LBRACK,
    ACTIONS(652), 1,
      anon_sym_LBRACE,
    ACTIONS(656), 1,
      anon_sym_COLON,
    ACTIONS(658), 1,
      sym_number,
    ACTIONS(662), 1,
      sym__single_quote_string_start,
    ACTIONS(664), 1,
      sym__double_quote_string_start,
    ACTIONS(751), 1,
      sym_identifier,
    STATE(367), 1,
      sym_function_call,
    STATE(402), 1,
      sym_boolean,
    STATE(518), 1,
      sym_cell,
    STATE(530), 1,
      sym_binary_operator,
    STATE(542), 1,
      sym_unary_operator,
    STATE(586), 1,
      sym_not_operator,
    STATE(614), 1,
      sym__binary_expression,
    STATE(905), 1,
      sym_indirect_access,
    STATE(1042), 1,
      sym_spread_operator,
    STATE(1196), 1,
      sym__range_element,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(642), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(660), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(520), 2,
      sym_comparison_operator,
      sym_boolean_operator,
    STATE(521), 5,
      sym_parenthesis,
      sym_field_expression,
      sym_postfix_operator,
      sym_string,
      sym_matrix,
    STATE(656), 5,
      sym__expression,
      sym_metaclass_operator,
      sym_handle_operator,
      sym_range,
      sym_lambda,
  [9528] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(421), 37,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_DOT,
      anon_sym_AT,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_LBRACE,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_case,
      anon_sym_otherwise,
      anon_sym_LF,
      anon_sym_CR,
  [9572] = 26,
    ACTIONS(571), 1,
      sym_identifier,
    ACTIONS(597), 1,
      sym__single_quote_string_start,
    ACTIONS(599), 1,
      sym__double_quote_string_start,
    ACTIONS(672), 1,
      anon_sym_LPAREN,
    ACTIONS(676), 1,
      anon_sym_TILDE,
    ACTIONS(678), 1,
      anon_sym_QMARK,
    ACTIONS(680), 1,
      anon_sym_AT,
    ACTIONS(682), 1,
      anon_sym_LBRACK,
    ACTIONS(686), 1,
      anon_sym_LBRACE,
    ACTIONS(688), 1,
      sym_number,
    STATE(216), 1,
      sym_function_call,
    STATE(363), 1,
      sym_boolean,
    STATE(508), 1,
      sym_unary_operator,
    STATE(509), 1,
      sym_binary_operator,
    STATE(510), 1,
      sym_cell,
    STATE(525), 1,
      sym_not_operator,
    STATE(615), 1,
      sym__binary_expression,
    STATE(847), 1,
      sym_ignored_argument,
    STATE(919), 1,
      sym_indirect_access,
    STATE(1179), 1,
      sym__range_element,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(595), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(674), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    STATE(511), 2,
      sym_comparison_operator,
      sym_boolean_operator,
    STATE(507), 5,
      sym_parenthesis,
      sym_field_expression,
      sym_postfix_operator,
      sym_string,
      sym_matrix,
    STATE(624), 5,
      sym__expression,
      sym_metaclass_operator,
      sym_handle_operator,
      sym_range,
      sym_lambda,
  [9663] = 9,
    ACTIONS(374), 1,
      anon_sym_COLON,
    ACTIONS(735), 1,
      anon_sym_LPAREN,
    ACTIONS(743), 1,
      anon_sym_LBRACE,
    ACTIONS(753), 1,
      anon_sym_AT,
    STATE(200), 1,
      sym__args,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(741), 2,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(364), 14,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
    ACTIONS(360), 15,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_end,
      anon_sym_case,
      anon_sym_otherwise,
      anon_sym_LF,
      anon_sym_CR,
  [9720] = 7,
    ACTIONS(735), 1,
      anon_sym_LPAREN,
    ACTIONS(743), 1,
      anon_sym_LBRACE,
    ACTIONS(753), 1,
      anon_sym_AT,
    STATE(200), 1,
      sym__args,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(741), 2,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(383), 30,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_case,
      anon_sym_otherwise,
      anon_sym_LF,
      anon_sym_CR,
  [9773] = 12,
    ACTIONS(378), 1,
      anon_sym_COLON,
    ACTIONS(755), 1,
      anon_sym_LPAREN,
    ACTIONS(757), 1,
      anon_sym_DOT,
    ACTIONS(759), 1,
      anon_sym_AT,
    ACTIONS(763), 1,
      anon_sym_LBRACE,
    STATE(362), 1,
      sym__args,
    STATE(425), 1,
      aux_sym_field_expression_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(376), 2,
      sym__entry_delimiter,
      aux_sym_matrix_token1,
    ACTIONS(761), 2,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(360), 11,
      anon_sym_SEMI,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_RBRACK,
      anon_sym_RBRACE,
    ACTIONS(364), 14,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
  [9836] = 26,
    ACTIONS(571), 1,
      sym_identifier,
    ACTIONS(597), 1,
      sym__single_quote_string_start,
    ACTIONS(599), 1,
      sym__double_quote_string_start,
    ACTIONS(672), 1,
      anon_sym_LPAREN,
    ACTIONS(676), 1,
      anon_sym_TILDE,
    ACTIONS(678), 1,
      anon_sym_QMARK,
    ACTIONS(680), 1,
      anon_sym_AT,
    ACTIONS(682), 1,
      anon_sym_LBRACK,
    ACTIONS(686), 1,
      anon_sym_LBRACE,
    ACTIONS(688), 1,
      sym_number,
    STATE(216), 1,
      sym_function_call,
    STATE(363), 1,
      sym_boolean,
    STATE(508), 1,
      sym_unary_operator,
    STATE(509), 1,
      sym_binary_operator,
    STATE(510), 1,
      sym_cell,
    STATE(525), 1,
      sym_not_operator,
    STATE(615), 1,
      sym__binary_expression,
    STATE(781), 1,
      sym_ignored_argument,
    STATE(919), 1,
      sym_indirect_access,
    STATE(1179), 1,
      sym__range_element,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(595), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(674), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    STATE(511), 2,
      sym_comparison_operator,
      sym_boolean_operator,
    STATE(507), 5,
      sym_parenthesis,
      sym_field_expression,
      sym_postfix_operator,
      sym_string,
      sym_matrix,
    STATE(619), 5,
      sym__expression,
      sym_metaclass_operator,
      sym_handle_operator,
      sym_range,
      sym_lambda,
  [9927] = 27,
    ACTIONS(640), 1,
      anon_sym_LPAREN,
    ACTIONS(644), 1,
      anon_sym_TILDE,
    ACTIONS(650), 1,
      anon_sym_LBRACK,
    ACTIONS(652), 1,
      anon_sym_LBRACE,
    ACTIONS(662), 1,
      sym__single_quote_string_start,
    ACTIONS(664), 1,
      sym__double_quote_string_start,
    ACTIONS(765), 1,
      sym_identifier,
    ACTIONS(767), 1,
      anon_sym_QMARK,
    ACTIONS(769), 1,
      anon_sym_AT,
    ACTIONS(771), 1,
      sym_number,
    STATE(384), 1,
      sym_function_call,
    STATE(456), 1,
      sym_boolean,
    STATE(521), 1,
      sym_parenthesis,
    STATE(530), 1,
      sym_binary_operator,
    STATE(573), 1,
      sym_unary_operator,
    STATE(585), 1,
      sym_cell,
    STATE(599), 1,
      sym_not_operator,
    STATE(614), 1,
      sym__binary_expression,
    STATE(905), 1,
      sym_indirect_access,
    STATE(1028), 1,
      sym__enum_value,
    STATE(1196), 1,
      sym__range_element,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(642), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(660), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(520), 2,
      sym_comparison_operator,
      sym_boolean_operator,
    STATE(572), 4,
      sym_field_expression,
      sym_postfix_operator,
      sym_string,
      sym_matrix,
    STATE(700), 5,
      sym__expression,
      sym_metaclass_operator,
      sym_handle_operator,
      sym_range,
      sym_lambda,
  [10020] = 12,
    ACTIONS(374), 1,
      anon_sym_COLON,
    ACTIONS(735), 1,
      anon_sym_LPAREN,
    ACTIONS(737), 1,
      anon_sym_DOT,
    ACTIONS(739), 1,
      anon_sym_AT,
    ACTIONS(743), 1,
      anon_sym_LBRACE,
    ACTIONS(773), 1,
      anon_sym_EQ,
    STATE(201), 1,
      sym__args,
    STATE(310), 1,
      aux_sym_field_expression_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(741), 2,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(360), 12,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_LF,
      anon_sym_CR,
    ACTIONS(364), 14,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
  [10083] = 7,
    ACTIONS(735), 1,
      anon_sym_LPAREN,
    ACTIONS(743), 1,
      anon_sym_LBRACE,
    ACTIONS(753), 1,
      anon_sym_AT,
    STATE(200), 1,
      sym__args,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(741), 2,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(364), 30,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_case,
      anon_sym_otherwise,
      anon_sym_LF,
      anon_sym_CR,
  [10136] = 12,
    ACTIONS(755), 1,
      anon_sym_LPAREN,
    ACTIONS(757), 1,
      anon_sym_DOT,
    ACTIONS(759), 1,
      anon_sym_AT,
    ACTIONS(763), 1,
      anon_sym_LBRACE,
    STATE(362), 1,
      sym__args,
    STATE(425), 1,
      aux_sym_field_expression_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(381), 2,
      sym__entry_delimiter,
      aux_sym_matrix_token1,
    ACTIONS(761), 2,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(374), 4,
      anon_sym_SEMI,
      anon_sym_RBRACK,
      anon_sym_RBRACE,
      anon_sym_COLON,
    ACTIONS(378), 8,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
    ACTIONS(364), 14,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
  [10199] = 26,
    ACTIONS(9), 1,
      anon_sym_LPAREN,
    ACTIONS(19), 1,
      anon_sym_LBRACK,
    ACTIONS(21), 1,
      anon_sym_LBRACE,
    ACTIONS(51), 1,
      sym__single_quote_string_start,
    ACTIONS(53), 1,
      sym__double_quote_string_start,
    ACTIONS(630), 1,
      anon_sym_EQ,
    ACTIONS(775), 1,
      sym_identifier,
    ACTIONS(777), 1,
      anon_sym_TILDE,
    ACTIONS(779), 1,
      anon_sym_QMARK,
    ACTIONS(781), 1,
      anon_sym_AT,
    ACTIONS(783), 1,
      sym_number,
    STATE(187), 1,
      sym_function_call,
    STATE(219), 1,
      sym_boolean,
    STATE(404), 1,
      sym_unary_operator,
    STATE(407), 1,
      sym_binary_operator,
    STATE(409), 1,
      sym_not_operator,
    STATE(423), 1,
      sym_cell,
    STATE(622), 1,
      sym__binary_expression,
    STATE(994), 1,
      sym_indirect_access,
    STATE(1181), 1,
      sym__range_element,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(11), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(47), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(446), 2,
      sym_comparison_operator,
      sym_boolean_operator,
    STATE(392), 5,
      sym_parenthesis,
      sym_field_expression,
      sym_postfix_operator,
      sym_string,
      sym_matrix,
    STATE(420), 5,
      sym__expression,
      sym_metaclass_operator,
      sym_handle_operator,
      sym_range,
      sym_lambda,
  [10290] = 10,
    ACTIONS(755), 1,
      anon_sym_LPAREN,
    ACTIONS(757), 1,
      anon_sym_DOT,
    ACTIONS(759), 1,
      anon_sym_AT,
    ACTIONS(763), 1,
      anon_sym_LBRACE,
    STATE(362), 1,
      sym__args,
    STATE(425), 1,
      aux_sym_field_expression_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(387), 2,
      sym__entry_delimiter,
      aux_sym_matrix_token1,
    ACTIONS(761), 2,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(364), 26,
      anon_sym_SEMI,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_RBRACK,
      anon_sym_RBRACE,
      anon_sym_COLON,
  [10349] = 27,
    ACTIONS(640), 1,
      anon_sym_LPAREN,
    ACTIONS(644), 1,
      anon_sym_TILDE,
    ACTIONS(650), 1,
      anon_sym_LBRACK,
    ACTIONS(652), 1,
      anon_sym_LBRACE,
    ACTIONS(662), 1,
      sym__single_quote_string_start,
    ACTIONS(664), 1,
      sym__double_quote_string_start,
    ACTIONS(765), 1,
      sym_identifier,
    ACTIONS(767), 1,
      anon_sym_QMARK,
    ACTIONS(769), 1,
      anon_sym_AT,
    ACTIONS(771), 1,
      sym_number,
    STATE(384), 1,
      sym_function_call,
    STATE(456), 1,
      sym_boolean,
    STATE(521), 1,
      sym_parenthesis,
    STATE(530), 1,
      sym_binary_operator,
    STATE(573), 1,
      sym_unary_operator,
    STATE(585), 1,
      sym_cell,
    STATE(599), 1,
      sym_not_operator,
    STATE(614), 1,
      sym__binary_expression,
    STATE(905), 1,
      sym_indirect_access,
    STATE(1083), 1,
      sym__enum_value,
    STATE(1196), 1,
      sym__range_element,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(642), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(660), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(520), 2,
      sym_comparison_operator,
      sym_boolean_operator,
    STATE(572), 4,
      sym_field_expression,
      sym_postfix_operator,
      sym_string,
      sym_matrix,
    STATE(700), 5,
      sym__expression,
      sym_metaclass_operator,
      sym_handle_operator,
      sym_range,
      sym_lambda,
  [10442] = 12,
    ACTIONS(374), 1,
      anon_sym_COLON,
    ACTIONS(755), 1,
      anon_sym_LPAREN,
    ACTIONS(757), 1,
      anon_sym_DOT,
    ACTIONS(759), 1,
      anon_sym_AT,
    ACTIONS(763), 1,
      anon_sym_LBRACE,
    STATE(362), 1,
      sym__args,
    STATE(425), 1,
      aux_sym_field_expression_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(376), 2,
      sym__entry_delimiter,
      aux_sym_matrix_token1,
    ACTIONS(761), 2,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(360), 11,
      anon_sym_SEMI,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_RBRACK,
      anon_sym_RBRACE,
    ACTIONS(364), 14,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
  [10505] = 10,
    ACTIONS(755), 1,
      anon_sym_LPAREN,
    ACTIONS(757), 1,
      anon_sym_DOT,
    ACTIONS(759), 1,
      anon_sym_AT,
    ACTIONS(763), 1,
      anon_sym_LBRACE,
    STATE(362), 1,
      sym__args,
    STATE(425), 1,
      aux_sym_field_expression_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(385), 2,
      sym__entry_delimiter,
      aux_sym_matrix_token1,
    ACTIONS(761), 2,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(383), 26,
      anon_sym_SEMI,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_RBRACK,
      anon_sym_RBRACE,
      anon_sym_COLON,
  [10564] = 9,
    ACTIONS(735), 1,
      anon_sym_LPAREN,
    ACTIONS(743), 1,
      anon_sym_LBRACE,
    ACTIONS(753), 1,
      anon_sym_AT,
    STATE(200), 1,
      sym__args,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(741), 2,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(374), 8,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_case,
      anon_sym_otherwise,
      anon_sym_LF,
      anon_sym_CR,
    ACTIONS(378), 8,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
    ACTIONS(364), 14,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
  [10621] = 9,
    ACTIONS(378), 1,
      anon_sym_COLON,
    ACTIONS(735), 1,
      anon_sym_LPAREN,
    ACTIONS(743), 1,
      anon_sym_LBRACE,
    ACTIONS(753), 1,
      anon_sym_AT,
    STATE(200), 1,
      sym__args,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(741), 2,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(364), 14,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
    ACTIONS(360), 15,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_end,
      anon_sym_case,
      anon_sym_otherwise,
      anon_sym_LF,
      anon_sym_CR,
  [10678] = 25,
    ACTIONS(640), 1,
      anon_sym_LPAREN,
    ACTIONS(644), 1,
      anon_sym_TILDE,
    ACTIONS(646), 1,
      anon_sym_QMARK,
    ACTIONS(648), 1,
      anon_sym_AT,
    ACTIONS(650), 1,
      anon_sym_LBRACK,
    ACTIONS(652), 1,
      anon_sym_LBRACE,
    ACTIONS(658), 1,
      sym_number,
    ACTIONS(662), 1,
      sym__single_quote_string_start,
    ACTIONS(664), 1,
      sym__double_quote_string_start,
    ACTIONS(751), 1,
      sym_identifier,
    STATE(367), 1,
      sym_function_call,
    STATE(402), 1,
      sym_boolean,
    STATE(518), 1,
      sym_cell,
    STATE(530), 1,
      sym_binary_operator,
    STATE(542), 1,
      sym_unary_operator,
    STATE(586), 1,
      sym_not_operator,
    STATE(614), 1,
      sym__binary_expression,
    STATE(905), 1,
      sym_indirect_access,
    STATE(1196), 1,
      sym__range_element,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(642), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(660), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(520), 2,
      sym_comparison_operator,
      sym_boolean_operator,
    STATE(521), 5,
      sym_parenthesis,
      sym_field_expression,
      sym_postfix_operator,
      sym_string,
      sym_matrix,
    STATE(654), 5,
      sym__expression,
      sym_metaclass_operator,
      sym_handle_operator,
      sym_range,
      sym_lambda,
  [10766] = 25,
    ACTIONS(9), 1,
      anon_sym_LPAREN,
    ACTIONS(15), 1,
      anon_sym_QMARK,
    ACTIONS(17), 1,
      anon_sym_AT,
    ACTIONS(19), 1,
      anon_sym_LBRACK,
    ACTIONS(21), 1,
      anon_sym_LBRACE,
    ACTIONS(45), 1,
      sym_number,
    ACTIONS(51), 1,
      sym__single_quote_string_start,
    ACTIONS(53), 1,
      sym__double_quote_string_start,
    ACTIONS(777), 1,
      anon_sym_TILDE,
    ACTIONS(785), 1,
      sym_identifier,
    STATE(190), 1,
      sym_function_call,
    STATE(205), 1,
      sym_boolean,
    STATE(389), 1,
      sym_unary_operator,
    STATE(422), 1,
      sym_binary_operator,
    STATE(423), 1,
      sym_cell,
    STATE(477), 1,
      sym_not_operator,
    STATE(622), 1,
      sym__binary_expression,
    STATE(994), 1,
      sym_indirect_access,
    STATE(1181), 1,
      sym__range_element,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(11), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(47), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(446), 2,
      sym_comparison_operator,
      sym_boolean_operator,
    STATE(411), 5,
      sym_parenthesis,
      sym_field_expression,
      sym_postfix_operator,
      sym_string,
      sym_matrix,
    STATE(605), 5,
      sym__expression,
      sym_metaclass_operator,
      sym_handle_operator,
      sym_range,
      sym_lambda,
  [10854] = 25,
    ACTIONS(640), 1,
      anon_sym_LPAREN,
    ACTIONS(644), 1,
      anon_sym_TILDE,
    ACTIONS(650), 1,
      anon_sym_LBRACK,
    ACTIONS(652), 1,
      anon_sym_LBRACE,
    ACTIONS(662), 1,
      sym__single_quote_string_start,
    ACTIONS(664), 1,
      sym__double_quote_string_start,
    ACTIONS(767), 1,
      anon_sym_QMARK,
    ACTIONS(769), 1,
      anon_sym_AT,
    ACTIONS(787), 1,
      sym_identifier,
    ACTIONS(789), 1,
      sym_number,
    STATE(358), 1,
      sym_function_call,
    STATE(440), 1,
      sym_boolean,
    STATE(518), 1,
      sym_cell,
    STATE(522), 1,
      sym__range_element,
    STATE(544), 1,
      sym_not_operator,
    STATE(547), 1,
      sym_unary_operator,
    STATE(556), 1,
      sym_binary_operator,
    STATE(614), 1,
      sym__binary_expression,
    STATE(905), 1,
      sym_indirect_access,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(642), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(660), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(520), 2,
      sym_comparison_operator,
      sym_boolean_operator,
    STATE(549), 5,
      sym_parenthesis,
      sym_field_expression,
      sym_postfix_operator,
      sym_string,
      sym_matrix,
    STATE(700), 5,
      sym__expression,
      sym_metaclass_operator,
      sym_handle_operator,
      sym_range,
      sym_lambda,
  [10942] = 5,
    STATE(223), 1,
      aux_sym__block_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(791), 2,
      anon_sym_SEMI,
      anon_sym_COMMA,
    ACTIONS(714), 14,
      sym_command_name,
      sym__single_quote_string_start,
      sym__double_quote_string_start,
      sym__multioutput_variable_start,
      ts_builtin_sym_end,
      anon_sym_LPAREN,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_AT,
      anon_sym_LBRACK,
      anon_sym_LBRACE,
      sym_number,
    ACTIONS(716), 18,
      sym_return_statement,
      sym_continue_statement,
      sym_break_statement,
      anon_sym_if,
      anon_sym_end,
      anon_sym_for,
      anon_sym_parfor,
      anon_sym_while,
      anon_sym_switch,
      anon_sym_global,
      anon_sym_persistent,
      anon_sym_function,
      anon_sym_endfunction,
      anon_sym_classdef,
      anon_sym_try,
      anon_sym_true,
      anon_sym_false,
      sym_identifier,
  [10990] = 25,
    ACTIONS(640), 1,
      anon_sym_LPAREN,
    ACTIONS(644), 1,
      anon_sym_TILDE,
    ACTIONS(650), 1,
      anon_sym_LBRACK,
    ACTIONS(652), 1,
      anon_sym_LBRACE,
    ACTIONS(658), 1,
      sym_number,
    ACTIONS(662), 1,
      sym__single_quote_string_start,
    ACTIONS(664), 1,
      sym__double_quote_string_start,
    ACTIONS(767), 1,
      anon_sym_QMARK,
    ACTIONS(769), 1,
      anon_sym_AT,
    ACTIONS(794), 1,
      sym_identifier,
    STATE(368), 1,
      sym_function_call,
    STATE(402), 1,
      sym_boolean,
    STATE(518), 1,
      sym_cell,
    STATE(530), 1,
      sym_binary_operator,
    STATE(542), 1,
      sym_unary_operator,
    STATE(586), 1,
      sym_not_operator,
    STATE(614), 1,
      sym__binary_expression,
    STATE(905), 1,
      sym_indirect_access,
    STATE(1196), 1,
      sym__range_element,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(642), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(660), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(520), 2,
      sym_comparison_operator,
      sym_boolean_operator,
    STATE(521), 5,
      sym_parenthesis,
      sym_field_expression,
      sym_postfix_operator,
      sym_string,
      sym_matrix,
    STATE(593), 5,
      sym__expression,
      sym_metaclass_operator,
      sym_handle_operator,
      sym_range,
      sym_lambda,
  [11078] = 5,
    STATE(223), 1,
      aux_sym__block_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(796), 2,
      anon_sym_SEMI,
      anon_sym_COMMA,
    ACTIONS(721), 14,
      sym_command_name,
      sym__single_quote_string_start,
      sym__double_quote_string_start,
      sym__multioutput_variable_start,
      ts_builtin_sym_end,
      anon_sym_LPAREN,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_AT,
      anon_sym_LBRACK,
      anon_sym_LBRACE,
      sym_number,
    ACTIONS(723), 18,
      sym_return_statement,
      sym_continue_statement,
      sym_break_statement,
      anon_sym_if,
      anon_sym_end,
      anon_sym_for,
      anon_sym_parfor,
      anon_sym_while,
      anon_sym_switch,
      anon_sym_global,
      anon_sym_persistent,
      anon_sym_function,
      anon_sym_endfunction,
      anon_sym_classdef,
      anon_sym_try,
      anon_sym_true,
      anon_sym_false,
      sym_identifier,
  [11126] = 25,
    ACTIONS(640), 1,
      anon_sym_LPAREN,
    ACTIONS(644), 1,
      anon_sym_TILDE,
    ACTIONS(650), 1,
      anon_sym_LBRACK,
    ACTIONS(652), 1,
      anon_sym_LBRACE,
    ACTIONS(658), 1,
      sym_number,
    ACTIONS(662), 1,
      sym__single_quote_string_start,
    ACTIONS(664), 1,
      sym__double_quote_string_start,
    ACTIONS(767), 1,
      anon_sym_QMARK,
    ACTIONS(769), 1,
      anon_sym_AT,
    ACTIONS(794), 1,
      sym_identifier,
    STATE(368), 1,
      sym_function_call,
    STATE(402), 1,
      sym_boolean,
    STATE(518), 1,
      sym_cell,
    STATE(530), 1,
      sym_binary_operator,
    STATE(542), 1,
      sym_unary_operator,
    STATE(586), 1,
      sym_not_operator,
    STATE(614), 1,
      sym__binary_expression,
    STATE(905), 1,
      sym_indirect_access,
    STATE(1196), 1,
      sym__range_element,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(642), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(660), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(520), 2,
      sym_comparison_operator,
      sym_boolean_operator,
    STATE(521), 5,
      sym_parenthesis,
      sym_field_expression,
      sym_postfix_operator,
      sym_string,
      sym_matrix,
    STATE(598), 5,
      sym__expression,
      sym_metaclass_operator,
      sym_handle_operator,
      sym_range,
      sym_lambda,
  [11214] = 5,
    STATE(347), 1,
      aux_sym__block_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(798), 2,
      anon_sym_SEMI,
      anon_sym_COMMA,
    ACTIONS(692), 14,
      sym_command_name,
      sym__single_quote_string_start,
      sym__double_quote_string_start,
      sym__multioutput_variable_start,
      ts_builtin_sym_end,
      anon_sym_LPAREN,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_AT,
      anon_sym_LBRACK,
      anon_sym_LBRACE,
      sym_number,
    ACTIONS(694), 18,
      sym_return_statement,
      sym_continue_statement,
      sym_break_statement,
      anon_sym_if,
      anon_sym_end,
      anon_sym_for,
      anon_sym_parfor,
      anon_sym_while,
      anon_sym_switch,
      anon_sym_global,
      anon_sym_persistent,
      anon_sym_function,
      anon_sym_endfunction,
      anon_sym_classdef,
      anon_sym_try,
      anon_sym_true,
      anon_sym_false,
      sym_identifier,
  [11262] = 25,
    ACTIONS(640), 1,
      anon_sym_LPAREN,
    ACTIONS(644), 1,
      anon_sym_TILDE,
    ACTIONS(650), 1,
      anon_sym_LBRACK,
    ACTIONS(652), 1,
      anon_sym_LBRACE,
    ACTIONS(662), 1,
      sym__single_quote_string_start,
    ACTIONS(664), 1,
      sym__double_quote_string_start,
    ACTIONS(767), 1,
      anon_sym_QMARK,
    ACTIONS(769), 1,
      anon_sym_AT,
    ACTIONS(787), 1,
      sym_identifier,
    ACTIONS(789), 1,
      sym_number,
    STATE(358), 1,
      sym_function_call,
    STATE(440), 1,
      sym_boolean,
    STATE(518), 1,
      sym_cell,
    STATE(534), 1,
      sym__range_element,
    STATE(544), 1,
      sym_not_operator,
    STATE(547), 1,
      sym_unary_operator,
    STATE(556), 1,
      sym_binary_operator,
    STATE(614), 1,
      sym__binary_expression,
    STATE(905), 1,
      sym_indirect_access,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(642), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(660), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(520), 2,
      sym_comparison_operator,
      sym_boolean_operator,
    STATE(549), 5,
      sym_parenthesis,
      sym_field_expression,
      sym_postfix_operator,
      sym_string,
      sym_matrix,
    STATE(700), 5,
      sym__expression,
      sym_metaclass_operator,
      sym_handle_operator,
      sym_range,
      sym_lambda,
  [11350] = 23,
    ACTIONS(640), 1,
      anon_sym_LPAREN,
    ACTIONS(644), 1,
      anon_sym_TILDE,
    ACTIONS(650), 1,
      anon_sym_LBRACK,
    ACTIONS(652), 1,
      anon_sym_LBRACE,
    ACTIONS(662), 1,
      sym__single_quote_string_start,
    ACTIONS(664), 1,
      sym__double_quote_string_start,
    ACTIONS(767), 1,
      anon_sym_QMARK,
    ACTIONS(769), 1,
      anon_sym_AT,
    ACTIONS(800), 1,
      sym_identifier,
    ACTIONS(802), 1,
      sym_number,
    STATE(375), 1,
      sym_function_call,
    STATE(448), 1,
      sym_boolean,
    STATE(529), 1,
      sym_binary_operator,
    STATE(552), 1,
      sym_cell,
    STATE(553), 1,
      sym_unary_operator,
    STATE(905), 1,
      sym_indirect_access,
    STATE(1196), 1,
      sym__range_element,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(642), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(660), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(535), 4,
      sym__binary_expression,
      sym_not_operator,
      sym_comparison_operator,
      sym_boolean_operator,
    STATE(563), 5,
      sym_parenthesis,
      sym_field_expression,
      sym_postfix_operator,
      sym_string,
      sym_matrix,
    STATE(689), 5,
      sym__expression,
      sym_metaclass_operator,
      sym_handle_operator,
      sym_range,
      sym_lambda,
  [11434] = 23,
    ACTIONS(640), 1,
      anon_sym_LPAREN,
    ACTIONS(644), 1,
      anon_sym_TILDE,
    ACTIONS(650), 1,
      anon_sym_LBRACK,
    ACTIONS(652), 1,
      anon_sym_LBRACE,
    ACTIONS(662), 1,
      sym__single_quote_string_start,
    ACTIONS(664), 1,
      sym__double_quote_string_start,
    ACTIONS(767), 1,
      anon_sym_QMARK,
    ACTIONS(769), 1,
      anon_sym_AT,
    ACTIONS(800), 1,
      sym_identifier,
    ACTIONS(802), 1,
      sym_number,
    STATE(375), 1,
      sym_function_call,
    STATE(448), 1,
      sym_boolean,
    STATE(529), 1,
      sym_binary_operator,
    STATE(552), 1,
      sym_cell,
    STATE(553), 1,
      sym_unary_operator,
    STATE(905), 1,
      sym_indirect_access,
    STATE(1196), 1,
      sym__range_element,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(642), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(660), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(537), 4,
      sym__binary_expression,
      sym_not_operator,
      sym_comparison_operator,
      sym_boolean_operator,
    STATE(563), 5,
      sym_parenthesis,
      sym_field_expression,
      sym_postfix_operator,
      sym_string,
      sym_matrix,
    STATE(689), 5,
      sym__expression,
      sym_metaclass_operator,
      sym_handle_operator,
      sym_range,
      sym_lambda,
  [11518] = 25,
    ACTIONS(9), 1,
      anon_sym_LPAREN,
    ACTIONS(15), 1,
      anon_sym_QMARK,
    ACTIONS(17), 1,
      anon_sym_AT,
    ACTIONS(19), 1,
      anon_sym_LBRACK,
    ACTIONS(21), 1,
      anon_sym_LBRACE,
    ACTIONS(45), 1,
      sym_number,
    ACTIONS(51), 1,
      sym__single_quote_string_start,
    ACTIONS(53), 1,
      sym__double_quote_string_start,
    ACTIONS(777), 1,
      anon_sym_TILDE,
    ACTIONS(785), 1,
      sym_identifier,
    STATE(190), 1,
      sym_function_call,
    STATE(205), 1,
      sym_boolean,
    STATE(389), 1,
      sym_unary_operator,
    STATE(422), 1,
      sym_binary_operator,
    STATE(423), 1,
      sym_cell,
    STATE(477), 1,
      sym_not_operator,
    STATE(622), 1,
      sym__binary_expression,
    STATE(994), 1,
      sym_indirect_access,
    STATE(1181), 1,
      sym__range_element,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(11), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(47), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(446), 2,
      sym_comparison_operator,
      sym_boolean_operator,
    STATE(411), 5,
      sym_parenthesis,
      sym_field_expression,
      sym_postfix_operator,
      sym_string,
      sym_matrix,
    STATE(515), 5,
      sym__expression,
      sym_metaclass_operator,
      sym_handle_operator,
      sym_range,
      sym_lambda,
  [11606] = 25,
    ACTIONS(640), 1,
      anon_sym_LPAREN,
    ACTIONS(644), 1,
      anon_sym_TILDE,
    ACTIONS(650), 1,
      anon_sym_LBRACK,
    ACTIONS(652), 1,
      anon_sym_LBRACE,
    ACTIONS(658), 1,
      sym_number,
    ACTIONS(662), 1,
      sym__single_quote_string_start,
    ACTIONS(664), 1,
      sym__double_quote_string_start,
    ACTIONS(767), 1,
      anon_sym_QMARK,
    ACTIONS(769), 1,
      anon_sym_AT,
    ACTIONS(804), 1,
      sym_identifier,
    STATE(402), 1,
      sym_boolean,
    STATE(427), 1,
      sym_function_call,
    STATE(518), 1,
      sym_cell,
    STATE(574), 1,
      sym_unary_operator,
    STATE(586), 1,
      sym_not_operator,
    STATE(589), 1,
      sym_binary_operator,
    STATE(614), 1,
      sym__binary_expression,
    STATE(905), 1,
      sym_indirect_access,
    STATE(1196), 1,
      sym__range_element,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(642), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(660), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(520), 2,
      sym_comparison_operator,
      sym_boolean_operator,
    STATE(576), 5,
      sym_parenthesis,
      sym_field_expression,
      sym_postfix_operator,
      sym_string,
      sym_matrix,
    STATE(700), 5,
      sym__expression,
      sym_metaclass_operator,
      sym_handle_operator,
      sym_range,
      sym_lambda,
  [11694] = 23,
    ACTIONS(640), 1,
      anon_sym_LPAREN,
    ACTIONS(644), 1,
      anon_sym_TILDE,
    ACTIONS(650), 1,
      anon_sym_LBRACK,
    ACTIONS(652), 1,
      anon_sym_LBRACE,
    ACTIONS(662), 1,
      sym__single_quote_string_start,
    ACTIONS(664), 1,
      sym__double_quote_string_start,
    ACTIONS(767), 1,
      anon_sym_QMARK,
    ACTIONS(769), 1,
      anon_sym_AT,
    ACTIONS(800), 1,
      sym_identifier,
    ACTIONS(802), 1,
      sym_number,
    STATE(375), 1,
      sym_function_call,
    STATE(448), 1,
      sym_boolean,
    STATE(529), 1,
      sym_binary_operator,
    STATE(552), 1,
      sym_cell,
    STATE(553), 1,
      sym_unary_operator,
    STATE(905), 1,
      sym_indirect_access,
    STATE(1196), 1,
      sym__range_element,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(642), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(660), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(538), 4,
      sym__binary_expression,
      sym_not_operator,
      sym_comparison_operator,
      sym_boolean_operator,
    STATE(563), 5,
      sym_parenthesis,
      sym_field_expression,
      sym_postfix_operator,
      sym_string,
      sym_matrix,
    STATE(689), 5,
      sym__expression,
      sym_metaclass_operator,
      sym_handle_operator,
      sym_range,
      sym_lambda,
  [11778] = 23,
    ACTIONS(640), 1,
      anon_sym_LPAREN,
    ACTIONS(644), 1,
      anon_sym_TILDE,
    ACTIONS(650), 1,
      anon_sym_LBRACK,
    ACTIONS(652), 1,
      anon_sym_LBRACE,
    ACTIONS(662), 1,
      sym__single_quote_string_start,
    ACTIONS(664), 1,
      sym__double_quote_string_start,
    ACTIONS(767), 1,
      anon_sym_QMARK,
    ACTIONS(769), 1,
      anon_sym_AT,
    ACTIONS(800), 1,
      sym_identifier,
    ACTIONS(802), 1,
      sym_number,
    STATE(375), 1,
      sym_function_call,
    STATE(448), 1,
      sym_boolean,
    STATE(529), 1,
      sym_binary_operator,
    STATE(552), 1,
      sym_cell,
    STATE(553), 1,
      sym_unary_operator,
    STATE(905), 1,
      sym_indirect_access,
    STATE(1196), 1,
      sym__range_element,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(642), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(660), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(539), 4,
      sym__binary_expression,
      sym_not_operator,
      sym_comparison_operator,
      sym_boolean_operator,
    STATE(563), 5,
      sym_parenthesis,
      sym_field_expression,
      sym_postfix_operator,
      sym_string,
      sym_matrix,
    STATE(689), 5,
      sym__expression,
      sym_metaclass_operator,
      sym_handle_operator,
      sym_range,
      sym_lambda,
  [11862] = 23,
    ACTIONS(640), 1,
      anon_sym_LPAREN,
    ACTIONS(644), 1,
      anon_sym_TILDE,
    ACTIONS(650), 1,
      anon_sym_LBRACK,
    ACTIONS(652), 1,
      anon_sym_LBRACE,
    ACTIONS(662), 1,
      sym__single_quote_string_start,
    ACTIONS(664), 1,
      sym__double_quote_string_start,
    ACTIONS(767), 1,
      anon_sym_QMARK,
    ACTIONS(769), 1,
      anon_sym_AT,
    ACTIONS(800), 1,
      sym_identifier,
    ACTIONS(802), 1,
      sym_number,
    STATE(375), 1,
      sym_function_call,
    STATE(448), 1,
      sym_boolean,
    STATE(529), 1,
      sym_binary_operator,
    STATE(552), 1,
      sym_cell,
    STATE(553), 1,
      sym_unary_operator,
    STATE(905), 1,
      sym_indirect_access,
    STATE(1196), 1,
      sym__range_element,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(642), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(660), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(540), 4,
      sym__binary_expression,
      sym_not_operator,
      sym_comparison_operator,
      sym_boolean_operator,
    STATE(563), 5,
      sym_parenthesis,
      sym_field_expression,
      sym_postfix_operator,
      sym_string,
      sym_matrix,
    STATE(689), 5,
      sym__expression,
      sym_metaclass_operator,
      sym_handle_operator,
      sym_range,
      sym_lambda,
  [11946] = 25,
    ACTIONS(640), 1,
      anon_sym_LPAREN,
    ACTIONS(644), 1,
      anon_sym_TILDE,
    ACTIONS(650), 1,
      anon_sym_LBRACK,
    ACTIONS(652), 1,
      anon_sym_LBRACE,
    ACTIONS(658), 1,
      sym_number,
    ACTIONS(662), 1,
      sym__single_quote_string_start,
    ACTIONS(664), 1,
      sym__double_quote_string_start,
    ACTIONS(794), 1,
      sym_identifier,
    ACTIONS(806), 1,
      anon_sym_QMARK,
    ACTIONS(808), 1,
      anon_sym_AT,
    STATE(368), 1,
      sym_function_call,
    STATE(402), 1,
      sym_boolean,
    STATE(518), 1,
      sym_cell,
    STATE(530), 1,
      sym_binary_operator,
    STATE(542), 1,
      sym_unary_operator,
    STATE(586), 1,
      sym_not_operator,
    STATE(614), 1,
      sym__binary_expression,
    STATE(905), 1,
      sym_indirect_access,
    STATE(1196), 1,
      sym__range_element,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(642), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(660), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(520), 2,
      sym_comparison_operator,
      sym_boolean_operator,
    STATE(521), 5,
      sym_parenthesis,
      sym_field_expression,
      sym_postfix_operator,
      sym_string,
      sym_matrix,
    STATE(596), 5,
      sym__expression,
      sym_metaclass_operator,
      sym_handle_operator,
      sym_range,
      sym_lambda,
  [12034] = 25,
    ACTIONS(640), 1,
      anon_sym_LPAREN,
    ACTIONS(644), 1,
      anon_sym_TILDE,
    ACTIONS(650), 1,
      anon_sym_LBRACK,
    ACTIONS(652), 1,
      anon_sym_LBRACE,
    ACTIONS(658), 1,
      sym_number,
    ACTIONS(662), 1,
      sym__single_quote_string_start,
    ACTIONS(664), 1,
      sym__double_quote_string_start,
    ACTIONS(794), 1,
      sym_identifier,
    ACTIONS(806), 1,
      anon_sym_QMARK,
    ACTIONS(808), 1,
      anon_sym_AT,
    STATE(368), 1,
      sym_function_call,
    STATE(402), 1,
      sym_boolean,
    STATE(518), 1,
      sym_cell,
    STATE(530), 1,
      sym_binary_operator,
    STATE(542), 1,
      sym_unary_operator,
    STATE(586), 1,
      sym_not_operator,
    STATE(614), 1,
      sym__binary_expression,
    STATE(905), 1,
      sym_indirect_access,
    STATE(1196), 1,
      sym__range_element,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(642), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(660), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(520), 2,
      sym_comparison_operator,
      sym_boolean_operator,
    STATE(521), 5,
      sym_parenthesis,
      sym_field_expression,
      sym_postfix_operator,
      sym_string,
      sym_matrix,
    STATE(597), 5,
      sym__expression,
      sym_metaclass_operator,
      sym_handle_operator,
      sym_range,
      sym_lambda,
  [12122] = 25,
    ACTIONS(9), 1,
      anon_sym_LPAREN,
    ACTIONS(15), 1,
      anon_sym_QMARK,
    ACTIONS(17), 1,
      anon_sym_AT,
    ACTIONS(19), 1,
      anon_sym_LBRACK,
    ACTIONS(21), 1,
      anon_sym_LBRACE,
    ACTIONS(45), 1,
      sym_number,
    ACTIONS(51), 1,
      sym__single_quote_string_start,
    ACTIONS(53), 1,
      sym__double_quote_string_start,
    ACTIONS(777), 1,
      anon_sym_TILDE,
    ACTIONS(785), 1,
      sym_identifier,
    STATE(190), 1,
      sym_function_call,
    STATE(205), 1,
      sym_boolean,
    STATE(389), 1,
      sym_unary_operator,
    STATE(422), 1,
      sym_binary_operator,
    STATE(423), 1,
      sym_cell,
    STATE(477), 1,
      sym_not_operator,
    STATE(622), 1,
      sym__binary_expression,
    STATE(994), 1,
      sym_indirect_access,
    STATE(1181), 1,
      sym__range_element,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(11), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(47), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(446), 2,
      sym_comparison_operator,
      sym_boolean_operator,
    STATE(411), 5,
      sym_parenthesis,
      sym_field_expression,
      sym_postfix_operator,
      sym_string,
      sym_matrix,
    STATE(512), 5,
      sym__expression,
      sym_metaclass_operator,
      sym_handle_operator,
      sym_range,
      sym_lambda,
  [12210] = 25,
    ACTIONS(640), 1,
      anon_sym_LPAREN,
    ACTIONS(644), 1,
      anon_sym_TILDE,
    ACTIONS(650), 1,
      anon_sym_LBRACK,
    ACTIONS(652), 1,
      anon_sym_LBRACE,
    ACTIONS(658), 1,
      sym_number,
    ACTIONS(662), 1,
      sym__single_quote_string_start,
    ACTIONS(664), 1,
      sym__double_quote_string_start,
    ACTIONS(794), 1,
      sym_identifier,
    ACTIONS(806), 1,
      anon_sym_QMARK,
    ACTIONS(808), 1,
      anon_sym_AT,
    STATE(368), 1,
      sym_function_call,
    STATE(402), 1,
      sym_boolean,
    STATE(518), 1,
      sym_cell,
    STATE(530), 1,
      sym_binary_operator,
    STATE(542), 1,
      sym_unary_operator,
    STATE(586), 1,
      sym_not_operator,
    STATE(614), 1,
      sym__binary_expression,
    STATE(905), 1,
      sym_indirect_access,
    STATE(1196), 1,
      sym__range_element,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(642), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(660), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(520), 2,
      sym_comparison_operator,
      sym_boolean_operator,
    STATE(521), 5,
      sym_parenthesis,
      sym_field_expression,
      sym_postfix_operator,
      sym_string,
      sym_matrix,
    STATE(543), 5,
      sym__expression,
      sym_metaclass_operator,
      sym_handle_operator,
      sym_range,
      sym_lambda,
  [12298] = 5,
    STATE(225), 1,
      aux_sym__block_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(810), 2,
      anon_sym_SEMI,
      anon_sym_COMMA,
    ACTIONS(347), 14,
      sym_command_name,
      sym__single_quote_string_start,
      sym__double_quote_string_start,
      sym__multioutput_variable_start,
      ts_builtin_sym_end,
      anon_sym_LPAREN,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_AT,
      anon_sym_LBRACK,
      anon_sym_LBRACE,
      sym_number,
    ACTIONS(279), 18,
      sym_return_statement,
      sym_continue_statement,
      sym_break_statement,
      anon_sym_if,
      anon_sym_end,
      anon_sym_for,
      anon_sym_parfor,
      anon_sym_while,
      anon_sym_switch,
      anon_sym_global,
      anon_sym_persistent,
      anon_sym_function,
      anon_sym_endfunction,
      anon_sym_classdef,
      anon_sym_try,
      anon_sym_true,
      anon_sym_false,
      sym_identifier,
  [12346] = 25,
    ACTIONS(640), 1,
      anon_sym_LPAREN,
    ACTIONS(644), 1,
      anon_sym_TILDE,
    ACTIONS(650), 1,
      anon_sym_LBRACK,
    ACTIONS(652), 1,
      anon_sym_LBRACE,
    ACTIONS(658), 1,
      sym_number,
    ACTIONS(662), 1,
      sym__single_quote_string_start,
    ACTIONS(664), 1,
      sym__double_quote_string_start,
    ACTIONS(794), 1,
      sym_identifier,
    ACTIONS(806), 1,
      anon_sym_QMARK,
    ACTIONS(808), 1,
      anon_sym_AT,
    STATE(368), 1,
      sym_function_call,
    STATE(402), 1,
      sym_boolean,
    STATE(518), 1,
      sym_cell,
    STATE(530), 1,
      sym_binary_operator,
    STATE(542), 1,
      sym_unary_operator,
    STATE(586), 1,
      sym_not_operator,
    STATE(614), 1,
      sym__binary_expression,
    STATE(905), 1,
      sym_indirect_access,
    STATE(1196), 1,
      sym__range_element,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(642), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(660), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(520), 2,
      sym_comparison_operator,
      sym_boolean_operator,
    STATE(521), 5,
      sym_parenthesis,
      sym_field_expression,
      sym_postfix_operator,
      sym_string,
      sym_matrix,
    STATE(593), 5,
      sym__expression,
      sym_metaclass_operator,
      sym_handle_operator,
      sym_range,
      sym_lambda,
  [12434] = 25,
    ACTIONS(640), 1,
      anon_sym_LPAREN,
    ACTIONS(644), 1,
      anon_sym_TILDE,
    ACTIONS(650), 1,
      anon_sym_LBRACK,
    ACTIONS(652), 1,
      anon_sym_LBRACE,
    ACTIONS(658), 1,
      sym_number,
    ACTIONS(662), 1,
      sym__single_quote_string_start,
    ACTIONS(664), 1,
      sym__double_quote_string_start,
    ACTIONS(794), 1,
      sym_identifier,
    ACTIONS(806), 1,
      anon_sym_QMARK,
    ACTIONS(808), 1,
      anon_sym_AT,
    STATE(368), 1,
      sym_function_call,
    STATE(402), 1,
      sym_boolean,
    STATE(518), 1,
      sym_cell,
    STATE(530), 1,
      sym_binary_operator,
    STATE(542), 1,
      sym_unary_operator,
    STATE(586), 1,
      sym_not_operator,
    STATE(614), 1,
      sym__binary_expression,
    STATE(905), 1,
      sym_indirect_access,
    STATE(1196), 1,
      sym__range_element,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(642), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(660), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(520), 2,
      sym_comparison_operator,
      sym_boolean_operator,
    STATE(521), 5,
      sym_parenthesis,
      sym_field_expression,
      sym_postfix_operator,
      sym_string,
      sym_matrix,
    STATE(598), 5,
      sym__expression,
      sym_metaclass_operator,
      sym_handle_operator,
      sym_range,
      sym_lambda,
  [12522] = 25,
    ACTIONS(640), 1,
      anon_sym_LPAREN,
    ACTIONS(644), 1,
      anon_sym_TILDE,
    ACTIONS(650), 1,
      anon_sym_LBRACK,
    ACTIONS(652), 1,
      anon_sym_LBRACE,
    ACTIONS(658), 1,
      sym_number,
    ACTIONS(662), 1,
      sym__single_quote_string_start,
    ACTIONS(664), 1,
      sym__double_quote_string_start,
    ACTIONS(767), 1,
      anon_sym_QMARK,
    ACTIONS(769), 1,
      anon_sym_AT,
    ACTIONS(812), 1,
      sym_identifier,
    STATE(402), 1,
      sym_boolean,
    STATE(414), 1,
      sym_function_call,
    STATE(518), 1,
      sym_cell,
    STATE(580), 1,
      sym_binary_operator,
    STATE(581), 1,
      sym_unary_operator,
    STATE(586), 1,
      sym_not_operator,
    STATE(614), 1,
      sym__binary_expression,
    STATE(905), 1,
      sym_indirect_access,
    STATE(1196), 1,
      sym__range_element,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(642), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(660), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(520), 2,
      sym_comparison_operator,
      sym_boolean_operator,
    STATE(578), 5,
      sym_parenthesis,
      sym_field_expression,
      sym_postfix_operator,
      sym_string,
      sym_matrix,
    STATE(700), 5,
      sym__expression,
      sym_metaclass_operator,
      sym_handle_operator,
      sym_range,
      sym_lambda,
  [12610] = 25,
    ACTIONS(640), 1,
      anon_sym_LPAREN,
    ACTIONS(644), 1,
      anon_sym_TILDE,
    ACTIONS(650), 1,
      anon_sym_LBRACK,
    ACTIONS(652), 1,
      anon_sym_LBRACE,
    ACTIONS(662), 1,
      sym__single_quote_string_start,
    ACTIONS(664), 1,
      sym__double_quote_string_start,
    ACTIONS(814), 1,
      sym_identifier,
    ACTIONS(816), 1,
      anon_sym_QMARK,
    ACTIONS(818), 1,
      anon_sym_AT,
    ACTIONS(820), 1,
      sym_number,
    STATE(377), 1,
      sym_function_call,
    STATE(394), 1,
      sym_boolean,
    STATE(518), 1,
      sym_cell,
    STATE(519), 1,
      sym_not_operator,
    STATE(531), 1,
      sym_unary_operator,
    STATE(561), 1,
      sym_binary_operator,
    STATE(614), 1,
      sym__binary_expression,
    STATE(905), 1,
      sym_indirect_access,
    STATE(1196), 1,
      sym__range_element,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(642), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(660), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(520), 2,
      sym_comparison_operator,
      sym_boolean_operator,
    STATE(527), 5,
      sym_parenthesis,
      sym_field_expression,
      sym_postfix_operator,
      sym_string,
      sym_matrix,
    STATE(551), 5,
      sym__expression,
      sym_metaclass_operator,
      sym_handle_operator,
      sym_range,
      sym_lambda,
  [12698] = 25,
    ACTIONS(9), 1,
      anon_sym_LPAREN,
    ACTIONS(19), 1,
      anon_sym_LBRACK,
    ACTIONS(21), 1,
      anon_sym_LBRACE,
    ACTIONS(51), 1,
      sym__single_quote_string_start,
    ACTIONS(53), 1,
      sym__double_quote_string_start,
    ACTIONS(775), 1,
      sym_identifier,
    ACTIONS(777), 1,
      anon_sym_TILDE,
    ACTIONS(779), 1,
      anon_sym_QMARK,
    ACTIONS(781), 1,
      anon_sym_AT,
    ACTIONS(783), 1,
      sym_number,
    STATE(187), 1,
      sym_function_call,
    STATE(219), 1,
      sym_boolean,
    STATE(404), 1,
      sym_unary_operator,
    STATE(407), 1,
      sym_binary_operator,
    STATE(409), 1,
      sym_not_operator,
    STATE(423), 1,
      sym_cell,
    STATE(622), 1,
      sym__binary_expression,
    STATE(994), 1,
      sym_indirect_access,
    STATE(1181), 1,
      sym__range_element,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(11), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(47), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(446), 2,
      sym_comparison_operator,
      sym_boolean_operator,
    STATE(392), 5,
      sym_parenthesis,
      sym_field_expression,
      sym_postfix_operator,
      sym_string,
      sym_matrix,
    STATE(420), 5,
      sym__expression,
      sym_metaclass_operator,
      sym_handle_operator,
      sym_range,
      sym_lambda,
  [12786] = 25,
    ACTIONS(640), 1,
      anon_sym_LPAREN,
    ACTIONS(644), 1,
      anon_sym_TILDE,
    ACTIONS(650), 1,
      anon_sym_LBRACK,
    ACTIONS(652), 1,
      anon_sym_LBRACE,
    ACTIONS(658), 1,
      sym_number,
    ACTIONS(662), 1,
      sym__single_quote_string_start,
    ACTIONS(664), 1,
      sym__double_quote_string_start,
    ACTIONS(767), 1,
      anon_sym_QMARK,
    ACTIONS(769), 1,
      anon_sym_AT,
    ACTIONS(794), 1,
      sym_identifier,
    STATE(368), 1,
      sym_function_call,
    STATE(402), 1,
      sym_boolean,
    STATE(518), 1,
      sym_cell,
    STATE(530), 1,
      sym_binary_operator,
    STATE(542), 1,
      sym_unary_operator,
    STATE(586), 1,
      sym_not_operator,
    STATE(614), 1,
      sym__binary_expression,
    STATE(905), 1,
      sym_indirect_access,
    STATE(1196), 1,
      sym__range_element,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(642), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(660), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(520), 2,
      sym_comparison_operator,
      sym_boolean_operator,
    STATE(521), 5,
      sym_parenthesis,
      sym_field_expression,
      sym_postfix_operator,
      sym_string,
      sym_matrix,
    STATE(595), 5,
      sym__expression,
      sym_metaclass_operator,
      sym_handle_operator,
      sym_range,
      sym_lambda,
  [12874] = 14,
    ACTIONS(381), 1,
      anon_sym_COLON,
    ACTIONS(822), 1,
      anon_sym_LPAREN,
    ACTIONS(824), 1,
      anon_sym_DOT,
    ACTIONS(826), 1,
      anon_sym_AT,
    ACTIONS(830), 1,
      anon_sym_LBRACE,
    ACTIONS(832), 1,
      anon_sym_EQ,
    STATE(437), 1,
      sym__args,
    STATE(483), 1,
      aux_sym_field_expression_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(360), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(364), 2,
      anon_sym_PIPE,
      anon_sym_AMP,
    ACTIONS(828), 2,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(376), 9,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_RBRACE,
    ACTIONS(387), 12,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
  [12940] = 25,
    ACTIONS(834), 1,
      sym_identifier,
    ACTIONS(836), 1,
      anon_sym_LPAREN,
    ACTIONS(840), 1,
      anon_sym_TILDE,
    ACTIONS(842), 1,
      anon_sym_QMARK,
    ACTIONS(844), 1,
      anon_sym_AT,
    ACTIONS(846), 1,
      anon_sym_LBRACK,
    ACTIONS(848), 1,
      anon_sym_LBRACE,
    ACTIONS(850), 1,
      sym_number,
    ACTIONS(854), 1,
      sym__single_quote_string_start,
    ACTIONS(856), 1,
      sym__double_quote_string_start,
    STATE(76), 1,
      sym_function_call,
    STATE(91), 1,
      sym_boolean,
    STATE(109), 1,
      sym_cell,
    STATE(124), 1,
      sym_binary_operator,
    STATE(126), 1,
      sym_unary_operator,
    STATE(146), 1,
      sym_not_operator,
    STATE(617), 1,
      sym__binary_expression,
    STATE(956), 1,
      sym_indirect_access,
    STATE(1159), 1,
      sym__range_element,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(838), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(852), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(114), 2,
      sym_comparison_operator,
      sym_boolean_operator,
    STATE(127), 5,
      sym_parenthesis,
      sym_field_expression,
      sym_postfix_operator,
      sym_string,
      sym_matrix,
    STATE(157), 5,
      sym__expression,
      sym_metaclass_operator,
      sym_handle_operator,
      sym_range,
      sym_lambda,
  [13028] = 25,
    ACTIONS(834), 1,
      sym_identifier,
    ACTIONS(836), 1,
      anon_sym_LPAREN,
    ACTIONS(840), 1,
      anon_sym_TILDE,
    ACTIONS(842), 1,
      anon_sym_QMARK,
    ACTIONS(844), 1,
      anon_sym_AT,
    ACTIONS(846), 1,
      anon_sym_LBRACK,
    ACTIONS(848), 1,
      anon_sym_LBRACE,
    ACTIONS(850), 1,
      sym_number,
    ACTIONS(854), 1,
      sym__single_quote_string_start,
    ACTIONS(856), 1,
      sym__double_quote_string_start,
    STATE(76), 1,
      sym_function_call,
    STATE(91), 1,
      sym_boolean,
    STATE(109), 1,
      sym_cell,
    STATE(124), 1,
      sym_binary_operator,
    STATE(126), 1,
      sym_unary_operator,
    STATE(146), 1,
      sym_not_operator,
    STATE(617), 1,
      sym__binary_expression,
    STATE(956), 1,
      sym_indirect_access,
    STATE(1159), 1,
      sym__range_element,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(838), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(852), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(114), 2,
      sym_comparison_operator,
      sym_boolean_operator,
    STATE(127), 5,
      sym_parenthesis,
      sym_field_expression,
      sym_postfix_operator,
      sym_string,
      sym_matrix,
    STATE(150), 5,
      sym__expression,
      sym_metaclass_operator,
      sym_handle_operator,
      sym_range,
      sym_lambda,
  [13116] = 25,
    ACTIONS(9), 1,
      anon_sym_LPAREN,
    ACTIONS(19), 1,
      anon_sym_LBRACK,
    ACTIONS(21), 1,
      anon_sym_LBRACE,
    ACTIONS(45), 1,
      sym_number,
    ACTIONS(51), 1,
      sym__single_quote_string_start,
    ACTIONS(53), 1,
      sym__double_quote_string_start,
    ACTIONS(777), 1,
      anon_sym_TILDE,
    ACTIONS(785), 1,
      sym_identifier,
    ACTIONS(858), 1,
      anon_sym_QMARK,
    ACTIONS(860), 1,
      anon_sym_AT,
    STATE(190), 1,
      sym_function_call,
    STATE(205), 1,
      sym_boolean,
    STATE(389), 1,
      sym_unary_operator,
    STATE(422), 1,
      sym_binary_operator,
    STATE(423), 1,
      sym_cell,
    STATE(477), 1,
      sym_not_operator,
    STATE(622), 1,
      sym__binary_expression,
    STATE(994), 1,
      sym_indirect_access,
    STATE(1181), 1,
      sym__range_element,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(11), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(47), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(446), 2,
      sym_comparison_operator,
      sym_boolean_operator,
    STATE(411), 5,
      sym_parenthesis,
      sym_field_expression,
      sym_postfix_operator,
      sym_string,
      sym_matrix,
    STATE(512), 5,
      sym__expression,
      sym_metaclass_operator,
      sym_handle_operator,
      sym_range,
      sym_lambda,
  [13204] = 25,
    ACTIONS(836), 1,
      anon_sym_LPAREN,
    ACTIONS(840), 1,
      anon_sym_TILDE,
    ACTIONS(846), 1,
      anon_sym_LBRACK,
    ACTIONS(848), 1,
      anon_sym_LBRACE,
    ACTIONS(854), 1,
      sym__single_quote_string_start,
    ACTIONS(856), 1,
      sym__double_quote_string_start,
    ACTIONS(862), 1,
      sym_identifier,
    ACTIONS(864), 1,
      anon_sym_QMARK,
    ACTIONS(866), 1,
      anon_sym_AT,
    ACTIONS(868), 1,
      sym_number,
    STATE(80), 1,
      sym_function_call,
    STATE(99), 1,
      sym_boolean,
    STATE(105), 1,
      sym_unary_operator,
    STATE(109), 1,
      sym_cell,
    STATE(121), 1,
      sym_binary_operator,
    STATE(139), 1,
      sym_not_operator,
    STATE(617), 1,
      sym__binary_expression,
    STATE(956), 1,
      sym_indirect_access,
    STATE(1159), 1,
      sym__range_element,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(838), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(852), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(114), 2,
      sym_comparison_operator,
      sym_boolean_operator,
    STATE(104), 5,
      sym_parenthesis,
      sym_field_expression,
      sym_postfix_operator,
      sym_string,
      sym_matrix,
    STATE(116), 5,
      sym__expression,
      sym_metaclass_operator,
      sym_handle_operator,
      sym_range,
      sym_lambda,
  [13292] = 25,
    ACTIONS(640), 1,
      anon_sym_LPAREN,
    ACTIONS(644), 1,
      anon_sym_TILDE,
    ACTIONS(650), 1,
      anon_sym_LBRACK,
    ACTIONS(652), 1,
      anon_sym_LBRACE,
    ACTIONS(658), 1,
      sym_number,
    ACTIONS(662), 1,
      sym__single_quote_string_start,
    ACTIONS(664), 1,
      sym__double_quote_string_start,
    ACTIONS(767), 1,
      anon_sym_QMARK,
    ACTIONS(769), 1,
      anon_sym_AT,
    ACTIONS(870), 1,
      sym_identifier,
    STATE(402), 1,
      sym_boolean,
    STATE(442), 1,
      sym_function_call,
    STATE(518), 1,
      sym_cell,
    STATE(564), 1,
      sym_binary_operator,
    STATE(565), 1,
      sym_unary_operator,
    STATE(586), 1,
      sym_not_operator,
    STATE(614), 1,
      sym__binary_expression,
    STATE(905), 1,
      sym_indirect_access,
    STATE(1196), 1,
      sym__range_element,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(642), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(660), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(520), 2,
      sym_comparison_operator,
      sym_boolean_operator,
    STATE(570), 5,
      sym_parenthesis,
      sym_field_expression,
      sym_postfix_operator,
      sym_string,
      sym_matrix,
    STATE(687), 5,
      sym__expression,
      sym_metaclass_operator,
      sym_handle_operator,
      sym_range,
      sym_lambda,
  [13380] = 14,
    ACTIONS(381), 1,
      anon_sym_COLON,
    ACTIONS(822), 1,
      anon_sym_LPAREN,
    ACTIONS(824), 1,
      anon_sym_DOT,
    ACTIONS(826), 1,
      anon_sym_AT,
    ACTIONS(830), 1,
      anon_sym_LBRACE,
    ACTIONS(872), 1,
      anon_sym_EQ,
    STATE(437), 1,
      sym__args,
    STATE(483), 1,
      aux_sym_field_expression_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(360), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(364), 2,
      anon_sym_PIPE,
      anon_sym_AMP,
    ACTIONS(828), 2,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(376), 9,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_RBRACE,
    ACTIONS(387), 12,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
  [13446] = 25,
    ACTIONS(597), 1,
      sym__single_quote_string_start,
    ACTIONS(599), 1,
      sym__double_quote_string_start,
    ACTIONS(672), 1,
      anon_sym_LPAREN,
    ACTIONS(682), 1,
      anon_sym_LBRACK,
    ACTIONS(686), 1,
      anon_sym_LBRACE,
    ACTIONS(767), 1,
      anon_sym_QMARK,
    ACTIONS(769), 1,
      anon_sym_AT,
    ACTIONS(874), 1,
      sym_identifier,
    ACTIONS(876), 1,
      anon_sym_TILDE,
    ACTIONS(878), 1,
      sym_number,
    STATE(217), 1,
      sym_function_call,
    STATE(357), 1,
      sym_boolean,
    STATE(497), 1,
      sym_cell,
    STATE(498), 1,
      sym_not_operator,
    STATE(501), 1,
      sym_unary_operator,
    STATE(592), 1,
      sym_binary_operator,
    STATE(614), 1,
      sym__binary_expression,
    STATE(919), 1,
      sym_indirect_access,
    STATE(1196), 1,
      sym__range_element,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(595), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(674), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    STATE(520), 2,
      sym_comparison_operator,
      sym_boolean_operator,
    STATE(503), 5,
      sym_parenthesis,
      sym_field_expression,
      sym_postfix_operator,
      sym_string,
      sym_matrix,
    STATE(700), 5,
      sym__expression,
      sym_metaclass_operator,
      sym_handle_operator,
      sym_range,
      sym_lambda,
  [13534] = 25,
    ACTIONS(640), 1,
      anon_sym_LPAREN,
    ACTIONS(644), 1,
      anon_sym_TILDE,
    ACTIONS(650), 1,
      anon_sym_LBRACK,
    ACTIONS(652), 1,
      anon_sym_LBRACE,
    ACTIONS(658), 1,
      sym_number,
    ACTIONS(662), 1,
      sym__single_quote_string_start,
    ACTIONS(664), 1,
      sym__double_quote_string_start,
    ACTIONS(767), 1,
      anon_sym_QMARK,
    ACTIONS(769), 1,
      anon_sym_AT,
    ACTIONS(794), 1,
      sym_identifier,
    STATE(368), 1,
      sym_function_call,
    STATE(402), 1,
      sym_boolean,
    STATE(518), 1,
      sym_cell,
    STATE(530), 1,
      sym_binary_operator,
    STATE(542), 1,
      sym_unary_operator,
    STATE(586), 1,
      sym_not_operator,
    STATE(614), 1,
      sym__binary_expression,
    STATE(905), 1,
      sym_indirect_access,
    STATE(1196), 1,
      sym__range_element,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(642), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(660), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(520), 2,
      sym_comparison_operator,
      sym_boolean_operator,
    STATE(521), 5,
      sym_parenthesis,
      sym_field_expression,
      sym_postfix_operator,
      sym_string,
      sym_matrix,
    STATE(685), 5,
      sym__expression,
      sym_metaclass_operator,
      sym_handle_operator,
      sym_range,
      sym_lambda,
  [13622] = 25,
    ACTIONS(9), 1,
      anon_sym_LPAREN,
    ACTIONS(19), 1,
      anon_sym_LBRACK,
    ACTIONS(21), 1,
      anon_sym_LBRACE,
    ACTIONS(51), 1,
      sym__single_quote_string_start,
    ACTIONS(53), 1,
      sym__double_quote_string_start,
    ACTIONS(775), 1,
      sym_identifier,
    ACTIONS(777), 1,
      anon_sym_TILDE,
    ACTIONS(779), 1,
      anon_sym_QMARK,
    ACTIONS(781), 1,
      anon_sym_AT,
    ACTIONS(783), 1,
      sym_number,
    STATE(187), 1,
      sym_function_call,
    STATE(219), 1,
      sym_boolean,
    STATE(404), 1,
      sym_unary_operator,
    STATE(407), 1,
      sym_binary_operator,
    STATE(409), 1,
      sym_not_operator,
    STATE(423), 1,
      sym_cell,
    STATE(622), 1,
      sym__binary_expression,
    STATE(994), 1,
      sym_indirect_access,
    STATE(1181), 1,
      sym__range_element,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(11), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(47), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(446), 2,
      sym_comparison_operator,
      sym_boolean_operator,
    STATE(392), 5,
      sym_parenthesis,
      sym_field_expression,
      sym_postfix_operator,
      sym_string,
      sym_matrix,
    STATE(396), 5,
      sym__expression,
      sym_metaclass_operator,
      sym_handle_operator,
      sym_range,
      sym_lambda,
  [13710] = 25,
    ACTIONS(9), 1,
      anon_sym_LPAREN,
    ACTIONS(19), 1,
      anon_sym_LBRACK,
    ACTIONS(21), 1,
      anon_sym_LBRACE,
    ACTIONS(51), 1,
      sym__single_quote_string_start,
    ACTIONS(53), 1,
      sym__double_quote_string_start,
    ACTIONS(775), 1,
      sym_identifier,
    ACTIONS(777), 1,
      anon_sym_TILDE,
    ACTIONS(779), 1,
      anon_sym_QMARK,
    ACTIONS(781), 1,
      anon_sym_AT,
    ACTIONS(783), 1,
      sym_number,
    STATE(187), 1,
      sym_function_call,
    STATE(219), 1,
      sym_boolean,
    STATE(404), 1,
      sym_unary_operator,
    STATE(407), 1,
      sym_binary_operator,
    STATE(409), 1,
      sym_not_operator,
    STATE(423), 1,
      sym_cell,
    STATE(622), 1,
      sym__binary_expression,
    STATE(994), 1,
      sym_indirect_access,
    STATE(1181), 1,
      sym__range_element,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(11), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(47), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(446), 2,
      sym_comparison_operator,
      sym_boolean_operator,
    STATE(392), 5,
      sym_parenthesis,
      sym_field_expression,
      sym_postfix_operator,
      sym_string,
      sym_matrix,
    STATE(452), 5,
      sym__expression,
      sym_metaclass_operator,
      sym_handle_operator,
      sym_range,
      sym_lambda,
  [13798] = 25,
    ACTIONS(9), 1,
      anon_sym_LPAREN,
    ACTIONS(19), 1,
      anon_sym_LBRACK,
    ACTIONS(21), 1,
      anon_sym_LBRACE,
    ACTIONS(51), 1,
      sym__single_quote_string_start,
    ACTIONS(53), 1,
      sym__double_quote_string_start,
    ACTIONS(775), 1,
      sym_identifier,
    ACTIONS(777), 1,
      anon_sym_TILDE,
    ACTIONS(779), 1,
      anon_sym_QMARK,
    ACTIONS(781), 1,
      anon_sym_AT,
    ACTIONS(783), 1,
      sym_number,
    STATE(187), 1,
      sym_function_call,
    STATE(219), 1,
      sym_boolean,
    STATE(404), 1,
      sym_unary_operator,
    STATE(407), 1,
      sym_binary_operator,
    STATE(409), 1,
      sym_not_operator,
    STATE(423), 1,
      sym_cell,
    STATE(622), 1,
      sym__binary_expression,
    STATE(994), 1,
      sym_indirect_access,
    STATE(1181), 1,
      sym__range_element,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(11), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(47), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(446), 2,
      sym_comparison_operator,
      sym_boolean_operator,
    STATE(392), 5,
      sym_parenthesis,
      sym_field_expression,
      sym_postfix_operator,
      sym_string,
      sym_matrix,
    STATE(447), 5,
      sym__expression,
      sym_metaclass_operator,
      sym_handle_operator,
      sym_range,
      sym_lambda,
  [13886] = 25,
    ACTIONS(9), 1,
      anon_sym_LPAREN,
    ACTIONS(19), 1,
      anon_sym_LBRACK,
    ACTIONS(21), 1,
      anon_sym_LBRACE,
    ACTIONS(45), 1,
      sym_number,
    ACTIONS(51), 1,
      sym__single_quote_string_start,
    ACTIONS(53), 1,
      sym__double_quote_string_start,
    ACTIONS(777), 1,
      anon_sym_TILDE,
    ACTIONS(785), 1,
      sym_identifier,
    ACTIONS(858), 1,
      anon_sym_QMARK,
    ACTIONS(860), 1,
      anon_sym_AT,
    STATE(190), 1,
      sym_function_call,
    STATE(205), 1,
      sym_boolean,
    STATE(389), 1,
      sym_unary_operator,
    STATE(422), 1,
      sym_binary_operator,
    STATE(423), 1,
      sym_cell,
    STATE(477), 1,
      sym_not_operator,
    STATE(622), 1,
      sym__binary_expression,
    STATE(994), 1,
      sym_indirect_access,
    STATE(1181), 1,
      sym__range_element,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(11), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(47), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(446), 2,
      sym_comparison_operator,
      sym_boolean_operator,
    STATE(411), 5,
      sym_parenthesis,
      sym_field_expression,
      sym_postfix_operator,
      sym_string,
      sym_matrix,
    STATE(515), 5,
      sym__expression,
      sym_metaclass_operator,
      sym_handle_operator,
      sym_range,
      sym_lambda,
  [13974] = 23,
    ACTIONS(597), 1,
      sym__single_quote_string_start,
    ACTIONS(599), 1,
      sym__double_quote_string_start,
    ACTIONS(672), 1,
      anon_sym_LPAREN,
    ACTIONS(682), 1,
      anon_sym_LBRACK,
    ACTIONS(686), 1,
      anon_sym_LBRACE,
    ACTIONS(767), 1,
      anon_sym_QMARK,
    ACTIONS(769), 1,
      anon_sym_AT,
    ACTIONS(876), 1,
      anon_sym_TILDE,
    ACTIONS(880), 1,
      sym_identifier,
    ACTIONS(882), 1,
      sym_number,
    STATE(214), 1,
      sym_function_call,
    STATE(374), 1,
      sym_boolean,
    STATE(472), 1,
      sym_binary_operator,
    STATE(489), 1,
      sym_unary_operator,
    STATE(505), 1,
      sym_cell,
    STATE(919), 1,
      sym_indirect_access,
    STATE(1196), 1,
      sym__range_element,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(595), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(674), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    STATE(468), 4,
      sym__binary_expression,
      sym_not_operator,
      sym_comparison_operator,
      sym_boolean_operator,
    STATE(480), 5,
      sym_parenthesis,
      sym_field_expression,
      sym_postfix_operator,
      sym_string,
      sym_matrix,
    STATE(690), 5,
      sym__expression,
      sym_metaclass_operator,
      sym_handle_operator,
      sym_range,
      sym_lambda,
  [14058] = 23,
    ACTIONS(597), 1,
      sym__single_quote_string_start,
    ACTIONS(599), 1,
      sym__double_quote_string_start,
    ACTIONS(672), 1,
      anon_sym_LPAREN,
    ACTIONS(682), 1,
      anon_sym_LBRACK,
    ACTIONS(686), 1,
      anon_sym_LBRACE,
    ACTIONS(767), 1,
      anon_sym_QMARK,
    ACTIONS(769), 1,
      anon_sym_AT,
    ACTIONS(876), 1,
      anon_sym_TILDE,
    ACTIONS(880), 1,
      sym_identifier,
    ACTIONS(882), 1,
      sym_number,
    STATE(214), 1,
      sym_function_call,
    STATE(374), 1,
      sym_boolean,
    STATE(472), 1,
      sym_binary_operator,
    STATE(489), 1,
      sym_unary_operator,
    STATE(505), 1,
      sym_cell,
    STATE(919), 1,
      sym_indirect_access,
    STATE(1196), 1,
      sym__range_element,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(595), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(674), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    STATE(470), 4,
      sym__binary_expression,
      sym_not_operator,
      sym_comparison_operator,
      sym_boolean_operator,
    STATE(480), 5,
      sym_parenthesis,
      sym_field_expression,
      sym_postfix_operator,
      sym_string,
      sym_matrix,
    STATE(690), 5,
      sym__expression,
      sym_metaclass_operator,
      sym_handle_operator,
      sym_range,
      sym_lambda,
  [14142] = 23,
    ACTIONS(597), 1,
      sym__single_quote_string_start,
    ACTIONS(599), 1,
      sym__double_quote_string_start,
    ACTIONS(672), 1,
      anon_sym_LPAREN,
    ACTIONS(682), 1,
      anon_sym_LBRACK,
    ACTIONS(686), 1,
      anon_sym_LBRACE,
    ACTIONS(767), 1,
      anon_sym_QMARK,
    ACTIONS(769), 1,
      anon_sym_AT,
    ACTIONS(876), 1,
      anon_sym_TILDE,
    ACTIONS(880), 1,
      sym_identifier,
    ACTIONS(882), 1,
      sym_number,
    STATE(214), 1,
      sym_function_call,
    STATE(374), 1,
      sym_boolean,
    STATE(472), 1,
      sym_binary_operator,
    STATE(489), 1,
      sym_unary_operator,
    STATE(505), 1,
      sym_cell,
    STATE(919), 1,
      sym_indirect_access,
    STATE(1196), 1,
      sym__range_element,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(595), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(674), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    STATE(471), 4,
      sym__binary_expression,
      sym_not_operator,
      sym_comparison_operator,
      sym_boolean_operator,
    STATE(480), 5,
      sym_parenthesis,
      sym_field_expression,
      sym_postfix_operator,
      sym_string,
      sym_matrix,
    STATE(690), 5,
      sym__expression,
      sym_metaclass_operator,
      sym_handle_operator,
      sym_range,
      sym_lambda,
  [14226] = 23,
    ACTIONS(597), 1,
      sym__single_quote_string_start,
    ACTIONS(599), 1,
      sym__double_quote_string_start,
    ACTIONS(672), 1,
      anon_sym_LPAREN,
    ACTIONS(682), 1,
      anon_sym_LBRACK,
    ACTIONS(686), 1,
      anon_sym_LBRACE,
    ACTIONS(767), 1,
      anon_sym_QMARK,
    ACTIONS(769), 1,
      anon_sym_AT,
    ACTIONS(876), 1,
      anon_sym_TILDE,
    ACTIONS(880), 1,
      sym_identifier,
    ACTIONS(882), 1,
      sym_number,
    STATE(214), 1,
      sym_function_call,
    STATE(374), 1,
      sym_boolean,
    STATE(472), 1,
      sym_binary_operator,
    STATE(489), 1,
      sym_unary_operator,
    STATE(505), 1,
      sym_cell,
    STATE(919), 1,
      sym_indirect_access,
    STATE(1196), 1,
      sym__range_element,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(595), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(674), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    STATE(474), 4,
      sym__binary_expression,
      sym_not_operator,
      sym_comparison_operator,
      sym_boolean_operator,
    STATE(480), 5,
      sym_parenthesis,
      sym_field_expression,
      sym_postfix_operator,
      sym_string,
      sym_matrix,
    STATE(690), 5,
      sym__expression,
      sym_metaclass_operator,
      sym_handle_operator,
      sym_range,
      sym_lambda,
  [14310] = 23,
    ACTIONS(597), 1,
      sym__single_quote_string_start,
    ACTIONS(599), 1,
      sym__double_quote_string_start,
    ACTIONS(672), 1,
      anon_sym_LPAREN,
    ACTIONS(682), 1,
      anon_sym_LBRACK,
    ACTIONS(686), 1,
      anon_sym_LBRACE,
    ACTIONS(767), 1,
      anon_sym_QMARK,
    ACTIONS(769), 1,
      anon_sym_AT,
    ACTIONS(876), 1,
      anon_sym_TILDE,
    ACTIONS(880), 1,
      sym_identifier,
    ACTIONS(882), 1,
      sym_number,
    STATE(214), 1,
      sym_function_call,
    STATE(374), 1,
      sym_boolean,
    STATE(472), 1,
      sym_binary_operator,
    STATE(489), 1,
      sym_unary_operator,
    STATE(505), 1,
      sym_cell,
    STATE(919), 1,
      sym_indirect_access,
    STATE(1196), 1,
      sym__range_element,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(595), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(674), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    STATE(475), 4,
      sym__binary_expression,
      sym_not_operator,
      sym_comparison_operator,
      sym_boolean_operator,
    STATE(480), 5,
      sym_parenthesis,
      sym_field_expression,
      sym_postfix_operator,
      sym_string,
      sym_matrix,
    STATE(690), 5,
      sym__expression,
      sym_metaclass_operator,
      sym_handle_operator,
      sym_range,
      sym_lambda,
  [14394] = 25,
    ACTIONS(597), 1,
      sym__single_quote_string_start,
    ACTIONS(599), 1,
      sym__double_quote_string_start,
    ACTIONS(652), 1,
      anon_sym_LBRACE,
    ACTIONS(672), 1,
      anon_sym_LPAREN,
    ACTIONS(682), 1,
      anon_sym_LBRACK,
    ACTIONS(767), 1,
      anon_sym_QMARK,
    ACTIONS(769), 1,
      anon_sym_AT,
    ACTIONS(876), 1,
      anon_sym_TILDE,
    ACTIONS(884), 1,
      sym_identifier,
    ACTIONS(886), 1,
      sym_number,
    STATE(212), 1,
      sym_function_call,
    STATE(371), 1,
      sym_boolean,
    STATE(476), 1,
      sym__range_element,
    STATE(495), 1,
      sym_binary_operator,
    STATE(496), 1,
      sym_unary_operator,
    STATE(500), 1,
      sym_not_operator,
    STATE(602), 1,
      sym_cell,
    STATE(615), 1,
      sym__binary_expression,
    STATE(919), 1,
      sym_indirect_access,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(595), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(674), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    STATE(520), 2,
      sym_comparison_operator,
      sym_boolean_operator,
    STATE(492), 5,
      sym_parenthesis,
      sym_field_expression,
      sym_postfix_operator,
      sym_string,
      sym_matrix,
    STATE(700), 5,
      sym__expression,
      sym_metaclass_operator,
      sym_handle_operator,
      sym_range,
      sym_lambda,
  [14482] = 25,
    ACTIONS(9), 1,
      anon_sym_LPAREN,
    ACTIONS(19), 1,
      anon_sym_LBRACK,
    ACTIONS(21), 1,
      anon_sym_LBRACE,
    ACTIONS(51), 1,
      sym__single_quote_string_start,
    ACTIONS(53), 1,
      sym__double_quote_string_start,
    ACTIONS(767), 1,
      anon_sym_QMARK,
    ACTIONS(769), 1,
      anon_sym_AT,
    ACTIONS(777), 1,
      anon_sym_TILDE,
    ACTIONS(888), 1,
      sym_identifier,
    ACTIONS(890), 1,
      sym_number,
    STATE(188), 1,
      sym_function_call,
    STATE(206), 1,
      sym_boolean,
    STATE(421), 1,
      sym_cell,
    STATE(428), 1,
      sym_not_operator,
    STATE(431), 1,
      sym_unary_operator,
    STATE(591), 1,
      sym_binary_operator,
    STATE(614), 1,
      sym__binary_expression,
    STATE(994), 1,
      sym_indirect_access,
    STATE(1196), 1,
      sym__range_element,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(11), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(47), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(520), 2,
      sym_comparison_operator,
      sym_boolean_operator,
    STATE(434), 5,
      sym_parenthesis,
      sym_field_expression,
      sym_postfix_operator,
      sym_string,
      sym_matrix,
    STATE(700), 5,
      sym__expression,
      sym_metaclass_operator,
      sym_handle_operator,
      sym_range,
      sym_lambda,
  [14570] = 25,
    ACTIONS(834), 1,
      sym_identifier,
    ACTIONS(836), 1,
      anon_sym_LPAREN,
    ACTIONS(840), 1,
      anon_sym_TILDE,
    ACTIONS(846), 1,
      anon_sym_LBRACK,
    ACTIONS(848), 1,
      anon_sym_LBRACE,
    ACTIONS(850), 1,
      sym_number,
    ACTIONS(854), 1,
      sym__single_quote_string_start,
    ACTIONS(856), 1,
      sym__double_quote_string_start,
    ACTIONS(892), 1,
      anon_sym_QMARK,
    ACTIONS(894), 1,
      anon_sym_AT,
    STATE(76), 1,
      sym_function_call,
    STATE(91), 1,
      sym_boolean,
    STATE(109), 1,
      sym_cell,
    STATE(124), 1,
      sym_binary_operator,
    STATE(126), 1,
      sym_unary_operator,
    STATE(146), 1,
      sym_not_operator,
    STATE(617), 1,
      sym__binary_expression,
    STATE(956), 1,
      sym_indirect_access,
    STATE(1159), 1,
      sym__range_element,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(838), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(852), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(114), 2,
      sym_comparison_operator,
      sym_boolean_operator,
    STATE(101), 5,
      sym__expression,
      sym_metaclass_operator,
      sym_handle_operator,
      sym_range,
      sym_lambda,
    STATE(127), 5,
      sym_parenthesis,
      sym_field_expression,
      sym_postfix_operator,
      sym_string,
      sym_matrix,
  [14658] = 25,
    ACTIONS(9), 1,
      anon_sym_LPAREN,
    ACTIONS(19), 1,
      anon_sym_LBRACK,
    ACTIONS(21), 1,
      anon_sym_LBRACE,
    ACTIONS(51), 1,
      sym__single_quote_string_start,
    ACTIONS(53), 1,
      sym__double_quote_string_start,
    ACTIONS(775), 1,
      sym_identifier,
    ACTIONS(777), 1,
      anon_sym_TILDE,
    ACTIONS(779), 1,
      anon_sym_QMARK,
    ACTIONS(781), 1,
      anon_sym_AT,
    ACTIONS(783), 1,
      sym_number,
    STATE(187), 1,
      sym_function_call,
    STATE(219), 1,
      sym_boolean,
    STATE(404), 1,
      sym_unary_operator,
    STATE(407), 1,
      sym_binary_operator,
    STATE(409), 1,
      sym_not_operator,
    STATE(423), 1,
      sym_cell,
    STATE(622), 1,
      sym__binary_expression,
    STATE(994), 1,
      sym_indirect_access,
    STATE(1181), 1,
      sym__range_element,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(11), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(47), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(446), 2,
      sym_comparison_operator,
      sym_boolean_operator,
    STATE(392), 5,
      sym_parenthesis,
      sym_field_expression,
      sym_postfix_operator,
      sym_string,
      sym_matrix,
    STATE(417), 5,
      sym__expression,
      sym_metaclass_operator,
      sym_handle_operator,
      sym_range,
      sym_lambda,
  [14746] = 25,
    ACTIONS(640), 1,
      anon_sym_LPAREN,
    ACTIONS(644), 1,
      anon_sym_TILDE,
    ACTIONS(650), 1,
      anon_sym_LBRACK,
    ACTIONS(652), 1,
      anon_sym_LBRACE,
    ACTIONS(658), 1,
      sym_number,
    ACTIONS(662), 1,
      sym__single_quote_string_start,
    ACTIONS(664), 1,
      sym__double_quote_string_start,
    ACTIONS(767), 1,
      anon_sym_QMARK,
    ACTIONS(769), 1,
      anon_sym_AT,
    ACTIONS(896), 1,
      sym_identifier,
    STATE(402), 1,
      sym_boolean,
    STATE(412), 1,
      sym_function_call,
    STATE(518), 1,
      sym_cell,
    STATE(577), 1,
      sym_unary_operator,
    STATE(582), 1,
      sym_binary_operator,
    STATE(586), 1,
      sym_not_operator,
    STATE(614), 1,
      sym__binary_expression,
    STATE(905), 1,
      sym_indirect_access,
    STATE(1196), 1,
      sym__range_element,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(642), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(660), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(520), 2,
      sym_comparison_operator,
      sym_boolean_operator,
    STATE(590), 5,
      sym_parenthesis,
      sym_field_expression,
      sym_postfix_operator,
      sym_string,
      sym_matrix,
    STATE(700), 5,
      sym__expression,
      sym_metaclass_operator,
      sym_handle_operator,
      sym_range,
      sym_lambda,
  [14834] = 25,
    ACTIONS(9), 1,
      anon_sym_LPAREN,
    ACTIONS(19), 1,
      anon_sym_LBRACK,
    ACTIONS(21), 1,
      anon_sym_LBRACE,
    ACTIONS(51), 1,
      sym__single_quote_string_start,
    ACTIONS(53), 1,
      sym__double_quote_string_start,
    ACTIONS(775), 1,
      sym_identifier,
    ACTIONS(777), 1,
      anon_sym_TILDE,
    ACTIONS(779), 1,
      anon_sym_QMARK,
    ACTIONS(781), 1,
      anon_sym_AT,
    ACTIONS(783), 1,
      sym_number,
    STATE(187), 1,
      sym_function_call,
    STATE(219), 1,
      sym_boolean,
    STATE(404), 1,
      sym_unary_operator,
    STATE(407), 1,
      sym_binary_operator,
    STATE(409), 1,
      sym_not_operator,
    STATE(423), 1,
      sym_cell,
    STATE(622), 1,
      sym__binary_expression,
    STATE(994), 1,
      sym_indirect_access,
    STATE(1181), 1,
      sym__range_element,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(11), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(47), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(446), 2,
      sym_comparison_operator,
      sym_boolean_operator,
    STATE(392), 5,
      sym_parenthesis,
      sym_field_expression,
      sym_postfix_operator,
      sym_string,
      sym_matrix,
    STATE(444), 5,
      sym__expression,
      sym_metaclass_operator,
      sym_handle_operator,
      sym_range,
      sym_lambda,
  [14922] = 25,
    ACTIONS(834), 1,
      sym_identifier,
    ACTIONS(836), 1,
      anon_sym_LPAREN,
    ACTIONS(840), 1,
      anon_sym_TILDE,
    ACTIONS(846), 1,
      anon_sym_LBRACK,
    ACTIONS(848), 1,
      anon_sym_LBRACE,
    ACTIONS(850), 1,
      sym_number,
    ACTIONS(854), 1,
      sym__single_quote_string_start,
    ACTIONS(856), 1,
      sym__double_quote_string_start,
    ACTIONS(892), 1,
      anon_sym_QMARK,
    ACTIONS(894), 1,
      anon_sym_AT,
    STATE(76), 1,
      sym_function_call,
    STATE(91), 1,
      sym_boolean,
    STATE(109), 1,
      sym_cell,
    STATE(124), 1,
      sym_binary_operator,
    STATE(126), 1,
      sym_unary_operator,
    STATE(146), 1,
      sym_not_operator,
    STATE(617), 1,
      sym__binary_expression,
    STATE(956), 1,
      sym_indirect_access,
    STATE(1159), 1,
      sym__range_element,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(838), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(852), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(114), 2,
      sym_comparison_operator,
      sym_boolean_operator,
    STATE(127), 5,
      sym_parenthesis,
      sym_field_expression,
      sym_postfix_operator,
      sym_string,
      sym_matrix,
    STATE(148), 5,
      sym__expression,
      sym_metaclass_operator,
      sym_handle_operator,
      sym_range,
      sym_lambda,
  [15010] = 25,
    ACTIONS(9), 1,
      anon_sym_LPAREN,
    ACTIONS(15), 1,
      anon_sym_QMARK,
    ACTIONS(17), 1,
      anon_sym_AT,
    ACTIONS(19), 1,
      anon_sym_LBRACK,
    ACTIONS(21), 1,
      anon_sym_LBRACE,
    ACTIONS(45), 1,
      sym_number,
    ACTIONS(51), 1,
      sym__single_quote_string_start,
    ACTIONS(53), 1,
      sym__double_quote_string_start,
    ACTIONS(777), 1,
      anon_sym_TILDE,
    ACTIONS(785), 1,
      sym_identifier,
    STATE(190), 1,
      sym_function_call,
    STATE(205), 1,
      sym_boolean,
    STATE(389), 1,
      sym_unary_operator,
    STATE(422), 1,
      sym_binary_operator,
    STATE(423), 1,
      sym_cell,
    STATE(477), 1,
      sym_not_operator,
    STATE(622), 1,
      sym__binary_expression,
    STATE(994), 1,
      sym_indirect_access,
    STATE(1181), 1,
      sym__range_element,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(11), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(47), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(446), 2,
      sym_comparison_operator,
      sym_boolean_operator,
    STATE(411), 5,
      sym_parenthesis,
      sym_field_expression,
      sym_postfix_operator,
      sym_string,
      sym_matrix,
    STATE(621), 5,
      sym__expression,
      sym_metaclass_operator,
      sym_handle_operator,
      sym_range,
      sym_lambda,
  [15098] = 25,
    ACTIONS(640), 1,
      anon_sym_LPAREN,
    ACTIONS(644), 1,
      anon_sym_TILDE,
    ACTIONS(646), 1,
      anon_sym_QMARK,
    ACTIONS(648), 1,
      anon_sym_AT,
    ACTIONS(650), 1,
      anon_sym_LBRACK,
    ACTIONS(652), 1,
      anon_sym_LBRACE,
    ACTIONS(658), 1,
      sym_number,
    ACTIONS(662), 1,
      sym__single_quote_string_start,
    ACTIONS(664), 1,
      sym__double_quote_string_start,
    ACTIONS(751), 1,
      sym_identifier,
    STATE(367), 1,
      sym_function_call,
    STATE(402), 1,
      sym_boolean,
    STATE(518), 1,
      sym_cell,
    STATE(530), 1,
      sym_binary_operator,
    STATE(542), 1,
      sym_unary_operator,
    STATE(586), 1,
      sym_not_operator,
    STATE(614), 1,
      sym__binary_expression,
    STATE(905), 1,
      sym_indirect_access,
    STATE(1196), 1,
      sym__range_element,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(642), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(660), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(520), 2,
      sym_comparison_operator,
      sym_boolean_operator,
    STATE(521), 5,
      sym_parenthesis,
      sym_field_expression,
      sym_postfix_operator,
      sym_string,
      sym_matrix,
    STATE(665), 5,
      sym__expression,
      sym_metaclass_operator,
      sym_handle_operator,
      sym_range,
      sym_lambda,
  [15186] = 25,
    ACTIONS(571), 1,
      sym_identifier,
    ACTIONS(597), 1,
      sym__single_quote_string_start,
    ACTIONS(599), 1,
      sym__double_quote_string_start,
    ACTIONS(672), 1,
      anon_sym_LPAREN,
    ACTIONS(678), 1,
      anon_sym_QMARK,
    ACTIONS(680), 1,
      anon_sym_AT,
    ACTIONS(682), 1,
      anon_sym_LBRACK,
    ACTIONS(686), 1,
      anon_sym_LBRACE,
    ACTIONS(688), 1,
      sym_number,
    ACTIONS(876), 1,
      anon_sym_TILDE,
    STATE(216), 1,
      sym_function_call,
    STATE(363), 1,
      sym_boolean,
    STATE(508), 1,
      sym_unary_operator,
    STATE(509), 1,
      sym_binary_operator,
    STATE(510), 1,
      sym_cell,
    STATE(525), 1,
      sym_not_operator,
    STATE(615), 1,
      sym__binary_expression,
    STATE(919), 1,
      sym_indirect_access,
    STATE(1179), 1,
      sym__range_element,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(595), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(674), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    STATE(511), 2,
      sym_comparison_operator,
      sym_boolean_operator,
    STATE(507), 5,
      sym_parenthesis,
      sym_field_expression,
      sym_postfix_operator,
      sym_string,
      sym_matrix,
    STATE(568), 5,
      sym__expression,
      sym_metaclass_operator,
      sym_handle_operator,
      sym_range,
      sym_lambda,
  [15274] = 25,
    ACTIONS(834), 1,
      sym_identifier,
    ACTIONS(836), 1,
      anon_sym_LPAREN,
    ACTIONS(840), 1,
      anon_sym_TILDE,
    ACTIONS(842), 1,
      anon_sym_QMARK,
    ACTIONS(844), 1,
      anon_sym_AT,
    ACTIONS(846), 1,
      anon_sym_LBRACK,
    ACTIONS(848), 1,
      anon_sym_LBRACE,
    ACTIONS(850), 1,
      sym_number,
    ACTIONS(854), 1,
      sym__single_quote_string_start,
    ACTIONS(856), 1,
      sym__double_quote_string_start,
    STATE(76), 1,
      sym_function_call,
    STATE(91), 1,
      sym_boolean,
    STATE(109), 1,
      sym_cell,
    STATE(124), 1,
      sym_binary_operator,
    STATE(126), 1,
      sym_unary_operator,
    STATE(146), 1,
      sym_not_operator,
    STATE(617), 1,
      sym__binary_expression,
    STATE(956), 1,
      sym_indirect_access,
    STATE(1159), 1,
      sym__range_element,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(838), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(852), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(114), 2,
      sym_comparison_operator,
      sym_boolean_operator,
    STATE(127), 5,
      sym_parenthesis,
      sym_field_expression,
      sym_postfix_operator,
      sym_string,
      sym_matrix,
    STATE(148), 5,
      sym__expression,
      sym_metaclass_operator,
      sym_handle_operator,
      sym_range,
      sym_lambda,
  [15362] = 25,
    ACTIONS(9), 1,
      anon_sym_LPAREN,
    ACTIONS(19), 1,
      anon_sym_LBRACK,
    ACTIONS(21), 1,
      anon_sym_LBRACE,
    ACTIONS(51), 1,
      sym__single_quote_string_start,
    ACTIONS(53), 1,
      sym__double_quote_string_start,
    ACTIONS(775), 1,
      sym_identifier,
    ACTIONS(777), 1,
      anon_sym_TILDE,
    ACTIONS(779), 1,
      anon_sym_QMARK,
    ACTIONS(781), 1,
      anon_sym_AT,
    ACTIONS(783), 1,
      sym_number,
    STATE(187), 1,
      sym_function_call,
    STATE(219), 1,
      sym_boolean,
    STATE(404), 1,
      sym_unary_operator,
    STATE(407), 1,
      sym_binary_operator,
    STATE(409), 1,
      sym_not_operator,
    STATE(423), 1,
      sym_cell,
    STATE(622), 1,
      sym__binary_expression,
    STATE(994), 1,
      sym_indirect_access,
    STATE(1181), 1,
      sym__range_element,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(11), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(47), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(446), 2,
      sym_comparison_operator,
      sym_boolean_operator,
    STATE(392), 5,
      sym_parenthesis,
      sym_field_expression,
      sym_postfix_operator,
      sym_string,
      sym_matrix,
    STATE(415), 5,
      sym__expression,
      sym_metaclass_operator,
      sym_handle_operator,
      sym_range,
      sym_lambda,
  [15450] = 25,
    ACTIONS(767), 1,
      anon_sym_QMARK,
    ACTIONS(769), 1,
      anon_sym_AT,
    ACTIONS(836), 1,
      anon_sym_LPAREN,
    ACTIONS(840), 1,
      anon_sym_TILDE,
    ACTIONS(846), 1,
      anon_sym_LBRACK,
    ACTIONS(848), 1,
      anon_sym_LBRACE,
    ACTIONS(854), 1,
      sym__single_quote_string_start,
    ACTIONS(856), 1,
      sym__double_quote_string_start,
    ACTIONS(898), 1,
      sym_identifier,
    ACTIONS(900), 1,
      sym_number,
    STATE(78), 1,
      sym_function_call,
    STATE(92), 1,
      sym_boolean,
    STATE(108), 1,
      sym_unary_operator,
    STATE(110), 1,
      sym_not_operator,
    STATE(115), 1,
      sym_cell,
    STATE(594), 1,
      sym_binary_operator,
    STATE(614), 1,
      sym__binary_expression,
    STATE(956), 1,
      sym_indirect_access,
    STATE(1196), 1,
      sym__range_element,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(838), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(852), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(520), 2,
      sym_comparison_operator,
      sym_boolean_operator,
    STATE(106), 5,
      sym_parenthesis,
      sym_field_expression,
      sym_postfix_operator,
      sym_string,
      sym_matrix,
    STATE(700), 5,
      sym__expression,
      sym_metaclass_operator,
      sym_handle_operator,
      sym_range,
      sym_lambda,
  [15538] = 25,
    ACTIONS(834), 1,
      sym_identifier,
    ACTIONS(836), 1,
      anon_sym_LPAREN,
    ACTIONS(840), 1,
      anon_sym_TILDE,
    ACTIONS(842), 1,
      anon_sym_QMARK,
    ACTIONS(844), 1,
      anon_sym_AT,
    ACTIONS(846), 1,
      anon_sym_LBRACK,
    ACTIONS(848), 1,
      anon_sym_LBRACE,
    ACTIONS(850), 1,
      sym_number,
    ACTIONS(854), 1,
      sym__single_quote_string_start,
    ACTIONS(856), 1,
      sym__double_quote_string_start,
    STATE(76), 1,
      sym_function_call,
    STATE(91), 1,
      sym_boolean,
    STATE(109), 1,
      sym_cell,
    STATE(124), 1,
      sym_binary_operator,
    STATE(126), 1,
      sym_unary_operator,
    STATE(146), 1,
      sym_not_operator,
    STATE(617), 1,
      sym__binary_expression,
    STATE(956), 1,
      sym_indirect_access,
    STATE(1159), 1,
      sym__range_element,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(838), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(852), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(114), 2,
      sym_comparison_operator,
      sym_boolean_operator,
    STATE(3), 5,
      sym__expression,
      sym_metaclass_operator,
      sym_handle_operator,
      sym_range,
      sym_lambda,
    STATE(127), 5,
      sym_parenthesis,
      sym_field_expression,
      sym_postfix_operator,
      sym_string,
      sym_matrix,
  [15626] = 25,
    ACTIONS(597), 1,
      sym__single_quote_string_start,
    ACTIONS(599), 1,
      sym__double_quote_string_start,
    ACTIONS(652), 1,
      anon_sym_LBRACE,
    ACTIONS(672), 1,
      anon_sym_LPAREN,
    ACTIONS(682), 1,
      anon_sym_LBRACK,
    ACTIONS(767), 1,
      anon_sym_QMARK,
    ACTIONS(769), 1,
      anon_sym_AT,
    ACTIONS(876), 1,
      anon_sym_TILDE,
    ACTIONS(884), 1,
      sym_identifier,
    ACTIONS(886), 1,
      sym_number,
    STATE(212), 1,
      sym_function_call,
    STATE(371), 1,
      sym_boolean,
    STATE(495), 1,
      sym_binary_operator,
    STATE(496), 1,
      sym_unary_operator,
    STATE(500), 1,
      sym_not_operator,
    STATE(504), 1,
      sym__range_element,
    STATE(602), 1,
      sym_cell,
    STATE(615), 1,
      sym__binary_expression,
    STATE(919), 1,
      sym_indirect_access,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(595), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(674), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    STATE(520), 2,
      sym_comparison_operator,
      sym_boolean_operator,
    STATE(492), 5,
      sym_parenthesis,
      sym_field_expression,
      sym_postfix_operator,
      sym_string,
      sym_matrix,
    STATE(700), 5,
      sym__expression,
      sym_metaclass_operator,
      sym_handle_operator,
      sym_range,
      sym_lambda,
  [15714] = 25,
    ACTIONS(640), 1,
      anon_sym_LPAREN,
    ACTIONS(644), 1,
      anon_sym_TILDE,
    ACTIONS(650), 1,
      anon_sym_LBRACK,
    ACTIONS(652), 1,
      anon_sym_LBRACE,
    ACTIONS(662), 1,
      sym__single_quote_string_start,
    ACTIONS(664), 1,
      sym__double_quote_string_start,
    ACTIONS(814), 1,
      sym_identifier,
    ACTIONS(816), 1,
      anon_sym_QMARK,
    ACTIONS(818), 1,
      anon_sym_AT,
    ACTIONS(820), 1,
      sym_number,
    STATE(377), 1,
      sym_function_call,
    STATE(394), 1,
      sym_boolean,
    STATE(518), 1,
      sym_cell,
    STATE(519), 1,
      sym_not_operator,
    STATE(531), 1,
      sym_unary_operator,
    STATE(561), 1,
      sym_binary_operator,
    STATE(614), 1,
      sym__binary_expression,
    STATE(905), 1,
      sym_indirect_access,
    STATE(1196), 1,
      sym__range_element,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(642), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(660), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(520), 2,
      sym_comparison_operator,
      sym_boolean_operator,
    STATE(527), 5,
      sym_parenthesis,
      sym_field_expression,
      sym_postfix_operator,
      sym_string,
      sym_matrix,
    STATE(543), 5,
      sym__expression,
      sym_metaclass_operator,
      sym_handle_operator,
      sym_range,
      sym_lambda,
  [15802] = 25,
    ACTIONS(9), 1,
      anon_sym_LPAREN,
    ACTIONS(15), 1,
      anon_sym_QMARK,
    ACTIONS(17), 1,
      anon_sym_AT,
    ACTIONS(19), 1,
      anon_sym_LBRACK,
    ACTIONS(21), 1,
      anon_sym_LBRACE,
    ACTIONS(45), 1,
      sym_number,
    ACTIONS(51), 1,
      sym__single_quote_string_start,
    ACTIONS(53), 1,
      sym__double_quote_string_start,
    ACTIONS(777), 1,
      anon_sym_TILDE,
    ACTIONS(785), 1,
      sym_identifier,
    STATE(190), 1,
      sym_function_call,
    STATE(205), 1,
      sym_boolean,
    STATE(389), 1,
      sym_unary_operator,
    STATE(422), 1,
      sym_binary_operator,
    STATE(423), 1,
      sym_cell,
    STATE(477), 1,
      sym_not_operator,
    STATE(622), 1,
      sym__binary_expression,
    STATE(994), 1,
      sym_indirect_access,
    STATE(1181), 1,
      sym__range_element,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(11), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(47), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(446), 2,
      sym_comparison_operator,
      sym_boolean_operator,
    STATE(411), 5,
      sym_parenthesis,
      sym_field_expression,
      sym_postfix_operator,
      sym_string,
      sym_matrix,
    STATE(513), 5,
      sym__expression,
      sym_metaclass_operator,
      sym_handle_operator,
      sym_range,
      sym_lambda,
  [15890] = 25,
    ACTIONS(640), 1,
      anon_sym_LPAREN,
    ACTIONS(644), 1,
      anon_sym_TILDE,
    ACTIONS(650), 1,
      anon_sym_LBRACK,
    ACTIONS(652), 1,
      anon_sym_LBRACE,
    ACTIONS(658), 1,
      sym_number,
    ACTIONS(662), 1,
      sym__single_quote_string_start,
    ACTIONS(664), 1,
      sym__double_quote_string_start,
    ACTIONS(767), 1,
      anon_sym_QMARK,
    ACTIONS(769), 1,
      anon_sym_AT,
    ACTIONS(870), 1,
      sym_identifier,
    STATE(402), 1,
      sym_boolean,
    STATE(442), 1,
      sym_function_call,
    STATE(518), 1,
      sym_cell,
    STATE(564), 1,
      sym_binary_operator,
    STATE(565), 1,
      sym_unary_operator,
    STATE(586), 1,
      sym_not_operator,
    STATE(614), 1,
      sym__binary_expression,
    STATE(905), 1,
      sym_indirect_access,
    STATE(1196), 1,
      sym__range_element,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(642), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(660), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(520), 2,
      sym_comparison_operator,
      sym_boolean_operator,
    STATE(570), 5,
      sym_parenthesis,
      sym_field_expression,
      sym_postfix_operator,
      sym_string,
      sym_matrix,
    STATE(680), 5,
      sym__expression,
      sym_metaclass_operator,
      sym_handle_operator,
      sym_range,
      sym_lambda,
  [15978] = 25,
    ACTIONS(834), 1,
      sym_identifier,
    ACTIONS(836), 1,
      anon_sym_LPAREN,
    ACTIONS(840), 1,
      anon_sym_TILDE,
    ACTIONS(842), 1,
      anon_sym_QMARK,
    ACTIONS(844), 1,
      anon_sym_AT,
    ACTIONS(846), 1,
      anon_sym_LBRACK,
    ACTIONS(848), 1,
      anon_sym_LBRACE,
    ACTIONS(850), 1,
      sym_number,
    ACTIONS(854), 1,
      sym__single_quote_string_start,
    ACTIONS(856), 1,
      sym__double_quote_string_start,
    STATE(76), 1,
      sym_function_call,
    STATE(91), 1,
      sym_boolean,
    STATE(109), 1,
      sym_cell,
    STATE(124), 1,
      sym_binary_operator,
    STATE(126), 1,
      sym_unary_operator,
    STATE(146), 1,
      sym_not_operator,
    STATE(617), 1,
      sym__binary_expression,
    STATE(956), 1,
      sym_indirect_access,
    STATE(1159), 1,
      sym__range_element,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(838), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(852), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(114), 2,
      sym_comparison_operator,
      sym_boolean_operator,
    STATE(2), 5,
      sym__expression,
      sym_metaclass_operator,
      sym_handle_operator,
      sym_range,
      sym_lambda,
    STATE(127), 5,
      sym_parenthesis,
      sym_field_expression,
      sym_postfix_operator,
      sym_string,
      sym_matrix,
  [16066] = 25,
    ACTIONS(640), 1,
      anon_sym_LPAREN,
    ACTIONS(644), 1,
      anon_sym_TILDE,
    ACTIONS(650), 1,
      anon_sym_LBRACK,
    ACTIONS(652), 1,
      anon_sym_LBRACE,
    ACTIONS(658), 1,
      sym_number,
    ACTIONS(662), 1,
      sym__single_quote_string_start,
    ACTIONS(664), 1,
      sym__double_quote_string_start,
    ACTIONS(767), 1,
      anon_sym_QMARK,
    ACTIONS(769), 1,
      anon_sym_AT,
    ACTIONS(870), 1,
      sym_identifier,
    STATE(402), 1,
      sym_boolean,
    STATE(442), 1,
      sym_function_call,
    STATE(518), 1,
      sym_cell,
    STATE(564), 1,
      sym_binary_operator,
    STATE(565), 1,
      sym_unary_operator,
    STATE(586), 1,
      sym_not_operator,
    STATE(614), 1,
      sym__binary_expression,
    STATE(905), 1,
      sym_indirect_access,
    STATE(1196), 1,
      sym__range_element,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(642), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(660), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(520), 2,
      sym_comparison_operator,
      sym_boolean_operator,
    STATE(570), 5,
      sym_parenthesis,
      sym_field_expression,
      sym_postfix_operator,
      sym_string,
      sym_matrix,
    STATE(681), 5,
      sym__expression,
      sym_metaclass_operator,
      sym_handle_operator,
      sym_range,
      sym_lambda,
  [16154] = 25,
    ACTIONS(9), 1,
      anon_sym_LPAREN,
    ACTIONS(19), 1,
      anon_sym_LBRACK,
    ACTIONS(51), 1,
      sym__single_quote_string_start,
    ACTIONS(53), 1,
      sym__double_quote_string_start,
    ACTIONS(652), 1,
      anon_sym_LBRACE,
    ACTIONS(767), 1,
      anon_sym_QMARK,
    ACTIONS(769), 1,
      anon_sym_AT,
    ACTIONS(777), 1,
      anon_sym_TILDE,
    ACTIONS(902), 1,
      sym_identifier,
    ACTIONS(904), 1,
      sym_number,
    STATE(189), 1,
      sym_function_call,
    STATE(218), 1,
      sym_boolean,
    STATE(388), 1,
      sym__range_element,
    STATE(435), 1,
      sym_binary_operator,
    STATE(449), 1,
      sym_unary_operator,
    STATE(454), 1,
      sym_not_operator,
    STATE(600), 1,
      sym_cell,
    STATE(622), 1,
      sym__binary_expression,
    STATE(994), 1,
      sym_indirect_access,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(11), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(47), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(520), 2,
      sym_comparison_operator,
      sym_boolean_operator,
    STATE(439), 5,
      sym_parenthesis,
      sym_field_expression,
      sym_postfix_operator,
      sym_string,
      sym_matrix,
    STATE(700), 5,
      sym__expression,
      sym_metaclass_operator,
      sym_handle_operator,
      sym_range,
      sym_lambda,
  [16242] = 23,
    ACTIONS(9), 1,
      anon_sym_LPAREN,
    ACTIONS(19), 1,
      anon_sym_LBRACK,
    ACTIONS(21), 1,
      anon_sym_LBRACE,
    ACTIONS(51), 1,
      sym__single_quote_string_start,
    ACTIONS(53), 1,
      sym__double_quote_string_start,
    ACTIONS(767), 1,
      anon_sym_QMARK,
    ACTIONS(769), 1,
      anon_sym_AT,
    ACTIONS(777), 1,
      anon_sym_TILDE,
    ACTIONS(906), 1,
      sym_identifier,
    ACTIONS(908), 1,
      sym_number,
    STATE(192), 1,
      sym_function_call,
    STATE(211), 1,
      sym_boolean,
    STATE(419), 1,
      sym_unary_operator,
    STATE(430), 1,
      sym_cell,
    STATE(443), 1,
      sym_binary_operator,
    STATE(994), 1,
      sym_indirect_access,
    STATE(1196), 1,
      sym__range_element,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(11), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(47), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(390), 4,
      sym__binary_expression,
      sym_not_operator,
      sym_comparison_operator,
      sym_boolean_operator,
    STATE(410), 5,
      sym_parenthesis,
      sym_field_expression,
      sym_postfix_operator,
      sym_string,
      sym_matrix,
    STATE(696), 5,
      sym__expression,
      sym_metaclass_operator,
      sym_handle_operator,
      sym_range,
      sym_lambda,
  [16326] = 23,
    ACTIONS(9), 1,
      anon_sym_LPAREN,
    ACTIONS(19), 1,
      anon_sym_LBRACK,
    ACTIONS(21), 1,
      anon_sym_LBRACE,
    ACTIONS(51), 1,
      sym__single_quote_string_start,
    ACTIONS(53), 1,
      sym__double_quote_string_start,
    ACTIONS(767), 1,
      anon_sym_QMARK,
    ACTIONS(769), 1,
      anon_sym_AT,
    ACTIONS(777), 1,
      anon_sym_TILDE,
    ACTIONS(906), 1,
      sym_identifier,
    ACTIONS(908), 1,
      sym_number,
    STATE(192), 1,
      sym_function_call,
    STATE(211), 1,
      sym_boolean,
    STATE(419), 1,
      sym_unary_operator,
    STATE(430), 1,
      sym_cell,
    STATE(443), 1,
      sym_binary_operator,
    STATE(994), 1,
      sym_indirect_access,
    STATE(1196), 1,
      sym__range_element,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(11), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(47), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(450), 4,
      sym__binary_expression,
      sym_not_operator,
      sym_comparison_operator,
      sym_boolean_operator,
    STATE(410), 5,
      sym_parenthesis,
      sym_field_expression,
      sym_postfix_operator,
      sym_string,
      sym_matrix,
    STATE(696), 5,
      sym__expression,
      sym_metaclass_operator,
      sym_handle_operator,
      sym_range,
      sym_lambda,
  [16410] = 23,
    ACTIONS(9), 1,
      anon_sym_LPAREN,
    ACTIONS(19), 1,
      anon_sym_LBRACK,
    ACTIONS(21), 1,
      anon_sym_LBRACE,
    ACTIONS(51), 1,
      sym__single_quote_string_start,
    ACTIONS(53), 1,
      sym__double_quote_string_start,
    ACTIONS(767), 1,
      anon_sym_QMARK,
    ACTIONS(769), 1,
      anon_sym_AT,
    ACTIONS(777), 1,
      anon_sym_TILDE,
    ACTIONS(906), 1,
      sym_identifier,
    ACTIONS(908), 1,
      sym_number,
    STATE(192), 1,
      sym_function_call,
    STATE(211), 1,
      sym_boolean,
    STATE(419), 1,
      sym_unary_operator,
    STATE(430), 1,
      sym_cell,
    STATE(443), 1,
      sym_binary_operator,
    STATE(994), 1,
      sym_indirect_access,
    STATE(1196), 1,
      sym__range_element,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(11), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(47), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(405), 4,
      sym__binary_expression,
      sym_not_operator,
      sym_comparison_operator,
      sym_boolean_operator,
    STATE(410), 5,
      sym_parenthesis,
      sym_field_expression,
      sym_postfix_operator,
      sym_string,
      sym_matrix,
    STATE(696), 5,
      sym__expression,
      sym_metaclass_operator,
      sym_handle_operator,
      sym_range,
      sym_lambda,
  [16494] = 25,
    ACTIONS(836), 1,
      anon_sym_LPAREN,
    ACTIONS(840), 1,
      anon_sym_TILDE,
    ACTIONS(846), 1,
      anon_sym_LBRACK,
    ACTIONS(848), 1,
      anon_sym_LBRACE,
    ACTIONS(854), 1,
      sym__single_quote_string_start,
    ACTIONS(856), 1,
      sym__double_quote_string_start,
    ACTIONS(862), 1,
      sym_identifier,
    ACTIONS(864), 1,
      anon_sym_QMARK,
    ACTIONS(866), 1,
      anon_sym_AT,
    ACTIONS(868), 1,
      sym_number,
    STATE(80), 1,
      sym_function_call,
    STATE(99), 1,
      sym_boolean,
    STATE(105), 1,
      sym_unary_operator,
    STATE(109), 1,
      sym_cell,
    STATE(121), 1,
      sym_binary_operator,
    STATE(139), 1,
      sym_not_operator,
    STATE(617), 1,
      sym__binary_expression,
    STATE(956), 1,
      sym_indirect_access,
    STATE(1159), 1,
      sym__range_element,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(838), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(852), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(114), 2,
      sym_comparison_operator,
      sym_boolean_operator,
    STATE(104), 5,
      sym_parenthesis,
      sym_field_expression,
      sym_postfix_operator,
      sym_string,
      sym_matrix,
    STATE(118), 5,
      sym__expression,
      sym_metaclass_operator,
      sym_handle_operator,
      sym_range,
      sym_lambda,
  [16582] = 23,
    ACTIONS(9), 1,
      anon_sym_LPAREN,
    ACTIONS(19), 1,
      anon_sym_LBRACK,
    ACTIONS(21), 1,
      anon_sym_LBRACE,
    ACTIONS(51), 1,
      sym__single_quote_string_start,
    ACTIONS(53), 1,
      sym__double_quote_string_start,
    ACTIONS(767), 1,
      anon_sym_QMARK,
    ACTIONS(769), 1,
      anon_sym_AT,
    ACTIONS(777), 1,
      anon_sym_TILDE,
    ACTIONS(906), 1,
      sym_identifier,
    ACTIONS(908), 1,
      sym_number,
    STATE(192), 1,
      sym_function_call,
    STATE(211), 1,
      sym_boolean,
    STATE(419), 1,
      sym_unary_operator,
    STATE(430), 1,
      sym_cell,
    STATE(443), 1,
      sym_binary_operator,
    STATE(994), 1,
      sym_indirect_access,
    STATE(1196), 1,
      sym__range_element,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(11), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(47), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(406), 4,
      sym__binary_expression,
      sym_not_operator,
      sym_comparison_operator,
      sym_boolean_operator,
    STATE(410), 5,
      sym_parenthesis,
      sym_field_expression,
      sym_postfix_operator,
      sym_string,
      sym_matrix,
    STATE(696), 5,
      sym__expression,
      sym_metaclass_operator,
      sym_handle_operator,
      sym_range,
      sym_lambda,
  [16666] = 23,
    ACTIONS(9), 1,
      anon_sym_LPAREN,
    ACTIONS(19), 1,
      anon_sym_LBRACK,
    ACTIONS(21), 1,
      anon_sym_LBRACE,
    ACTIONS(51), 1,
      sym__single_quote_string_start,
    ACTIONS(53), 1,
      sym__double_quote_string_start,
    ACTIONS(767), 1,
      anon_sym_QMARK,
    ACTIONS(769), 1,
      anon_sym_AT,
    ACTIONS(777), 1,
      anon_sym_TILDE,
    ACTIONS(906), 1,
      sym_identifier,
    ACTIONS(908), 1,
      sym_number,
    STATE(192), 1,
      sym_function_call,
    STATE(211), 1,
      sym_boolean,
    STATE(419), 1,
      sym_unary_operator,
    STATE(430), 1,
      sym_cell,
    STATE(443), 1,
      sym_binary_operator,
    STATE(994), 1,
      sym_indirect_access,
    STATE(1196), 1,
      sym__range_element,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(11), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(47), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(393), 4,
      sym__binary_expression,
      sym_not_operator,
      sym_comparison_operator,
      sym_boolean_operator,
    STATE(410), 5,
      sym_parenthesis,
      sym_field_expression,
      sym_postfix_operator,
      sym_string,
      sym_matrix,
    STATE(696), 5,
      sym__expression,
      sym_metaclass_operator,
      sym_handle_operator,
      sym_range,
      sym_lambda,
  [16750] = 25,
    ACTIONS(640), 1,
      anon_sym_LPAREN,
    ACTIONS(644), 1,
      anon_sym_TILDE,
    ACTIONS(646), 1,
      anon_sym_QMARK,
    ACTIONS(648), 1,
      anon_sym_AT,
    ACTIONS(650), 1,
      anon_sym_LBRACK,
    ACTIONS(652), 1,
      anon_sym_LBRACE,
    ACTIONS(658), 1,
      sym_number,
    ACTIONS(662), 1,
      sym__single_quote_string_start,
    ACTIONS(664), 1,
      sym__double_quote_string_start,
    ACTIONS(751), 1,
      sym_identifier,
    STATE(367), 1,
      sym_function_call,
    STATE(402), 1,
      sym_boolean,
    STATE(518), 1,
      sym_cell,
    STATE(530), 1,
      sym_binary_operator,
    STATE(542), 1,
      sym_unary_operator,
    STATE(586), 1,
      sym_not_operator,
    STATE(614), 1,
      sym__binary_expression,
    STATE(905), 1,
      sym_indirect_access,
    STATE(1196), 1,
      sym__range_element,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(642), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(660), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(520), 2,
      sym_comparison_operator,
      sym_boolean_operator,
    STATE(521), 5,
      sym_parenthesis,
      sym_field_expression,
      sym_postfix_operator,
      sym_string,
      sym_matrix,
    STATE(646), 5,
      sym__expression,
      sym_metaclass_operator,
      sym_handle_operator,
      sym_range,
      sym_lambda,
  [16838] = 25,
    ACTIONS(571), 1,
      sym_identifier,
    ACTIONS(597), 1,
      sym__single_quote_string_start,
    ACTIONS(599), 1,
      sym__double_quote_string_start,
    ACTIONS(672), 1,
      anon_sym_LPAREN,
    ACTIONS(682), 1,
      anon_sym_LBRACK,
    ACTIONS(686), 1,
      anon_sym_LBRACE,
    ACTIONS(688), 1,
      sym_number,
    ACTIONS(876), 1,
      anon_sym_TILDE,
    ACTIONS(910), 1,
      anon_sym_QMARK,
    ACTIONS(912), 1,
      anon_sym_AT,
    STATE(216), 1,
      sym_function_call,
    STATE(363), 1,
      sym_boolean,
    STATE(508), 1,
      sym_unary_operator,
    STATE(509), 1,
      sym_binary_operator,
    STATE(510), 1,
      sym_cell,
    STATE(525), 1,
      sym_not_operator,
    STATE(615), 1,
      sym__binary_expression,
    STATE(919), 1,
      sym_indirect_access,
    STATE(1179), 1,
      sym__range_element,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(595), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(674), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    STATE(511), 2,
      sym_comparison_operator,
      sym_boolean_operator,
    STATE(507), 5,
      sym_parenthesis,
      sym_field_expression,
      sym_postfix_operator,
      sym_string,
      sym_matrix,
    STATE(568), 5,
      sym__expression,
      sym_metaclass_operator,
      sym_handle_operator,
      sym_range,
      sym_lambda,
  [16926] = 25,
    ACTIONS(9), 1,
      anon_sym_LPAREN,
    ACTIONS(19), 1,
      anon_sym_LBRACK,
    ACTIONS(21), 1,
      anon_sym_LBRACE,
    ACTIONS(45), 1,
      sym_number,
    ACTIONS(51), 1,
      sym__single_quote_string_start,
    ACTIONS(53), 1,
      sym__double_quote_string_start,
    ACTIONS(777), 1,
      anon_sym_TILDE,
    ACTIONS(785), 1,
      sym_identifier,
    ACTIONS(858), 1,
      anon_sym_QMARK,
    ACTIONS(860), 1,
      anon_sym_AT,
    STATE(190), 1,
      sym_function_call,
    STATE(205), 1,
      sym_boolean,
    STATE(389), 1,
      sym_unary_operator,
    STATE(422), 1,
      sym_binary_operator,
    STATE(423), 1,
      sym_cell,
    STATE(477), 1,
      sym_not_operator,
    STATE(622), 1,
      sym__binary_expression,
    STATE(994), 1,
      sym_indirect_access,
    STATE(1181), 1,
      sym__range_element,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(11), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(47), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(446), 2,
      sym_comparison_operator,
      sym_boolean_operator,
    STATE(411), 5,
      sym_parenthesis,
      sym_field_expression,
      sym_postfix_operator,
      sym_string,
      sym_matrix,
    STATE(516), 5,
      sym__expression,
      sym_metaclass_operator,
      sym_handle_operator,
      sym_range,
      sym_lambda,
  [17014] = 25,
    ACTIONS(9), 1,
      anon_sym_LPAREN,
    ACTIONS(19), 1,
      anon_sym_LBRACK,
    ACTIONS(21), 1,
      anon_sym_LBRACE,
    ACTIONS(45), 1,
      sym_number,
    ACTIONS(51), 1,
      sym__single_quote_string_start,
    ACTIONS(53), 1,
      sym__double_quote_string_start,
    ACTIONS(777), 1,
      anon_sym_TILDE,
    ACTIONS(785), 1,
      sym_identifier,
    ACTIONS(858), 1,
      anon_sym_QMARK,
    ACTIONS(860), 1,
      anon_sym_AT,
    STATE(190), 1,
      sym_function_call,
    STATE(205), 1,
      sym_boolean,
    STATE(389), 1,
      sym_unary_operator,
    STATE(422), 1,
      sym_binary_operator,
    STATE(423), 1,
      sym_cell,
    STATE(477), 1,
      sym_not_operator,
    STATE(622), 1,
      sym__binary_expression,
    STATE(994), 1,
      sym_indirect_access,
    STATE(1181), 1,
      sym__range_element,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(11), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(47), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(446), 2,
      sym_comparison_operator,
      sym_boolean_operator,
    STATE(411), 5,
      sym_parenthesis,
      sym_field_expression,
      sym_postfix_operator,
      sym_string,
      sym_matrix,
    STATE(517), 5,
      sym__expression,
      sym_metaclass_operator,
      sym_handle_operator,
      sym_range,
      sym_lambda,
  [17102] = 25,
    ACTIONS(834), 1,
      sym_identifier,
    ACTIONS(836), 1,
      anon_sym_LPAREN,
    ACTIONS(840), 1,
      anon_sym_TILDE,
    ACTIONS(842), 1,
      anon_sym_QMARK,
    ACTIONS(844), 1,
      anon_sym_AT,
    ACTIONS(846), 1,
      anon_sym_LBRACK,
    ACTIONS(848), 1,
      anon_sym_LBRACE,
    ACTIONS(850), 1,
      sym_number,
    ACTIONS(854), 1,
      sym__single_quote_string_start,
    ACTIONS(856), 1,
      sym__double_quote_string_start,
    STATE(76), 1,
      sym_function_call,
    STATE(91), 1,
      sym_boolean,
    STATE(109), 1,
      sym_cell,
    STATE(124), 1,
      sym_binary_operator,
    STATE(126), 1,
      sym_unary_operator,
    STATE(146), 1,
      sym_not_operator,
    STATE(617), 1,
      sym__binary_expression,
    STATE(956), 1,
      sym_indirect_access,
    STATE(1159), 1,
      sym__range_element,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(838), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(852), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(114), 2,
      sym_comparison_operator,
      sym_boolean_operator,
    STATE(127), 5,
      sym_parenthesis,
      sym_field_expression,
      sym_postfix_operator,
      sym_string,
      sym_matrix,
    STATE(151), 5,
      sym__expression,
      sym_metaclass_operator,
      sym_handle_operator,
      sym_range,
      sym_lambda,
  [17190] = 25,
    ACTIONS(834), 1,
      sym_identifier,
    ACTIONS(836), 1,
      anon_sym_LPAREN,
    ACTIONS(840), 1,
      anon_sym_TILDE,
    ACTIONS(842), 1,
      anon_sym_QMARK,
    ACTIONS(844), 1,
      anon_sym_AT,
    ACTIONS(846), 1,
      anon_sym_LBRACK,
    ACTIONS(848), 1,
      anon_sym_LBRACE,
    ACTIONS(850), 1,
      sym_number,
    ACTIONS(854), 1,
      sym__single_quote_string_start,
    ACTIONS(856), 1,
      sym__double_quote_string_start,
    STATE(76), 1,
      sym_function_call,
    STATE(91), 1,
      sym_boolean,
    STATE(109), 1,
      sym_cell,
    STATE(124), 1,
      sym_binary_operator,
    STATE(126), 1,
      sym_unary_operator,
    STATE(146), 1,
      sym_not_operator,
    STATE(617), 1,
      sym__binary_expression,
    STATE(956), 1,
      sym_indirect_access,
    STATE(1159), 1,
      sym__range_element,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(838), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(852), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(114), 2,
      sym_comparison_operator,
      sym_boolean_operator,
    STATE(4), 5,
      sym__expression,
      sym_metaclass_operator,
      sym_handle_operator,
      sym_range,
      sym_lambda,
    STATE(127), 5,
      sym_parenthesis,
      sym_field_expression,
      sym_postfix_operator,
      sym_string,
      sym_matrix,
  [17278] = 25,
    ACTIONS(836), 1,
      anon_sym_LPAREN,
    ACTIONS(840), 1,
      anon_sym_TILDE,
    ACTIONS(846), 1,
      anon_sym_LBRACK,
    ACTIONS(848), 1,
      anon_sym_LBRACE,
    ACTIONS(854), 1,
      sym__single_quote_string_start,
    ACTIONS(856), 1,
      sym__double_quote_string_start,
    ACTIONS(862), 1,
      sym_identifier,
    ACTIONS(864), 1,
      anon_sym_QMARK,
    ACTIONS(866), 1,
      anon_sym_AT,
    ACTIONS(868), 1,
      sym_number,
    STATE(80), 1,
      sym_function_call,
    STATE(99), 1,
      sym_boolean,
    STATE(105), 1,
      sym_unary_operator,
    STATE(109), 1,
      sym_cell,
    STATE(121), 1,
      sym_binary_operator,
    STATE(139), 1,
      sym_not_operator,
    STATE(617), 1,
      sym__binary_expression,
    STATE(956), 1,
      sym_indirect_access,
    STATE(1159), 1,
      sym__range_element,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(838), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(852), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(114), 2,
      sym_comparison_operator,
      sym_boolean_operator,
    STATE(104), 5,
      sym_parenthesis,
      sym_field_expression,
      sym_postfix_operator,
      sym_string,
      sym_matrix,
    STATE(113), 5,
      sym__expression,
      sym_metaclass_operator,
      sym_handle_operator,
      sym_range,
      sym_lambda,
  [17366] = 25,
    ACTIONS(836), 1,
      anon_sym_LPAREN,
    ACTIONS(840), 1,
      anon_sym_TILDE,
    ACTIONS(846), 1,
      anon_sym_LBRACK,
    ACTIONS(848), 1,
      anon_sym_LBRACE,
    ACTIONS(854), 1,
      sym__single_quote_string_start,
    ACTIONS(856), 1,
      sym__double_quote_string_start,
    ACTIONS(862), 1,
      sym_identifier,
    ACTIONS(864), 1,
      anon_sym_QMARK,
    ACTIONS(866), 1,
      anon_sym_AT,
    ACTIONS(868), 1,
      sym_number,
    STATE(80), 1,
      sym_function_call,
    STATE(99), 1,
      sym_boolean,
    STATE(105), 1,
      sym_unary_operator,
    STATE(109), 1,
      sym_cell,
    STATE(121), 1,
      sym_binary_operator,
    STATE(139), 1,
      sym_not_operator,
    STATE(617), 1,
      sym__binary_expression,
    STATE(956), 1,
      sym_indirect_access,
    STATE(1159), 1,
      sym__range_element,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(838), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(852), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(114), 2,
      sym_comparison_operator,
      sym_boolean_operator,
    STATE(104), 5,
      sym_parenthesis,
      sym_field_expression,
      sym_postfix_operator,
      sym_string,
      sym_matrix,
    STATE(112), 5,
      sym__expression,
      sym_metaclass_operator,
      sym_handle_operator,
      sym_range,
      sym_lambda,
  [17454] = 25,
    ACTIONS(640), 1,
      anon_sym_LPAREN,
    ACTIONS(644), 1,
      anon_sym_TILDE,
    ACTIONS(646), 1,
      anon_sym_QMARK,
    ACTIONS(648), 1,
      anon_sym_AT,
    ACTIONS(650), 1,
      anon_sym_LBRACK,
    ACTIONS(652), 1,
      anon_sym_LBRACE,
    ACTIONS(658), 1,
      sym_number,
    ACTIONS(662), 1,
      sym__single_quote_string_start,
    ACTIONS(664), 1,
      sym__double_quote_string_start,
    ACTIONS(751), 1,
      sym_identifier,
    STATE(367), 1,
      sym_function_call,
    STATE(402), 1,
      sym_boolean,
    STATE(518), 1,
      sym_cell,
    STATE(530), 1,
      sym_binary_operator,
    STATE(542), 1,
      sym_unary_operator,
    STATE(586), 1,
      sym_not_operator,
    STATE(614), 1,
      sym__binary_expression,
    STATE(905), 1,
      sym_indirect_access,
    STATE(1196), 1,
      sym__range_element,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(642), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(660), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(520), 2,
      sym_comparison_operator,
      sym_boolean_operator,
    STATE(521), 5,
      sym_parenthesis,
      sym_field_expression,
      sym_postfix_operator,
      sym_string,
      sym_matrix,
    STATE(644), 5,
      sym__expression,
      sym_metaclass_operator,
      sym_handle_operator,
      sym_range,
      sym_lambda,
  [17542] = 25,
    ACTIONS(640), 1,
      anon_sym_LPAREN,
    ACTIONS(644), 1,
      anon_sym_TILDE,
    ACTIONS(646), 1,
      anon_sym_QMARK,
    ACTIONS(648), 1,
      anon_sym_AT,
    ACTIONS(650), 1,
      anon_sym_LBRACK,
    ACTIONS(652), 1,
      anon_sym_LBRACE,
    ACTIONS(658), 1,
      sym_number,
    ACTIONS(662), 1,
      sym__single_quote_string_start,
    ACTIONS(664), 1,
      sym__double_quote_string_start,
    ACTIONS(751), 1,
      sym_identifier,
    STATE(367), 1,
      sym_function_call,
    STATE(402), 1,
      sym_boolean,
    STATE(518), 1,
      sym_cell,
    STATE(530), 1,
      sym_binary_operator,
    STATE(542), 1,
      sym_unary_operator,
    STATE(586), 1,
      sym_not_operator,
    STATE(614), 1,
      sym__binary_expression,
    STATE(905), 1,
      sym_indirect_access,
    STATE(1196), 1,
      sym__range_element,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(642), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(660), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(520), 2,
      sym_comparison_operator,
      sym_boolean_operator,
    STATE(521), 5,
      sym_parenthesis,
      sym_field_expression,
      sym_postfix_operator,
      sym_string,
      sym_matrix,
    STATE(645), 5,
      sym__expression,
      sym_metaclass_operator,
      sym_handle_operator,
      sym_range,
      sym_lambda,
  [17630] = 25,
    ACTIONS(9), 1,
      anon_sym_LPAREN,
    ACTIONS(19), 1,
      anon_sym_LBRACK,
    ACTIONS(51), 1,
      sym__single_quote_string_start,
    ACTIONS(53), 1,
      sym__double_quote_string_start,
    ACTIONS(652), 1,
      anon_sym_LBRACE,
    ACTIONS(767), 1,
      anon_sym_QMARK,
    ACTIONS(769), 1,
      anon_sym_AT,
    ACTIONS(777), 1,
      anon_sym_TILDE,
    ACTIONS(902), 1,
      sym_identifier,
    ACTIONS(904), 1,
      sym_number,
    STATE(189), 1,
      sym_function_call,
    STATE(218), 1,
      sym_boolean,
    STATE(403), 1,
      sym__range_element,
    STATE(435), 1,
      sym_binary_operator,
    STATE(449), 1,
      sym_unary_operator,
    STATE(454), 1,
      sym_not_operator,
    STATE(600), 1,
      sym_cell,
    STATE(622), 1,
      sym__binary_expression,
    STATE(994), 1,
      sym_indirect_access,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(11), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(47), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(520), 2,
      sym_comparison_operator,
      sym_boolean_operator,
    STATE(439), 5,
      sym_parenthesis,
      sym_field_expression,
      sym_postfix_operator,
      sym_string,
      sym_matrix,
    STATE(700), 5,
      sym__expression,
      sym_metaclass_operator,
      sym_handle_operator,
      sym_range,
      sym_lambda,
  [17718] = 25,
    ACTIONS(834), 1,
      sym_identifier,
    ACTIONS(836), 1,
      anon_sym_LPAREN,
    ACTIONS(840), 1,
      anon_sym_TILDE,
    ACTIONS(846), 1,
      anon_sym_LBRACK,
    ACTIONS(848), 1,
      anon_sym_LBRACE,
    ACTIONS(850), 1,
      sym_number,
    ACTIONS(854), 1,
      sym__single_quote_string_start,
    ACTIONS(856), 1,
      sym__double_quote_string_start,
    ACTIONS(892), 1,
      anon_sym_QMARK,
    ACTIONS(894), 1,
      anon_sym_AT,
    STATE(76), 1,
      sym_function_call,
    STATE(91), 1,
      sym_boolean,
    STATE(109), 1,
      sym_cell,
    STATE(124), 1,
      sym_binary_operator,
    STATE(126), 1,
      sym_unary_operator,
    STATE(146), 1,
      sym_not_operator,
    STATE(617), 1,
      sym__binary_expression,
    STATE(956), 1,
      sym_indirect_access,
    STATE(1159), 1,
      sym__range_element,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(838), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(852), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(114), 2,
      sym_comparison_operator,
      sym_boolean_operator,
    STATE(127), 5,
      sym_parenthesis,
      sym_field_expression,
      sym_postfix_operator,
      sym_string,
      sym_matrix,
    STATE(149), 5,
      sym__expression,
      sym_metaclass_operator,
      sym_handle_operator,
      sym_range,
      sym_lambda,
  [17806] = 25,
    ACTIONS(9), 1,
      anon_sym_LPAREN,
    ACTIONS(19), 1,
      anon_sym_LBRACK,
    ACTIONS(21), 1,
      anon_sym_LBRACE,
    ACTIONS(45), 1,
      sym_number,
    ACTIONS(51), 1,
      sym__single_quote_string_start,
    ACTIONS(53), 1,
      sym__double_quote_string_start,
    ACTIONS(777), 1,
      anon_sym_TILDE,
    ACTIONS(785), 1,
      sym_identifier,
    ACTIONS(858), 1,
      anon_sym_QMARK,
    ACTIONS(860), 1,
      anon_sym_AT,
    STATE(190), 1,
      sym_function_call,
    STATE(205), 1,
      sym_boolean,
    STATE(389), 1,
      sym_unary_operator,
    STATE(422), 1,
      sym_binary_operator,
    STATE(423), 1,
      sym_cell,
    STATE(477), 1,
      sym_not_operator,
    STATE(622), 1,
      sym__binary_expression,
    STATE(994), 1,
      sym_indirect_access,
    STATE(1181), 1,
      sym__range_element,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(11), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(47), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(446), 2,
      sym_comparison_operator,
      sym_boolean_operator,
    STATE(396), 5,
      sym__expression,
      sym_metaclass_operator,
      sym_handle_operator,
      sym_range,
      sym_lambda,
    STATE(411), 5,
      sym_parenthesis,
      sym_field_expression,
      sym_postfix_operator,
      sym_string,
      sym_matrix,
  [17894] = 25,
    ACTIONS(836), 1,
      anon_sym_LPAREN,
    ACTIONS(840), 1,
      anon_sym_TILDE,
    ACTIONS(846), 1,
      anon_sym_LBRACK,
    ACTIONS(848), 1,
      anon_sym_LBRACE,
    ACTIONS(854), 1,
      sym__single_quote_string_start,
    ACTIONS(856), 1,
      sym__double_quote_string_start,
    ACTIONS(862), 1,
      sym_identifier,
    ACTIONS(864), 1,
      anon_sym_QMARK,
    ACTIONS(866), 1,
      anon_sym_AT,
    ACTIONS(868), 1,
      sym_number,
    STATE(80), 1,
      sym_function_call,
    STATE(99), 1,
      sym_boolean,
    STATE(105), 1,
      sym_unary_operator,
    STATE(109), 1,
      sym_cell,
    STATE(121), 1,
      sym_binary_operator,
    STATE(139), 1,
      sym_not_operator,
    STATE(617), 1,
      sym__binary_expression,
    STATE(956), 1,
      sym_indirect_access,
    STATE(1159), 1,
      sym__range_element,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(838), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(852), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(114), 2,
      sym_comparison_operator,
      sym_boolean_operator,
    STATE(104), 5,
      sym_parenthesis,
      sym_field_expression,
      sym_postfix_operator,
      sym_string,
      sym_matrix,
    STATE(111), 5,
      sym__expression,
      sym_metaclass_operator,
      sym_handle_operator,
      sym_range,
      sym_lambda,
  [17982] = 25,
    ACTIONS(640), 1,
      anon_sym_LPAREN,
    ACTIONS(644), 1,
      anon_sym_TILDE,
    ACTIONS(650), 1,
      anon_sym_LBRACK,
    ACTIONS(652), 1,
      anon_sym_LBRACE,
    ACTIONS(658), 1,
      sym_number,
    ACTIONS(662), 1,
      sym__single_quote_string_start,
    ACTIONS(664), 1,
      sym__double_quote_string_start,
    ACTIONS(794), 1,
      sym_identifier,
    ACTIONS(806), 1,
      anon_sym_QMARK,
    ACTIONS(808), 1,
      anon_sym_AT,
    STATE(368), 1,
      sym_function_call,
    STATE(402), 1,
      sym_boolean,
    STATE(518), 1,
      sym_cell,
    STATE(530), 1,
      sym_binary_operator,
    STATE(542), 1,
      sym_unary_operator,
    STATE(586), 1,
      sym_not_operator,
    STATE(614), 1,
      sym__binary_expression,
    STATE(905), 1,
      sym_indirect_access,
    STATE(1196), 1,
      sym__range_element,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(642), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(660), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(520), 2,
      sym_comparison_operator,
      sym_boolean_operator,
    STATE(521), 5,
      sym_parenthesis,
      sym_field_expression,
      sym_postfix_operator,
      sym_string,
      sym_matrix,
    STATE(595), 5,
      sym__expression,
      sym_metaclass_operator,
      sym_handle_operator,
      sym_range,
      sym_lambda,
  [18070] = 25,
    ACTIONS(836), 1,
      anon_sym_LPAREN,
    ACTIONS(840), 1,
      anon_sym_TILDE,
    ACTIONS(846), 1,
      anon_sym_LBRACK,
    ACTIONS(848), 1,
      anon_sym_LBRACE,
    ACTIONS(854), 1,
      sym__single_quote_string_start,
    ACTIONS(856), 1,
      sym__double_quote_string_start,
    ACTIONS(862), 1,
      sym_identifier,
    ACTIONS(864), 1,
      anon_sym_QMARK,
    ACTIONS(866), 1,
      anon_sym_AT,
    ACTIONS(868), 1,
      sym_number,
    STATE(80), 1,
      sym_function_call,
    STATE(99), 1,
      sym_boolean,
    STATE(105), 1,
      sym_unary_operator,
    STATE(109), 1,
      sym_cell,
    STATE(121), 1,
      sym_binary_operator,
    STATE(139), 1,
      sym_not_operator,
    STATE(617), 1,
      sym__binary_expression,
    STATE(956), 1,
      sym_indirect_access,
    STATE(1159), 1,
      sym__range_element,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(838), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(852), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(114), 2,
      sym_comparison_operator,
      sym_boolean_operator,
    STATE(101), 5,
      sym__expression,
      sym_metaclass_operator,
      sym_handle_operator,
      sym_range,
      sym_lambda,
    STATE(104), 5,
      sym_parenthesis,
      sym_field_expression,
      sym_postfix_operator,
      sym_string,
      sym_matrix,
  [18158] = 25,
    ACTIONS(834), 1,
      sym_identifier,
    ACTIONS(836), 1,
      anon_sym_LPAREN,
    ACTIONS(840), 1,
      anon_sym_TILDE,
    ACTIONS(846), 1,
      anon_sym_LBRACK,
    ACTIONS(848), 1,
      anon_sym_LBRACE,
    ACTIONS(850), 1,
      sym_number,
    ACTIONS(854), 1,
      sym__single_quote_string_start,
    ACTIONS(856), 1,
      sym__double_quote_string_start,
    ACTIONS(892), 1,
      anon_sym_QMARK,
    ACTIONS(894), 1,
      anon_sym_AT,
    STATE(76), 1,
      sym_function_call,
    STATE(91), 1,
      sym_boolean,
    STATE(109), 1,
      sym_cell,
    STATE(124), 1,
      sym_binary_operator,
    STATE(126), 1,
      sym_unary_operator,
    STATE(146), 1,
      sym_not_operator,
    STATE(617), 1,
      sym__binary_expression,
    STATE(956), 1,
      sym_indirect_access,
    STATE(1159), 1,
      sym__range_element,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(838), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(852), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(114), 2,
      sym_comparison_operator,
      sym_boolean_operator,
    STATE(127), 5,
      sym_parenthesis,
      sym_field_expression,
      sym_postfix_operator,
      sym_string,
      sym_matrix,
    STATE(151), 5,
      sym__expression,
      sym_metaclass_operator,
      sym_handle_operator,
      sym_range,
      sym_lambda,
  [18246] = 25,
    ACTIONS(834), 1,
      sym_identifier,
    ACTIONS(836), 1,
      anon_sym_LPAREN,
    ACTIONS(840), 1,
      anon_sym_TILDE,
    ACTIONS(846), 1,
      anon_sym_LBRACK,
    ACTIONS(848), 1,
      anon_sym_LBRACE,
    ACTIONS(850), 1,
      sym_number,
    ACTIONS(854), 1,
      sym__single_quote_string_start,
    ACTIONS(856), 1,
      sym__double_quote_string_start,
    ACTIONS(892), 1,
      anon_sym_QMARK,
    ACTIONS(894), 1,
      anon_sym_AT,
    STATE(76), 1,
      sym_function_call,
    STATE(91), 1,
      sym_boolean,
    STATE(109), 1,
      sym_cell,
    STATE(124), 1,
      sym_binary_operator,
    STATE(126), 1,
      sym_unary_operator,
    STATE(146), 1,
      sym_not_operator,
    STATE(617), 1,
      sym__binary_expression,
    STATE(956), 1,
      sym_indirect_access,
    STATE(1159), 1,
      sym__range_element,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(838), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(852), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(114), 2,
      sym_comparison_operator,
      sym_boolean_operator,
    STATE(127), 5,
      sym_parenthesis,
      sym_field_expression,
      sym_postfix_operator,
      sym_string,
      sym_matrix,
    STATE(150), 5,
      sym__expression,
      sym_metaclass_operator,
      sym_handle_operator,
      sym_range,
      sym_lambda,
  [18334] = 4,
    ACTIONS(737), 1,
      anon_sym_DOT,
    STATE(311), 1,
      aux_sym_field_expression_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(389), 33,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_case,
      anon_sym_otherwise,
      anon_sym_LF,
      anon_sym_CR,
  [18380] = 4,
    ACTIONS(914), 1,
      anon_sym_DOT,
    STATE(311), 1,
      aux_sym_field_expression_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(399), 33,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_case,
      anon_sym_otherwise,
      anon_sym_LF,
      anon_sym_CR,
  [18426] = 25,
    ACTIONS(571), 1,
      sym_identifier,
    ACTIONS(597), 1,
      sym__single_quote_string_start,
    ACTIONS(599), 1,
      sym__double_quote_string_start,
    ACTIONS(672), 1,
      anon_sym_LPAREN,
    ACTIONS(682), 1,
      anon_sym_LBRACK,
    ACTIONS(686), 1,
      anon_sym_LBRACE,
    ACTIONS(688), 1,
      sym_number,
    ACTIONS(876), 1,
      anon_sym_TILDE,
    ACTIONS(910), 1,
      anon_sym_QMARK,
    ACTIONS(912), 1,
      anon_sym_AT,
    STATE(216), 1,
      sym_function_call,
    STATE(363), 1,
      sym_boolean,
    STATE(508), 1,
      sym_unary_operator,
    STATE(509), 1,
      sym_binary_operator,
    STATE(510), 1,
      sym_cell,
    STATE(525), 1,
      sym_not_operator,
    STATE(615), 1,
      sym__binary_expression,
    STATE(919), 1,
      sym_indirect_access,
    STATE(1179), 1,
      sym__range_element,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(595), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(674), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    STATE(511), 2,
      sym_comparison_operator,
      sym_boolean_operator,
    STATE(507), 5,
      sym_parenthesis,
      sym_field_expression,
      sym_postfix_operator,
      sym_string,
      sym_matrix,
    STATE(569), 5,
      sym__expression,
      sym_metaclass_operator,
      sym_handle_operator,
      sym_range,
      sym_lambda,
  [18514] = 25,
    ACTIONS(9), 1,
      anon_sym_LPAREN,
    ACTIONS(15), 1,
      anon_sym_QMARK,
    ACTIONS(17), 1,
      anon_sym_AT,
    ACTIONS(19), 1,
      anon_sym_LBRACK,
    ACTIONS(21), 1,
      anon_sym_LBRACE,
    ACTIONS(45), 1,
      sym_number,
    ACTIONS(51), 1,
      sym__single_quote_string_start,
    ACTIONS(53), 1,
      sym__double_quote_string_start,
    ACTIONS(777), 1,
      anon_sym_TILDE,
    ACTIONS(785), 1,
      sym_identifier,
    STATE(190), 1,
      sym_function_call,
    STATE(205), 1,
      sym_boolean,
    STATE(389), 1,
      sym_unary_operator,
    STATE(422), 1,
      sym_binary_operator,
    STATE(423), 1,
      sym_cell,
    STATE(477), 1,
      sym_not_operator,
    STATE(622), 1,
      sym__binary_expression,
    STATE(994), 1,
      sym_indirect_access,
    STATE(1181), 1,
      sym__range_element,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(11), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(47), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(446), 2,
      sym_comparison_operator,
      sym_boolean_operator,
    STATE(411), 5,
      sym_parenthesis,
      sym_field_expression,
      sym_postfix_operator,
      sym_string,
      sym_matrix,
    STATE(640), 5,
      sym__expression,
      sym_metaclass_operator,
      sym_handle_operator,
      sym_range,
      sym_lambda,
  [18602] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(550), 35,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_AT,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_LBRACE,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_case,
      anon_sym_otherwise,
      anon_sym_LF,
      anon_sym_CR,
  [18644] = 25,
    ACTIONS(571), 1,
      sym_identifier,
    ACTIONS(597), 1,
      sym__single_quote_string_start,
    ACTIONS(599), 1,
      sym__double_quote_string_start,
    ACTIONS(672), 1,
      anon_sym_LPAREN,
    ACTIONS(682), 1,
      anon_sym_LBRACK,
    ACTIONS(686), 1,
      anon_sym_LBRACE,
    ACTIONS(688), 1,
      sym_number,
    ACTIONS(876), 1,
      anon_sym_TILDE,
    ACTIONS(910), 1,
      anon_sym_QMARK,
    ACTIONS(912), 1,
      anon_sym_AT,
    STATE(216), 1,
      sym_function_call,
    STATE(363), 1,
      sym_boolean,
    STATE(508), 1,
      sym_unary_operator,
    STATE(509), 1,
      sym_binary_operator,
    STATE(510), 1,
      sym_cell,
    STATE(525), 1,
      sym_not_operator,
    STATE(615), 1,
      sym__binary_expression,
    STATE(919), 1,
      sym_indirect_access,
    STATE(1179), 1,
      sym__range_element,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(595), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(674), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    STATE(511), 2,
      sym_comparison_operator,
      sym_boolean_operator,
    STATE(507), 5,
      sym_parenthesis,
      sym_field_expression,
      sym_postfix_operator,
      sym_string,
      sym_matrix,
    STATE(571), 5,
      sym__expression,
      sym_metaclass_operator,
      sym_handle_operator,
      sym_range,
      sym_lambda,
  [18732] = 25,
    ACTIONS(640), 1,
      anon_sym_LPAREN,
    ACTIONS(644), 1,
      anon_sym_TILDE,
    ACTIONS(646), 1,
      anon_sym_QMARK,
    ACTIONS(648), 1,
      anon_sym_AT,
    ACTIONS(650), 1,
      anon_sym_LBRACK,
    ACTIONS(652), 1,
      anon_sym_LBRACE,
    ACTIONS(658), 1,
      sym_number,
    ACTIONS(662), 1,
      sym__single_quote_string_start,
    ACTIONS(664), 1,
      sym__double_quote_string_start,
    ACTIONS(751), 1,
      sym_identifier,
    STATE(367), 1,
      sym_function_call,
    STATE(402), 1,
      sym_boolean,
    STATE(518), 1,
      sym_cell,
    STATE(530), 1,
      sym_binary_operator,
    STATE(542), 1,
      sym_unary_operator,
    STATE(586), 1,
      sym_not_operator,
    STATE(614), 1,
      sym__binary_expression,
    STATE(905), 1,
      sym_indirect_access,
    STATE(1196), 1,
      sym__range_element,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(642), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(660), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(520), 2,
      sym_comparison_operator,
      sym_boolean_operator,
    STATE(521), 5,
      sym_parenthesis,
      sym_field_expression,
      sym_postfix_operator,
      sym_string,
      sym_matrix,
    STATE(593), 5,
      sym__expression,
      sym_metaclass_operator,
      sym_handle_operator,
      sym_range,
      sym_lambda,
  [18820] = 25,
    ACTIONS(640), 1,
      anon_sym_LPAREN,
    ACTIONS(644), 1,
      anon_sym_TILDE,
    ACTIONS(650), 1,
      anon_sym_LBRACK,
    ACTIONS(652), 1,
      anon_sym_LBRACE,
    ACTIONS(658), 1,
      sym_number,
    ACTIONS(662), 1,
      sym__single_quote_string_start,
    ACTIONS(664), 1,
      sym__double_quote_string_start,
    ACTIONS(767), 1,
      anon_sym_QMARK,
    ACTIONS(769), 1,
      anon_sym_AT,
    ACTIONS(917), 1,
      sym_identifier,
    STATE(395), 1,
      sym_function_call,
    STATE(402), 1,
      sym_boolean,
    STATE(518), 1,
      sym_cell,
    STATE(579), 1,
      sym_binary_operator,
    STATE(583), 1,
      sym_unary_operator,
    STATE(586), 1,
      sym_not_operator,
    STATE(614), 1,
      sym__binary_expression,
    STATE(905), 1,
      sym_indirect_access,
    STATE(1196), 1,
      sym__range_element,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(642), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(660), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(520), 2,
      sym_comparison_operator,
      sym_boolean_operator,
    STATE(584), 5,
      sym_parenthesis,
      sym_field_expression,
      sym_postfix_operator,
      sym_string,
      sym_matrix,
    STATE(700), 5,
      sym__expression,
      sym_metaclass_operator,
      sym_handle_operator,
      sym_range,
      sym_lambda,
  [18908] = 25,
    ACTIONS(597), 1,
      sym__single_quote_string_start,
    ACTIONS(599), 1,
      sym__double_quote_string_start,
    ACTIONS(620), 1,
      sym_identifier,
    ACTIONS(672), 1,
      anon_sym_LPAREN,
    ACTIONS(682), 1,
      anon_sym_LBRACK,
    ACTIONS(686), 1,
      anon_sym_LBRACE,
    ACTIONS(876), 1,
      anon_sym_TILDE,
    ACTIONS(919), 1,
      anon_sym_QMARK,
    ACTIONS(921), 1,
      anon_sym_AT,
    ACTIONS(923), 1,
      sym_number,
    STATE(207), 1,
      sym_function_call,
    STATE(359), 1,
      sym_boolean,
    STATE(466), 1,
      sym_unary_operator,
    STATE(469), 1,
      sym_not_operator,
    STATE(499), 1,
      sym_binary_operator,
    STATE(510), 1,
      sym_cell,
    STATE(615), 1,
      sym__binary_expression,
    STATE(919), 1,
      sym_indirect_access,
    STATE(1179), 1,
      sym__range_element,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(595), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(674), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    STATE(511), 2,
      sym_comparison_operator,
      sym_boolean_operator,
    STATE(463), 5,
      sym_parenthesis,
      sym_field_expression,
      sym_postfix_operator,
      sym_string,
      sym_matrix,
    STATE(494), 5,
      sym__expression,
      sym_metaclass_operator,
      sym_handle_operator,
      sym_range,
      sym_lambda,
  [18996] = 25,
    ACTIONS(640), 1,
      anon_sym_LPAREN,
    ACTIONS(644), 1,
      anon_sym_TILDE,
    ACTIONS(646), 1,
      anon_sym_QMARK,
    ACTIONS(648), 1,
      anon_sym_AT,
    ACTIONS(650), 1,
      anon_sym_LBRACK,
    ACTIONS(652), 1,
      anon_sym_LBRACE,
    ACTIONS(658), 1,
      sym_number,
    ACTIONS(662), 1,
      sym__single_quote_string_start,
    ACTIONS(664), 1,
      sym__double_quote_string_start,
    ACTIONS(751), 1,
      sym_identifier,
    STATE(367), 1,
      sym_function_call,
    STATE(402), 1,
      sym_boolean,
    STATE(518), 1,
      sym_cell,
    STATE(530), 1,
      sym_binary_operator,
    STATE(542), 1,
      sym_unary_operator,
    STATE(586), 1,
      sym_not_operator,
    STATE(614), 1,
      sym__binary_expression,
    STATE(905), 1,
      sym_indirect_access,
    STATE(1196), 1,
      sym__range_element,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(642), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(660), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(520), 2,
      sym_comparison_operator,
      sym_boolean_operator,
    STATE(521), 5,
      sym_parenthesis,
      sym_field_expression,
      sym_postfix_operator,
      sym_string,
      sym_matrix,
    STATE(598), 5,
      sym__expression,
      sym_metaclass_operator,
      sym_handle_operator,
      sym_range,
      sym_lambda,
  [19084] = 25,
    ACTIONS(640), 1,
      anon_sym_LPAREN,
    ACTIONS(644), 1,
      anon_sym_TILDE,
    ACTIONS(650), 1,
      anon_sym_LBRACK,
    ACTIONS(652), 1,
      anon_sym_LBRACE,
    ACTIONS(662), 1,
      sym__single_quote_string_start,
    ACTIONS(664), 1,
      sym__double_quote_string_start,
    ACTIONS(814), 1,
      sym_identifier,
    ACTIONS(816), 1,
      anon_sym_QMARK,
    ACTIONS(818), 1,
      anon_sym_AT,
    ACTIONS(820), 1,
      sym_number,
    STATE(377), 1,
      sym_function_call,
    STATE(394), 1,
      sym_boolean,
    STATE(518), 1,
      sym_cell,
    STATE(519), 1,
      sym_not_operator,
    STATE(531), 1,
      sym_unary_operator,
    STATE(561), 1,
      sym_binary_operator,
    STATE(614), 1,
      sym__binary_expression,
    STATE(905), 1,
      sym_indirect_access,
    STATE(1196), 1,
      sym__range_element,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(642), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(660), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(520), 2,
      sym_comparison_operator,
      sym_boolean_operator,
    STATE(527), 5,
      sym_parenthesis,
      sym_field_expression,
      sym_postfix_operator,
      sym_string,
      sym_matrix,
    STATE(550), 5,
      sym__expression,
      sym_metaclass_operator,
      sym_handle_operator,
      sym_range,
      sym_lambda,
  [19172] = 25,
    ACTIONS(571), 1,
      sym_identifier,
    ACTIONS(597), 1,
      sym__single_quote_string_start,
    ACTIONS(599), 1,
      sym__double_quote_string_start,
    ACTIONS(672), 1,
      anon_sym_LPAREN,
    ACTIONS(682), 1,
      anon_sym_LBRACK,
    ACTIONS(686), 1,
      anon_sym_LBRACE,
    ACTIONS(688), 1,
      sym_number,
    ACTIONS(876), 1,
      anon_sym_TILDE,
    ACTIONS(910), 1,
      anon_sym_QMARK,
    ACTIONS(912), 1,
      anon_sym_AT,
    STATE(216), 1,
      sym_function_call,
    STATE(363), 1,
      sym_boolean,
    STATE(508), 1,
      sym_unary_operator,
    STATE(509), 1,
      sym_binary_operator,
    STATE(510), 1,
      sym_cell,
    STATE(525), 1,
      sym_not_operator,
    STATE(615), 1,
      sym__binary_expression,
    STATE(919), 1,
      sym_indirect_access,
    STATE(1179), 1,
      sym__range_element,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(595), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(674), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    STATE(511), 2,
      sym_comparison_operator,
      sym_boolean_operator,
    STATE(461), 5,
      sym__expression,
      sym_metaclass_operator,
      sym_handle_operator,
      sym_range,
      sym_lambda,
    STATE(507), 5,
      sym_parenthesis,
      sym_field_expression,
      sym_postfix_operator,
      sym_string,
      sym_matrix,
  [19260] = 25,
    ACTIONS(571), 1,
      sym_identifier,
    ACTIONS(597), 1,
      sym__single_quote_string_start,
    ACTIONS(599), 1,
      sym__double_quote_string_start,
    ACTIONS(672), 1,
      anon_sym_LPAREN,
    ACTIONS(682), 1,
      anon_sym_LBRACK,
    ACTIONS(686), 1,
      anon_sym_LBRACE,
    ACTIONS(688), 1,
      sym_number,
    ACTIONS(876), 1,
      anon_sym_TILDE,
    ACTIONS(910), 1,
      anon_sym_QMARK,
    ACTIONS(912), 1,
      anon_sym_AT,
    STATE(216), 1,
      sym_function_call,
    STATE(363), 1,
      sym_boolean,
    STATE(508), 1,
      sym_unary_operator,
    STATE(509), 1,
      sym_binary_operator,
    STATE(510), 1,
      sym_cell,
    STATE(525), 1,
      sym_not_operator,
    STATE(615), 1,
      sym__binary_expression,
    STATE(919), 1,
      sym_indirect_access,
    STATE(1179), 1,
      sym__range_element,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(595), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(674), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    STATE(511), 2,
      sym_comparison_operator,
      sym_boolean_operator,
    STATE(507), 5,
      sym_parenthesis,
      sym_field_expression,
      sym_postfix_operator,
      sym_string,
      sym_matrix,
    STATE(566), 5,
      sym__expression,
      sym_metaclass_operator,
      sym_handle_operator,
      sym_range,
      sym_lambda,
  [19348] = 25,
    ACTIONS(571), 1,
      sym_identifier,
    ACTIONS(597), 1,
      sym__single_quote_string_start,
    ACTIONS(599), 1,
      sym__double_quote_string_start,
    ACTIONS(672), 1,
      anon_sym_LPAREN,
    ACTIONS(682), 1,
      anon_sym_LBRACK,
    ACTIONS(686), 1,
      anon_sym_LBRACE,
    ACTIONS(688), 1,
      sym_number,
    ACTIONS(876), 1,
      anon_sym_TILDE,
    ACTIONS(910), 1,
      anon_sym_QMARK,
    ACTIONS(912), 1,
      anon_sym_AT,
    STATE(216), 1,
      sym_function_call,
    STATE(363), 1,
      sym_boolean,
    STATE(508), 1,
      sym_unary_operator,
    STATE(509), 1,
      sym_binary_operator,
    STATE(510), 1,
      sym_cell,
    STATE(525), 1,
      sym_not_operator,
    STATE(615), 1,
      sym__binary_expression,
    STATE(919), 1,
      sym_indirect_access,
    STATE(1179), 1,
      sym__range_element,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(595), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(674), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    STATE(511), 2,
      sym_comparison_operator,
      sym_boolean_operator,
    STATE(507), 5,
      sym_parenthesis,
      sym_field_expression,
      sym_postfix_operator,
      sym_string,
      sym_matrix,
    STATE(567), 5,
      sym__expression,
      sym_metaclass_operator,
      sym_handle_operator,
      sym_range,
      sym_lambda,
  [19436] = 25,
    ACTIONS(597), 1,
      sym__single_quote_string_start,
    ACTIONS(599), 1,
      sym__double_quote_string_start,
    ACTIONS(620), 1,
      sym_identifier,
    ACTIONS(672), 1,
      anon_sym_LPAREN,
    ACTIONS(682), 1,
      anon_sym_LBRACK,
    ACTIONS(686), 1,
      anon_sym_LBRACE,
    ACTIONS(876), 1,
      anon_sym_TILDE,
    ACTIONS(919), 1,
      anon_sym_QMARK,
    ACTIONS(921), 1,
      anon_sym_AT,
    ACTIONS(923), 1,
      sym_number,
    STATE(207), 1,
      sym_function_call,
    STATE(359), 1,
      sym_boolean,
    STATE(466), 1,
      sym_unary_operator,
    STATE(469), 1,
      sym_not_operator,
    STATE(499), 1,
      sym_binary_operator,
    STATE(510), 1,
      sym_cell,
    STATE(615), 1,
      sym__binary_expression,
    STATE(919), 1,
      sym_indirect_access,
    STATE(1179), 1,
      sym__range_element,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(595), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(674), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    STATE(511), 2,
      sym_comparison_operator,
      sym_boolean_operator,
    STATE(463), 5,
      sym_parenthesis,
      sym_field_expression,
      sym_postfix_operator,
      sym_string,
      sym_matrix,
    STATE(493), 5,
      sym__expression,
      sym_metaclass_operator,
      sym_handle_operator,
      sym_range,
      sym_lambda,
  [19524] = 23,
    ACTIONS(767), 1,
      anon_sym_QMARK,
    ACTIONS(769), 1,
      anon_sym_AT,
    ACTIONS(836), 1,
      anon_sym_LPAREN,
    ACTIONS(840), 1,
      anon_sym_TILDE,
    ACTIONS(846), 1,
      anon_sym_LBRACK,
    ACTIONS(848), 1,
      anon_sym_LBRACE,
    ACTIONS(854), 1,
      sym__single_quote_string_start,
    ACTIONS(856), 1,
      sym__double_quote_string_start,
    ACTIONS(925), 1,
      sym_identifier,
    ACTIONS(927), 1,
      sym_number,
    STATE(79), 1,
      sym_function_call,
    STATE(95), 1,
      sym_boolean,
    STATE(103), 1,
      sym_binary_operator,
    STATE(119), 1,
      sym_cell,
    STATE(129), 1,
      sym_unary_operator,
    STATE(956), 1,
      sym_indirect_access,
    STATE(1196), 1,
      sym__range_element,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(838), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(852), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(145), 4,
      sym__binary_expression,
      sym_not_operator,
      sym_comparison_operator,
      sym_boolean_operator,
    STATE(128), 5,
      sym_parenthesis,
      sym_field_expression,
      sym_postfix_operator,
      sym_string,
      sym_matrix,
    STATE(691), 5,
      sym__expression,
      sym_metaclass_operator,
      sym_handle_operator,
      sym_range,
      sym_lambda,
  [19608] = 23,
    ACTIONS(767), 1,
      anon_sym_QMARK,
    ACTIONS(769), 1,
      anon_sym_AT,
    ACTIONS(836), 1,
      anon_sym_LPAREN,
    ACTIONS(840), 1,
      anon_sym_TILDE,
    ACTIONS(846), 1,
      anon_sym_LBRACK,
    ACTIONS(848), 1,
      anon_sym_LBRACE,
    ACTIONS(854), 1,
      sym__single_quote_string_start,
    ACTIONS(856), 1,
      sym__double_quote_string_start,
    ACTIONS(925), 1,
      sym_identifier,
    ACTIONS(927), 1,
      sym_number,
    STATE(79), 1,
      sym_function_call,
    STATE(95), 1,
      sym_boolean,
    STATE(103), 1,
      sym_binary_operator,
    STATE(119), 1,
      sym_cell,
    STATE(129), 1,
      sym_unary_operator,
    STATE(956), 1,
      sym_indirect_access,
    STATE(1196), 1,
      sym__range_element,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(838), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(852), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(144), 4,
      sym__binary_expression,
      sym_not_operator,
      sym_comparison_operator,
      sym_boolean_operator,
    STATE(128), 5,
      sym_parenthesis,
      sym_field_expression,
      sym_postfix_operator,
      sym_string,
      sym_matrix,
    STATE(691), 5,
      sym__expression,
      sym_metaclass_operator,
      sym_handle_operator,
      sym_range,
      sym_lambda,
  [19692] = 23,
    ACTIONS(767), 1,
      anon_sym_QMARK,
    ACTIONS(769), 1,
      anon_sym_AT,
    ACTIONS(836), 1,
      anon_sym_LPAREN,
    ACTIONS(840), 1,
      anon_sym_TILDE,
    ACTIONS(846), 1,
      anon_sym_LBRACK,
    ACTIONS(848), 1,
      anon_sym_LBRACE,
    ACTIONS(854), 1,
      sym__single_quote_string_start,
    ACTIONS(856), 1,
      sym__double_quote_string_start,
    ACTIONS(925), 1,
      sym_identifier,
    ACTIONS(927), 1,
      sym_number,
    STATE(79), 1,
      sym_function_call,
    STATE(95), 1,
      sym_boolean,
    STATE(103), 1,
      sym_binary_operator,
    STATE(119), 1,
      sym_cell,
    STATE(129), 1,
      sym_unary_operator,
    STATE(956), 1,
      sym_indirect_access,
    STATE(1196), 1,
      sym__range_element,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(838), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(852), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(143), 4,
      sym__binary_expression,
      sym_not_operator,
      sym_comparison_operator,
      sym_boolean_operator,
    STATE(128), 5,
      sym_parenthesis,
      sym_field_expression,
      sym_postfix_operator,
      sym_string,
      sym_matrix,
    STATE(691), 5,
      sym__expression,
      sym_metaclass_operator,
      sym_handle_operator,
      sym_range,
      sym_lambda,
  [19776] = 23,
    ACTIONS(767), 1,
      anon_sym_QMARK,
    ACTIONS(769), 1,
      anon_sym_AT,
    ACTIONS(836), 1,
      anon_sym_LPAREN,
    ACTIONS(840), 1,
      anon_sym_TILDE,
    ACTIONS(846), 1,
      anon_sym_LBRACK,
    ACTIONS(848), 1,
      anon_sym_LBRACE,
    ACTIONS(854), 1,
      sym__single_quote_string_start,
    ACTIONS(856), 1,
      sym__double_quote_string_start,
    ACTIONS(925), 1,
      sym_identifier,
    ACTIONS(927), 1,
      sym_number,
    STATE(79), 1,
      sym_function_call,
    STATE(95), 1,
      sym_boolean,
    STATE(103), 1,
      sym_binary_operator,
    STATE(119), 1,
      sym_cell,
    STATE(129), 1,
      sym_unary_operator,
    STATE(956), 1,
      sym_indirect_access,
    STATE(1196), 1,
      sym__range_element,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(838), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(852), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(142), 4,
      sym__binary_expression,
      sym_not_operator,
      sym_comparison_operator,
      sym_boolean_operator,
    STATE(128), 5,
      sym_parenthesis,
      sym_field_expression,
      sym_postfix_operator,
      sym_string,
      sym_matrix,
    STATE(691), 5,
      sym__expression,
      sym_metaclass_operator,
      sym_handle_operator,
      sym_range,
      sym_lambda,
  [19860] = 23,
    ACTIONS(767), 1,
      anon_sym_QMARK,
    ACTIONS(769), 1,
      anon_sym_AT,
    ACTIONS(836), 1,
      anon_sym_LPAREN,
    ACTIONS(840), 1,
      anon_sym_TILDE,
    ACTIONS(846), 1,
      anon_sym_LBRACK,
    ACTIONS(848), 1,
      anon_sym_LBRACE,
    ACTIONS(854), 1,
      sym__single_quote_string_start,
    ACTIONS(856), 1,
      sym__double_quote_string_start,
    ACTIONS(925), 1,
      sym_identifier,
    ACTIONS(927), 1,
      sym_number,
    STATE(79), 1,
      sym_function_call,
    STATE(95), 1,
      sym_boolean,
    STATE(103), 1,
      sym_binary_operator,
    STATE(119), 1,
      sym_cell,
    STATE(129), 1,
      sym_unary_operator,
    STATE(956), 1,
      sym_indirect_access,
    STATE(1196), 1,
      sym__range_element,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(838), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(852), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(141), 4,
      sym__binary_expression,
      sym_not_operator,
      sym_comparison_operator,
      sym_boolean_operator,
    STATE(128), 5,
      sym_parenthesis,
      sym_field_expression,
      sym_postfix_operator,
      sym_string,
      sym_matrix,
    STATE(691), 5,
      sym__expression,
      sym_metaclass_operator,
      sym_handle_operator,
      sym_range,
      sym_lambda,
  [19944] = 25,
    ACTIONS(652), 1,
      anon_sym_LBRACE,
    ACTIONS(767), 1,
      anon_sym_QMARK,
    ACTIONS(769), 1,
      anon_sym_AT,
    ACTIONS(836), 1,
      anon_sym_LPAREN,
    ACTIONS(840), 1,
      anon_sym_TILDE,
    ACTIONS(846), 1,
      anon_sym_LBRACK,
    ACTIONS(854), 1,
      sym__single_quote_string_start,
    ACTIONS(856), 1,
      sym__double_quote_string_start,
    ACTIONS(929), 1,
      sym_identifier,
    ACTIONS(931), 1,
      sym_number,
    STATE(77), 1,
      sym_function_call,
    STATE(97), 1,
      sym_boolean,
    STATE(107), 1,
      sym_binary_operator,
    STATE(131), 1,
      sym__range_element,
    STATE(134), 1,
      sym_unary_operator,
    STATE(136), 1,
      sym_not_operator,
    STATE(601), 1,
      sym_cell,
    STATE(617), 1,
      sym__binary_expression,
    STATE(956), 1,
      sym_indirect_access,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(838), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(852), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(520), 2,
      sym_comparison_operator,
      sym_boolean_operator,
    STATE(133), 5,
      sym_parenthesis,
      sym_field_expression,
      sym_postfix_operator,
      sym_string,
      sym_matrix,
    STATE(700), 5,
      sym__expression,
      sym_metaclass_operator,
      sym_handle_operator,
      sym_range,
      sym_lambda,
  [20032] = 25,
    ACTIONS(597), 1,
      sym__single_quote_string_start,
    ACTIONS(599), 1,
      sym__double_quote_string_start,
    ACTIONS(620), 1,
      sym_identifier,
    ACTIONS(672), 1,
      anon_sym_LPAREN,
    ACTIONS(682), 1,
      anon_sym_LBRACK,
    ACTIONS(686), 1,
      anon_sym_LBRACE,
    ACTIONS(876), 1,
      anon_sym_TILDE,
    ACTIONS(919), 1,
      anon_sym_QMARK,
    ACTIONS(921), 1,
      anon_sym_AT,
    ACTIONS(923), 1,
      sym_number,
    STATE(207), 1,
      sym_function_call,
    STATE(359), 1,
      sym_boolean,
    STATE(466), 1,
      sym_unary_operator,
    STATE(469), 1,
      sym_not_operator,
    STATE(499), 1,
      sym_binary_operator,
    STATE(510), 1,
      sym_cell,
    STATE(615), 1,
      sym__binary_expression,
    STATE(919), 1,
      sym_indirect_access,
    STATE(1179), 1,
      sym__range_element,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(595), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(674), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    STATE(511), 2,
      sym_comparison_operator,
      sym_boolean_operator,
    STATE(460), 5,
      sym__expression,
      sym_metaclass_operator,
      sym_handle_operator,
      sym_range,
      sym_lambda,
    STATE(463), 5,
      sym_parenthesis,
      sym_field_expression,
      sym_postfix_operator,
      sym_string,
      sym_matrix,
  [20120] = 25,
    ACTIONS(597), 1,
      sym__single_quote_string_start,
    ACTIONS(599), 1,
      sym__double_quote_string_start,
    ACTIONS(620), 1,
      sym_identifier,
    ACTIONS(672), 1,
      anon_sym_LPAREN,
    ACTIONS(682), 1,
      anon_sym_LBRACK,
    ACTIONS(686), 1,
      anon_sym_LBRACE,
    ACTIONS(876), 1,
      anon_sym_TILDE,
    ACTIONS(919), 1,
      anon_sym_QMARK,
    ACTIONS(921), 1,
      anon_sym_AT,
    ACTIONS(923), 1,
      sym_number,
    STATE(207), 1,
      sym_function_call,
    STATE(359), 1,
      sym_boolean,
    STATE(466), 1,
      sym_unary_operator,
    STATE(469), 1,
      sym_not_operator,
    STATE(499), 1,
      sym_binary_operator,
    STATE(510), 1,
      sym_cell,
    STATE(615), 1,
      sym__binary_expression,
    STATE(919), 1,
      sym_indirect_access,
    STATE(1179), 1,
      sym__range_element,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(595), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(674), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    STATE(511), 2,
      sym_comparison_operator,
      sym_boolean_operator,
    STATE(463), 5,
      sym_parenthesis,
      sym_field_expression,
      sym_postfix_operator,
      sym_string,
      sym_matrix,
    STATE(486), 5,
      sym__expression,
      sym_metaclass_operator,
      sym_handle_operator,
      sym_range,
      sym_lambda,
  [20208] = 25,
    ACTIONS(652), 1,
      anon_sym_LBRACE,
    ACTIONS(767), 1,
      anon_sym_QMARK,
    ACTIONS(769), 1,
      anon_sym_AT,
    ACTIONS(836), 1,
      anon_sym_LPAREN,
    ACTIONS(840), 1,
      anon_sym_TILDE,
    ACTIONS(846), 1,
      anon_sym_LBRACK,
    ACTIONS(854), 1,
      sym__single_quote_string_start,
    ACTIONS(856), 1,
      sym__double_quote_string_start,
    ACTIONS(929), 1,
      sym_identifier,
    ACTIONS(931), 1,
      sym_number,
    STATE(77), 1,
      sym_function_call,
    STATE(97), 1,
      sym_boolean,
    STATE(107), 1,
      sym_binary_operator,
    STATE(134), 1,
      sym_unary_operator,
    STATE(136), 1,
      sym_not_operator,
    STATE(137), 1,
      sym__range_element,
    STATE(601), 1,
      sym_cell,
    STATE(617), 1,
      sym__binary_expression,
    STATE(956), 1,
      sym_indirect_access,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(838), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(852), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(520), 2,
      sym_comparison_operator,
      sym_boolean_operator,
    STATE(133), 5,
      sym_parenthesis,
      sym_field_expression,
      sym_postfix_operator,
      sym_string,
      sym_matrix,
    STATE(700), 5,
      sym__expression,
      sym_metaclass_operator,
      sym_handle_operator,
      sym_range,
      sym_lambda,
  [20296] = 25,
    ACTIONS(597), 1,
      sym__single_quote_string_start,
    ACTIONS(599), 1,
      sym__double_quote_string_start,
    ACTIONS(620), 1,
      sym_identifier,
    ACTIONS(672), 1,
      anon_sym_LPAREN,
    ACTIONS(682), 1,
      anon_sym_LBRACK,
    ACTIONS(686), 1,
      anon_sym_LBRACE,
    ACTIONS(876), 1,
      anon_sym_TILDE,
    ACTIONS(919), 1,
      anon_sym_QMARK,
    ACTIONS(921), 1,
      anon_sym_AT,
    ACTIONS(923), 1,
      sym_number,
    STATE(207), 1,
      sym_function_call,
    STATE(359), 1,
      sym_boolean,
    STATE(466), 1,
      sym_unary_operator,
    STATE(469), 1,
      sym_not_operator,
    STATE(499), 1,
      sym_binary_operator,
    STATE(510), 1,
      sym_cell,
    STATE(615), 1,
      sym__binary_expression,
    STATE(919), 1,
      sym_indirect_access,
    STATE(1179), 1,
      sym__range_element,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(595), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(674), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    STATE(511), 2,
      sym_comparison_operator,
      sym_boolean_operator,
    STATE(463), 5,
      sym_parenthesis,
      sym_field_expression,
      sym_postfix_operator,
      sym_string,
      sym_matrix,
    STATE(484), 5,
      sym__expression,
      sym_metaclass_operator,
      sym_handle_operator,
      sym_range,
      sym_lambda,
  [20384] = 25,
    ACTIONS(597), 1,
      sym__single_quote_string_start,
    ACTIONS(599), 1,
      sym__double_quote_string_start,
    ACTIONS(620), 1,
      sym_identifier,
    ACTIONS(672), 1,
      anon_sym_LPAREN,
    ACTIONS(682), 1,
      anon_sym_LBRACK,
    ACTIONS(686), 1,
      anon_sym_LBRACE,
    ACTIONS(876), 1,
      anon_sym_TILDE,
    ACTIONS(919), 1,
      anon_sym_QMARK,
    ACTIONS(921), 1,
      anon_sym_AT,
    ACTIONS(923), 1,
      sym_number,
    STATE(207), 1,
      sym_function_call,
    STATE(359), 1,
      sym_boolean,
    STATE(466), 1,
      sym_unary_operator,
    STATE(469), 1,
      sym_not_operator,
    STATE(499), 1,
      sym_binary_operator,
    STATE(510), 1,
      sym_cell,
    STATE(615), 1,
      sym__binary_expression,
    STATE(919), 1,
      sym_indirect_access,
    STATE(1179), 1,
      sym__range_element,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(595), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(674), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    STATE(511), 2,
      sym_comparison_operator,
      sym_boolean_operator,
    STATE(461), 5,
      sym__expression,
      sym_metaclass_operator,
      sym_handle_operator,
      sym_range,
      sym_lambda,
    STATE(463), 5,
      sym_parenthesis,
      sym_field_expression,
      sym_postfix_operator,
      sym_string,
      sym_matrix,
  [20472] = 25,
    ACTIONS(834), 1,
      sym_identifier,
    ACTIONS(836), 1,
      anon_sym_LPAREN,
    ACTIONS(840), 1,
      anon_sym_TILDE,
    ACTIONS(846), 1,
      anon_sym_LBRACK,
    ACTIONS(848), 1,
      anon_sym_LBRACE,
    ACTIONS(850), 1,
      sym_number,
    ACTIONS(854), 1,
      sym__single_quote_string_start,
    ACTIONS(856), 1,
      sym__double_quote_string_start,
    ACTIONS(892), 1,
      anon_sym_QMARK,
    ACTIONS(894), 1,
      anon_sym_AT,
    STATE(76), 1,
      sym_function_call,
    STATE(91), 1,
      sym_boolean,
    STATE(109), 1,
      sym_cell,
    STATE(124), 1,
      sym_binary_operator,
    STATE(126), 1,
      sym_unary_operator,
    STATE(146), 1,
      sym_not_operator,
    STATE(617), 1,
      sym__binary_expression,
    STATE(956), 1,
      sym_indirect_access,
    STATE(1159), 1,
      sym__range_element,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(838), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(852), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(114), 2,
      sym_comparison_operator,
      sym_boolean_operator,
    STATE(127), 5,
      sym_parenthesis,
      sym_field_expression,
      sym_postfix_operator,
      sym_string,
      sym_matrix,
    STATE(147), 5,
      sym__expression,
      sym_metaclass_operator,
      sym_handle_operator,
      sym_range,
      sym_lambda,
  [20560] = 25,
    ACTIONS(9), 1,
      anon_sym_LPAREN,
    ACTIONS(15), 1,
      anon_sym_QMARK,
    ACTIONS(17), 1,
      anon_sym_AT,
    ACTIONS(19), 1,
      anon_sym_LBRACK,
    ACTIONS(21), 1,
      anon_sym_LBRACE,
    ACTIONS(45), 1,
      sym_number,
    ACTIONS(51), 1,
      sym__single_quote_string_start,
    ACTIONS(53), 1,
      sym__double_quote_string_start,
    ACTIONS(777), 1,
      anon_sym_TILDE,
    ACTIONS(785), 1,
      sym_identifier,
    STATE(190), 1,
      sym_function_call,
    STATE(205), 1,
      sym_boolean,
    STATE(389), 1,
      sym_unary_operator,
    STATE(422), 1,
      sym_binary_operator,
    STATE(423), 1,
      sym_cell,
    STATE(477), 1,
      sym_not_operator,
    STATE(622), 1,
      sym__binary_expression,
    STATE(994), 1,
      sym_indirect_access,
    STATE(1181), 1,
      sym__range_element,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(11), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(47), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(446), 2,
      sym_comparison_operator,
      sym_boolean_operator,
    STATE(411), 5,
      sym_parenthesis,
      sym_field_expression,
      sym_postfix_operator,
      sym_string,
      sym_matrix,
    STATE(633), 5,
      sym__expression,
      sym_metaclass_operator,
      sym_handle_operator,
      sym_range,
      sym_lambda,
  [20648] = 25,
    ACTIONS(571), 1,
      sym_identifier,
    ACTIONS(597), 1,
      sym__single_quote_string_start,
    ACTIONS(599), 1,
      sym__double_quote_string_start,
    ACTIONS(672), 1,
      anon_sym_LPAREN,
    ACTIONS(678), 1,
      anon_sym_QMARK,
    ACTIONS(680), 1,
      anon_sym_AT,
    ACTIONS(682), 1,
      anon_sym_LBRACK,
    ACTIONS(686), 1,
      anon_sym_LBRACE,
    ACTIONS(688), 1,
      sym_number,
    ACTIONS(876), 1,
      anon_sym_TILDE,
    STATE(216), 1,
      sym_function_call,
    STATE(363), 1,
      sym_boolean,
    STATE(508), 1,
      sym_unary_operator,
    STATE(509), 1,
      sym_binary_operator,
    STATE(510), 1,
      sym_cell,
    STATE(525), 1,
      sym_not_operator,
    STATE(615), 1,
      sym__binary_expression,
    STATE(919), 1,
      sym_indirect_access,
    STATE(1179), 1,
      sym__range_element,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(595), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(674), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    STATE(511), 2,
      sym_comparison_operator,
      sym_boolean_operator,
    STATE(507), 5,
      sym_parenthesis,
      sym_field_expression,
      sym_postfix_operator,
      sym_string,
      sym_matrix,
    STATE(571), 5,
      sym__expression,
      sym_metaclass_operator,
      sym_handle_operator,
      sym_range,
      sym_lambda,
  [20736] = 25,
    ACTIONS(640), 1,
      anon_sym_LPAREN,
    ACTIONS(644), 1,
      anon_sym_TILDE,
    ACTIONS(650), 1,
      anon_sym_LBRACK,
    ACTIONS(652), 1,
      anon_sym_LBRACE,
    ACTIONS(662), 1,
      sym__single_quote_string_start,
    ACTIONS(664), 1,
      sym__double_quote_string_start,
    ACTIONS(814), 1,
      sym_identifier,
    ACTIONS(816), 1,
      anon_sym_QMARK,
    ACTIONS(818), 1,
      anon_sym_AT,
    ACTIONS(820), 1,
      sym_number,
    STATE(377), 1,
      sym_function_call,
    STATE(394), 1,
      sym_boolean,
    STATE(518), 1,
      sym_cell,
    STATE(519), 1,
      sym_not_operator,
    STATE(531), 1,
      sym_unary_operator,
    STATE(561), 1,
      sym_binary_operator,
    STATE(614), 1,
      sym__binary_expression,
    STATE(905), 1,
      sym_indirect_access,
    STATE(1196), 1,
      sym__range_element,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(642), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(660), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(520), 2,
      sym_comparison_operator,
      sym_boolean_operator,
    STATE(527), 5,
      sym_parenthesis,
      sym_field_expression,
      sym_postfix_operator,
      sym_string,
      sym_matrix,
    STATE(558), 5,
      sym__expression,
      sym_metaclass_operator,
      sym_handle_operator,
      sym_range,
      sym_lambda,
  [20824] = 25,
    ACTIONS(640), 1,
      anon_sym_LPAREN,
    ACTIONS(644), 1,
      anon_sym_TILDE,
    ACTIONS(650), 1,
      anon_sym_LBRACK,
    ACTIONS(652), 1,
      anon_sym_LBRACE,
    ACTIONS(662), 1,
      sym__single_quote_string_start,
    ACTIONS(664), 1,
      sym__double_quote_string_start,
    ACTIONS(814), 1,
      sym_identifier,
    ACTIONS(816), 1,
      anon_sym_QMARK,
    ACTIONS(818), 1,
      anon_sym_AT,
    ACTIONS(820), 1,
      sym_number,
    STATE(377), 1,
      sym_function_call,
    STATE(394), 1,
      sym_boolean,
    STATE(518), 1,
      sym_cell,
    STATE(519), 1,
      sym_not_operator,
    STATE(531), 1,
      sym_unary_operator,
    STATE(561), 1,
      sym_binary_operator,
    STATE(614), 1,
      sym__binary_expression,
    STATE(905), 1,
      sym_indirect_access,
    STATE(1196), 1,
      sym__range_element,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(642), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(660), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(520), 2,
      sym_comparison_operator,
      sym_boolean_operator,
    STATE(527), 5,
      sym_parenthesis,
      sym_field_expression,
      sym_postfix_operator,
      sym_string,
      sym_matrix,
    STATE(560), 5,
      sym__expression,
      sym_metaclass_operator,
      sym_handle_operator,
      sym_range,
      sym_lambda,
  [20912] = 5,
    ACTIONS(937), 1,
      anon_sym_arguments,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    STATE(341), 2,
      sym_arguments_statement,
      aux_sym_function_definition_repeat1,
    ACTIONS(933), 14,
      sym_command_name,
      sym__single_quote_string_start,
      sym__double_quote_string_start,
      sym__multioutput_variable_start,
      ts_builtin_sym_end,
      anon_sym_LPAREN,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_AT,
      anon_sym_LBRACK,
      anon_sym_LBRACE,
      sym_number,
    ACTIONS(935), 18,
      sym_return_statement,
      sym_continue_statement,
      sym_break_statement,
      anon_sym_if,
      anon_sym_end,
      anon_sym_for,
      anon_sym_parfor,
      anon_sym_while,
      anon_sym_switch,
      anon_sym_global,
      anon_sym_persistent,
      anon_sym_function,
      anon_sym_endfunction,
      anon_sym_classdef,
      anon_sym_try,
      anon_sym_true,
      anon_sym_false,
      sym_identifier,
  [20960] = 25,
    ACTIONS(9), 1,
      anon_sym_LPAREN,
    ACTIONS(19), 1,
      anon_sym_LBRACK,
    ACTIONS(21), 1,
      anon_sym_LBRACE,
    ACTIONS(45), 1,
      sym_number,
    ACTIONS(51), 1,
      sym__single_quote_string_start,
    ACTIONS(53), 1,
      sym__double_quote_string_start,
    ACTIONS(777), 1,
      anon_sym_TILDE,
    ACTIONS(785), 1,
      sym_identifier,
    ACTIONS(858), 1,
      anon_sym_QMARK,
    ACTIONS(860), 1,
      anon_sym_AT,
    STATE(190), 1,
      sym_function_call,
    STATE(205), 1,
      sym_boolean,
    STATE(389), 1,
      sym_unary_operator,
    STATE(422), 1,
      sym_binary_operator,
    STATE(423), 1,
      sym_cell,
    STATE(477), 1,
      sym_not_operator,
    STATE(622), 1,
      sym__binary_expression,
    STATE(994), 1,
      sym_indirect_access,
    STATE(1181), 1,
      sym__range_element,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(11), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(47), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(446), 2,
      sym_comparison_operator,
      sym_boolean_operator,
    STATE(411), 5,
      sym_parenthesis,
      sym_field_expression,
      sym_postfix_operator,
      sym_string,
      sym_matrix,
    STATE(513), 5,
      sym__expression,
      sym_metaclass_operator,
      sym_handle_operator,
      sym_range,
      sym_lambda,
  [21048] = 25,
    ACTIONS(640), 1,
      anon_sym_LPAREN,
    ACTIONS(644), 1,
      anon_sym_TILDE,
    ACTIONS(650), 1,
      anon_sym_LBRACK,
    ACTIONS(652), 1,
      anon_sym_LBRACE,
    ACTIONS(662), 1,
      sym__single_quote_string_start,
    ACTIONS(664), 1,
      sym__double_quote_string_start,
    ACTIONS(767), 1,
      anon_sym_QMARK,
    ACTIONS(769), 1,
      anon_sym_AT,
    ACTIONS(940), 1,
      sym_identifier,
    ACTIONS(942), 1,
      sym_number,
    STATE(366), 1,
      sym_function_call,
    STATE(398), 1,
      sym_boolean,
    STATE(530), 1,
      sym_binary_operator,
    STATE(533), 1,
      sym_unary_operator,
    STATE(536), 1,
      sym_not_operator,
    STATE(541), 1,
      sym_cell,
    STATE(614), 1,
      sym__binary_expression,
    STATE(905), 1,
      sym_indirect_access,
    STATE(1196), 1,
      sym__range_element,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(642), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(660), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(520), 2,
      sym_comparison_operator,
      sym_boolean_operator,
    STATE(532), 5,
      sym_parenthesis,
      sym_field_expression,
      sym_postfix_operator,
      sym_string,
      sym_matrix,
    STATE(700), 5,
      sym__expression,
      sym_metaclass_operator,
      sym_handle_operator,
      sym_range,
      sym_lambda,
  [21136] = 25,
    ACTIONS(571), 1,
      sym_identifier,
    ACTIONS(597), 1,
      sym__single_quote_string_start,
    ACTIONS(599), 1,
      sym__double_quote_string_start,
    ACTIONS(672), 1,
      anon_sym_LPAREN,
    ACTIONS(678), 1,
      anon_sym_QMARK,
    ACTIONS(680), 1,
      anon_sym_AT,
    ACTIONS(682), 1,
      anon_sym_LBRACK,
    ACTIONS(686), 1,
      anon_sym_LBRACE,
    ACTIONS(688), 1,
      sym_number,
    ACTIONS(876), 1,
      anon_sym_TILDE,
    STATE(216), 1,
      sym_function_call,
    STATE(363), 1,
      sym_boolean,
    STATE(508), 1,
      sym_unary_operator,
    STATE(509), 1,
      sym_binary_operator,
    STATE(510), 1,
      sym_cell,
    STATE(525), 1,
      sym_not_operator,
    STATE(615), 1,
      sym__binary_expression,
    STATE(919), 1,
      sym_indirect_access,
    STATE(1179), 1,
      sym__range_element,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(595), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(674), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    STATE(511), 2,
      sym_comparison_operator,
      sym_boolean_operator,
    STATE(507), 5,
      sym_parenthesis,
      sym_field_expression,
      sym_postfix_operator,
      sym_string,
      sym_matrix,
    STATE(569), 5,
      sym__expression,
      sym_metaclass_operator,
      sym_handle_operator,
      sym_range,
      sym_lambda,
  [21224] = 7,
    ACTIONS(755), 1,
      anon_sym_LPAREN,
    ACTIONS(759), 1,
      anon_sym_AT,
    ACTIONS(763), 1,
      anon_sym_LBRACE,
    STATE(362), 1,
      sym__args,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(408), 2,
      sym__entry_delimiter,
      aux_sym_matrix_token1,
    ACTIONS(406), 29,
      anon_sym_SEMI,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_DOT,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_RBRACK,
      anon_sym_RBRACE,
      anon_sym_COLON,
  [21276] = 25,
    ACTIONS(640), 1,
      anon_sym_LPAREN,
    ACTIONS(644), 1,
      anon_sym_TILDE,
    ACTIONS(650), 1,
      anon_sym_LBRACK,
    ACTIONS(652), 1,
      anon_sym_LBRACE,
    ACTIONS(658), 1,
      sym_number,
    ACTIONS(662), 1,
      sym__single_quote_string_start,
    ACTIONS(664), 1,
      sym__double_quote_string_start,
    ACTIONS(767), 1,
      anon_sym_QMARK,
    ACTIONS(769), 1,
      anon_sym_AT,
    ACTIONS(870), 1,
      sym_identifier,
    STATE(402), 1,
      sym_boolean,
    STATE(442), 1,
      sym_function_call,
    STATE(518), 1,
      sym_cell,
    STATE(564), 1,
      sym_binary_operator,
    STATE(565), 1,
      sym_unary_operator,
    STATE(586), 1,
      sym_not_operator,
    STATE(614), 1,
      sym__binary_expression,
    STATE(905), 1,
      sym_indirect_access,
    STATE(1196), 1,
      sym__range_element,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(642), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(660), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(520), 2,
      sym_comparison_operator,
      sym_boolean_operator,
    STATE(570), 5,
      sym_parenthesis,
      sym_field_expression,
      sym_postfix_operator,
      sym_string,
      sym_matrix,
    STATE(684), 5,
      sym__expression,
      sym_metaclass_operator,
      sym_handle_operator,
      sym_range,
      sym_lambda,
  [21364] = 5,
    STATE(223), 1,
      aux_sym__block_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(796), 2,
      anon_sym_SEMI,
      anon_sym_COMMA,
    ACTIONS(700), 14,
      sym_command_name,
      sym__single_quote_string_start,
      sym__double_quote_string_start,
      sym__multioutput_variable_start,
      ts_builtin_sym_end,
      anon_sym_LPAREN,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_AT,
      anon_sym_LBRACK,
      anon_sym_LBRACE,
      sym_number,
    ACTIONS(702), 18,
      sym_return_statement,
      sym_continue_statement,
      sym_break_statement,
      anon_sym_if,
      anon_sym_end,
      anon_sym_for,
      anon_sym_parfor,
      anon_sym_while,
      anon_sym_switch,
      anon_sym_global,
      anon_sym_persistent,
      anon_sym_function,
      anon_sym_endfunction,
      anon_sym_classdef,
      anon_sym_try,
      anon_sym_true,
      anon_sym_false,
      sym_identifier,
  [21412] = 25,
    ACTIONS(640), 1,
      anon_sym_LPAREN,
    ACTIONS(644), 1,
      anon_sym_TILDE,
    ACTIONS(646), 1,
      anon_sym_QMARK,
    ACTIONS(648), 1,
      anon_sym_AT,
    ACTIONS(650), 1,
      anon_sym_LBRACK,
    ACTIONS(652), 1,
      anon_sym_LBRACE,
    ACTIONS(658), 1,
      sym_number,
    ACTIONS(662), 1,
      sym__single_quote_string_start,
    ACTIONS(664), 1,
      sym__double_quote_string_start,
    ACTIONS(751), 1,
      sym_identifier,
    STATE(367), 1,
      sym_function_call,
    STATE(402), 1,
      sym_boolean,
    STATE(518), 1,
      sym_cell,
    STATE(530), 1,
      sym_binary_operator,
    STATE(542), 1,
      sym_unary_operator,
    STATE(586), 1,
      sym_not_operator,
    STATE(614), 1,
      sym__binary_expression,
    STATE(905), 1,
      sym_indirect_access,
    STATE(1196), 1,
      sym__range_element,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(642), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(660), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(520), 2,
      sym_comparison_operator,
      sym_boolean_operator,
    STATE(521), 5,
      sym_parenthesis,
      sym_field_expression,
      sym_postfix_operator,
      sym_string,
      sym_matrix,
    STATE(595), 5,
      sym__expression,
      sym_metaclass_operator,
      sym_handle_operator,
      sym_range,
      sym_lambda,
  [21500] = 25,
    ACTIONS(836), 1,
      anon_sym_LPAREN,
    ACTIONS(840), 1,
      anon_sym_TILDE,
    ACTIONS(846), 1,
      anon_sym_LBRACK,
    ACTIONS(848), 1,
      anon_sym_LBRACE,
    ACTIONS(854), 1,
      sym__single_quote_string_start,
    ACTIONS(856), 1,
      sym__double_quote_string_start,
    ACTIONS(862), 1,
      sym_identifier,
    ACTIONS(864), 1,
      anon_sym_QMARK,
    ACTIONS(866), 1,
      anon_sym_AT,
    ACTIONS(868), 1,
      sym_number,
    STATE(80), 1,
      sym_function_call,
    STATE(99), 1,
      sym_boolean,
    STATE(105), 1,
      sym_unary_operator,
    STATE(109), 1,
      sym_cell,
    STATE(121), 1,
      sym_binary_operator,
    STATE(139), 1,
      sym_not_operator,
    STATE(617), 1,
      sym__binary_expression,
    STATE(956), 1,
      sym_indirect_access,
    STATE(1159), 1,
      sym__range_element,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(838), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(852), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(114), 2,
      sym_comparison_operator,
      sym_boolean_operator,
    STATE(104), 5,
      sym_parenthesis,
      sym_field_expression,
      sym_postfix_operator,
      sym_string,
      sym_matrix,
    STATE(135), 5,
      sym__expression,
      sym_metaclass_operator,
      sym_handle_operator,
      sym_range,
      sym_lambda,
  [21588] = 25,
    ACTIONS(597), 1,
      sym__single_quote_string_start,
    ACTIONS(599), 1,
      sym__double_quote_string_start,
    ACTIONS(620), 1,
      sym_identifier,
    ACTIONS(672), 1,
      anon_sym_LPAREN,
    ACTIONS(682), 1,
      anon_sym_LBRACK,
    ACTIONS(686), 1,
      anon_sym_LBRACE,
    ACTIONS(876), 1,
      anon_sym_TILDE,
    ACTIONS(919), 1,
      anon_sym_QMARK,
    ACTIONS(921), 1,
      anon_sym_AT,
    ACTIONS(923), 1,
      sym_number,
    STATE(207), 1,
      sym_function_call,
    STATE(359), 1,
      sym_boolean,
    STATE(466), 1,
      sym_unary_operator,
    STATE(469), 1,
      sym_not_operator,
    STATE(499), 1,
      sym_binary_operator,
    STATE(510), 1,
      sym_cell,
    STATE(615), 1,
      sym__binary_expression,
    STATE(919), 1,
      sym_indirect_access,
    STATE(1179), 1,
      sym__range_element,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(595), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(674), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    STATE(511), 2,
      sym_comparison_operator,
      sym_boolean_operator,
    STATE(463), 5,
      sym_parenthesis,
      sym_field_expression,
      sym_postfix_operator,
      sym_string,
      sym_matrix,
    STATE(502), 5,
      sym__expression,
      sym_metaclass_operator,
      sym_handle_operator,
      sym_range,
      sym_lambda,
  [21676] = 25,
    ACTIONS(640), 1,
      anon_sym_LPAREN,
    ACTIONS(644), 1,
      anon_sym_TILDE,
    ACTIONS(650), 1,
      anon_sym_LBRACK,
    ACTIONS(652), 1,
      anon_sym_LBRACE,
    ACTIONS(662), 1,
      sym__single_quote_string_start,
    ACTIONS(664), 1,
      sym__double_quote_string_start,
    ACTIONS(814), 1,
      sym_identifier,
    ACTIONS(816), 1,
      anon_sym_QMARK,
    ACTIONS(818), 1,
      anon_sym_AT,
    ACTIONS(820), 1,
      sym_number,
    STATE(377), 1,
      sym_function_call,
    STATE(394), 1,
      sym_boolean,
    STATE(518), 1,
      sym_cell,
    STATE(519), 1,
      sym_not_operator,
    STATE(531), 1,
      sym_unary_operator,
    STATE(561), 1,
      sym_binary_operator,
    STATE(614), 1,
      sym__binary_expression,
    STATE(905), 1,
      sym_indirect_access,
    STATE(1196), 1,
      sym__range_element,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(642), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(660), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(520), 2,
      sym_comparison_operator,
      sym_boolean_operator,
    STATE(524), 5,
      sym__expression,
      sym_metaclass_operator,
      sym_handle_operator,
      sym_range,
      sym_lambda,
    STATE(527), 5,
      sym_parenthesis,
      sym_field_expression,
      sym_postfix_operator,
      sym_string,
      sym_matrix,
  [21764] = 25,
    ACTIONS(640), 1,
      anon_sym_LPAREN,
    ACTIONS(644), 1,
      anon_sym_TILDE,
    ACTIONS(650), 1,
      anon_sym_LBRACK,
    ACTIONS(652), 1,
      anon_sym_LBRACE,
    ACTIONS(662), 1,
      sym__single_quote_string_start,
    ACTIONS(664), 1,
      sym__double_quote_string_start,
    ACTIONS(814), 1,
      sym_identifier,
    ACTIONS(816), 1,
      anon_sym_QMARK,
    ACTIONS(818), 1,
      anon_sym_AT,
    ACTIONS(820), 1,
      sym_number,
    STATE(377), 1,
      sym_function_call,
    STATE(394), 1,
      sym_boolean,
    STATE(518), 1,
      sym_cell,
    STATE(519), 1,
      sym_not_operator,
    STATE(531), 1,
      sym_unary_operator,
    STATE(561), 1,
      sym_binary_operator,
    STATE(614), 1,
      sym__binary_expression,
    STATE(905), 1,
      sym_indirect_access,
    STATE(1196), 1,
      sym__range_element,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(642), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(660), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(520), 2,
      sym_comparison_operator,
      sym_boolean_operator,
    STATE(527), 5,
      sym_parenthesis,
      sym_field_expression,
      sym_postfix_operator,
      sym_string,
      sym_matrix,
    STATE(562), 5,
      sym__expression,
      sym_metaclass_operator,
      sym_handle_operator,
      sym_range,
      sym_lambda,
  [21852] = 25,
    ACTIONS(640), 1,
      anon_sym_LPAREN,
    ACTIONS(644), 1,
      anon_sym_TILDE,
    ACTIONS(650), 1,
      anon_sym_LBRACK,
    ACTIONS(652), 1,
      anon_sym_LBRACE,
    ACTIONS(658), 1,
      sym_number,
    ACTIONS(662), 1,
      sym__single_quote_string_start,
    ACTIONS(664), 1,
      sym__double_quote_string_start,
    ACTIONS(767), 1,
      anon_sym_QMARK,
    ACTIONS(769), 1,
      anon_sym_AT,
    ACTIONS(944), 1,
      sym_identifier,
    STATE(400), 1,
      sym_function_call,
    STATE(402), 1,
      sym_boolean,
    STATE(518), 1,
      sym_cell,
    STATE(586), 1,
      sym_not_operator,
    STATE(587), 1,
      sym_binary_operator,
    STATE(588), 1,
      sym_unary_operator,
    STATE(614), 1,
      sym__binary_expression,
    STATE(905), 1,
      sym_indirect_access,
    STATE(1196), 1,
      sym__range_element,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(642), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(660), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(520), 2,
      sym_comparison_operator,
      sym_boolean_operator,
    STATE(575), 5,
      sym_parenthesis,
      sym_field_expression,
      sym_postfix_operator,
      sym_string,
      sym_matrix,
    STATE(700), 5,
      sym__expression,
      sym_metaclass_operator,
      sym_handle_operator,
      sym_range,
      sym_lambda,
  [21940] = 14,
    ACTIONS(381), 1,
      anon_sym_COLON,
    ACTIONS(822), 1,
      anon_sym_LPAREN,
    ACTIONS(824), 1,
      anon_sym_DOT,
    ACTIONS(826), 1,
      anon_sym_AT,
    ACTIONS(830), 1,
      anon_sym_LBRACE,
    ACTIONS(946), 1,
      anon_sym_EQ,
    STATE(437), 1,
      sym__args,
    STATE(483), 1,
      aux_sym_field_expression_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(360), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(364), 2,
      anon_sym_PIPE,
      anon_sym_AMP,
    ACTIONS(828), 2,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(376), 9,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_RBRACE,
    ACTIONS(387), 12,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
  [22006] = 14,
    ACTIONS(381), 1,
      anon_sym_COLON,
    ACTIONS(822), 1,
      anon_sym_LPAREN,
    ACTIONS(824), 1,
      anon_sym_DOT,
    ACTIONS(826), 1,
      anon_sym_AT,
    ACTIONS(830), 1,
      anon_sym_LBRACE,
    ACTIONS(948), 1,
      anon_sym_EQ,
    STATE(437), 1,
      sym__args,
    STATE(483), 1,
      aux_sym_field_expression_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(360), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(364), 2,
      anon_sym_PIPE,
      anon_sym_AMP,
    ACTIONS(828), 2,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(376), 9,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_RBRACE,
    ACTIONS(387), 12,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
  [22072] = 25,
    ACTIONS(640), 1,
      anon_sym_LPAREN,
    ACTIONS(644), 1,
      anon_sym_TILDE,
    ACTIONS(646), 1,
      anon_sym_QMARK,
    ACTIONS(648), 1,
      anon_sym_AT,
    ACTIONS(650), 1,
      anon_sym_LBRACK,
    ACTIONS(652), 1,
      anon_sym_LBRACE,
    ACTIONS(658), 1,
      sym_number,
    ACTIONS(662), 1,
      sym__single_quote_string_start,
    ACTIONS(664), 1,
      sym__double_quote_string_start,
    ACTIONS(751), 1,
      sym_identifier,
    STATE(367), 1,
      sym_function_call,
    STATE(402), 1,
      sym_boolean,
    STATE(518), 1,
      sym_cell,
    STATE(530), 1,
      sym_binary_operator,
    STATE(542), 1,
      sym_unary_operator,
    STATE(586), 1,
      sym_not_operator,
    STATE(614), 1,
      sym__binary_expression,
    STATE(905), 1,
      sym_indirect_access,
    STATE(1196), 1,
      sym__range_element,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(642), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(660), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(520), 2,
      sym_comparison_operator,
      sym_boolean_operator,
    STATE(521), 5,
      sym_parenthesis,
      sym_field_expression,
      sym_postfix_operator,
      sym_string,
      sym_matrix,
    STATE(641), 5,
      sym__expression,
      sym_metaclass_operator,
      sym_handle_operator,
      sym_range,
      sym_lambda,
  [22160] = 8,
    ACTIONS(755), 1,
      anon_sym_LPAREN,
    ACTIONS(763), 1,
      anon_sym_LBRACE,
    ACTIONS(950), 1,
      anon_sym_AT,
    STATE(360), 1,
      sym__args,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(385), 2,
      sym__entry_delimiter,
      aux_sym_matrix_token1,
    ACTIONS(761), 2,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(383), 26,
      anon_sym_SEMI,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_RBRACK,
      anon_sym_RBRACE,
      anon_sym_COLON,
  [22213] = 13,
    ACTIONS(822), 1,
      anon_sym_LPAREN,
    ACTIONS(824), 1,
      anon_sym_DOT,
    ACTIONS(826), 1,
      anon_sym_AT,
    ACTIONS(830), 1,
      anon_sym_LBRACE,
    STATE(437), 1,
      sym__args,
    STATE(483), 1,
      aux_sym_field_expression_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(364), 2,
      anon_sym_PIPE,
      anon_sym_AMP,
    ACTIONS(378), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(828), 2,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(381), 4,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
      anon_sym_COLON,
    ACTIONS(952), 6,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
    ACTIONS(387), 12,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
  [22276] = 10,
    ACTIONS(378), 1,
      anon_sym_COLON,
    ACTIONS(755), 1,
      anon_sym_LPAREN,
    ACTIONS(763), 1,
      anon_sym_LBRACE,
    ACTIONS(950), 1,
      anon_sym_AT,
    STATE(360), 1,
      sym__args,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(376), 2,
      sym__entry_delimiter,
      aux_sym_matrix_token1,
    ACTIONS(761), 2,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(360), 11,
      anon_sym_SEMI,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_RBRACK,
      anon_sym_RBRACE,
    ACTIONS(364), 14,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
  [22333] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(427), 2,
      sym__entry_delimiter,
      aux_sym_matrix_token1,
    ACTIONS(425), 32,
      anon_sym_SEMI,
      anon_sym_LPAREN,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_DOT,
      anon_sym_AT,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_RBRACK,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COLON,
  [22376] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(423), 2,
      sym__entry_delimiter,
      aux_sym_matrix_token1,
    ACTIONS(421), 32,
      anon_sym_SEMI,
      anon_sym_LPAREN,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_DOT,
      anon_sym_AT,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_RBRACK,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COLON,
  [22419] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(431), 2,
      sym__entry_delimiter,
      aux_sym_matrix_token1,
    ACTIONS(429), 32,
      anon_sym_SEMI,
      anon_sym_LPAREN,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_DOT,
      anon_sym_AT,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_RBRACK,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COLON,
  [22462] = 10,
    ACTIONS(374), 1,
      anon_sym_COLON,
    ACTIONS(755), 1,
      anon_sym_LPAREN,
    ACTIONS(763), 1,
      anon_sym_LBRACE,
    ACTIONS(950), 1,
      anon_sym_AT,
    STATE(360), 1,
      sym__args,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(376), 2,
      sym__entry_delimiter,
      aux_sym_matrix_token1,
    ACTIONS(761), 2,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(360), 11,
      anon_sym_SEMI,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_RBRACK,
      anon_sym_RBRACE,
    ACTIONS(364), 14,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
  [22519] = 14,
    ACTIONS(381), 1,
      anon_sym_COLON,
    ACTIONS(822), 1,
      anon_sym_LPAREN,
    ACTIONS(824), 1,
      anon_sym_DOT,
    ACTIONS(826), 1,
      anon_sym_AT,
    ACTIONS(830), 1,
      anon_sym_LBRACE,
    ACTIONS(832), 1,
      anon_sym_EQ,
    STATE(437), 1,
      sym__args,
    STATE(483), 1,
      aux_sym_field_expression_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(360), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(364), 2,
      anon_sym_PIPE,
      anon_sym_AMP,
    ACTIONS(828), 2,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(376), 8,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
    ACTIONS(387), 12,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
  [22584] = 4,
    ACTIONS(955), 1,
      anon_sym_DOT,
    STATE(365), 1,
      aux_sym_handle_operator_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(410), 32,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_case,
      anon_sym_otherwise,
      anon_sym_LF,
      anon_sym_CR,
  [22629] = 10,
    ACTIONS(822), 1,
      anon_sym_LPAREN,
    ACTIONS(824), 1,
      anon_sym_DOT,
    ACTIONS(826), 1,
      anon_sym_AT,
    ACTIONS(830), 1,
      anon_sym_LBRACE,
    STATE(437), 1,
      sym__args,
    STATE(483), 1,
      aux_sym_field_expression_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(828), 2,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(383), 4,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(385), 22,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_RBRACE,
      anon_sym_COLON,
  [22686] = 13,
    ACTIONS(381), 1,
      anon_sym_COLON,
    ACTIONS(822), 1,
      anon_sym_LPAREN,
    ACTIONS(824), 1,
      anon_sym_DOT,
    ACTIONS(826), 1,
      anon_sym_AT,
    ACTIONS(830), 1,
      anon_sym_LBRACE,
    STATE(437), 1,
      sym__args,
    STATE(479), 1,
      aux_sym_field_expression_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(360), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(364), 2,
      anon_sym_PIPE,
      anon_sym_AMP,
    ACTIONS(828), 2,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(376), 9,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_RBRACE,
    ACTIONS(387), 12,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
  [22749] = 13,
    ACTIONS(381), 1,
      anon_sym_COLON,
    ACTIONS(822), 1,
      anon_sym_LPAREN,
    ACTIONS(824), 1,
      anon_sym_DOT,
    ACTIONS(826), 1,
      anon_sym_AT,
    ACTIONS(830), 1,
      anon_sym_LBRACE,
    STATE(437), 1,
      sym__args,
    STATE(483), 1,
      aux_sym_field_expression_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(360), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(364), 2,
      anon_sym_PIPE,
      anon_sym_AMP,
    ACTIONS(828), 2,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(376), 9,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_RBRACE,
    ACTIONS(387), 12,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
  [22812] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(449), 2,
      sym__entry_delimiter,
      aux_sym_matrix_token1,
    ACTIONS(447), 32,
      anon_sym_SEMI,
      anon_sym_LPAREN,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_DOT,
      anon_sym_AT,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_RBRACK,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COLON,
  [22855] = 4,
    ACTIONS(958), 1,
      anon_sym_DOT,
    STATE(365), 1,
      aux_sym_handle_operator_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(393), 32,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_case,
      anon_sym_otherwise,
      anon_sym_LF,
      anon_sym_CR,
  [22900] = 10,
    ACTIONS(755), 1,
      anon_sym_LPAREN,
    ACTIONS(763), 1,
      anon_sym_LBRACE,
    ACTIONS(950), 1,
      anon_sym_AT,
    STATE(360), 1,
      sym__args,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(381), 2,
      sym__entry_delimiter,
      aux_sym_matrix_token1,
    ACTIONS(761), 2,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(374), 4,
      anon_sym_SEMI,
      anon_sym_RBRACK,
      anon_sym_RBRACE,
      anon_sym_COLON,
    ACTIONS(378), 8,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
    ACTIONS(364), 14,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
  [22957] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(437), 2,
      sym__entry_delimiter,
      aux_sym_matrix_token1,
    ACTIONS(435), 32,
      anon_sym_SEMI,
      anon_sym_LPAREN,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_DOT,
      anon_sym_AT,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_RBRACK,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COLON,
  [23000] = 4,
    ACTIONS(958), 1,
      anon_sym_DOT,
    STATE(370), 1,
      aux_sym_handle_operator_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(417), 32,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_case,
      anon_sym_otherwise,
      anon_sym_LF,
      anon_sym_CR,
  [23045] = 8,
    ACTIONS(755), 1,
      anon_sym_LPAREN,
    ACTIONS(763), 1,
      anon_sym_LBRACE,
    ACTIONS(950), 1,
      anon_sym_AT,
    STATE(360), 1,
      sym__args,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(387), 2,
      sym__entry_delimiter,
      aux_sym_matrix_token1,
    ACTIONS(761), 2,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(364), 26,
      anon_sym_SEMI,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_RBRACK,
      anon_sym_RBRACE,
      anon_sym_COLON,
  [23098] = 10,
    ACTIONS(822), 1,
      anon_sym_LPAREN,
    ACTIONS(824), 1,
      anon_sym_DOT,
    ACTIONS(826), 1,
      anon_sym_AT,
    ACTIONS(830), 1,
      anon_sym_LBRACE,
    STATE(437), 1,
      sym__args,
    STATE(483), 1,
      aux_sym_field_expression_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(828), 2,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(364), 4,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(387), 22,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_RBRACE,
      anon_sym_COLON,
  [23155] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(445), 2,
      sym__entry_delimiter,
      aux_sym_matrix_token1,
    ACTIONS(443), 32,
      anon_sym_SEMI,
      anon_sym_LPAREN,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_DOT,
      anon_sym_AT,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_RBRACK,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COLON,
  [23198] = 13,
    ACTIONS(822), 1,
      anon_sym_LPAREN,
    ACTIONS(824), 1,
      anon_sym_DOT,
    ACTIONS(826), 1,
      anon_sym_AT,
    ACTIONS(830), 1,
      anon_sym_LBRACE,
    ACTIONS(952), 1,
      anon_sym_COLON,
    STATE(437), 1,
      sym__args,
    STATE(483), 1,
      aux_sym_field_expression_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(360), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(364), 2,
      anon_sym_PIPE,
      anon_sym_AMP,
    ACTIONS(828), 2,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(376), 9,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_RBRACE,
    ACTIONS(387), 12,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
  [23261] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(441), 2,
      sym__entry_delimiter,
      aux_sym_matrix_token1,
    ACTIONS(439), 32,
      anon_sym_SEMI,
      anon_sym_LPAREN,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_DOT,
      anon_sym_AT,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_RBRACK,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COLON,
  [23304] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(552), 2,
      sym__entry_delimiter,
      aux_sym_matrix_token1,
    ACTIONS(550), 31,
      anon_sym_SEMI,
      anon_sym_LPAREN,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_AT,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_RBRACK,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COLON,
  [23346] = 13,
    ACTIONS(381), 1,
      anon_sym_COLON,
    ACTIONS(822), 1,
      anon_sym_LPAREN,
    ACTIONS(824), 1,
      anon_sym_DOT,
    ACTIONS(826), 1,
      anon_sym_AT,
    ACTIONS(830), 1,
      anon_sym_LBRACE,
    STATE(437), 1,
      sym__args,
    STATE(479), 1,
      aux_sym_field_expression_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(360), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(364), 2,
      anon_sym_PIPE,
      anon_sym_AMP,
    ACTIONS(828), 2,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(376), 8,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
    ACTIONS(387), 12,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
  [23408] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(960), 14,
      sym_command_name,
      sym__single_quote_string_start,
      sym__double_quote_string_start,
      sym__multioutput_variable_start,
      ts_builtin_sym_end,
      anon_sym_LPAREN,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_AT,
      anon_sym_LBRACK,
      anon_sym_LBRACE,
      sym_number,
    ACTIONS(962), 19,
      sym_return_statement,
      sym_continue_statement,
      sym_break_statement,
      anon_sym_if,
      anon_sym_end,
      anon_sym_for,
      anon_sym_parfor,
      anon_sym_while,
      anon_sym_switch,
      anon_sym_global,
      anon_sym_persistent,
      anon_sym_arguments,
      anon_sym_function,
      anon_sym_endfunction,
      anon_sym_classdef,
      anon_sym_try,
      anon_sym_true,
      anon_sym_false,
      sym_identifier,
  [23450] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(964), 14,
      sym_command_name,
      sym__single_quote_string_start,
      sym__double_quote_string_start,
      sym__multioutput_variable_start,
      ts_builtin_sym_end,
      anon_sym_LPAREN,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_AT,
      anon_sym_LBRACK,
      anon_sym_LBRACE,
      sym_number,
    ACTIONS(966), 19,
      sym_return_statement,
      sym_continue_statement,
      sym_break_statement,
      anon_sym_if,
      anon_sym_end,
      anon_sym_for,
      anon_sym_parfor,
      anon_sym_while,
      anon_sym_switch,
      anon_sym_global,
      anon_sym_persistent,
      anon_sym_arguments,
      anon_sym_function,
      anon_sym_endfunction,
      anon_sym_classdef,
      anon_sym_try,
      anon_sym_true,
      anon_sym_false,
      sym_identifier,
  [23492] = 7,
    ACTIONS(822), 1,
      anon_sym_LPAREN,
    ACTIONS(826), 1,
      anon_sym_AT,
    ACTIONS(830), 1,
      anon_sym_LBRACE,
    STATE(437), 1,
      sym__args,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(406), 5,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_DOT,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(408), 24,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_RBRACE,
      anon_sym_COLON,
  [23542] = 14,
    ACTIONS(381), 1,
      anon_sym_COLON,
    ACTIONS(822), 1,
      anon_sym_LPAREN,
    ACTIONS(824), 1,
      anon_sym_DOT,
    ACTIONS(826), 1,
      anon_sym_AT,
    ACTIONS(830), 1,
      anon_sym_LBRACE,
    STATE(437), 1,
      sym__args,
    STATE(483), 1,
      aux_sym_field_expression_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(360), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(364), 2,
      anon_sym_PIPE,
      anon_sym_AMP,
    ACTIONS(828), 2,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(968), 2,
      anon_sym_COMMA,
      anon_sym_RPAREN,
    ACTIONS(376), 6,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
    ACTIONS(387), 12,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
  [23606] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(410), 33,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_DOT,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_case,
      anon_sym_otherwise,
      anon_sym_LF,
      anon_sym_CR,
  [23646] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(970), 14,
      sym_command_name,
      sym__single_quote_string_start,
      sym__double_quote_string_start,
      sym__multioutput_variable_start,
      ts_builtin_sym_end,
      anon_sym_LPAREN,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_AT,
      anon_sym_LBRACK,
      anon_sym_LBRACE,
      sym_number,
    ACTIONS(972), 19,
      sym_return_statement,
      sym_continue_statement,
      sym_break_statement,
      anon_sym_if,
      anon_sym_end,
      anon_sym_for,
      anon_sym_parfor,
      anon_sym_while,
      anon_sym_switch,
      anon_sym_global,
      anon_sym_persistent,
      anon_sym_arguments,
      anon_sym_function,
      anon_sym_endfunction,
      anon_sym_classdef,
      anon_sym_try,
      anon_sym_true,
      anon_sym_false,
      sym_identifier,
  [23688] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(974), 14,
      sym_command_name,
      sym__single_quote_string_start,
      sym__double_quote_string_start,
      sym__multioutput_variable_start,
      ts_builtin_sym_end,
      anon_sym_LPAREN,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_AT,
      anon_sym_LBRACK,
      anon_sym_LBRACE,
      sym_number,
    ACTIONS(976), 19,
      sym_return_statement,
      sym_continue_statement,
      sym_break_statement,
      anon_sym_if,
      anon_sym_end,
      anon_sym_for,
      anon_sym_parfor,
      anon_sym_while,
      anon_sym_switch,
      anon_sym_global,
      anon_sym_persistent,
      anon_sym_arguments,
      anon_sym_function,
      anon_sym_endfunction,
      anon_sym_classdef,
      anon_sym_try,
      anon_sym_true,
      anon_sym_false,
      sym_identifier,
  [23730] = 3,
    ACTIONS(978), 1,
      anon_sym_COLON,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(540), 31,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_end,
      anon_sym_case,
      anon_sym_otherwise,
      anon_sym_LF,
      anon_sym_CR,
  [23771] = 5,
    ACTIONS(515), 1,
      anon_sym_COLON,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(741), 2,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(364), 14,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
    ACTIONS(360), 15,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_end,
      anon_sym_case,
      anon_sym_otherwise,
      anon_sym_LF,
      anon_sym_CR,
  [23816] = 5,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(984), 2,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
    ACTIONS(980), 4,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
    ACTIONS(982), 6,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
    ACTIONS(554), 20,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_case,
      anon_sym_otherwise,
      anon_sym_LF,
      anon_sym_CR,
  [23861] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(517), 32,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_case,
      anon_sym_otherwise,
      anon_sym_LF,
      anon_sym_CR,
  [23900] = 5,
    ACTIONS(378), 1,
      anon_sym_COLON,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(741), 2,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(364), 14,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
    ACTIONS(360), 15,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_end,
      anon_sym_case,
      anon_sym_otherwise,
      anon_sym_LF,
      anon_sym_CR,
  [23945] = 4,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(984), 2,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
    ACTIONS(982), 6,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
    ACTIONS(554), 24,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_case,
      anon_sym_otherwise,
      anon_sym_LF,
      anon_sym_CR,
  [23988] = 11,
    ACTIONS(822), 1,
      anon_sym_LPAREN,
    ACTIONS(830), 1,
      anon_sym_LBRACE,
    ACTIONS(952), 1,
      anon_sym_COLON,
    ACTIONS(986), 1,
      anon_sym_AT,
    STATE(445), 1,
      sym__args,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(360), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(364), 2,
      anon_sym_PIPE,
      anon_sym_AMP,
    ACTIONS(828), 2,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(376), 9,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_RBRACE,
    ACTIONS(387), 12,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
  [24045] = 14,
    ACTIONS(381), 1,
      anon_sym_COLON,
    ACTIONS(822), 1,
      anon_sym_LPAREN,
    ACTIONS(824), 1,
      anon_sym_DOT,
    ACTIONS(826), 1,
      anon_sym_AT,
    ACTIONS(830), 1,
      anon_sym_LBRACE,
    ACTIONS(988), 1,
      anon_sym_RPAREN,
    STATE(437), 1,
      sym__args,
    STATE(483), 1,
      aux_sym_field_expression_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(360), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(364), 2,
      anon_sym_PIPE,
      anon_sym_AMP,
    ACTIONS(828), 2,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(376), 6,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
    ACTIONS(387), 12,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
  [24108] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(455), 32,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_case,
      anon_sym_otherwise,
      anon_sym_LF,
      anon_sym_CR,
  [24147] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(511), 32,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_case,
      anon_sym_otherwise,
      anon_sym_LF,
      anon_sym_CR,
  [24186] = 8,
    ACTIONS(822), 1,
      anon_sym_LPAREN,
    ACTIONS(830), 1,
      anon_sym_LBRACE,
    ACTIONS(986), 1,
      anon_sym_AT,
    STATE(445), 1,
      sym__args,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(828), 2,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(383), 4,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(385), 22,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_RBRACE,
      anon_sym_COLON,
  [24237] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(451), 32,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_case,
      anon_sym_otherwise,
      anon_sym_LF,
      anon_sym_CR,
  [24276] = 14,
    ACTIONS(381), 1,
      anon_sym_COLON,
    ACTIONS(822), 1,
      anon_sym_LPAREN,
    ACTIONS(824), 1,
      anon_sym_DOT,
    ACTIONS(826), 1,
      anon_sym_AT,
    ACTIONS(830), 1,
      anon_sym_LBRACE,
    ACTIONS(990), 1,
      anon_sym_RPAREN,
    STATE(437), 1,
      sym__args,
    STATE(483), 1,
      aux_sym_field_expression_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(360), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(364), 2,
      anon_sym_PIPE,
      anon_sym_AMP,
    ACTIONS(828), 2,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(376), 6,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
    ACTIONS(387), 12,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
  [24339] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(530), 32,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_case,
      anon_sym_otherwise,
      anon_sym_LF,
      anon_sym_CR,
  [24378] = 11,
    ACTIONS(381), 1,
      anon_sym_COLON,
    ACTIONS(822), 1,
      anon_sym_LPAREN,
    ACTIONS(830), 1,
      anon_sym_LBRACE,
    ACTIONS(986), 1,
      anon_sym_AT,
    STATE(445), 1,
      sym__args,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(360), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(364), 2,
      anon_sym_PIPE,
      anon_sym_AMP,
    ACTIONS(828), 2,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(376), 9,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_RBRACE,
    ACTIONS(387), 12,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
  [24435] = 4,
    ACTIONS(526), 1,
      anon_sym_COLON,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(523), 8,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
    ACTIONS(521), 23,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_end,
      anon_sym_case,
      anon_sym_otherwise,
      anon_sym_LF,
      anon_sym_CR,
  [24478] = 5,
    ACTIONS(463), 1,
      anon_sym_COLON,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(741), 2,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(364), 14,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
    ACTIONS(360), 15,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_end,
      anon_sym_case,
      anon_sym_otherwise,
      anon_sym_LF,
      anon_sym_CR,
  [24523] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(984), 2,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
    ACTIONS(554), 30,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_case,
      anon_sym_otherwise,
      anon_sym_LF,
      anon_sym_CR,
  [24564] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(984), 2,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
    ACTIONS(554), 30,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_case,
      anon_sym_otherwise,
      anon_sym_LF,
      anon_sym_CR,
  [24605] = 5,
    ACTIONS(468), 1,
      anon_sym_COLON,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(741), 2,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(364), 14,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
    ACTIONS(360), 15,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_end,
      anon_sym_case,
      anon_sym_otherwise,
      anon_sym_LF,
      anon_sym_CR,
  [24650] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(546), 32,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_case,
      anon_sym_otherwise,
      anon_sym_LF,
      anon_sym_CR,
  [24689] = 4,
    ACTIONS(378), 1,
      anon_sym_COLON,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(364), 14,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
    ACTIONS(360), 17,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_end,
      anon_sym_case,
      anon_sym_otherwise,
      anon_sym_LF,
      anon_sym_CR,
  [24732] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(741), 2,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(364), 30,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_case,
      anon_sym_otherwise,
      anon_sym_LF,
      anon_sym_CR,
  [24773] = 5,
    ACTIONS(374), 1,
      anon_sym_COLON,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(741), 2,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(364), 14,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
    ACTIONS(360), 15,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_end,
      anon_sym_case,
      anon_sym_otherwise,
      anon_sym_LF,
      anon_sym_CR,
  [24818] = 14,
    ACTIONS(381), 1,
      anon_sym_COLON,
    ACTIONS(822), 1,
      anon_sym_LPAREN,
    ACTIONS(824), 1,
      anon_sym_DOT,
    ACTIONS(826), 1,
      anon_sym_AT,
    ACTIONS(830), 1,
      anon_sym_LBRACE,
    ACTIONS(992), 1,
      anon_sym_RPAREN,
    STATE(437), 1,
      sym__args,
    STATE(483), 1,
      aux_sym_field_expression_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(360), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(364), 2,
      anon_sym_PIPE,
      anon_sym_AMP,
    ACTIONS(828), 2,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(376), 6,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
    ACTIONS(387), 12,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
  [24881] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(491), 32,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_case,
      anon_sym_otherwise,
      anon_sym_LF,
      anon_sym_CR,
  [24920] = 14,
    ACTIONS(381), 1,
      anon_sym_COLON,
    ACTIONS(822), 1,
      anon_sym_LPAREN,
    ACTIONS(824), 1,
      anon_sym_DOT,
    ACTIONS(826), 1,
      anon_sym_AT,
    ACTIONS(830), 1,
      anon_sym_LBRACE,
    ACTIONS(994), 1,
      anon_sym_RPAREN,
    STATE(437), 1,
      sym__args,
    STATE(483), 1,
      aux_sym_field_expression_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(360), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(364), 2,
      anon_sym_PIPE,
      anon_sym_AMP,
    ACTIONS(828), 2,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(376), 6,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
    ACTIONS(387), 12,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
  [24983] = 5,
    ACTIONS(998), 1,
      anon_sym_AMP_AMP,
    ACTIONS(1000), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(996), 6,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
    ACTIONS(495), 24,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_case,
      anon_sym_otherwise,
      anon_sym_LF,
      anon_sym_CR,
  [25028] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(435), 5,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_DOT,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(437), 27,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_AT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COLON,
  [25069] = 5,
    ACTIONS(998), 1,
      anon_sym_AMP_AMP,
    ACTIONS(1000), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(996), 6,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
    ACTIONS(536), 24,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_case,
      anon_sym_otherwise,
      anon_sym_LF,
      anon_sym_CR,
  [25114] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(421), 5,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_DOT,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(423), 27,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_AT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COLON,
  [25155] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(741), 2,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(364), 30,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_case,
      anon_sym_otherwise,
      anon_sym_LF,
      anon_sym_CR,
  [25196] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(996), 6,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
    ACTIONS(487), 26,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_case,
      anon_sym_otherwise,
      anon_sym_LF,
      anon_sym_CR,
  [25237] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(741), 2,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(383), 30,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_case,
      anon_sym_otherwise,
      anon_sym_LF,
      anon_sym_CR,
  [25278] = 5,
    ACTIONS(466), 1,
      anon_sym_COLON,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(741), 2,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(364), 14,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
    ACTIONS(360), 15,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_end,
      anon_sym_case,
      anon_sym_otherwise,
      anon_sym_LF,
      anon_sym_CR,
  [25323] = 4,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(741), 2,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(364), 14,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
    ACTIONS(360), 16,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_case,
      anon_sym_otherwise,
      anon_sym_LF,
      anon_sym_CR,
  [25366] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(443), 5,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_DOT,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(445), 27,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_AT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COLON,
  [25407] = 5,
    ACTIONS(757), 1,
      anon_sym_DOT,
    STATE(453), 1,
      aux_sym_field_expression_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(391), 2,
      sym__entry_delimiter,
      aux_sym_matrix_token1,
    ACTIONS(389), 28,
      anon_sym_SEMI,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_RBRACK,
      anon_sym_RBRACE,
      anon_sym_COLON,
  [25452] = 5,
    ACTIONS(1002), 1,
      anon_sym_DOT,
    STATE(426), 1,
      aux_sym_handle_operator_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(415), 2,
      sym__entry_delimiter,
      aux_sym_matrix_token1,
    ACTIONS(410), 28,
      anon_sym_SEMI,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_RBRACK,
      anon_sym_RBRACE,
      anon_sym_COLON,
  [25497] = 14,
    ACTIONS(381), 1,
      anon_sym_COLON,
    ACTIONS(822), 1,
      anon_sym_LPAREN,
    ACTIONS(824), 1,
      anon_sym_DOT,
    ACTIONS(826), 1,
      anon_sym_AT,
    ACTIONS(830), 1,
      anon_sym_LBRACE,
    ACTIONS(1005), 1,
      anon_sym_RPAREN,
    STATE(437), 1,
      sym__args,
    STATE(483), 1,
      aux_sym_field_expression_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(360), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(364), 2,
      anon_sym_PIPE,
      anon_sym_AMP,
    ACTIONS(828), 2,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(376), 6,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
    ACTIONS(387), 12,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
  [25560] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(383), 32,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_case,
      anon_sym_otherwise,
      anon_sym_LF,
      anon_sym_CR,
  [25599] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(459), 32,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_case,
      anon_sym_otherwise,
      anon_sym_LF,
      anon_sym_CR,
  [25638] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(741), 2,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(364), 30,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_case,
      anon_sym_otherwise,
      anon_sym_LF,
      anon_sym_CR,
  [25679] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(741), 2,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(383), 30,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_case,
      anon_sym_otherwise,
      anon_sym_LF,
      anon_sym_CR,
  [25720] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(447), 5,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_DOT,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(449), 27,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_AT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COLON,
  [25761] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(503), 32,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_case,
      anon_sym_otherwise,
      anon_sym_LF,
      anon_sym_CR,
  [25800] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(741), 2,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(383), 30,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_case,
      anon_sym_otherwise,
      anon_sym_LF,
      anon_sym_CR,
  [25841] = 5,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(741), 2,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(466), 8,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_case,
      anon_sym_otherwise,
      anon_sym_LF,
      anon_sym_CR,
    ACTIONS(468), 8,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
    ACTIONS(364), 14,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
  [25886] = 5,
    ACTIONS(1007), 1,
      anon_sym_DOT,
    STATE(426), 1,
      aux_sym_handle_operator_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(397), 2,
      sym__entry_delimiter,
      aux_sym_matrix_token1,
    ACTIONS(393), 28,
      anon_sym_SEMI,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_RBRACK,
      anon_sym_RBRACE,
      anon_sym_COLON,
  [25931] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(429), 5,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_DOT,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(431), 27,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_AT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COLON,
  [25972] = 5,
    ACTIONS(1007), 1,
      anon_sym_DOT,
    STATE(436), 1,
      aux_sym_handle_operator_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(419), 2,
      sym__entry_delimiter,
      aux_sym_matrix_token1,
    ACTIONS(417), 28,
      anon_sym_SEMI,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_RBRACK,
      anon_sym_RBRACE,
      anon_sym_COLON,
  [26017] = 5,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(741), 2,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(374), 8,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_case,
      anon_sym_otherwise,
      anon_sym_LF,
      anon_sym_CR,
    ACTIONS(378), 8,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
    ACTIONS(364), 14,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
  [26062] = 11,
    ACTIONS(822), 1,
      anon_sym_LPAREN,
    ACTIONS(830), 1,
      anon_sym_LBRACE,
    ACTIONS(986), 1,
      anon_sym_AT,
    STATE(445), 1,
      sym__args,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(364), 2,
      anon_sym_PIPE,
      anon_sym_AMP,
    ACTIONS(378), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(828), 2,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(381), 4,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
      anon_sym_COLON,
    ACTIONS(952), 6,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
    ACTIONS(387), 12,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
  [26119] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(507), 32,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_case,
      anon_sym_otherwise,
      anon_sym_LF,
      anon_sym_CR,
  [26158] = 13,
    ACTIONS(381), 1,
      anon_sym_COLON,
    ACTIONS(822), 1,
      anon_sym_LPAREN,
    ACTIONS(824), 1,
      anon_sym_DOT,
    ACTIONS(826), 1,
      anon_sym_AT,
    ACTIONS(830), 1,
      anon_sym_LBRACE,
    STATE(437), 1,
      sym__args,
    STATE(483), 1,
      aux_sym_field_expression_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(360), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(364), 2,
      anon_sym_PIPE,
      anon_sym_AMP,
    ACTIONS(828), 2,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(376), 7,
      anon_sym_RPAREN,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
    ACTIONS(387), 12,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
  [26219] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(741), 2,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(364), 30,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_case,
      anon_sym_otherwise,
      anon_sym_LF,
      anon_sym_CR,
  [26260] = 5,
    ACTIONS(998), 1,
      anon_sym_AMP_AMP,
    ACTIONS(1000), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(996), 6,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
    ACTIONS(481), 24,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_case,
      anon_sym_otherwise,
      anon_sym_LF,
      anon_sym_CR,
  [26305] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(425), 5,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_DOT,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(427), 27,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_AT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COLON,
  [26346] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(364), 14,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
    ACTIONS(360), 18,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_case,
      anon_sym_otherwise,
      anon_sym_LF,
      anon_sym_CR,
  [26387] = 4,
    ACTIONS(998), 1,
      anon_sym_AMP_AMP,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(996), 6,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
    ACTIONS(473), 25,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_case,
      anon_sym_otherwise,
      anon_sym_LF,
      anon_sym_CR,
  [26430] = 8,
    ACTIONS(822), 1,
      anon_sym_LPAREN,
    ACTIONS(830), 1,
      anon_sym_LBRACE,
    ACTIONS(986), 1,
      anon_sym_AT,
    STATE(445), 1,
      sym__args,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(828), 2,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(364), 4,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(387), 22,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_RBRACE,
      anon_sym_COLON,
  [26481] = 5,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(741), 2,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(463), 8,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
    ACTIONS(515), 8,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_case,
      anon_sym_otherwise,
      anon_sym_LF,
      anon_sym_CR,
    ACTIONS(364), 14,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
  [26526] = 6,
    ACTIONS(1009), 1,
      anon_sym_AMP,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(984), 2,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
    ACTIONS(980), 4,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
    ACTIONS(982), 6,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
    ACTIONS(554), 19,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_PIPE,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_case,
      anon_sym_otherwise,
      anon_sym_LF,
      anon_sym_CR,
  [26573] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(499), 32,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_case,
      anon_sym_otherwise,
      anon_sym_LF,
      anon_sym_CR,
  [26612] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(996), 6,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
    ACTIONS(473), 26,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_case,
      anon_sym_otherwise,
      anon_sym_LF,
      anon_sym_CR,
  [26653] = 5,
    ACTIONS(1011), 1,
      anon_sym_DOT,
    STATE(453), 1,
      aux_sym_field_expression_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(404), 2,
      sym__entry_delimiter,
      aux_sym_matrix_token1,
    ACTIONS(399), 28,
      anon_sym_SEMI,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_RBRACK,
      anon_sym_RBRACE,
      anon_sym_COLON,
  [26698] = 4,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(378), 8,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
    ACTIONS(374), 10,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_case,
      anon_sym_otherwise,
      anon_sym_LF,
      anon_sym_CR,
    ACTIONS(364), 14,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
  [26741] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(439), 5,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_DOT,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(441), 27,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_AT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COLON,
  [26782] = 12,
    ACTIONS(381), 1,
      anon_sym_COLON,
    ACTIONS(822), 1,
      anon_sym_LPAREN,
    ACTIONS(830), 1,
      anon_sym_LBRACE,
    ACTIONS(986), 1,
      anon_sym_AT,
    STATE(445), 1,
      sym__args,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(360), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(364), 2,
      anon_sym_PIPE,
      anon_sym_AMP,
    ACTIONS(828), 2,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(968), 2,
      anon_sym_COMMA,
      anon_sym_RPAREN,
    ACTIONS(376), 6,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
    ACTIONS(387), 12,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
  [26840] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(415), 2,
      sym__entry_delimiter,
      aux_sym_matrix_token1,
    ACTIONS(410), 29,
      anon_sym_SEMI,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_DOT,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_RBRACK,
      anon_sym_RBRACE,
      anon_sym_COLON,
  [26880] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(550), 4,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(552), 27,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_AT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COLON,
  [26920] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(519), 2,
      sym__entry_delimiter,
      aux_sym_matrix_token1,
    ACTIONS(517), 28,
      anon_sym_SEMI,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_RBRACK,
      anon_sym_RBRACE,
      anon_sym_COLON,
  [26959] = 6,
    ACTIONS(1016), 1,
      anon_sym_AMP_AMP,
    ACTIONS(1018), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(485), 2,
      sym__entry_delimiter,
      aux_sym_matrix_token1,
    ACTIONS(1014), 6,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
    ACTIONS(481), 20,
      anon_sym_SEMI,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_RBRACK,
      anon_sym_RBRACE,
      anon_sym_COLON,
  [27004] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(457), 2,
      sym__entry_delimiter,
      aux_sym_matrix_token1,
    ACTIONS(455), 28,
      anon_sym_SEMI,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_RBRACK,
      anon_sym_RBRACE,
      anon_sym_COLON,
  [27043] = 5,
    ACTIONS(1020), 1,
      anon_sym_DOT,
    STATE(462), 1,
      aux_sym_handle_operator_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(410), 4,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(415), 24,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_RBRACE,
      anon_sym_COLON,
  [27086] = 6,
    ACTIONS(378), 1,
      anon_sym_COLON,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(376), 2,
      sym__entry_delimiter,
      aux_sym_matrix_token1,
    ACTIONS(761), 2,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(360), 11,
      anon_sym_SEMI,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_RBRACK,
      anon_sym_RBRACE,
    ACTIONS(364), 14,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
  [27131] = 5,
    ACTIONS(1023), 1,
      anon_sym_DOT,
    STATE(478), 1,
      aux_sym_handle_operator_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(417), 4,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(419), 24,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_RBRACE,
      anon_sym_COLON,
  [27174] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(548), 2,
      sym__entry_delimiter,
      aux_sym_matrix_token1,
    ACTIONS(546), 28,
      anon_sym_SEMI,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_RBRACK,
      anon_sym_RBRACE,
      anon_sym_COLON,
  [27213] = 6,
    ACTIONS(463), 1,
      anon_sym_COLON,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(376), 2,
      sym__entry_delimiter,
      aux_sym_matrix_token1,
    ACTIONS(761), 2,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(360), 11,
      anon_sym_SEMI,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_RBRACK,
      anon_sym_RBRACE,
    ACTIONS(364), 14,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
  [27258] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(513), 2,
      sym__entry_delimiter,
      aux_sym_matrix_token1,
    ACTIONS(511), 28,
      anon_sym_SEMI,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_RBRACK,
      anon_sym_RBRACE,
      anon_sym_COLON,
  [27297] = 5,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(562), 2,
      sym__entry_delimiter,
      aux_sym_matrix_token1,
    ACTIONS(1027), 2,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
    ACTIONS(1025), 6,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
    ACTIONS(554), 20,
      anon_sym_SEMI,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_RBRACK,
      anon_sym_RBRACE,
      anon_sym_COLON,
  [27340] = 5,
    ACTIONS(378), 1,
      anon_sym_COLON,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(376), 2,
      sym__entry_delimiter,
      aux_sym_matrix_token1,
    ACTIONS(360), 13,
      anon_sym_SEMI,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_RBRACK,
      anon_sym_RBRACE,
    ACTIONS(364), 14,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
  [27383] = 4,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(562), 2,
      sym__entry_delimiter,
      aux_sym_matrix_token1,
    ACTIONS(1027), 2,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
    ACTIONS(554), 26,
      anon_sym_SEMI,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_RBRACK,
      anon_sym_RBRACE,
      anon_sym_COLON,
  [27424] = 4,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(562), 2,
      sym__entry_delimiter,
      aux_sym_matrix_token1,
    ACTIONS(1027), 2,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
    ACTIONS(554), 26,
      anon_sym_SEMI,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_RBRACK,
      anon_sym_RBRACE,
      anon_sym_COLON,
  [27465] = 4,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(387), 2,
      sym__entry_delimiter,
      aux_sym_matrix_token1,
    ACTIONS(761), 2,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(364), 26,
      anon_sym_SEMI,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_RBRACK,
      anon_sym_RBRACE,
      anon_sym_COLON,
  [27506] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(509), 2,
      sym__entry_delimiter,
      aux_sym_matrix_token1,
    ACTIONS(507), 28,
      anon_sym_SEMI,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_RBRACK,
      anon_sym_RBRACE,
      anon_sym_COLON,
  [27545] = 7,
    ACTIONS(1031), 1,
      anon_sym_AMP,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(562), 2,
      sym__entry_delimiter,
      aux_sym_matrix_token1,
    ACTIONS(1027), 2,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
    ACTIONS(1029), 4,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
    ACTIONS(1025), 6,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
    ACTIONS(554), 15,
      anon_sym_SEMI,
      anon_sym_PIPE,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_RBRACK,
      anon_sym_RBRACE,
      anon_sym_COLON,
  [27592] = 6,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(562), 2,
      sym__entry_delimiter,
      aux_sym_matrix_token1,
    ACTIONS(1027), 2,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
    ACTIONS(1029), 4,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
    ACTIONS(1025), 6,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
    ACTIONS(554), 16,
      anon_sym_SEMI,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_RBRACK,
      anon_sym_RBRACE,
      anon_sym_COLON,
  [27637] = 4,
    ACTIONS(1033), 1,
      anon_sym_COLON,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(544), 2,
      sym__entry_delimiter,
      aux_sym_matrix_token1,
    ACTIONS(540), 27,
      anon_sym_SEMI,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_RBRACK,
      anon_sym_RBRACE,
  [27678] = 4,
    ACTIONS(374), 1,
      anon_sym_COLON,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(364), 14,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
    ACTIONS(360), 15,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_end,
      anon_sym_case,
      anon_sym_otherwise,
      anon_sym_LF,
      anon_sym_CR,
  [27719] = 5,
    ACTIONS(1023), 1,
      anon_sym_DOT,
    STATE(462), 1,
      aux_sym_handle_operator_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(393), 4,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(397), 24,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_RBRACE,
      anon_sym_COLON,
  [27762] = 5,
    ACTIONS(824), 1,
      anon_sym_DOT,
    STATE(488), 1,
      aux_sym_field_expression_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(389), 4,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(391), 24,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_RBRACE,
      anon_sym_COLON,
  [27805] = 4,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(387), 2,
      sym__entry_delimiter,
      aux_sym_matrix_token1,
    ACTIONS(761), 2,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(364), 26,
      anon_sym_SEMI,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_RBRACK,
      anon_sym_RBRACE,
      anon_sym_COLON,
  [27846] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(453), 2,
      sym__entry_delimiter,
      aux_sym_matrix_token1,
    ACTIONS(451), 28,
      anon_sym_SEMI,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_RBRACK,
      anon_sym_RBRACE,
      anon_sym_COLON,
  [27885] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(532), 2,
      sym__entry_delimiter,
      aux_sym_matrix_token1,
    ACTIONS(530), 28,
      anon_sym_SEMI,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_RBRACK,
      anon_sym_RBRACE,
      anon_sym_COLON,
  [27924] = 5,
    ACTIONS(824), 1,
      anon_sym_DOT,
    STATE(488), 1,
      aux_sym_field_expression_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(389), 4,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(391), 24,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_RBRACE,
      anon_sym_COLON,
  [27967] = 4,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(477), 2,
      sym__entry_delimiter,
      aux_sym_matrix_token1,
    ACTIONS(1014), 6,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
    ACTIONS(473), 22,
      anon_sym_SEMI,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_RBRACK,
      anon_sym_RBRACE,
      anon_sym_COLON,
  [28008] = 6,
    ACTIONS(374), 1,
      anon_sym_COLON,
    ACTIONS(773), 1,
      anon_sym_EQ,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(741), 2,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(360), 12,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_LF,
      anon_sym_CR,
    ACTIONS(364), 14,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
  [28053] = 5,
    ACTIONS(1016), 1,
      anon_sym_AMP_AMP,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(477), 2,
      sym__entry_delimiter,
      aux_sym_matrix_token1,
    ACTIONS(1014), 6,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
    ACTIONS(473), 21,
      anon_sym_SEMI,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_RBRACK,
      anon_sym_RBRACE,
      anon_sym_COLON,
  [28096] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(505), 2,
      sym__entry_delimiter,
      aux_sym_matrix_token1,
    ACTIONS(503), 28,
      anon_sym_SEMI,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_RBRACK,
      anon_sym_RBRACE,
      anon_sym_COLON,
  [28135] = 5,
    ACTIONS(1035), 1,
      anon_sym_DOT,
    STATE(488), 1,
      aux_sym_field_expression_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(399), 4,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(404), 24,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_RBRACE,
      anon_sym_COLON,
  [28178] = 4,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(387), 2,
      sym__entry_delimiter,
      aux_sym_matrix_token1,
    ACTIONS(761), 2,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(364), 26,
      anon_sym_SEMI,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_RBRACK,
      anon_sym_RBRACE,
      anon_sym_COLON,
  [28219] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(501), 2,
      sym__entry_delimiter,
      aux_sym_matrix_token1,
    ACTIONS(499), 28,
      anon_sym_SEMI,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_RBRACK,
      anon_sym_RBRACE,
      anon_sym_COLON,
  [28258] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(493), 2,
      sym__entry_delimiter,
      aux_sym_matrix_token1,
    ACTIONS(491), 28,
      anon_sym_SEMI,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_RBRACK,
      anon_sym_RBRACE,
      anon_sym_COLON,
  [28297] = 6,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(381), 2,
      sym__entry_delimiter,
      aux_sym_matrix_token1,
    ACTIONS(761), 2,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(374), 4,
      anon_sym_SEMI,
      anon_sym_RBRACK,
      anon_sym_RBRACE,
      anon_sym_COLON,
    ACTIONS(378), 8,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
    ACTIONS(364), 14,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
  [28342] = 6,
    ACTIONS(1016), 1,
      anon_sym_AMP_AMP,
    ACTIONS(1018), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(497), 2,
      sym__entry_delimiter,
      aux_sym_matrix_token1,
    ACTIONS(1014), 6,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
    ACTIONS(495), 20,
      anon_sym_SEMI,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_RBRACK,
      anon_sym_RBRACE,
      anon_sym_COLON,
  [28387] = 4,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(489), 2,
      sym__entry_delimiter,
      aux_sym_matrix_token1,
    ACTIONS(1014), 6,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
    ACTIONS(487), 22,
      anon_sym_SEMI,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_RBRACK,
      anon_sym_RBRACE,
      anon_sym_COLON,
  [28428] = 6,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(471), 2,
      sym__entry_delimiter,
      aux_sym_matrix_token1,
    ACTIONS(761), 2,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(466), 4,
      anon_sym_SEMI,
      anon_sym_RBRACK,
      anon_sym_RBRACE,
      anon_sym_COLON,
    ACTIONS(468), 8,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
    ACTIONS(364), 14,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
  [28473] = 6,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(534), 2,
      sym__entry_delimiter,
      aux_sym_matrix_token1,
    ACTIONS(761), 2,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(515), 4,
      anon_sym_SEMI,
      anon_sym_RBRACK,
      anon_sym_RBRACE,
      anon_sym_COLON,
    ACTIONS(463), 8,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
    ACTIONS(364), 14,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
  [28518] = 4,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(385), 2,
      sym__entry_delimiter,
      aux_sym_matrix_token1,
    ACTIONS(761), 2,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(383), 26,
      anon_sym_SEMI,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_RBRACK,
      anon_sym_RBRACE,
      anon_sym_COLON,
  [28559] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(385), 2,
      sym__entry_delimiter,
      aux_sym_matrix_token1,
    ACTIONS(383), 28,
      anon_sym_SEMI,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_RBRACK,
      anon_sym_RBRACE,
      anon_sym_COLON,
  [28598] = 6,
    ACTIONS(468), 1,
      anon_sym_COLON,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(376), 2,
      sym__entry_delimiter,
      aux_sym_matrix_token1,
    ACTIONS(761), 2,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(360), 11,
      anon_sym_SEMI,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_RBRACK,
      anon_sym_RBRACE,
    ACTIONS(364), 14,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
  [28643] = 5,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(381), 2,
      sym__entry_delimiter,
      aux_sym_matrix_token1,
    ACTIONS(374), 6,
      anon_sym_SEMI,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_RBRACK,
      anon_sym_RBRACE,
      anon_sym_COLON,
    ACTIONS(378), 8,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
    ACTIONS(364), 14,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
  [28686] = 4,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(385), 2,
      sym__entry_delimiter,
      aux_sym_matrix_token1,
    ACTIONS(761), 2,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(383), 26,
      anon_sym_SEMI,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_RBRACK,
      anon_sym_RBRACE,
      anon_sym_COLON,
  [28727] = 6,
    ACTIONS(1016), 1,
      anon_sym_AMP_AMP,
    ACTIONS(1018), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(538), 2,
      sym__entry_delimiter,
      aux_sym_matrix_token1,
    ACTIONS(1014), 6,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
    ACTIONS(536), 20,
      anon_sym_SEMI,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_RBRACK,
      anon_sym_RBRACE,
      anon_sym_COLON,
  [28772] = 4,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(385), 2,
      sym__entry_delimiter,
      aux_sym_matrix_token1,
    ACTIONS(761), 2,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(383), 26,
      anon_sym_SEMI,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_RBRACK,
      anon_sym_RBRACE,
      anon_sym_COLON,
  [28813] = 5,
    ACTIONS(526), 1,
      anon_sym_COLON,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(528), 2,
      sym__entry_delimiter,
      aux_sym_matrix_token1,
    ACTIONS(523), 8,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
    ACTIONS(521), 19,
      anon_sym_SEMI,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_RBRACK,
      anon_sym_RBRACE,
  [28856] = 4,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(387), 2,
      sym__entry_delimiter,
      aux_sym_matrix_token1,
    ACTIONS(761), 2,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(364), 26,
      anon_sym_SEMI,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_RBRACK,
      anon_sym_RBRACE,
      anon_sym_COLON,
  [28897] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(461), 2,
      sym__entry_delimiter,
      aux_sym_matrix_token1,
    ACTIONS(459), 28,
      anon_sym_SEMI,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_RBRACK,
      anon_sym_RBRACE,
      anon_sym_COLON,
  [28936] = 6,
    ACTIONS(374), 1,
      anon_sym_COLON,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(376), 2,
      sym__entry_delimiter,
      aux_sym_matrix_token1,
    ACTIONS(761), 2,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(360), 11,
      anon_sym_SEMI,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_RBRACK,
      anon_sym_RBRACE,
    ACTIONS(364), 14,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
  [28981] = 6,
    ACTIONS(515), 1,
      anon_sym_COLON,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(376), 2,
      sym__entry_delimiter,
      aux_sym_matrix_token1,
    ACTIONS(761), 2,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(360), 11,
      anon_sym_SEMI,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_RBRACK,
      anon_sym_RBRACE,
    ACTIONS(364), 14,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
  [29026] = 6,
    ACTIONS(466), 1,
      anon_sym_COLON,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(376), 2,
      sym__entry_delimiter,
      aux_sym_matrix_token1,
    ACTIONS(761), 2,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(360), 11,
      anon_sym_SEMI,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_RBRACK,
      anon_sym_RBRACE,
    ACTIONS(364), 14,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
  [29071] = 5,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(376), 2,
      sym__entry_delimiter,
      aux_sym_matrix_token1,
    ACTIONS(761), 2,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(360), 12,
      anon_sym_SEMI,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_RBRACK,
      anon_sym_RBRACE,
      anon_sym_COLON,
    ACTIONS(364), 14,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
  [29114] = 4,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(376), 2,
      sym__entry_delimiter,
      aux_sym_matrix_token1,
    ACTIONS(360), 14,
      anon_sym_SEMI,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_RBRACK,
      anon_sym_RBRACE,
      anon_sym_COLON,
    ACTIONS(364), 14,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
  [29155] = 5,
    ACTIONS(1040), 1,
      anon_sym_AMP_AMP,
    ACTIONS(1042), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1038), 6,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
    ACTIONS(495), 21,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_end,
      anon_sym_case,
      anon_sym_otherwise,
      anon_sym_LF,
      anon_sym_CR,
  [29197] = 5,
    ACTIONS(1040), 1,
      anon_sym_AMP_AMP,
    ACTIONS(1042), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1038), 6,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
    ACTIONS(536), 21,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_end,
      anon_sym_case,
      anon_sym_otherwise,
      anon_sym_LF,
      anon_sym_CR,
  [29239] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(410), 5,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_DOT,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(415), 24,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_RBRACE,
      anon_sym_COLON,
  [29277] = 5,
    ACTIONS(1040), 1,
      anon_sym_AMP_AMP,
    ACTIONS(1042), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1038), 6,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
    ACTIONS(481), 21,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_end,
      anon_sym_case,
      anon_sym_otherwise,
      anon_sym_LF,
      anon_sym_CR,
  [29319] = 4,
    ACTIONS(1040), 1,
      anon_sym_AMP_AMP,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1038), 6,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
    ACTIONS(473), 22,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_end,
      anon_sym_case,
      anon_sym_otherwise,
      anon_sym_LF,
      anon_sym_CR,
  [29359] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1038), 6,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
    ACTIONS(473), 23,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_end,
      anon_sym_case,
      anon_sym_otherwise,
      anon_sym_LF,
      anon_sym_CR,
  [29397] = 6,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(360), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(364), 2,
      anon_sym_PIPE,
      anon_sym_AMP,
    ACTIONS(828), 2,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(376), 10,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_RBRACE,
      anon_sym_COLON,
    ACTIONS(387), 12,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
  [29440] = 6,
    ACTIONS(952), 1,
      anon_sym_COLON,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(360), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(364), 2,
      anon_sym_PIPE,
      anon_sym_AMP,
    ACTIONS(376), 11,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_RBRACE,
    ACTIONS(387), 12,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
  [29483] = 5,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(360), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(364), 2,
      anon_sym_PIPE,
      anon_sym_AMP,
    ACTIONS(376), 12,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_RBRACE,
      anon_sym_COLON,
    ACTIONS(387), 12,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
  [29524] = 7,
    ACTIONS(381), 1,
      anon_sym_COLON,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(360), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(364), 2,
      anon_sym_PIPE,
      anon_sym_AMP,
    ACTIONS(828), 2,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(376), 9,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_RBRACE,
    ACTIONS(387), 12,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
  [29569] = 6,
    ACTIONS(1047), 1,
      anon_sym_COLON,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(521), 2,
      anon_sym_PIPE,
      anon_sym_AMP,
    ACTIONS(523), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1044), 6,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
    ACTIONS(528), 17,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_RBRACE,
  [29612] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(530), 4,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(532), 24,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_RBRACE,
      anon_sym_COLON,
  [29649] = 7,
    ACTIONS(1053), 1,
      anon_sym_AMP_AMP,
    ACTIONS(1055), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(536), 2,
      anon_sym_PIPE,
      anon_sym_AMP,
    ACTIONS(1049), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1051), 4,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
    ACTIONS(538), 18,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_RBRACE,
      anon_sym_COLON,
  [29694] = 5,
    ACTIONS(374), 1,
      anon_sym_COLON,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(376), 2,
      sym__entry_delimiter,
      aux_sym_matrix_token1,
    ACTIONS(360), 11,
      anon_sym_SEMI,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_RBRACK,
      anon_sym_RBRACE,
    ACTIONS(364), 14,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
  [29735] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(459), 4,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(461), 24,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_RBRACE,
      anon_sym_COLON,
  [29772] = 7,
    ACTIONS(952), 1,
      anon_sym_COLON,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(360), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(364), 2,
      anon_sym_PIPE,
      anon_sym_AMP,
    ACTIONS(828), 2,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(376), 9,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_RBRACE,
    ACTIONS(387), 12,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
  [29817] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(451), 4,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(453), 24,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_RBRACE,
      anon_sym_COLON,
  [29854] = 4,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(828), 2,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(364), 4,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(387), 22,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_RBRACE,
      anon_sym_COLON,
  [29893] = 7,
    ACTIONS(471), 1,
      anon_sym_COLON,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(360), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(364), 2,
      anon_sym_PIPE,
      anon_sym_AMP,
    ACTIONS(828), 2,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(376), 9,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_RBRACE,
    ACTIONS(387), 12,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
  [29938] = 7,
    ACTIONS(1057), 1,
      anon_sym_COLON,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(360), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(364), 2,
      anon_sym_PIPE,
      anon_sym_AMP,
    ACTIONS(828), 2,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(376), 9,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_RBRACE,
    ACTIONS(387), 12,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
  [29983] = 4,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(828), 2,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(383), 4,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(385), 22,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_RBRACE,
      anon_sym_COLON,
  [30022] = 4,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(828), 2,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(383), 4,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(385), 22,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_RBRACE,
      anon_sym_COLON,
  [30061] = 4,
    ACTIONS(1047), 1,
      anon_sym_COLON,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(540), 4,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(544), 23,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_RBRACE,
  [30100] = 6,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1064), 2,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
    ACTIONS(554), 4,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1060), 4,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
    ACTIONS(1062), 6,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
    ACTIONS(562), 12,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_RBRACE,
      anon_sym_COLON,
  [30143] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(383), 4,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(385), 24,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_RBRACE,
      anon_sym_COLON,
  [30180] = 7,
    ACTIONS(1066), 1,
      anon_sym_AMP,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1064), 2,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
    ACTIONS(554), 3,
      anon_sym_PIPE,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1060), 4,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
    ACTIONS(1062), 6,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
    ACTIONS(562), 12,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_RBRACE,
      anon_sym_COLON,
  [30225] = 4,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1064), 2,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
    ACTIONS(554), 4,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(562), 22,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_RBRACE,
      anon_sym_COLON,
  [30264] = 4,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1064), 2,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
    ACTIONS(554), 4,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(562), 22,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_RBRACE,
      anon_sym_COLON,
  [30303] = 5,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1064), 2,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
    ACTIONS(554), 4,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1062), 6,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
    ACTIONS(562), 16,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_RBRACE,
      anon_sym_COLON,
  [30344] = 4,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(828), 2,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(383), 4,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(385), 22,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_RBRACE,
      anon_sym_COLON,
  [30383] = 7,
    ACTIONS(534), 1,
      anon_sym_COLON,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(360), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(364), 2,
      anon_sym_PIPE,
      anon_sym_AMP,
    ACTIONS(828), 2,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(376), 9,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_RBRACE,
    ACTIONS(387), 12,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
  [30428] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(455), 4,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(457), 24,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_RBRACE,
      anon_sym_COLON,
  [30465] = 6,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(364), 2,
      anon_sym_PIPE,
      anon_sym_AMP,
    ACTIONS(378), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(381), 6,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_RBRACE,
      anon_sym_COLON,
    ACTIONS(952), 6,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
    ACTIONS(387), 12,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
  [30508] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(546), 4,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(548), 24,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_RBRACE,
      anon_sym_COLON,
  [30545] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(517), 4,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(519), 24,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_RBRACE,
      anon_sym_COLON,
  [30582] = 7,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(364), 2,
      anon_sym_PIPE,
      anon_sym_AMP,
    ACTIONS(463), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(828), 2,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(534), 4,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
      anon_sym_COLON,
    ACTIONS(1057), 6,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
    ACTIONS(387), 12,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
  [30627] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(511), 4,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(513), 24,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_RBRACE,
      anon_sym_COLON,
  [30664] = 7,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(364), 2,
      anon_sym_PIPE,
      anon_sym_AMP,
    ACTIONS(378), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(828), 2,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(381), 4,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
      anon_sym_COLON,
    ACTIONS(952), 6,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
    ACTIONS(387), 12,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
  [30709] = 5,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(473), 2,
      anon_sym_PIPE,
      anon_sym_AMP,
    ACTIONS(1049), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1051), 4,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
    ACTIONS(477), 20,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_RBRACE,
      anon_sym_COLON,
  [30750] = 5,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(487), 2,
      anon_sym_PIPE,
      anon_sym_AMP,
    ACTIONS(1049), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1051), 4,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
    ACTIONS(489), 20,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_RBRACE,
      anon_sym_COLON,
  [30791] = 4,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(828), 2,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(364), 4,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(387), 22,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_RBRACE,
      anon_sym_COLON,
  [30830] = 4,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(828), 2,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(364), 4,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(387), 22,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_RBRACE,
      anon_sym_COLON,
  [30869] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(491), 4,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(493), 24,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_RBRACE,
      anon_sym_COLON,
  [30906] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(499), 4,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(501), 24,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_RBRACE,
      anon_sym_COLON,
  [30943] = 7,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(364), 2,
      anon_sym_PIPE,
      anon_sym_AMP,
    ACTIONS(468), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(828), 2,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(471), 4,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
      anon_sym_COLON,
    ACTIONS(1068), 6,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
    ACTIONS(387), 12,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
  [30988] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(503), 4,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(505), 24,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_RBRACE,
      anon_sym_COLON,
  [31025] = 6,
    ACTIONS(1053), 1,
      anon_sym_AMP_AMP,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(473), 2,
      anon_sym_PIPE,
      anon_sym_AMP,
    ACTIONS(1049), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1051), 4,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
    ACTIONS(477), 19,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE_PIPE,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_RBRACE,
      anon_sym_COLON,
  [31068] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(507), 4,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(509), 24,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_RBRACE,
      anon_sym_COLON,
  [31105] = 7,
    ACTIONS(1053), 1,
      anon_sym_AMP_AMP,
    ACTIONS(1055), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(481), 2,
      anon_sym_PIPE,
      anon_sym_AMP,
    ACTIONS(1049), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1051), 4,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
    ACTIONS(485), 18,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_RBRACE,
      anon_sym_COLON,
  [31150] = 7,
    ACTIONS(1068), 1,
      anon_sym_COLON,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(360), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(364), 2,
      anon_sym_PIPE,
      anon_sym_AMP,
    ACTIONS(828), 2,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(376), 9,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_RBRACE,
    ACTIONS(387), 12,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
  [31195] = 7,
    ACTIONS(1053), 1,
      anon_sym_AMP_AMP,
    ACTIONS(1055), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(495), 2,
      anon_sym_PIPE,
      anon_sym_AMP,
    ACTIONS(1049), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1051), 4,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
    ACTIONS(497), 18,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_RBRACE,
      anon_sym_COLON,
  [31240] = 4,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(828), 2,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(364), 4,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(387), 22,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_RBRACE,
      anon_sym_COLON,
  [31279] = 7,
    ACTIONS(471), 1,
      anon_sym_COLON,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(360), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(364), 2,
      anon_sym_PIPE,
      anon_sym_AMP,
    ACTIONS(828), 2,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(376), 8,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
    ACTIONS(387), 12,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
  [31323] = 7,
    ACTIONS(534), 1,
      anon_sym_COLON,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(360), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(364), 2,
      anon_sym_PIPE,
      anon_sym_AMP,
    ACTIONS(828), 2,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(376), 8,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
    ACTIONS(387), 12,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
  [31367] = 4,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(477), 2,
      sym__entry_delimiter,
      aux_sym_matrix_token1,
    ACTIONS(1071), 6,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
    ACTIONS(473), 19,
      anon_sym_SEMI,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_RBRACK,
      anon_sym_RBRACE,
  [31405] = 5,
    ACTIONS(1073), 1,
      anon_sym_AMP_AMP,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(477), 2,
      sym__entry_delimiter,
      aux_sym_matrix_token1,
    ACTIONS(1071), 6,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
    ACTIONS(473), 18,
      anon_sym_SEMI,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_RBRACK,
      anon_sym_RBRACE,
  [31445] = 6,
    ACTIONS(1073), 1,
      anon_sym_AMP_AMP,
    ACTIONS(1075), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(538), 2,
      sym__entry_delimiter,
      aux_sym_matrix_token1,
    ACTIONS(1071), 6,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
    ACTIONS(536), 17,
      anon_sym_SEMI,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_RBRACK,
      anon_sym_RBRACE,
  [31487] = 6,
    ACTIONS(1073), 1,
      anon_sym_AMP_AMP,
    ACTIONS(1075), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(497), 2,
      sym__entry_delimiter,
      aux_sym_matrix_token1,
    ACTIONS(1071), 6,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
    ACTIONS(495), 17,
      anon_sym_SEMI,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_RBRACK,
      anon_sym_RBRACE,
  [31529] = 7,
    ACTIONS(381), 1,
      anon_sym_COLON,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(360), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(364), 2,
      anon_sym_PIPE,
      anon_sym_AMP,
    ACTIONS(828), 2,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(376), 8,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
    ACTIONS(387), 12,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
  [31573] = 6,
    ACTIONS(1073), 1,
      anon_sym_AMP_AMP,
    ACTIONS(1075), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(485), 2,
      sym__entry_delimiter,
      aux_sym_matrix_token1,
    ACTIONS(1071), 6,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
    ACTIONS(481), 17,
      anon_sym_SEMI,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_RBRACK,
      anon_sym_RBRACE,
  [31615] = 8,
    ACTIONS(381), 1,
      anon_sym_COLON,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(360), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(364), 2,
      anon_sym_PIPE,
      anon_sym_AMP,
    ACTIONS(828), 2,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(968), 2,
      anon_sym_COMMA,
      anon_sym_RPAREN,
    ACTIONS(376), 6,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
    ACTIONS(387), 12,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
  [31661] = 8,
    ACTIONS(534), 1,
      anon_sym_COLON,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(360), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(364), 2,
      anon_sym_PIPE,
      anon_sym_AMP,
    ACTIONS(828), 2,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(968), 2,
      anon_sym_COMMA,
      anon_sym_RPAREN,
    ACTIONS(376), 6,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
    ACTIONS(387), 12,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
  [31707] = 8,
    ACTIONS(534), 1,
      anon_sym_COLON,
    ACTIONS(1005), 1,
      anon_sym_RPAREN,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(360), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(364), 2,
      anon_sym_PIPE,
      anon_sym_AMP,
    ACTIONS(828), 2,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(376), 6,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
    ACTIONS(387), 12,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
  [31752] = 8,
    ACTIONS(381), 1,
      anon_sym_COLON,
    ACTIONS(990), 1,
      anon_sym_RPAREN,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(360), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(364), 2,
      anon_sym_PIPE,
      anon_sym_AMP,
    ACTIONS(828), 2,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(376), 6,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
    ACTIONS(387), 12,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
  [31797] = 8,
    ACTIONS(381), 1,
      anon_sym_COLON,
    ACTIONS(1005), 1,
      anon_sym_RPAREN,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(360), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(364), 2,
      anon_sym_PIPE,
      anon_sym_AMP,
    ACTIONS(828), 2,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(376), 6,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
    ACTIONS(387), 12,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
  [31842] = 8,
    ACTIONS(534), 1,
      anon_sym_COLON,
    ACTIONS(992), 1,
      anon_sym_RPAREN,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(360), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(364), 2,
      anon_sym_PIPE,
      anon_sym_AMP,
    ACTIONS(828), 2,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(376), 6,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
    ACTIONS(387), 12,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
  [31887] = 8,
    ACTIONS(381), 1,
      anon_sym_COLON,
    ACTIONS(994), 1,
      anon_sym_RPAREN,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(360), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(364), 2,
      anon_sym_PIPE,
      anon_sym_AMP,
    ACTIONS(828), 2,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(376), 6,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
    ACTIONS(387), 12,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
  [31932] = 8,
    ACTIONS(471), 1,
      anon_sym_COLON,
    ACTIONS(988), 1,
      anon_sym_RPAREN,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(360), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(364), 2,
      anon_sym_PIPE,
      anon_sym_AMP,
    ACTIONS(828), 2,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(376), 6,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
    ACTIONS(387), 12,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
  [31977] = 8,
    ACTIONS(471), 1,
      anon_sym_COLON,
    ACTIONS(994), 1,
      anon_sym_RPAREN,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(360), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(364), 2,
      anon_sym_PIPE,
      anon_sym_AMP,
    ACTIONS(828), 2,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(376), 6,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
    ACTIONS(387), 12,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
  [32022] = 8,
    ACTIONS(534), 1,
      anon_sym_COLON,
    ACTIONS(994), 1,
      anon_sym_RPAREN,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(360), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(364), 2,
      anon_sym_PIPE,
      anon_sym_AMP,
    ACTIONS(828), 2,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(376), 6,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
    ACTIONS(387), 12,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
  [32067] = 8,
    ACTIONS(471), 1,
      anon_sym_COLON,
    ACTIONS(992), 1,
      anon_sym_RPAREN,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(360), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(364), 2,
      anon_sym_PIPE,
      anon_sym_AMP,
    ACTIONS(828), 2,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(376), 6,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
    ACTIONS(387), 12,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
  [32112] = 8,
    ACTIONS(534), 1,
      anon_sym_COLON,
    ACTIONS(988), 1,
      anon_sym_RPAREN,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(360), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(364), 2,
      anon_sym_PIPE,
      anon_sym_AMP,
    ACTIONS(828), 2,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(376), 6,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
    ACTIONS(387), 12,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
  [32157] = 8,
    ACTIONS(381), 1,
      anon_sym_COLON,
    ACTIONS(988), 1,
      anon_sym_RPAREN,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(360), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(364), 2,
      anon_sym_PIPE,
      anon_sym_AMP,
    ACTIONS(828), 2,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(376), 6,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
    ACTIONS(387), 12,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
  [32202] = 7,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(360), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(364), 2,
      anon_sym_PIPE,
      anon_sym_AMP,
    ACTIONS(828), 2,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(968), 2,
      anon_sym_COMMA,
      anon_sym_RPAREN,
    ACTIONS(376), 6,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
    ACTIONS(387), 12,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
  [32245] = 6,
    ACTIONS(381), 1,
      anon_sym_COLON,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(360), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(364), 2,
      anon_sym_PIPE,
      anon_sym_AMP,
    ACTIONS(376), 9,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_RBRACE,
    ACTIONS(387), 12,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
  [32286] = 8,
    ACTIONS(471), 1,
      anon_sym_COLON,
    ACTIONS(990), 1,
      anon_sym_RPAREN,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(360), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(364), 2,
      anon_sym_PIPE,
      anon_sym_AMP,
    ACTIONS(828), 2,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(376), 6,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
    ACTIONS(387), 12,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
  [32331] = 8,
    ACTIONS(534), 1,
      anon_sym_COLON,
    ACTIONS(990), 1,
      anon_sym_RPAREN,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(360), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(364), 2,
      anon_sym_PIPE,
      anon_sym_AMP,
    ACTIONS(828), 2,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(376), 6,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
    ACTIONS(387), 12,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
  [32376] = 8,
    ACTIONS(471), 1,
      anon_sym_COLON,
    ACTIONS(1005), 1,
      anon_sym_RPAREN,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(360), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(364), 2,
      anon_sym_PIPE,
      anon_sym_AMP,
    ACTIONS(828), 2,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(376), 6,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
    ACTIONS(387), 12,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
  [32421] = 8,
    ACTIONS(381), 1,
      anon_sym_COLON,
    ACTIONS(992), 1,
      anon_sym_RPAREN,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(360), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(364), 2,
      anon_sym_PIPE,
      anon_sym_AMP,
    ACTIONS(828), 2,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(376), 6,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
    ACTIONS(387), 12,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
  [32466] = 7,
    ACTIONS(471), 1,
      anon_sym_COLON,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(360), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(364), 2,
      anon_sym_PIPE,
      anon_sym_AMP,
    ACTIONS(1077), 2,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(376), 6,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
    ACTIONS(387), 12,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
  [32508] = 7,
    ACTIONS(471), 1,
      anon_sym_COLON,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(360), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(364), 2,
      anon_sym_PIPE,
      anon_sym_AMP,
    ACTIONS(1079), 2,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(376), 6,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
    ACTIONS(387), 12,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
  [32550] = 7,
    ACTIONS(1085), 1,
      anon_sym_AMP_AMP,
    ACTIONS(1087), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(495), 2,
      anon_sym_PIPE,
      anon_sym_AMP,
    ACTIONS(1081), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1083), 4,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
    ACTIONS(497), 15,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_RBRACE,
  [32592] = 7,
    ACTIONS(471), 1,
      anon_sym_COLON,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(360), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(364), 2,
      anon_sym_PIPE,
      anon_sym_AMP,
    ACTIONS(1089), 2,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(376), 6,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
    ACTIONS(387), 12,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
  [32634] = 7,
    ACTIONS(1085), 1,
      anon_sym_AMP_AMP,
    ACTIONS(1087), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(536), 2,
      anon_sym_PIPE,
      anon_sym_AMP,
    ACTIONS(1081), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1083), 4,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
    ACTIONS(538), 15,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_RBRACE,
  [32676] = 6,
    ACTIONS(1085), 1,
      anon_sym_AMP_AMP,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(473), 2,
      anon_sym_PIPE,
      anon_sym_AMP,
    ACTIONS(1081), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1083), 4,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
    ACTIONS(477), 16,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE_PIPE,
      anon_sym_RBRACE,
  [32716] = 5,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(473), 2,
      anon_sym_PIPE,
      anon_sym_AMP,
    ACTIONS(1081), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1083), 4,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
    ACTIONS(477), 17,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_RBRACE,
  [32754] = 7,
    ACTIONS(1085), 1,
      anon_sym_AMP_AMP,
    ACTIONS(1087), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(481), 2,
      anon_sym_PIPE,
      anon_sym_AMP,
    ACTIONS(1081), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1083), 4,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
    ACTIONS(485), 15,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_RBRACE,
  [32796] = 7,
    ACTIONS(381), 1,
      anon_sym_COLON,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(360), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(364), 2,
      anon_sym_PIPE,
      anon_sym_AMP,
    ACTIONS(968), 2,
      anon_sym_COMMA,
      anon_sym_RPAREN,
    ACTIONS(376), 6,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
    ACTIONS(387), 12,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
  [32838] = 6,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(360), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(364), 2,
      anon_sym_PIPE,
      anon_sym_AMP,
    ACTIONS(1077), 2,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(376), 6,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
    ACTIONS(387), 12,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
  [32877] = 6,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(360), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(364), 2,
      anon_sym_PIPE,
      anon_sym_AMP,
    ACTIONS(1089), 2,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(376), 6,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
    ACTIONS(387), 12,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
  [32916] = 6,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(360), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(364), 2,
      anon_sym_PIPE,
      anon_sym_AMP,
    ACTIONS(1079), 2,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(376), 6,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
    ACTIONS(387), 12,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
  [32955] = 4,
    ACTIONS(1091), 1,
      anon_sym_DOT,
    STATE(603), 1,
      aux_sym_handle_operator_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(410), 20,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_LBRACE,
      anon_sym_EQ,
      anon_sym_end,
      anon_sym_case,
      anon_sym_otherwise,
      sym_identifier,
      anon_sym_LF,
      anon_sym_CR,
  [32988] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(410), 21,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_AMP,
      anon_sym_DOT,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_LBRACE,
      anon_sym_EQ,
      anon_sym_end,
      anon_sym_case,
      anon_sym_otherwise,
      sym_identifier,
      anon_sym_LF,
      anon_sym_CR,
  [33016] = 11,
    ACTIONS(1040), 1,
      anon_sym_AMP_AMP,
    ACTIONS(1042), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(1096), 1,
      anon_sym_end,
    ACTIONS(1098), 1,
      anon_sym_case,
    ACTIONS(1100), 1,
      anon_sym_otherwise,
    STATE(1140), 1,
      sym_otherwise_clause,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    STATE(639), 2,
      sym__end_of_line,
      aux_sym_elseif_clause_repeat1,
    STATE(794), 2,
      sym_case_clause,
      aux_sym_switch_statement_repeat1,
    ACTIONS(1094), 4,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_CR,
    ACTIONS(1038), 6,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
  [33061] = 16,
    ACTIONS(1102), 1,
      sym_identifier,
    ACTIONS(1104), 1,
      anon_sym_COMMA,
    ACTIONS(1106), 1,
      anon_sym_LPAREN,
    ACTIONS(1108), 1,
      anon_sym_DOT,
    ACTIONS(1110), 1,
      anon_sym_TILDE,
    ACTIONS(1112), 1,
      anon_sym_AT,
    ACTIONS(1114), 1,
      anon_sym_RBRACK,
    ACTIONS(1116), 1,
      anon_sym_LBRACE,
    STATE(642), 1,
      sym_function_call,
    STATE(647), 1,
      sym__args,
    STATE(679), 1,
      aux_sym_field_expression_repeat1,
    STATE(972), 1,
      sym_boolean,
    STATE(987), 1,
      sym_indirect_access,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(660), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(631), 3,
      sym_field_expression,
      sym_ignored_argument,
      aux_sym_multioutput_variable_repeat1,
  [33114] = 4,
    ACTIONS(1118), 1,
      anon_sym_DOT,
    STATE(603), 1,
      aux_sym_handle_operator_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(393), 15,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_end,
      anon_sym_case,
      anon_sym_otherwise,
      anon_sym_LF,
      anon_sym_CR,
  [33142] = 4,
    ACTIONS(1118), 1,
      anon_sym_DOT,
    STATE(607), 1,
      aux_sym_handle_operator_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(417), 15,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_end,
      anon_sym_case,
      anon_sym_otherwise,
      anon_sym_LF,
      anon_sym_CR,
  [33170] = 5,
    ACTIONS(1120), 1,
      anon_sym_DOT,
    STATE(609), 1,
      aux_sym_handle_operator_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(410), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(415), 11,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
  [33198] = 5,
    ACTIONS(1123), 1,
      anon_sym_DOT,
    STATE(613), 1,
      aux_sym_handle_operator_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(419), 2,
      sym__entry_delimiter,
      aux_sym_matrix_token1,
    ACTIONS(417), 11,
      anon_sym_SEMI,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_RBRACK,
      anon_sym_RBRACE,
  [33226] = 13,
    ACTIONS(1125), 1,
      sym_identifier,
    ACTIONS(1129), 1,
      anon_sym_LPAREN,
    ACTIONS(1131), 1,
      anon_sym_DOT,
    ACTIONS(1133), 1,
      anon_sym_LBRACE,
    ACTIONS(1135), 1,
      anon_sym_EQ,
    STATE(651), 1,
      aux_sym_handle_operator_repeat1,
    STATE(661), 1,
      sym_dimensions,
    STATE(678), 1,
      sym_property_name,
    STATE(718), 1,
      sym_validation_functions,
    STATE(827), 1,
      sym_default_value,
    STATE(1036), 1,
      sym__end_of_line,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1127), 4,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_CR,
  [33270] = 5,
    ACTIONS(1137), 1,
      anon_sym_DOT,
    STATE(612), 1,
      aux_sym_handle_operator_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(415), 2,
      sym__entry_delimiter,
      aux_sym_matrix_token1,
    ACTIONS(410), 11,
      anon_sym_SEMI,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_RBRACK,
      anon_sym_RBRACE,
  [33298] = 5,
    ACTIONS(1123), 1,
      anon_sym_DOT,
    STATE(612), 1,
      aux_sym_handle_operator_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(397), 2,
      sym__entry_delimiter,
      aux_sym_matrix_token1,
    ACTIONS(393), 11,
      anon_sym_SEMI,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_RBRACK,
      anon_sym_RBRACE,
  [33326] = 6,
    ACTIONS(1140), 1,
      anon_sym_PIPE,
    ACTIONS(1142), 1,
      anon_sym_AMP,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1064), 2,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
    ACTIONS(1060), 4,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
    ACTIONS(1062), 6,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
  [33355] = 6,
    ACTIONS(1150), 1,
      anon_sym_PIPE,
    ACTIONS(1152), 1,
      anon_sym_AMP,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1148), 2,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
    ACTIONS(1144), 4,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
    ACTIONS(1146), 6,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
  [33384] = 8,
    ACTIONS(1073), 1,
      anon_sym_AMP_AMP,
    ACTIONS(1075), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(1156), 1,
      aux_sym_matrix_token1,
    ACTIONS(1158), 1,
      sym__entry_delimiter,
    STATE(790), 1,
      aux_sym_row_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1154), 3,
      anon_sym_SEMI,
      anon_sym_RBRACK,
      anon_sym_RBRACE,
    ACTIONS(1071), 6,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
  [33417] = 6,
    ACTIONS(1166), 1,
      anon_sym_PIPE,
    ACTIONS(1168), 1,
      anon_sym_AMP,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1164), 2,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
    ACTIONS(1160), 4,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
    ACTIONS(1162), 6,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
  [33446] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(410), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(415), 12,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_DOT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
  [33469] = 8,
    ACTIONS(614), 1,
      aux_sym_matrix_token1,
    ACTIONS(1073), 1,
      anon_sym_AMP_AMP,
    ACTIONS(1075), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(1170), 1,
      sym__entry_delimiter,
    STATE(768), 1,
      aux_sym_row_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(612), 3,
      anon_sym_SEMI,
      anon_sym_RBRACK,
      anon_sym_RBRACE,
    ACTIONS(1071), 6,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
  [33502] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(415), 2,
      sym__entry_delimiter,
      aux_sym_matrix_token1,
    ACTIONS(410), 12,
      anon_sym_SEMI,
      anon_sym_DOT,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_RBRACK,
      anon_sym_RBRACE,
  [33525] = 6,
    ACTIONS(1040), 1,
      anon_sym_AMP_AMP,
    ACTIONS(1042), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    STATE(7), 2,
      sym__end_of_line,
      aux_sym_elseif_clause_repeat1,
    ACTIONS(1172), 4,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_CR,
    ACTIONS(1038), 6,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
  [33554] = 6,
    ACTIONS(1180), 1,
      anon_sym_PIPE,
    ACTIONS(1182), 1,
      anon_sym_AMP,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1178), 2,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
    ACTIONS(1174), 4,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
    ACTIONS(1176), 6,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
  [33583] = 5,
    ACTIONS(1184), 1,
      anon_sym_DOT,
    STATE(609), 1,
      aux_sym_handle_operator_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(393), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(397), 9,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_RBRACE,
  [33609] = 6,
    ACTIONS(1073), 1,
      anon_sym_AMP_AMP,
    ACTIONS(1075), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1188), 2,
      sym__entry_delimiter,
      aux_sym_matrix_token1,
    ACTIONS(1186), 3,
      anon_sym_SEMI,
      anon_sym_RBRACK,
      anon_sym_RBRACE,
    ACTIONS(1071), 6,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
  [33637] = 11,
    ACTIONS(1190), 1,
      sym_identifier,
    ACTIONS(1193), 1,
      anon_sym_COMMA,
    ACTIONS(1196), 1,
      anon_sym_LPAREN,
    ACTIONS(1199), 1,
      anon_sym_TILDE,
    ACTIONS(1202), 1,
      anon_sym_RBRACK,
    STATE(642), 1,
      sym_function_call,
    STATE(972), 1,
      sym_boolean,
    STATE(987), 1,
      sym_indirect_access,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1204), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(625), 3,
      sym_field_expression,
      sym_ignored_argument,
      aux_sym_multioutput_variable_repeat1,
  [33675] = 5,
    ACTIONS(1184), 1,
      anon_sym_DOT,
    STATE(623), 1,
      aux_sym_handle_operator_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(417), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(419), 9,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_RBRACE,
  [33701] = 6,
    ACTIONS(1040), 1,
      anon_sym_AMP_AMP,
    ACTIONS(1042), 1,
      anon_sym_PIPE_PIPE,
    STATE(179), 1,
      sym__end_of_line,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1207), 4,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_CR,
    ACTIONS(1038), 6,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
  [33729] = 11,
    ACTIONS(1102), 1,
      sym_identifier,
    ACTIONS(1104), 1,
      anon_sym_COMMA,
    ACTIONS(1110), 1,
      anon_sym_TILDE,
    ACTIONS(1114), 1,
      anon_sym_RBRACK,
    ACTIONS(1209), 1,
      anon_sym_LPAREN,
    STATE(642), 1,
      sym_function_call,
    STATE(972), 1,
      sym_boolean,
    STATE(987), 1,
      sym_indirect_access,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(660), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(631), 3,
      sym_field_expression,
      sym_ignored_argument,
      aux_sym_multioutput_variable_repeat1,
  [33767] = 11,
    ACTIONS(1125), 1,
      sym_identifier,
    ACTIONS(1129), 1,
      anon_sym_LPAREN,
    ACTIONS(1133), 1,
      anon_sym_LBRACE,
    ACTIONS(1135), 1,
      anon_sym_EQ,
    STATE(661), 1,
      sym_dimensions,
    STATE(678), 1,
      sym_property_name,
    STATE(718), 1,
      sym_validation_functions,
    STATE(827), 1,
      sym_default_value,
    STATE(1036), 1,
      sym__end_of_line,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1127), 4,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_CR,
  [33805] = 6,
    ACTIONS(1040), 1,
      anon_sym_AMP_AMP,
    ACTIONS(1042), 1,
      anon_sym_PIPE_PIPE,
    STATE(179), 1,
      sym__end_of_line,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1207), 4,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_CR,
    ACTIONS(1038), 6,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
  [33833] = 11,
    ACTIONS(1102), 1,
      sym_identifier,
    ACTIONS(1110), 1,
      anon_sym_TILDE,
    ACTIONS(1209), 1,
      anon_sym_LPAREN,
    ACTIONS(1211), 1,
      anon_sym_COMMA,
    ACTIONS(1213), 1,
      anon_sym_RBRACK,
    STATE(642), 1,
      sym_function_call,
    STATE(972), 1,
      sym_boolean,
    STATE(987), 1,
      sym_indirect_access,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(660), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(625), 3,
      sym_field_expression,
      sym_ignored_argument,
      aux_sym_multioutput_variable_repeat1,
  [33871] = 6,
    ACTIONS(1040), 1,
      anon_sym_AMP_AMP,
    ACTIONS(1042), 1,
      anon_sym_PIPE_PIPE,
    STATE(240), 1,
      sym__end_of_line,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1215), 4,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_CR,
    ACTIONS(1038), 6,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
  [33899] = 5,
    ACTIONS(1040), 1,
      anon_sym_AMP_AMP,
    ACTIONS(1042), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1217), 4,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_CR,
    ACTIONS(1038), 6,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
  [33924] = 8,
    ACTIONS(1085), 1,
      anon_sym_AMP_AMP,
    ACTIONS(1087), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(1219), 1,
      anon_sym_COMMA,
    STATE(946), 1,
      aux_sym_arguments_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1081), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1221), 2,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
    ACTIONS(1083), 4,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
  [33955] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(439), 3,
      anon_sym_true,
      anon_sym_false,
      sym_identifier,
    ACTIONS(441), 9,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_DOT,
      anon_sym_TILDE,
      anon_sym_AT,
      anon_sym_RBRACK,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
  [33976] = 12,
    ACTIONS(662), 1,
      sym__single_quote_string_start,
    ACTIONS(664), 1,
      sym__double_quote_string_start,
    ACTIONS(1209), 1,
      anon_sym_LPAREN,
    ACTIONS(1223), 1,
      sym_identifier,
    ACTIONS(1225), 1,
      sym_number,
    STATE(832), 1,
      sym_function_call,
    STATE(972), 1,
      sym_boolean,
    STATE(987), 1,
      sym_indirect_access,
    STATE(1134), 1,
      sym_parfor_options,
    STATE(1200), 1,
      sym_string,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(660), 2,
      anon_sym_true,
      anon_sym_false,
  [34015] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(425), 3,
      anon_sym_true,
      anon_sym_false,
      sym_identifier,
    ACTIONS(427), 9,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_DOT,
      anon_sym_TILDE,
      anon_sym_AT,
      anon_sym_RBRACK,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
  [34036] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(421), 3,
      anon_sym_true,
      anon_sym_false,
      sym_identifier,
    ACTIONS(423), 9,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_DOT,
      anon_sym_TILDE,
      anon_sym_AT,
      anon_sym_RBRACK,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
  [34057] = 8,
    ACTIONS(1098), 1,
      anon_sym_case,
    ACTIONS(1100), 1,
      anon_sym_otherwise,
    ACTIONS(1229), 1,
      anon_sym_end,
    STATE(1193), 1,
      sym_otherwise_clause,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    STATE(688), 2,
      sym__end_of_line,
      aux_sym_elseif_clause_repeat1,
    STATE(802), 2,
      sym_case_clause,
      aux_sym_switch_statement_repeat1,
    ACTIONS(1227), 4,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_CR,
  [34088] = 5,
    ACTIONS(1040), 1,
      anon_sym_AMP_AMP,
    ACTIONS(1042), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1231), 4,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_CR,
    ACTIONS(1038), 6,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
  [34113] = 8,
    ACTIONS(1085), 1,
      anon_sym_AMP_AMP,
    ACTIONS(1087), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(1233), 1,
      anon_sym_COMMA,
    STATE(979), 1,
      aux_sym_arguments_repeat2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1081), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1235), 2,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
    ACTIONS(1083), 4,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
  [34144] = 9,
    ACTIONS(1108), 1,
      anon_sym_DOT,
    ACTIONS(1112), 1,
      anon_sym_AT,
    ACTIONS(1116), 1,
      anon_sym_LBRACE,
    ACTIONS(1241), 1,
      anon_sym_LPAREN,
    STATE(647), 1,
      sym__args,
    STATE(679), 1,
      aux_sym_field_expression_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1237), 3,
      anon_sym_true,
      anon_sym_false,
      sym_identifier,
    ACTIONS(1239), 3,
      anon_sym_COMMA,
      anon_sym_TILDE,
      anon_sym_RBRACK,
  [34177] = 9,
    ACTIONS(1108), 1,
      anon_sym_DOT,
    ACTIONS(1112), 1,
      anon_sym_AT,
    ACTIONS(1116), 1,
      anon_sym_LBRACE,
    ACTIONS(1241), 1,
      anon_sym_LPAREN,
    STATE(647), 1,
      sym__args,
    STATE(679), 1,
      aux_sym_field_expression_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1202), 3,
      anon_sym_COMMA,
      anon_sym_TILDE,
      anon_sym_RBRACK,
    ACTIONS(1243), 3,
      anon_sym_true,
      anon_sym_false,
      sym_identifier,
  [34210] = 8,
    ACTIONS(1085), 1,
      anon_sym_AMP_AMP,
    ACTIONS(1087), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(1233), 1,
      anon_sym_COMMA,
    STATE(993), 1,
      aux_sym_arguments_repeat2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1081), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1245), 2,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
    ACTIONS(1083), 4,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
  [34241] = 8,
    ACTIONS(1085), 1,
      anon_sym_AMP_AMP,
    ACTIONS(1087), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(1233), 1,
      anon_sym_COMMA,
    STATE(991), 1,
      aux_sym_arguments_repeat2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1081), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1245), 2,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
    ACTIONS(1083), 4,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
  [34272] = 8,
    ACTIONS(1085), 1,
      anon_sym_AMP_AMP,
    ACTIONS(1087), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(1233), 1,
      anon_sym_COMMA,
    STATE(916), 1,
      aux_sym_arguments_repeat2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1081), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1247), 2,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
    ACTIONS(1083), 4,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
  [34303] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(429), 3,
      anon_sym_true,
      anon_sym_false,
      sym_identifier,
    ACTIONS(431), 9,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_DOT,
      anon_sym_TILDE,
      anon_sym_AT,
      anon_sym_RBRACK,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
  [34324] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(447), 3,
      anon_sym_true,
      anon_sym_false,
      sym_identifier,
    ACTIONS(449), 9,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_DOT,
      anon_sym_TILDE,
      anon_sym_AT,
      anon_sym_RBRACK,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
  [34345] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(443), 3,
      anon_sym_true,
      anon_sym_false,
      sym_identifier,
    ACTIONS(445), 9,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_DOT,
      anon_sym_TILDE,
      anon_sym_AT,
      anon_sym_RBRACK,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
  [34366] = 9,
    ACTIONS(1131), 1,
      anon_sym_DOT,
    ACTIONS(1133), 1,
      anon_sym_LBRACE,
    ACTIONS(1135), 1,
      anon_sym_EQ,
    STATE(651), 1,
      aux_sym_handle_operator_repeat1,
    STATE(739), 1,
      sym_validation_functions,
    STATE(866), 1,
      sym_default_value,
    STATE(1019), 1,
      sym__end_of_line,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1249), 4,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_CR,
  [34398] = 4,
    ACTIONS(1253), 1,
      anon_sym_DOT,
    STATE(603), 1,
      aux_sym_handle_operator_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1251), 9,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_AMP,
      anon_sym_LBRACE,
      anon_sym_EQ,
      sym_identifier,
      anon_sym_LF,
      anon_sym_CR,
  [34420] = 10,
    ACTIONS(1255), 1,
      sym_identifier,
    ACTIONS(1258), 1,
      anon_sym_end,
    ACTIONS(1260), 1,
      anon_sym_function,
    ACTIONS(1266), 1,
      sym__multioutput_variable_start,
    STATE(762), 1,
      sym__function_definition_with_end,
    STATE(1057), 1,
      sym_function_output,
    STATE(1146), 1,
      sym_multioutput_variable,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1263), 2,
      anon_sym_get_DOT,
      anon_sym_set_DOT,
    STATE(652), 2,
      sym_function_signature,
      aux_sym_methods_repeat1,
  [34454] = 10,
    ACTIONS(55), 1,
      sym__multioutput_variable_start,
    ACTIONS(1269), 1,
      sym_identifier,
    ACTIONS(1271), 1,
      anon_sym_end,
    ACTIONS(1273), 1,
      anon_sym_function,
    STATE(762), 1,
      sym__function_definition_with_end,
    STATE(1057), 1,
      sym_function_output,
    STATE(1146), 1,
      sym_multioutput_variable,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1275), 2,
      anon_sym_get_DOT,
      anon_sym_set_DOT,
    STATE(652), 2,
      sym_function_signature,
      aux_sym_methods_repeat1,
  [34488] = 6,
    ACTIONS(1085), 1,
      anon_sym_AMP_AMP,
    ACTIONS(1087), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1081), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1277), 3,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
    ACTIONS(1083), 4,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
  [34514] = 7,
    ACTIONS(1112), 1,
      anon_sym_AT,
    ACTIONS(1116), 1,
      anon_sym_LBRACE,
    ACTIONS(1241), 1,
      anon_sym_LPAREN,
    STATE(647), 1,
      sym__args,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(406), 3,
      anon_sym_true,
      anon_sym_false,
      sym_identifier,
    ACTIONS(408), 4,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_TILDE,
      anon_sym_RBRACK,
  [34542] = 6,
    ACTIONS(1085), 1,
      anon_sym_AMP_AMP,
    ACTIONS(1087), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1081), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1279), 3,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
    ACTIONS(1083), 4,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
  [34568] = 10,
    ACTIONS(1110), 1,
      anon_sym_TILDE,
    ACTIONS(1209), 1,
      anon_sym_LPAREN,
    ACTIONS(1281), 1,
      sym_identifier,
    ACTIONS(1283), 1,
      anon_sym_RBRACK,
    STATE(643), 1,
      sym_function_call,
    STATE(972), 1,
      sym_boolean,
    STATE(987), 1,
      sym_indirect_access,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(660), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(742), 2,
      sym_field_expression,
      sym_ignored_argument,
  [34602] = 10,
    ACTIONS(1110), 1,
      anon_sym_TILDE,
    ACTIONS(1209), 1,
      anon_sym_LPAREN,
    ACTIONS(1213), 1,
      anon_sym_RBRACK,
    ACTIONS(1281), 1,
      sym_identifier,
    STATE(643), 1,
      sym_function_call,
    STATE(972), 1,
      sym_boolean,
    STATE(987), 1,
      sym_indirect_access,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(660), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(742), 2,
      sym_field_expression,
      sym_ignored_argument,
  [34636] = 10,
    ACTIONS(55), 1,
      sym__multioutput_variable_start,
    ACTIONS(1269), 1,
      sym_identifier,
    ACTIONS(1273), 1,
      anon_sym_function,
    ACTIONS(1285), 1,
      anon_sym_end,
    STATE(762), 1,
      sym__function_definition_with_end,
    STATE(1057), 1,
      sym_function_output,
    STATE(1146), 1,
      sym_multioutput_variable,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1275), 2,
      anon_sym_get_DOT,
      anon_sym_set_DOT,
    STATE(653), 2,
      sym_function_signature,
      aux_sym_methods_repeat1,
  [34670] = 10,
    ACTIONS(55), 1,
      sym__multioutput_variable_start,
    ACTIONS(1269), 1,
      sym_identifier,
    ACTIONS(1271), 1,
      anon_sym_end,
    ACTIONS(1273), 1,
      anon_sym_function,
    STATE(762), 1,
      sym__function_definition_with_end,
    STATE(1057), 1,
      sym_function_output,
    STATE(1146), 1,
      sym_multioutput_variable,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1275), 2,
      anon_sym_get_DOT,
      anon_sym_set_DOT,
    STATE(663), 2,
      sym_function_signature,
      aux_sym_methods_repeat1,
  [34704] = 9,
    ACTIONS(1133), 1,
      anon_sym_LBRACE,
    ACTIONS(1135), 1,
      anon_sym_EQ,
    ACTIONS(1287), 1,
      sym_identifier,
    STATE(683), 1,
      sym_property_name,
    STATE(740), 1,
      sym_validation_functions,
    STATE(824), 1,
      sym_default_value,
    STATE(1029), 1,
      sym__end_of_line,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1289), 4,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_CR,
  [34736] = 9,
    ACTIONS(1131), 1,
      anon_sym_DOT,
    ACTIONS(1133), 1,
      anon_sym_LBRACE,
    ACTIONS(1135), 1,
      anon_sym_EQ,
    STATE(651), 1,
      aux_sym_handle_operator_repeat1,
    STATE(740), 1,
      sym_validation_functions,
    STATE(824), 1,
      sym_default_value,
    STATE(1029), 1,
      sym__end_of_line,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1289), 4,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_CR,
  [34768] = 10,
    ACTIONS(55), 1,
      sym__multioutput_variable_start,
    ACTIONS(1269), 1,
      sym_identifier,
    ACTIONS(1273), 1,
      anon_sym_function,
    ACTIONS(1291), 1,
      anon_sym_end,
    STATE(762), 1,
      sym__function_definition_with_end,
    STATE(1057), 1,
      sym_function_output,
    STATE(1146), 1,
      sym_multioutput_variable,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1275), 2,
      anon_sym_get_DOT,
      anon_sym_set_DOT,
    STATE(652), 2,
      sym_function_signature,
      aux_sym_methods_repeat1,
  [34802] = 7,
    ACTIONS(1293), 1,
      anon_sym_end,
    ACTIONS(1295), 1,
      anon_sym_properties,
    ACTIONS(1297), 1,
      anon_sym_methods,
    ACTIONS(1299), 1,
      anon_sym_events,
    ACTIONS(1301), 1,
      anon_sym_enumeration,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    STATE(673), 5,
      sym_properties,
      sym_methods,
      sym_events,
      sym_enumeration,
      aux_sym_class_definition_repeat1,
  [34829] = 6,
    ACTIONS(1085), 1,
      anon_sym_AMP_AMP,
    ACTIONS(1087), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1081), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1303), 2,
      anon_sym_COMMA,
      anon_sym_RPAREN,
    ACTIONS(1083), 4,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
  [34854] = 7,
    ACTIONS(1295), 1,
      anon_sym_properties,
    ACTIONS(1297), 1,
      anon_sym_methods,
    ACTIONS(1299), 1,
      anon_sym_events,
    ACTIONS(1301), 1,
      anon_sym_enumeration,
    ACTIONS(1305), 1,
      anon_sym_end,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    STATE(669), 5,
      sym_properties,
      sym_methods,
      sym_events,
      sym_enumeration,
      aux_sym_class_definition_repeat1,
  [34881] = 9,
    ACTIONS(1110), 1,
      anon_sym_TILDE,
    ACTIONS(1209), 1,
      anon_sym_LPAREN,
    ACTIONS(1281), 1,
      sym_identifier,
    STATE(643), 1,
      sym_function_call,
    STATE(972), 1,
      sym_boolean,
    STATE(987), 1,
      sym_indirect_access,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(660), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(742), 2,
      sym_field_expression,
      sym_ignored_argument,
  [34912] = 7,
    ACTIONS(1295), 1,
      anon_sym_properties,
    ACTIONS(1297), 1,
      anon_sym_methods,
    ACTIONS(1299), 1,
      anon_sym_events,
    ACTIONS(1301), 1,
      anon_sym_enumeration,
    ACTIONS(1307), 1,
      anon_sym_end,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    STATE(666), 5,
      sym_properties,
      sym_methods,
      sym_events,
      sym_enumeration,
      aux_sym_class_definition_repeat1,
  [34939] = 7,
    ACTIONS(1309), 1,
      anon_sym_end,
    ACTIONS(1311), 1,
      anon_sym_properties,
    ACTIONS(1314), 1,
      anon_sym_methods,
    ACTIONS(1317), 1,
      anon_sym_events,
    ACTIONS(1320), 1,
      anon_sym_enumeration,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    STATE(669), 5,
      sym_properties,
      sym_methods,
      sym_events,
      sym_enumeration,
      aux_sym_class_definition_repeat1,
  [34966] = 7,
    ACTIONS(1295), 1,
      anon_sym_properties,
    ACTIONS(1297), 1,
      anon_sym_methods,
    ACTIONS(1299), 1,
      anon_sym_events,
    ACTIONS(1301), 1,
      anon_sym_enumeration,
    ACTIONS(1323), 1,
      anon_sym_end,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    STATE(669), 5,
      sym_properties,
      sym_methods,
      sym_events,
      sym_enumeration,
      aux_sym_class_definition_repeat1,
  [34993] = 7,
    ACTIONS(1295), 1,
      anon_sym_properties,
    ACTIONS(1297), 1,
      anon_sym_methods,
    ACTIONS(1299), 1,
      anon_sym_events,
    ACTIONS(1301), 1,
      anon_sym_enumeration,
    ACTIONS(1325), 1,
      anon_sym_end,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    STATE(669), 5,
      sym_properties,
      sym_methods,
      sym_events,
      sym_enumeration,
      aux_sym_class_definition_repeat1,
  [35020] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(435), 3,
      anon_sym_true,
      anon_sym_false,
      sym_identifier,
    ACTIONS(437), 7,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_DOT,
      anon_sym_TILDE,
      anon_sym_AT,
      anon_sym_RBRACK,
      anon_sym_LBRACE,
  [35039] = 7,
    ACTIONS(1295), 1,
      anon_sym_properties,
    ACTIONS(1297), 1,
      anon_sym_methods,
    ACTIONS(1299), 1,
      anon_sym_events,
    ACTIONS(1301), 1,
      anon_sym_enumeration,
    ACTIONS(1327), 1,
      anon_sym_end,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    STATE(669), 5,
      sym_properties,
      sym_methods,
      sym_events,
      sym_enumeration,
      aux_sym_class_definition_repeat1,
  [35066] = 9,
    ACTIONS(1110), 1,
      anon_sym_TILDE,
    ACTIONS(1209), 1,
      anon_sym_LPAREN,
    ACTIONS(1329), 1,
      sym_identifier,
    STATE(606), 1,
      sym_function_call,
    STATE(972), 1,
      sym_boolean,
    STATE(987), 1,
      sym_indirect_access,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(660), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(628), 2,
      sym_field_expression,
      sym_ignored_argument,
  [35097] = 7,
    ACTIONS(1295), 1,
      anon_sym_properties,
    ACTIONS(1297), 1,
      anon_sym_methods,
    ACTIONS(1299), 1,
      anon_sym_events,
    ACTIONS(1301), 1,
      anon_sym_enumeration,
    ACTIONS(1327), 1,
      anon_sym_end,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    STATE(671), 5,
      sym_properties,
      sym_methods,
      sym_events,
      sym_enumeration,
      aux_sym_class_definition_repeat1,
  [35124] = 7,
    ACTIONS(1295), 1,
      anon_sym_properties,
    ACTIONS(1297), 1,
      anon_sym_methods,
    ACTIONS(1299), 1,
      anon_sym_events,
    ACTIONS(1301), 1,
      anon_sym_enumeration,
    ACTIONS(1305), 1,
      anon_sym_end,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    STATE(670), 5,
      sym_properties,
      sym_methods,
      sym_events,
      sym_enumeration,
      aux_sym_class_definition_repeat1,
  [35151] = 5,
    ACTIONS(1331), 1,
      anon_sym_DOT,
    STATE(677), 1,
      aux_sym_field_expression_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(399), 3,
      anon_sym_true,
      anon_sym_false,
      sym_identifier,
    ACTIONS(404), 4,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_TILDE,
      anon_sym_RBRACK,
  [35173] = 7,
    ACTIONS(1133), 1,
      anon_sym_LBRACE,
    ACTIONS(1135), 1,
      anon_sym_EQ,
    STATE(740), 1,
      sym_validation_functions,
    STATE(824), 1,
      sym_default_value,
    STATE(1029), 1,
      sym__end_of_line,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1289), 4,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_CR,
  [35199] = 5,
    ACTIONS(1108), 1,
      anon_sym_DOT,
    STATE(677), 1,
      aux_sym_field_expression_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(389), 3,
      anon_sym_true,
      anon_sym_false,
      sym_identifier,
    ACTIONS(391), 4,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_TILDE,
      anon_sym_RBRACK,
  [35221] = 6,
    ACTIONS(1085), 1,
      anon_sym_AMP_AMP,
    ACTIONS(1087), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(1334), 1,
      anon_sym_RPAREN,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1081), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1083), 4,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
  [35245] = 6,
    ACTIONS(1085), 1,
      anon_sym_AMP_AMP,
    ACTIONS(1087), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(1336), 1,
      anon_sym_RPAREN,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1081), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1083), 4,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
  [35269] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1338), 9,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_AMP,
      anon_sym_LBRACE,
      anon_sym_EQ,
      sym_identifier,
      anon_sym_LF,
      anon_sym_CR,
  [35285] = 7,
    ACTIONS(1133), 1,
      anon_sym_LBRACE,
    ACTIONS(1135), 1,
      anon_sym_EQ,
    STATE(739), 1,
      sym_validation_functions,
    STATE(866), 1,
      sym_default_value,
    STATE(1019), 1,
      sym__end_of_line,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1249), 4,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_CR,
  [35311] = 6,
    ACTIONS(1085), 1,
      anon_sym_AMP_AMP,
    ACTIONS(1087), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(1340), 1,
      anon_sym_RPAREN,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1081), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1083), 4,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
  [35335] = 6,
    ACTIONS(603), 1,
      anon_sym_COMMA,
    ACTIONS(1085), 1,
      anon_sym_AMP_AMP,
    ACTIONS(1087), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1081), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1083), 4,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
  [35359] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1342), 9,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_AMP,
      anon_sym_LBRACE,
      anon_sym_EQ,
      sym_identifier,
      anon_sym_LF,
      anon_sym_CR,
  [35375] = 6,
    ACTIONS(1085), 1,
      anon_sym_AMP_AMP,
    ACTIONS(1087), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(1344), 1,
      anon_sym_RPAREN,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1081), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1083), 4,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
  [35399] = 4,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    STATE(688), 2,
      sym__end_of_line,
      aux_sym_elseif_clause_repeat1,
    ACTIONS(605), 3,
      anon_sym_end,
      anon_sym_case,
      anon_sym_otherwise,
    ACTIONS(1346), 4,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_CR,
  [35419] = 5,
    ACTIONS(1053), 1,
      anon_sym_AMP_AMP,
    ACTIONS(1055), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1049), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1051), 4,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
  [35440] = 5,
    ACTIONS(1351), 1,
      anon_sym_AMP_AMP,
    ACTIONS(1353), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1014), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1349), 4,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
  [35461] = 5,
    ACTIONS(1357), 1,
      anon_sym_AMP_AMP,
    ACTIONS(1359), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(475), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1355), 4,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
  [35482] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(622), 8,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_LBRACE,
      anon_sym_EQ,
      sym_identifier,
      anon_sym_LF,
      anon_sym_CR,
  [35497] = 6,
    ACTIONS(1363), 1,
      anon_sym_LPAREN,
    ACTIONS(1365), 1,
      anon_sym_EQ,
    STATE(32), 1,
      sym__end_of_line,
    STATE(812), 1,
      sym_function_arguments,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1361), 4,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_CR,
  [35520] = 6,
    ACTIONS(1363), 1,
      anon_sym_LPAREN,
    ACTIONS(1365), 1,
      anon_sym_EQ,
    STATE(26), 1,
      sym__end_of_line,
    STATE(875), 1,
      sym_function_arguments,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1367), 4,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_CR,
  [35543] = 6,
    ACTIONS(1363), 1,
      anon_sym_LPAREN,
    ACTIONS(1365), 1,
      anon_sym_EQ,
    STATE(788), 1,
      sym__end_of_line,
    STATE(818), 1,
      sym_function_arguments,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1369), 4,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_CR,
  [35566] = 5,
    ACTIONS(1373), 1,
      anon_sym_AMP_AMP,
    ACTIONS(1375), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(996), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1371), 4,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
  [35587] = 6,
    ACTIONS(1363), 1,
      anon_sym_LPAREN,
    ACTIONS(1365), 1,
      anon_sym_EQ,
    STATE(62), 1,
      sym__end_of_line,
    STATE(868), 1,
      sym_function_arguments,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1377), 4,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_CR,
  [35610] = 6,
    ACTIONS(1363), 1,
      anon_sym_LPAREN,
    ACTIONS(1365), 1,
      anon_sym_EQ,
    STATE(61), 1,
      sym__end_of_line,
    STATE(811), 1,
      sym_function_arguments,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1379), 4,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_CR,
  [35633] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(622), 3,
      anon_sym_true,
      anon_sym_false,
      sym_identifier,
    ACTIONS(630), 5,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_TILDE,
      anon_sym_RBRACK,
  [35650] = 5,
    ACTIONS(1085), 1,
      anon_sym_AMP_AMP,
    ACTIONS(1087), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1081), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1083), 4,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
  [35671] = 5,
    ACTIONS(1363), 1,
      anon_sym_LPAREN,
    STATE(29), 1,
      sym__end_of_line,
    STATE(883), 1,
      sym_function_arguments,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1381), 4,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_CR,
  [35691] = 5,
    ACTIONS(1363), 1,
      anon_sym_LPAREN,
    STATE(70), 1,
      sym__end_of_line,
    STATE(876), 1,
      sym_function_arguments,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1383), 4,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_CR,
  [35711] = 5,
    ACTIONS(1363), 1,
      anon_sym_LPAREN,
    STATE(55), 1,
      sym__end_of_line,
    STATE(849), 1,
      sym_function_arguments,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1385), 4,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_CR,
  [35731] = 5,
    ACTIONS(1389), 1,
      anon_sym_LPAREN,
    STATE(870), 1,
      sym_attributes,
    STATE(903), 1,
      sym__end_of_line,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1387), 4,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_CR,
  [35751] = 5,
    ACTIONS(1363), 1,
      anon_sym_LPAREN,
    STATE(21), 1,
      sym__end_of_line,
    STATE(841), 1,
      sym_function_arguments,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1391), 4,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_CR,
  [35771] = 6,
    ACTIONS(1393), 1,
      sym_identifier,
    ACTIONS(1395), 1,
      anon_sym_LPAREN,
    STATE(992), 1,
      sym_boolean,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(660), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(191), 2,
      sym_indirect_access,
      sym_function_call,
  [35793] = 6,
    ACTIONS(1397), 1,
      sym_identifier,
    ACTIONS(1399), 1,
      anon_sym_TILDE,
    ACTIONS(1401), 1,
      anon_sym_end,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    STATE(629), 2,
      sym_ignored_argument,
      sym_property_name,
    STATE(716), 2,
      sym_property,
      aux_sym_arguments_statement_repeat1,
  [35815] = 6,
    ACTIONS(1397), 1,
      sym_identifier,
    ACTIONS(1399), 1,
      anon_sym_TILDE,
    ACTIONS(1403), 1,
      anon_sym_end,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    STATE(629), 2,
      sym_ignored_argument,
      sym_property_name,
    STATE(720), 2,
      sym_property,
      aux_sym_arguments_statement_repeat1,
  [35837] = 6,
    ACTIONS(1397), 1,
      sym_identifier,
    ACTIONS(1399), 1,
      anon_sym_TILDE,
    ACTIONS(1405), 1,
      anon_sym_end,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    STATE(629), 2,
      sym_ignored_argument,
      sym_property_name,
    STATE(721), 2,
      sym_property,
      aux_sym_arguments_statement_repeat1,
  [35859] = 6,
    ACTIONS(1397), 1,
      sym_identifier,
    ACTIONS(1399), 1,
      anon_sym_TILDE,
    ACTIONS(1405), 1,
      anon_sym_end,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    STATE(629), 2,
      sym_ignored_argument,
      sym_property_name,
    STATE(720), 2,
      sym_property,
      aux_sym_arguments_statement_repeat1,
  [35881] = 6,
    ACTIONS(1407), 1,
      sym_identifier,
    ACTIONS(1409), 1,
      anon_sym_LPAREN,
    STATE(892), 1,
      sym_boolean,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(660), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(383), 2,
      sym_indirect_access,
      sym_function_call,
  [35903] = 4,
    ACTIONS(1411), 1,
      sym_identifier,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    STATE(12), 2,
      sym__end_of_line,
      aux_sym_elseif_clause_repeat1,
    ACTIONS(1413), 4,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_CR,
  [35921] = 6,
    ACTIONS(1397), 1,
      sym_identifier,
    ACTIONS(1399), 1,
      anon_sym_TILDE,
    ACTIONS(1415), 1,
      anon_sym_end,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    STATE(629), 2,
      sym_ignored_argument,
      sym_property_name,
    STATE(710), 2,
      sym_property,
      aux_sym_arguments_statement_repeat1,
  [35943] = 5,
    ACTIONS(1419), 1,
      anon_sym_LT,
    STATE(668), 1,
      sym__end_of_line,
    STATE(884), 1,
      sym_superclasses,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1417), 4,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_CR,
  [35963] = 6,
    ACTIONS(1397), 1,
      sym_identifier,
    ACTIONS(1399), 1,
      anon_sym_TILDE,
    ACTIONS(1421), 1,
      anon_sym_end,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    STATE(629), 2,
      sym_ignored_argument,
      sym_property_name,
    STATE(708), 2,
      sym_property,
      aux_sym_arguments_statement_repeat1,
  [35985] = 6,
    ACTIONS(1397), 1,
      sym_identifier,
    ACTIONS(1399), 1,
      anon_sym_TILDE,
    ACTIONS(1423), 1,
      anon_sym_end,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    STATE(629), 2,
      sym_ignored_argument,
      sym_property_name,
    STATE(720), 2,
      sym_property,
      aux_sym_arguments_statement_repeat1,
  [36007] = 7,
    ACTIONS(1209), 1,
      anon_sym_LPAREN,
    ACTIONS(1425), 1,
      sym_identifier,
    STATE(731), 1,
      sym_function_call,
    STATE(972), 1,
      sym_boolean,
    STATE(987), 1,
      sym_indirect_access,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(660), 2,
      anon_sym_true,
      anon_sym_false,
  [36031] = 5,
    ACTIONS(1135), 1,
      anon_sym_EQ,
    STATE(824), 1,
      sym_default_value,
    STATE(1029), 1,
      sym__end_of_line,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1289), 4,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_CR,
  [36051] = 4,
    ACTIONS(1131), 1,
      anon_sym_DOT,
    STATE(651), 1,
      aux_sym_handle_operator_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1427), 5,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_AMP,
      anon_sym_LF,
      anon_sym_CR,
  [36069] = 6,
    ACTIONS(1429), 1,
      sym_identifier,
    ACTIONS(1432), 1,
      anon_sym_TILDE,
    ACTIONS(1435), 1,
      anon_sym_end,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    STATE(629), 2,
      sym_ignored_argument,
      sym_property_name,
    STATE(720), 2,
      sym_property,
      aux_sym_arguments_statement_repeat1,
  [36091] = 6,
    ACTIONS(1397), 1,
      sym_identifier,
    ACTIONS(1399), 1,
      anon_sym_TILDE,
    ACTIONS(1437), 1,
      anon_sym_end,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    STATE(629), 2,
      sym_ignored_argument,
      sym_property_name,
    STATE(720), 2,
      sym_property,
      aux_sym_arguments_statement_repeat1,
  [36113] = 5,
    ACTIONS(1363), 1,
      anon_sym_LPAREN,
    STATE(780), 1,
      sym__end_of_line,
    STATE(831), 1,
      sym_function_arguments,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1439), 4,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_CR,
  [36133] = 6,
    ACTIONS(1209), 1,
      anon_sym_LPAREN,
    ACTIONS(1441), 1,
      sym_identifier,
    STATE(972), 1,
      sym_boolean,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(660), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(655), 2,
      sym_indirect_access,
      sym_function_call,
  [36155] = 6,
    ACTIONS(1443), 1,
      sym_identifier,
    ACTIONS(1445), 1,
      anon_sym_LPAREN,
    STATE(931), 1,
      sym_boolean,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(660), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(345), 2,
      sym_indirect_access,
      sym_function_call,
  [36177] = 5,
    ACTIONS(1363), 1,
      anon_sym_LPAREN,
    STATE(63), 1,
      sym__end_of_line,
    STATE(889), 1,
      sym_function_arguments,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1447), 4,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_CR,
  [36197] = 5,
    ACTIONS(1389), 1,
      anon_sym_LPAREN,
    STATE(871), 1,
      sym_attributes,
    STATE(1003), 1,
      sym__end_of_line,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1449), 4,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_CR,
  [36217] = 5,
    ACTIONS(1389), 1,
      anon_sym_LPAREN,
    STATE(659), 1,
      sym__end_of_line,
    STATE(863), 1,
      sym_attributes,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1451), 4,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_CR,
  [36237] = 5,
    ACTIONS(1389), 1,
      anon_sym_LPAREN,
    STATE(713), 1,
      sym__end_of_line,
    STATE(859), 1,
      sym_attributes,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1453), 4,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_CR,
  [36257] = 5,
    ACTIONS(1363), 1,
      anon_sym_LPAREN,
    STATE(39), 1,
      sym__end_of_line,
    STATE(806), 1,
      sym_function_arguments,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1455), 4,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_CR,
  [36277] = 5,
    ACTIONS(1363), 1,
      anon_sym_LPAREN,
    STATE(28), 1,
      sym__end_of_line,
    STATE(804), 1,
      sym_function_arguments,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1457), 4,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_CR,
  [36297] = 8,
    ACTIONS(1112), 1,
      anon_sym_AT,
    ACTIONS(1116), 1,
      anon_sym_LBRACE,
    ACTIONS(1241), 1,
      anon_sym_LPAREN,
    ACTIONS(1459), 1,
      anon_sym_COMMA,
    ACTIONS(1461), 1,
      anon_sym_RBRACE,
    STATE(647), 1,
      sym__args,
    STATE(1021), 1,
      aux_sym_validation_functions_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [36323] = 7,
    ACTIONS(1209), 1,
      anon_sym_LPAREN,
    ACTIONS(1463), 1,
      sym_identifier,
    STATE(745), 1,
      sym_function_call,
    STATE(972), 1,
      sym_boolean,
    STATE(987), 1,
      sym_indirect_access,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(660), 2,
      anon_sym_true,
      anon_sym_false,
  [36347] = 5,
    ACTIONS(1467), 1,
      anon_sym_LPAREN,
    STATE(715), 1,
      sym__end_of_line,
    STATE(843), 1,
      sym__argument_attributes,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1465), 4,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_CR,
  [36367] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1469), 7,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LBRACE,
      anon_sym_EQ,
      sym_identifier,
      anon_sym_LF,
      anon_sym_CR,
  [36381] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1471), 7,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LBRACE,
      anon_sym_EQ,
      sym_identifier,
      anon_sym_LF,
      anon_sym_CR,
  [36395] = 5,
    ACTIONS(1363), 1,
      anon_sym_LPAREN,
    STATE(756), 1,
      sym__end_of_line,
    STATE(872), 1,
      sym_function_arguments,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1473), 4,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_CR,
  [36415] = 5,
    ACTIONS(1419), 1,
      anon_sym_LT,
    STATE(664), 1,
      sym__end_of_line,
    STATE(810), 1,
      sym_superclasses,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1475), 4,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_CR,
  [36435] = 6,
    ACTIONS(1477), 1,
      sym_identifier,
    ACTIONS(1479), 1,
      anon_sym_LPAREN,
    STATE(960), 1,
      sym_boolean,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(660), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(84), 2,
      sym_indirect_access,
      sym_function_call,
  [36457] = 5,
    ACTIONS(1135), 1,
      anon_sym_EQ,
    STATE(809), 1,
      sym_default_value,
    STATE(1010), 1,
      sym__end_of_line,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1481), 4,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_CR,
  [36477] = 5,
    ACTIONS(1135), 1,
      anon_sym_EQ,
    STATE(866), 1,
      sym_default_value,
    STATE(1019), 1,
      sym__end_of_line,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1249), 4,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_CR,
  [36497] = 5,
    ACTIONS(1363), 1,
      anon_sym_LPAREN,
    STATE(67), 1,
      sym__end_of_line,
    STATE(882), 1,
      sym_function_arguments,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1483), 4,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_CR,
  [36517] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1243), 3,
      anon_sym_true,
      anon_sym_false,
      sym_identifier,
    ACTIONS(1202), 4,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_TILDE,
      anon_sym_RBRACK,
  [36533] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1485), 3,
      anon_sym_end,
      anon_sym_function,
      sym_identifier,
    ACTIONS(1487), 3,
      sym__multioutput_variable_start,
      anon_sym_get_DOT,
      anon_sym_set_DOT,
  [36548] = 6,
    ACTIONS(83), 1,
      anon_sym_else,
    ACTIONS(1489), 1,
      anon_sym_elseif,
    ACTIONS(1491), 1,
      anon_sym_end,
    STATE(1153), 1,
      sym_else_clause,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    STATE(823), 2,
      sym_elseif_clause,
      aux_sym_if_statement_repeat1,
  [36569] = 6,
    ACTIONS(1112), 1,
      anon_sym_AT,
    ACTIONS(1116), 1,
      anon_sym_LBRACE,
    ACTIONS(1241), 1,
      anon_sym_LPAREN,
    STATE(647), 1,
      sym__args,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1493), 2,
      anon_sym_COMMA,
      anon_sym_RBRACE,
  [36590] = 6,
    ACTIONS(55), 1,
      sym__multioutput_variable_start,
    ACTIONS(1495), 1,
      sym_identifier,
    STATE(1047), 1,
      sym_function_output,
    STATE(1146), 1,
      sym_multioutput_variable,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1497), 2,
      anon_sym_get_DOT,
      anon_sym_set_DOT,
  [36611] = 4,
    ACTIONS(1501), 1,
      sym_command_argument,
    STATE(767), 1,
      aux_sym_command_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1499), 4,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_CR,
  [36628] = 6,
    ACTIONS(55), 1,
      sym__multioutput_variable_start,
    ACTIONS(1503), 1,
      sym_identifier,
    STATE(1004), 1,
      sym_function_output,
    STATE(1146), 1,
      sym_multioutput_variable,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1505), 2,
      anon_sym_get_DOT,
      anon_sym_set_DOT,
  [36649] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1507), 3,
      anon_sym_end,
      anon_sym_function,
      sym_identifier,
    ACTIONS(1509), 3,
      sym__multioutput_variable_start,
      anon_sym_get_DOT,
      anon_sym_set_DOT,
  [36664] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    STATE(11), 2,
      sym__end_of_line,
      aux_sym_elseif_clause_repeat1,
    ACTIONS(1511), 4,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_CR,
  [36679] = 4,
    ACTIONS(163), 1,
      ts_builtin_sym_end,
    ACTIONS(1515), 1,
      anon_sym_function,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1513), 4,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_CR,
  [36696] = 4,
    ACTIONS(1517), 1,
      ts_builtin_sym_end,
    ACTIONS(1521), 1,
      anon_sym_function,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1519), 4,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_CR,
  [36713] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1523), 3,
      anon_sym_end,
      anon_sym_function,
      sym_identifier,
    ACTIONS(1525), 3,
      sym__multioutput_variable_start,
      anon_sym_get_DOT,
      anon_sym_set_DOT,
  [36728] = 4,
    ACTIONS(206), 1,
      ts_builtin_sym_end,
    ACTIONS(1529), 1,
      anon_sym_function,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1527), 4,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_CR,
  [36745] = 4,
    ACTIONS(1533), 1,
      anon_sym_AMP,
    STATE(755), 1,
      aux_sym_superclasses_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1531), 4,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_CR,
  [36762] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1536), 3,
      anon_sym_end,
      anon_sym_function,
      sym_identifier,
    ACTIONS(1538), 3,
      sym__multioutput_variable_start,
      anon_sym_get_DOT,
      anon_sym_set_DOT,
  [36777] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1513), 3,
      anon_sym_end,
      anon_sym_function,
      sym_identifier,
    ACTIONS(1540), 3,
      sym__multioutput_variable_start,
      anon_sym_get_DOT,
      anon_sym_set_DOT,
  [36792] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1519), 3,
      anon_sym_end,
      anon_sym_function,
      sym_identifier,
    ACTIONS(1542), 3,
      sym__multioutput_variable_start,
      anon_sym_get_DOT,
      anon_sym_set_DOT,
  [36807] = 4,
    ACTIONS(1544), 1,
      ts_builtin_sym_end,
    ACTIONS(1548), 1,
      anon_sym_function,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1546), 4,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_CR,
  [36824] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1527), 3,
      anon_sym_end,
      anon_sym_function,
      sym_identifier,
    ACTIONS(1550), 3,
      sym__multioutput_variable_start,
      anon_sym_get_DOT,
      anon_sym_set_DOT,
  [36839] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1552), 3,
      anon_sym_end,
      anon_sym_function,
      sym_identifier,
    ACTIONS(1554), 3,
      sym__multioutput_variable_start,
      anon_sym_get_DOT,
      anon_sym_set_DOT,
  [36854] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1556), 3,
      anon_sym_end,
      anon_sym_function,
      sym_identifier,
    ACTIONS(1558), 3,
      sym__multioutput_variable_start,
      anon_sym_get_DOT,
      anon_sym_set_DOT,
  [36869] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1560), 3,
      anon_sym_end,
      anon_sym_function,
      sym_identifier,
    ACTIONS(1562), 3,
      sym__multioutput_variable_start,
      anon_sym_get_DOT,
      anon_sym_set_DOT,
  [36884] = 4,
    ACTIONS(1566), 1,
      anon_sym_AMP,
    STATE(755), 1,
      aux_sym_superclasses_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1564), 4,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_CR,
  [36901] = 6,
    ACTIONS(55), 1,
      sym__multioutput_variable_start,
    ACTIONS(1568), 1,
      sym_identifier,
    STATE(1020), 1,
      sym_function_output,
    STATE(1146), 1,
      sym_multioutput_variable,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1570), 2,
      anon_sym_get_DOT,
      anon_sym_set_DOT,
  [36922] = 6,
    ACTIONS(55), 1,
      sym__multioutput_variable_start,
    ACTIONS(1572), 1,
      sym_identifier,
    STATE(1017), 1,
      sym_function_output,
    STATE(1146), 1,
      sym_multioutput_variable,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1574), 2,
      anon_sym_get_DOT,
      anon_sym_set_DOT,
  [36943] = 4,
    ACTIONS(1578), 1,
      sym_command_argument,
    STATE(769), 1,
      aux_sym_command_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1576), 4,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_CR,
  [36960] = 5,
    ACTIONS(618), 1,
      aux_sym_matrix_token1,
    ACTIONS(1580), 1,
      sym__entry_delimiter,
    STATE(772), 1,
      aux_sym_row_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(616), 3,
      anon_sym_SEMI,
      anon_sym_RBRACK,
      anon_sym_RBRACE,
  [36979] = 4,
    ACTIONS(1584), 1,
      sym_command_argument,
    STATE(769), 1,
      aux_sym_command_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1582), 4,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_CR,
  [36996] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1587), 3,
      anon_sym_end,
      anon_sym_function,
      sym_identifier,
    ACTIONS(1589), 3,
      sym__multioutput_variable_start,
      anon_sym_get_DOT,
      anon_sym_set_DOT,
  [37011] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1591), 3,
      anon_sym_end,
      anon_sym_function,
      sym_identifier,
    ACTIONS(1593), 3,
      sym__multioutput_variable_start,
      anon_sym_get_DOT,
      anon_sym_set_DOT,
  [37026] = 5,
    ACTIONS(1188), 1,
      aux_sym_matrix_token1,
    ACTIONS(1595), 1,
      sym__entry_delimiter,
    STATE(772), 1,
      aux_sym_row_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1186), 3,
      anon_sym_SEMI,
      anon_sym_RBRACK,
      anon_sym_RBRACE,
  [37045] = 4,
    ACTIONS(179), 1,
      ts_builtin_sym_end,
    ACTIONS(1598), 1,
      anon_sym_function,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1523), 4,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_CR,
  [37062] = 4,
    ACTIONS(156), 1,
      ts_builtin_sym_end,
    ACTIONS(1600), 1,
      anon_sym_function,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1507), 4,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_CR,
  [37079] = 6,
    ACTIONS(83), 1,
      anon_sym_else,
    ACTIONS(1489), 1,
      anon_sym_elseif,
    ACTIONS(1602), 1,
      anon_sym_end,
    STATE(1204), 1,
      sym_else_clause,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    STATE(823), 2,
      sym_elseif_clause,
      aux_sym_if_statement_repeat1,
  [37100] = 4,
    ACTIONS(1604), 1,
      ts_builtin_sym_end,
    ACTIONS(1606), 1,
      anon_sym_function,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1552), 4,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_CR,
  [37117] = 4,
    ACTIONS(1608), 1,
      ts_builtin_sym_end,
    ACTIONS(1610), 1,
      anon_sym_function,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1560), 4,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_CR,
  [37134] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1612), 3,
      anon_sym_end,
      anon_sym_function,
      sym_identifier,
    ACTIONS(1614), 3,
      sym__multioutput_variable_start,
      anon_sym_get_DOT,
      anon_sym_set_DOT,
  [37149] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1616), 3,
      anon_sym_end,
      anon_sym_function,
      sym_identifier,
    ACTIONS(1618), 3,
      sym__multioutput_variable_start,
      anon_sym_get_DOT,
      anon_sym_set_DOT,
  [37164] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1620), 3,
      anon_sym_end,
      anon_sym_function,
      sym_identifier,
    ACTIONS(1622), 3,
      sym__multioutput_variable_start,
      anon_sym_get_DOT,
      anon_sym_set_DOT,
  [37179] = 5,
    ACTIONS(614), 1,
      aux_sym_matrix_token1,
    ACTIONS(1170), 1,
      sym__entry_delimiter,
    STATE(768), 1,
      aux_sym_row_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(612), 3,
      anon_sym_SEMI,
      anon_sym_RBRACK,
      anon_sym_RBRACE,
  [37198] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1546), 3,
      anon_sym_end,
      anon_sym_function,
      sym_identifier,
    ACTIONS(1624), 3,
      sym__multioutput_variable_start,
      anon_sym_get_DOT,
      anon_sym_set_DOT,
  [37213] = 4,
    ACTIONS(1626), 1,
      sym_identifier,
    STATE(792), 1,
      aux_sym_global_operator_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1628), 4,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_CR,
  [37230] = 6,
    ACTIONS(83), 1,
      anon_sym_else,
    ACTIONS(1489), 1,
      anon_sym_elseif,
    ACTIONS(1602), 1,
      anon_sym_end,
    STATE(1204), 1,
      sym_else_clause,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    STATE(787), 2,
      sym_elseif_clause,
      aux_sym_if_statement_repeat1,
  [37251] = 4,
    ACTIONS(1630), 1,
      ts_builtin_sym_end,
    ACTIONS(1632), 1,
      anon_sym_function,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1612), 4,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_CR,
  [37268] = 4,
    ACTIONS(215), 1,
      ts_builtin_sym_end,
    ACTIONS(1634), 1,
      anon_sym_function,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1587), 4,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_CR,
  [37285] = 6,
    ACTIONS(83), 1,
      anon_sym_else,
    ACTIONS(1489), 1,
      anon_sym_elseif,
    ACTIONS(1636), 1,
      anon_sym_end,
    STATE(1173), 1,
      sym_else_clause,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    STATE(823), 2,
      sym_elseif_clause,
      aux_sym_if_statement_repeat1,
  [37306] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1638), 3,
      anon_sym_end,
      anon_sym_function,
      sym_identifier,
    ACTIONS(1640), 3,
      sym__multioutput_variable_start,
      anon_sym_get_DOT,
      anon_sym_set_DOT,
  [37321] = 4,
    ACTIONS(1642), 1,
      sym_identifier,
    STATE(799), 1,
      aux_sym_global_operator_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1644), 4,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_CR,
  [37338] = 5,
    ACTIONS(614), 1,
      aux_sym_matrix_token1,
    ACTIONS(1170), 1,
      sym__entry_delimiter,
    STATE(772), 1,
      aux_sym_row_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(612), 3,
      anon_sym_SEMI,
      anon_sym_RBRACK,
      anon_sym_RBRACE,
  [37357] = 4,
    ACTIONS(1646), 1,
      ts_builtin_sym_end,
    ACTIONS(1648), 1,
      anon_sym_function,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1591), 4,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_CR,
  [37374] = 4,
    ACTIONS(1650), 1,
      sym_identifier,
    STATE(792), 1,
      aux_sym_global_operator_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1653), 4,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_CR,
  [37391] = 4,
    ACTIONS(195), 1,
      ts_builtin_sym_end,
    ACTIONS(1657), 1,
      anon_sym_function,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1655), 4,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_CR,
  [37408] = 6,
    ACTIONS(1659), 1,
      anon_sym_end,
    ACTIONS(1661), 1,
      anon_sym_case,
    ACTIONS(1663), 1,
      anon_sym_otherwise,
    STATE(1193), 1,
      sym_otherwise_clause,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    STATE(805), 2,
      sym_case_clause,
      aux_sym_switch_statement_repeat1,
  [37429] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1655), 3,
      anon_sym_end,
      anon_sym_function,
      sym_identifier,
    ACTIONS(1665), 3,
      sym__multioutput_variable_start,
      anon_sym_get_DOT,
      anon_sym_set_DOT,
  [37444] = 5,
    ACTIONS(1156), 1,
      aux_sym_matrix_token1,
    ACTIONS(1158), 1,
      sym__entry_delimiter,
    STATE(790), 1,
      aux_sym_row_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1154), 3,
      anon_sym_SEMI,
      anon_sym_RBRACK,
      anon_sym_RBRACE,
  [37463] = 4,
    ACTIONS(1667), 1,
      sym_identifier,
    STATE(783), 1,
      aux_sym_global_operator_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1669), 4,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_CR,
  [37480] = 4,
    ACTIONS(1566), 1,
      anon_sym_AMP,
    STATE(764), 1,
      aux_sym_superclasses_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1671), 4,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_CR,
  [37497] = 4,
    ACTIONS(1626), 1,
      sym_identifier,
    STATE(792), 1,
      aux_sym_global_operator_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1673), 4,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_CR,
  [37514] = 6,
    ACTIONS(83), 1,
      anon_sym_else,
    ACTIONS(1489), 1,
      anon_sym_elseif,
    ACTIONS(1491), 1,
      anon_sym_end,
    STATE(1153), 1,
      sym_else_clause,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    STATE(775), 2,
      sym_elseif_clause,
      aux_sym_if_statement_repeat1,
  [37535] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1675), 3,
      anon_sym_end,
      anon_sym_function,
      sym_identifier,
    ACTIONS(1677), 3,
      sym__multioutput_variable_start,
      anon_sym_get_DOT,
      anon_sym_set_DOT,
  [37550] = 6,
    ACTIONS(1661), 1,
      anon_sym_case,
    ACTIONS(1663), 1,
      anon_sym_otherwise,
    ACTIONS(1679), 1,
      anon_sym_end,
    STATE(1188), 1,
      sym_otherwise_clause,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    STATE(805), 2,
      sym_case_clause,
      aux_sym_switch_statement_repeat1,
  [37571] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1681), 5,
      anon_sym_end,
      anon_sym_properties,
      anon_sym_methods,
      anon_sym_events,
      anon_sym_enumeration,
  [37583] = 3,
    STATE(34), 1,
      sym__end_of_line,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1683), 4,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_CR,
  [37597] = 4,
    ACTIONS(1687), 1,
      anon_sym_case,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1685), 2,
      anon_sym_end,
      anon_sym_otherwise,
    STATE(805), 2,
      sym_case_clause,
      aux_sym_switch_statement_repeat1,
  [37613] = 3,
    STATE(24), 1,
      sym__end_of_line,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1690), 4,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_CR,
  [37627] = 6,
    ACTIONS(1110), 1,
      anon_sym_TILDE,
    ACTIONS(1692), 1,
      sym_identifier,
    ACTIONS(1694), 1,
      anon_sym_RPAREN,
    STATE(1013), 1,
      sym_ignored_argument,
    STATE(1147), 1,
      sym__lambda_arguments,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [37647] = 6,
    ACTIONS(1110), 1,
      anon_sym_TILDE,
    ACTIONS(1692), 1,
      sym_identifier,
    ACTIONS(1696), 1,
      anon_sym_RPAREN,
    STATE(1013), 1,
      sym_ignored_argument,
    STATE(1195), 1,
      sym__lambda_arguments,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [37667] = 3,
    STATE(1007), 1,
      sym__end_of_line,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1698), 4,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_CR,
  [37681] = 3,
    STATE(675), 1,
      sym__end_of_line,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1700), 4,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_CR,
  [37695] = 3,
    STATE(64), 1,
      sym__end_of_line,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1702), 4,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_CR,
  [37709] = 3,
    STATE(30), 1,
      sym__end_of_line,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1704), 4,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_CR,
  [37723] = 6,
    ACTIONS(1110), 1,
      anon_sym_TILDE,
    ACTIONS(1692), 1,
      sym_identifier,
    ACTIONS(1706), 1,
      anon_sym_RPAREN,
    STATE(1013), 1,
      sym_ignored_argument,
    STATE(1158), 1,
      sym__lambda_arguments,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [37743] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1708), 5,
      anon_sym_end,
      anon_sym_properties,
      anon_sym_methods,
      anon_sym_events,
      anon_sym_enumeration,
  [37755] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1710), 5,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_EQ,
      anon_sym_LF,
      anon_sym_CR,
  [37767] = 6,
    ACTIONS(1110), 1,
      anon_sym_TILDE,
    ACTIONS(1692), 1,
      sym_identifier,
    ACTIONS(1712), 1,
      anon_sym_RPAREN,
    STATE(1013), 1,
      sym_ignored_argument,
    STATE(1139), 1,
      sym__lambda_arguments,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [37787] = 3,
    STATE(179), 1,
      sym__end_of_line,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1207), 4,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_CR,
  [37801] = 3,
    STATE(779), 1,
      sym__end_of_line,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1714), 4,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_CR,
  [37815] = 6,
    ACTIONS(1110), 1,
      anon_sym_TILDE,
    ACTIONS(1692), 1,
      sym_identifier,
    ACTIONS(1716), 1,
      anon_sym_RPAREN,
    STATE(1013), 1,
      sym_ignored_argument,
    STATE(1198), 1,
      sym__lambda_arguments,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [37835] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1718), 5,
      anon_sym_end,
      anon_sym_properties,
      anon_sym_methods,
      anon_sym_events,
      anon_sym_enumeration,
  [37847] = 6,
    ACTIONS(1110), 1,
      anon_sym_TILDE,
    ACTIONS(1692), 1,
      sym_identifier,
    ACTIONS(1720), 1,
      anon_sym_RPAREN,
    STATE(1013), 1,
      sym_ignored_argument,
    STATE(1201), 1,
      sym__lambda_arguments,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [37867] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1722), 5,
      anon_sym_end,
      anon_sym_properties,
      anon_sym_methods,
      anon_sym_events,
      anon_sym_enumeration,
  [37879] = 5,
    ACTIONS(1724), 1,
      anon_sym_elseif,
    ACTIONS(1727), 1,
      anon_sym_else,
    ACTIONS(1729), 1,
      anon_sym_end,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    STATE(823), 2,
      sym_elseif_clause,
      aux_sym_if_statement_repeat1,
  [37897] = 3,
    STATE(1019), 1,
      sym__end_of_line,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1249), 4,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_CR,
  [37911] = 4,
    ACTIONS(1731), 1,
      sym__double_quote_string_end,
    STATE(839), 1,
      aux_sym_string_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1733), 3,
      sym_formatting_sequence,
      sym_escape_sequence,
      sym_string_content,
  [37927] = 6,
    ACTIONS(1110), 1,
      anon_sym_TILDE,
    ACTIONS(1692), 1,
      sym_identifier,
    ACTIONS(1735), 1,
      anon_sym_RPAREN,
    STATE(1013), 1,
      sym_ignored_argument,
    STATE(1156), 1,
      sym__lambda_arguments,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [37947] = 3,
    STATE(1029), 1,
      sym__end_of_line,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1289), 4,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_CR,
  [37961] = 6,
    ACTIONS(1110), 1,
      anon_sym_TILDE,
    ACTIONS(1692), 1,
      sym_identifier,
    ACTIONS(1737), 1,
      anon_sym_RPAREN,
    STATE(1013), 1,
      sym_ignored_argument,
    STATE(1208), 1,
      sym__lambda_arguments,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [37981] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1739), 5,
      anon_sym_end,
      anon_sym_properties,
      anon_sym_methods,
      anon_sym_events,
      anon_sym_enumeration,
  [37993] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1741), 5,
      anon_sym_end,
      anon_sym_properties,
      anon_sym_methods,
      anon_sym_events,
      anon_sym_enumeration,
  [38005] = 3,
    STATE(743), 1,
      sym__end_of_line,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1743), 4,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_CR,
  [38019] = 6,
    ACTIONS(1112), 1,
      anon_sym_AT,
    ACTIONS(1116), 1,
      anon_sym_LBRACE,
    ACTIONS(1241), 1,
      anon_sym_LPAREN,
    ACTIONS(1745), 1,
      anon_sym_RPAREN,
    STATE(647), 1,
      sym__args,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [38039] = 4,
    ACTIONS(1747), 1,
      sym__single_quote_string_end,
    STATE(886), 1,
      aux_sym_string_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1749), 3,
      sym_formatting_sequence,
      sym_escape_sequence,
      sym_string_content,
  [38055] = 4,
    ACTIONS(1751), 1,
      sym__double_quote_string_end,
    STATE(887), 1,
      aux_sym_string_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1753), 3,
      sym_formatting_sequence,
      sym_escape_sequence,
      sym_string_content,
  [38071] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1755), 5,
      anon_sym_end,
      anon_sym_properties,
      anon_sym_methods,
      anon_sym_events,
      anon_sym_enumeration,
  [38083] = 4,
    ACTIONS(1747), 1,
      sym__double_quote_string_end,
    STATE(885), 1,
      aux_sym_string_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1757), 3,
      sym_formatting_sequence,
      sym_escape_sequence,
      sym_string_content,
  [38099] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1759), 5,
      anon_sym_end,
      anon_sym_properties,
      anon_sym_methods,
      anon_sym_events,
      anon_sym_enumeration,
  [38111] = 4,
    ACTIONS(1751), 1,
      sym__single_quote_string_end,
    STATE(842), 1,
      aux_sym_string_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1761), 3,
      sym_formatting_sequence,
      sym_escape_sequence,
      sym_string_content,
  [38127] = 4,
    ACTIONS(1763), 1,
      sym__double_quote_string_end,
    STATE(887), 1,
      aux_sym_string_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1753), 3,
      sym_formatting_sequence,
      sym_escape_sequence,
      sym_string_content,
  [38143] = 6,
    ACTIONS(1110), 1,
      anon_sym_TILDE,
    ACTIONS(1692), 1,
      sym_identifier,
    ACTIONS(1765), 1,
      anon_sym_RPAREN,
    STATE(1013), 1,
      sym_ignored_argument,
    STATE(1161), 1,
      sym__lambda_arguments,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [38163] = 3,
    STATE(40), 1,
      sym__end_of_line,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1767), 4,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_CR,
  [38177] = 4,
    ACTIONS(1769), 1,
      sym__single_quote_string_end,
    STATE(842), 1,
      aux_sym_string_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1771), 3,
      sym_formatting_sequence,
      sym_escape_sequence,
      sym_string_content,
  [38193] = 3,
    STATE(707), 1,
      sym__end_of_line,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1774), 4,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_CR,
  [38207] = 5,
    ACTIONS(1776), 1,
      anon_sym_SEMI,
    ACTIONS(1779), 1,
      aux_sym_matrix_token1,
    STATE(844), 1,
      aux_sym_matrix_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1782), 2,
      anon_sym_RBRACK,
      anon_sym_RBRACE,
  [38225] = 4,
    ACTIONS(1763), 1,
      sym__single_quote_string_end,
    STATE(842), 1,
      aux_sym_string_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1761), 3,
      sym_formatting_sequence,
      sym_escape_sequence,
      sym_string_content,
  [38241] = 6,
    ACTIONS(1110), 1,
      anon_sym_TILDE,
    ACTIONS(1692), 1,
      sym_identifier,
    ACTIONS(1784), 1,
      anon_sym_RPAREN,
    STATE(1013), 1,
      sym_ignored_argument,
    STATE(1202), 1,
      sym__lambda_arguments,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [38261] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1188), 2,
      sym__entry_delimiter,
      aux_sym_matrix_token1,
    ACTIONS(1186), 3,
      anon_sym_SEMI,
      anon_sym_RBRACK,
      anon_sym_RBRACE,
  [38275] = 4,
    ACTIONS(1786), 1,
      sym__double_quote_string_end,
    STATE(834), 1,
      aux_sym_string_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1788), 3,
      sym_formatting_sequence,
      sym_escape_sequence,
      sym_string_content,
  [38291] = 3,
    STATE(57), 1,
      sym__end_of_line,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1790), 4,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_CR,
  [38305] = 4,
    ACTIONS(1786), 1,
      sym__single_quote_string_end,
    STATE(838), 1,
      aux_sym_string_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1792), 3,
      sym_formatting_sequence,
      sym_escape_sequence,
      sym_string_content,
  [38321] = 6,
    ACTIONS(1110), 1,
      anon_sym_TILDE,
    ACTIONS(1692), 1,
      sym_identifier,
    ACTIONS(1794), 1,
      anon_sym_RPAREN,
    STATE(1013), 1,
      sym_ignored_argument,
    STATE(1194), 1,
      sym__lambda_arguments,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [38341] = 6,
    ACTIONS(1110), 1,
      anon_sym_TILDE,
    ACTIONS(1692), 1,
      sym_identifier,
    ACTIONS(1796), 1,
      anon_sym_RPAREN,
    STATE(1013), 1,
      sym_ignored_argument,
    STATE(1166), 1,
      sym__lambda_arguments,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [38361] = 3,
    STATE(240), 1,
      sym__end_of_line,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1215), 4,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_CR,
  [38375] = 4,
    ACTIONS(1798), 1,
      sym__single_quote_string_end,
    STATE(878), 1,
      aux_sym_string_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1800), 3,
      sym_formatting_sequence,
      sym_escape_sequence,
      sym_string_content,
  [38391] = 4,
    ACTIONS(1798), 1,
      sym__double_quote_string_end,
    STATE(880), 1,
      aux_sym_string_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1802), 3,
      sym_formatting_sequence,
      sym_escape_sequence,
      sym_string_content,
  [38407] = 3,
    STATE(1131), 1,
      sym__end_of_line,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1804), 4,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_CR,
  [38421] = 3,
    ACTIONS(1808), 1,
      anon_sym_LPAREN,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1806), 4,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_CR,
  [38435] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1810), 5,
      anon_sym_end,
      anon_sym_properties,
      anon_sym_methods,
      anon_sym_events,
      anon_sym_enumeration,
  [38447] = 3,
    STATE(709), 1,
      sym__end_of_line,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1812), 4,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_CR,
  [38461] = 3,
    STATE(168), 1,
      sym__end_of_line,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1814), 4,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_CR,
  [38475] = 3,
    STATE(1126), 1,
      sym__end_of_line,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1816), 4,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_CR,
  [38489] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1818), 5,
      anon_sym_end,
      anon_sym_properties,
      anon_sym_methods,
      anon_sym_events,
      anon_sym_enumeration,
  [38501] = 3,
    STATE(660), 1,
      sym__end_of_line,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1820), 4,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_CR,
  [38515] = 6,
    ACTIONS(1110), 1,
      anon_sym_TILDE,
    ACTIONS(1692), 1,
      sym_identifier,
    ACTIONS(1822), 1,
      anon_sym_RPAREN,
    STATE(1013), 1,
      sym_ignored_argument,
    STATE(1180), 1,
      sym__lambda_arguments,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [38535] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1824), 5,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_EQ,
      anon_sym_LF,
      anon_sym_CR,
  [38547] = 3,
    STATE(1010), 1,
      sym__end_of_line,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1481), 4,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_CR,
  [38561] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1826), 5,
      anon_sym_end,
      anon_sym_properties,
      anon_sym_methods,
      anon_sym_events,
      anon_sym_enumeration,
  [38573] = 3,
    STATE(60), 1,
      sym__end_of_line,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1828), 4,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_CR,
  [38587] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1830), 5,
      anon_sym_end,
      anon_sym_properties,
      anon_sym_methods,
      anon_sym_events,
      anon_sym_enumeration,
  [38599] = 3,
    STATE(911), 1,
      sym__end_of_line,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1832), 4,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_CR,
  [38613] = 3,
    STATE(1059), 1,
      sym__end_of_line,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1834), 4,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_CR,
  [38627] = 3,
    STATE(801), 1,
      sym__end_of_line,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1836), 4,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_CR,
  [38641] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1531), 5,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_AMP,
      anon_sym_LF,
      anon_sym_CR,
  [38653] = 3,
    STATE(179), 1,
      sym__end_of_line,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1207), 4,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_CR,
  [38667] = 3,
    STATE(38), 1,
      sym__end_of_line,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1838), 4,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_CR,
  [38681] = 3,
    STATE(68), 1,
      sym__end_of_line,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1840), 4,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_CR,
  [38695] = 3,
    STATE(168), 1,
      sym__end_of_line,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1814), 4,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_CR,
  [38709] = 4,
    ACTIONS(1842), 1,
      sym__single_quote_string_end,
    STATE(842), 1,
      aux_sym_string_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1761), 3,
      sym_formatting_sequence,
      sym_escape_sequence,
      sym_string_content,
  [38725] = 6,
    ACTIONS(1110), 1,
      anon_sym_TILDE,
    ACTIONS(1692), 1,
      sym_identifier,
    ACTIONS(1844), 1,
      anon_sym_RPAREN,
    STATE(1013), 1,
      sym_ignored_argument,
    STATE(1171), 1,
      sym__lambda_arguments,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [38745] = 4,
    ACTIONS(1842), 1,
      sym__double_quote_string_end,
    STATE(887), 1,
      aux_sym_string_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1753), 3,
      sym_formatting_sequence,
      sym_escape_sequence,
      sym_string_content,
  [38761] = 4,
    ACTIONS(1731), 1,
      sym__single_quote_string_end,
    STATE(845), 1,
      aux_sym_string_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1846), 3,
      sym_formatting_sequence,
      sym_escape_sequence,
      sym_string_content,
  [38777] = 3,
    STATE(49), 1,
      sym__end_of_line,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1848), 4,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_CR,
  [38791] = 3,
    STATE(43), 1,
      sym__end_of_line,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1850), 4,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_CR,
  [38805] = 3,
    STATE(676), 1,
      sym__end_of_line,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1852), 4,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_CR,
  [38819] = 4,
    ACTIONS(1854), 1,
      sym__double_quote_string_end,
    STATE(887), 1,
      aux_sym_string_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1753), 3,
      sym_formatting_sequence,
      sym_escape_sequence,
      sym_string_content,
  [38835] = 4,
    ACTIONS(1854), 1,
      sym__single_quote_string_end,
    STATE(842), 1,
      aux_sym_string_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1761), 3,
      sym_formatting_sequence,
      sym_escape_sequence,
      sym_string_content,
  [38851] = 4,
    ACTIONS(1769), 1,
      sym__double_quote_string_end,
    STATE(887), 1,
      aux_sym_string_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1856), 3,
      sym_formatting_sequence,
      sym_escape_sequence,
      sym_string_content,
  [38867] = 3,
    STATE(227), 1,
      sym__end_of_line,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1859), 4,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_CR,
  [38881] = 3,
    STATE(46), 1,
      sym__end_of_line,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1861), 4,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_CR,
  [38895] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1523), 4,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_CR,
  [38906] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1863), 4,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_CR,
  [38917] = 5,
    ACTIONS(822), 1,
      anon_sym_LPAREN,
    ACTIONS(830), 1,
      anon_sym_LBRACE,
    ACTIONS(986), 1,
      anon_sym_AT,
    STATE(445), 1,
      sym__args,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [38934] = 5,
    ACTIONS(1865), 1,
      anon_sym_SEMI,
    ACTIONS(1867), 1,
      aux_sym_matrix_token1,
    ACTIONS(1869), 1,
      anon_sym_RBRACK,
    STATE(908), 1,
      aux_sym_matrix_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [38951] = 4,
    ACTIONS(1871), 1,
      anon_sym_COMMA,
    STATE(894), 1,
      aux_sym_arguments_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1874), 2,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
  [38966] = 4,
    ACTIONS(1876), 1,
      anon_sym_end,
    ACTIONS(1878), 1,
      anon_sym_endfunction,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1517), 2,
      ts_builtin_sym_end,
      anon_sym_function,
  [38981] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1880), 4,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_CR,
  [38992] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1882), 4,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_CR,
  [39003] = 4,
    ACTIONS(208), 1,
      anon_sym_end,
    ACTIONS(1884), 1,
      anon_sym_endfunction,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(206), 2,
      ts_builtin_sym_end,
      anon_sym_function,
  [39018] = 4,
    ACTIONS(204), 1,
      anon_sym_end,
    ACTIONS(1886), 1,
      anon_sym_endfunction,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(163), 2,
      ts_builtin_sym_end,
      anon_sym_function,
  [39033] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1655), 4,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_CR,
  [39044] = 4,
    ACTIONS(197), 1,
      anon_sym_end,
    ACTIONS(1888), 1,
      anon_sym_endfunction,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(195), 2,
      ts_builtin_sym_end,
      anon_sym_function,
  [39059] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1890), 4,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_CR,
  [39070] = 5,
    ACTIONS(1892), 1,
      sym_identifier,
    ACTIONS(1894), 1,
      anon_sym_end,
    STATE(856), 1,
      sym_enum,
    STATE(912), 1,
      aux_sym_enumeration_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [39087] = 5,
    ACTIONS(1865), 1,
      anon_sym_SEMI,
    ACTIONS(1867), 1,
      aux_sym_matrix_token1,
    ACTIONS(1896), 1,
      anon_sym_RBRACE,
    STATE(909), 1,
      aux_sym_matrix_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [39104] = 5,
    ACTIONS(822), 1,
      anon_sym_LPAREN,
    ACTIONS(826), 1,
      anon_sym_AT,
    ACTIONS(830), 1,
      anon_sym_LBRACE,
    STATE(437), 1,
      sym__args,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [39121] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1898), 4,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_CR,
  [39132] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1900), 4,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_CR,
  [39143] = 5,
    ACTIONS(1865), 1,
      anon_sym_SEMI,
    ACTIONS(1867), 1,
      aux_sym_matrix_token1,
    ACTIONS(1902), 1,
      anon_sym_RBRACK,
    STATE(844), 1,
      aux_sym_matrix_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [39160] = 5,
    ACTIONS(1865), 1,
      anon_sym_SEMI,
    ACTIONS(1867), 1,
      aux_sym_matrix_token1,
    ACTIONS(1904), 1,
      anon_sym_RBRACE,
    STATE(844), 1,
      aux_sym_matrix_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [39177] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1906), 4,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_CR,
  [39188] = 5,
    ACTIONS(1892), 1,
      sym_identifier,
    ACTIONS(1908), 1,
      anon_sym_end,
    STATE(856), 1,
      sym_enum,
    STATE(942), 1,
      aux_sym_enumeration_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [39205] = 5,
    ACTIONS(1892), 1,
      sym_identifier,
    ACTIONS(1908), 1,
      anon_sym_end,
    STATE(856), 1,
      sym_enum,
    STATE(949), 1,
      aux_sym_enumeration_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [39222] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1910), 4,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_CR,
  [39233] = 4,
    ACTIONS(1912), 1,
      ts_builtin_sym_end,
    ACTIONS(1914), 1,
      anon_sym_function,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    STATE(914), 2,
      sym_function_definition,
      aux_sym_source_file_repeat1,
  [39248] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1507), 4,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_CR,
  [39259] = 4,
    ACTIONS(1233), 1,
      anon_sym_COMMA,
    STATE(959), 1,
      aux_sym_arguments_repeat2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1917), 2,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
  [39274] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1919), 4,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_CR,
  [39285] = 4,
    ACTIONS(158), 1,
      anon_sym_end,
    ACTIONS(1921), 1,
      anon_sym_endfunction,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(156), 2,
      ts_builtin_sym_end,
      anon_sym_function,
  [39300] = 5,
    ACTIONS(1923), 1,
      anon_sym_LPAREN,
    ACTIONS(1925), 1,
      anon_sym_AT,
    ACTIONS(1927), 1,
      anon_sym_LBRACE,
    STATE(362), 1,
      sym__args,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [39317] = 4,
    ACTIONS(181), 1,
      anon_sym_end,
    ACTIONS(1929), 1,
      anon_sym_endfunction,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(179), 2,
      ts_builtin_sym_end,
      anon_sym_function,
  [39332] = 4,
    ACTIONS(228), 1,
      anon_sym_end,
    ACTIONS(1931), 1,
      anon_sym_endfunction,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(179), 2,
      ts_builtin_sym_end,
      anon_sym_function,
  [39347] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1933), 4,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_CR,
  [39358] = 4,
    ACTIONS(170), 1,
      anon_sym_end,
    ACTIONS(1935), 1,
      anon_sym_endfunction,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(156), 2,
      ts_builtin_sym_end,
      anon_sym_function,
  [39373] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1937), 4,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_CR,
  [39384] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1939), 4,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_CR,
  [39395] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1941), 4,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_CR,
  [39406] = 4,
    ACTIONS(1943), 1,
      anon_sym_end,
    ACTIONS(1945), 1,
      anon_sym_endfunction,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1604), 2,
      ts_builtin_sym_end,
      anon_sym_function,
  [39421] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1947), 4,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_CR,
  [39432] = 4,
    ACTIONS(1949), 1,
      ts_builtin_sym_end,
    ACTIONS(1951), 1,
      anon_sym_function,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    STATE(914), 2,
      sym_function_definition,
      aux_sym_source_file_repeat1,
  [39447] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1953), 4,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_CR,
  [39458] = 5,
    ACTIONS(1923), 1,
      anon_sym_LPAREN,
    ACTIONS(1927), 1,
      anon_sym_LBRACE,
    ACTIONS(1955), 1,
      anon_sym_AT,
    STATE(360), 1,
      sym__args,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [39475] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1957), 4,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_CR,
  [39486] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1959), 4,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_CR,
  [39497] = 4,
    ACTIONS(217), 1,
      anon_sym_end,
    ACTIONS(1961), 1,
      anon_sym_endfunction,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(215), 2,
      ts_builtin_sym_end,
      anon_sym_function,
  [39512] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1963), 4,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_CR,
  [39523] = 5,
    ACTIONS(1865), 1,
      anon_sym_SEMI,
    ACTIONS(1867), 1,
      aux_sym_matrix_token1,
    ACTIONS(1965), 1,
      anon_sym_RBRACK,
    STATE(844), 1,
      aux_sym_matrix_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [39540] = 5,
    ACTIONS(1865), 1,
      anon_sym_SEMI,
    ACTIONS(1867), 1,
      aux_sym_matrix_token1,
    ACTIONS(1967), 1,
      anon_sym_RBRACE,
    STATE(844), 1,
      aux_sym_matrix_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [39557] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1969), 4,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_CR,
  [39568] = 5,
    ACTIONS(1865), 1,
      anon_sym_SEMI,
    ACTIONS(1867), 1,
      aux_sym_matrix_token1,
    ACTIONS(1971), 1,
      anon_sym_RBRACK,
    STATE(952), 1,
      aux_sym_matrix_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [39585] = 5,
    ACTIONS(1865), 1,
      anon_sym_SEMI,
    ACTIONS(1867), 1,
      aux_sym_matrix_token1,
    ACTIONS(1973), 1,
      anon_sym_RBRACE,
    STATE(954), 1,
      aux_sym_matrix_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [39602] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1975), 4,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_CR,
  [39613] = 5,
    ACTIONS(1892), 1,
      sym_identifier,
    ACTIONS(1977), 1,
      anon_sym_end,
    STATE(856), 1,
      sym_enum,
    STATE(949), 1,
      aux_sym_enumeration_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [39630] = 4,
    ACTIONS(1981), 1,
      anon_sym_DOT,
    STATE(609), 1,
      aux_sym_handle_operator_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1979), 2,
      anon_sym_LPAREN,
      anon_sym_LBRACE,
  [39645] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1983), 4,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_CR,
  [39656] = 4,
    ACTIONS(1985), 1,
      anon_sym_COMMA,
    STATE(894), 1,
      aux_sym_arguments_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1987), 2,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
  [39671] = 4,
    ACTIONS(1989), 1,
      anon_sym_COMMA,
    STATE(894), 1,
      aux_sym_arguments_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1987), 2,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
  [39686] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1991), 4,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_CR,
  [39697] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1993), 4,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_CR,
  [39708] = 5,
    ACTIONS(1995), 1,
      sym_identifier,
    ACTIONS(1998), 1,
      anon_sym_end,
    STATE(856), 1,
      sym_enum,
    STATE(949), 1,
      aux_sym_enumeration_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [39725] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2000), 4,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_CR,
  [39736] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1513), 4,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_CR,
  [39747] = 5,
    ACTIONS(1865), 1,
      anon_sym_SEMI,
    ACTIONS(1867), 1,
      aux_sym_matrix_token1,
    ACTIONS(2002), 1,
      anon_sym_RBRACK,
    STATE(844), 1,
      aux_sym_matrix_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [39764] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1519), 4,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_CR,
  [39775] = 5,
    ACTIONS(1865), 1,
      anon_sym_SEMI,
    ACTIONS(1867), 1,
      aux_sym_matrix_token1,
    ACTIONS(2004), 1,
      anon_sym_RBRACE,
    STATE(844), 1,
      aux_sym_matrix_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [39792] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1527), 4,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_CR,
  [39803] = 5,
    ACTIONS(2006), 1,
      anon_sym_LPAREN,
    ACTIONS(2008), 1,
      anon_sym_AT,
    ACTIONS(2010), 1,
      anon_sym_LBRACE,
    STATE(90), 1,
      sym__args,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [39820] = 5,
    ACTIONS(1865), 1,
      anon_sym_SEMI,
    ACTIONS(1867), 1,
      aux_sym_matrix_token1,
    ACTIONS(2012), 1,
      anon_sym_RBRACE,
    STATE(937), 1,
      aux_sym_matrix_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [39837] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2014), 4,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_CR,
  [39848] = 4,
    ACTIONS(2016), 1,
      anon_sym_COMMA,
    STATE(959), 1,
      aux_sym_arguments_repeat2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2019), 2,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
  [39863] = 5,
    ACTIONS(2006), 1,
      anon_sym_LPAREN,
    ACTIONS(2010), 1,
      anon_sym_LBRACE,
    ACTIONS(2021), 1,
      anon_sym_AT,
    STATE(88), 1,
      sym__args,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [39880] = 4,
    ACTIONS(165), 1,
      anon_sym_end,
    ACTIONS(2023), 1,
      anon_sym_endfunction,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(163), 2,
      ts_builtin_sym_end,
      anon_sym_function,
  [39895] = 4,
    ACTIONS(213), 1,
      anon_sym_end,
    ACTIONS(2025), 1,
      anon_sym_endfunction,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(195), 2,
      ts_builtin_sym_end,
      anon_sym_function,
  [39910] = 4,
    ACTIONS(2027), 1,
      anon_sym_end,
    ACTIONS(2029), 1,
      anon_sym_endfunction,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1517), 2,
      ts_builtin_sym_end,
      anon_sym_function,
  [39925] = 4,
    ACTIONS(224), 1,
      anon_sym_end,
    ACTIONS(2031), 1,
      anon_sym_endfunction,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(206), 2,
      ts_builtin_sym_end,
      anon_sym_function,
  [39940] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2033), 4,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_CR,
  [39951] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2035), 4,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_CR,
  [39962] = 5,
    ACTIONS(1865), 1,
      anon_sym_SEMI,
    ACTIONS(1867), 1,
      aux_sym_matrix_token1,
    ACTIONS(2037), 1,
      anon_sym_RBRACK,
    STATE(936), 1,
      aux_sym_matrix_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [39979] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2039), 4,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_CR,
  [39990] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2041), 4,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_CR,
  [40001] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2043), 4,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_CR,
  [40012] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2045), 4,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_CR,
  [40023] = 5,
    ACTIONS(1116), 1,
      anon_sym_LBRACE,
    ACTIONS(1241), 1,
      anon_sym_LPAREN,
    ACTIONS(2047), 1,
      anon_sym_AT,
    STATE(637), 1,
      sym__args,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [40040] = 4,
    ACTIONS(2049), 1,
      anon_sym_end,
    ACTIONS(2051), 1,
      anon_sym_endfunction,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1630), 2,
      ts_builtin_sym_end,
      anon_sym_function,
  [40055] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2053), 4,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_CR,
  [40066] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1552), 4,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_CR,
  [40077] = 3,
    ACTIONS(2055), 1,
      aux_sym_matrix_token1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1782), 3,
      anon_sym_SEMI,
      anon_sym_RBRACK,
      anon_sym_RBRACE,
  [40090] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1560), 4,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_CR,
  [40101] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1587), 4,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_CR,
  [40112] = 4,
    ACTIONS(1233), 1,
      anon_sym_COMMA,
    STATE(959), 1,
      aux_sym_arguments_repeat2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2057), 2,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
  [40127] = 4,
    ACTIONS(2059), 1,
      anon_sym_end,
    ACTIONS(2061), 1,
      anon_sym_endfunction,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1604), 2,
      ts_builtin_sym_end,
      anon_sym_function,
  [40142] = 4,
    ACTIONS(2065), 1,
      anon_sym_DOT,
    STATE(943), 1,
      aux_sym_handle_operator_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2063), 2,
      anon_sym_LPAREN,
      anon_sym_LBRACE,
  [40157] = 4,
    ACTIONS(345), 1,
      ts_builtin_sym_end,
    ACTIONS(1951), 1,
      anon_sym_function,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    STATE(914), 2,
      sym_function_definition,
      aux_sym_source_file_repeat1,
  [40172] = 4,
    ACTIONS(226), 1,
      anon_sym_end,
    ACTIONS(2067), 1,
      anon_sym_endfunction,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(215), 2,
      ts_builtin_sym_end,
      anon_sym_function,
  [40187] = 4,
    ACTIONS(1219), 1,
      anon_sym_COMMA,
    STATE(945), 1,
      aux_sym_arguments_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1221), 2,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
  [40202] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2069), 4,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_CR,
  [40213] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2071), 4,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_CR,
  [40224] = 5,
    ACTIONS(1112), 1,
      anon_sym_AT,
    ACTIONS(1116), 1,
      anon_sym_LBRACE,
    ACTIONS(1241), 1,
      anon_sym_LPAREN,
    STATE(647), 1,
      sym__args,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [40241] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2073), 4,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_CR,
  [40252] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1591), 4,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_CR,
  [40263] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1612), 4,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_CR,
  [40274] = 4,
    ACTIONS(1233), 1,
      anon_sym_COMMA,
    STATE(959), 1,
      aux_sym_arguments_repeat2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2075), 2,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
  [40289] = 5,
    ACTIONS(2077), 1,
      anon_sym_LPAREN,
    ACTIONS(2079), 1,
      anon_sym_AT,
    ACTIONS(2081), 1,
      anon_sym_LBRACE,
    STATE(200), 1,
      sym__args,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [40306] = 4,
    ACTIONS(1233), 1,
      anon_sym_COMMA,
    STATE(959), 1,
      aux_sym_arguments_repeat2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2075), 2,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
  [40321] = 5,
    ACTIONS(2077), 1,
      anon_sym_LPAREN,
    ACTIONS(2081), 1,
      anon_sym_LBRACE,
    ACTIONS(2083), 1,
      anon_sym_AT,
    STATE(201), 1,
      sym__args,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [40338] = 4,
    ACTIONS(2085), 1,
      anon_sym_end,
    ACTIONS(2087), 1,
      anon_sym_endfunction,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1630), 2,
      ts_builtin_sym_end,
      anon_sym_function,
  [40353] = 5,
    ACTIONS(1865), 1,
      anon_sym_SEMI,
    ACTIONS(1867), 1,
      aux_sym_matrix_token1,
    ACTIONS(2089), 1,
      anon_sym_RBRACK,
    STATE(1000), 1,
      aux_sym_matrix_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [40370] = 5,
    ACTIONS(1865), 1,
      anon_sym_SEMI,
    ACTIONS(1867), 1,
      aux_sym_matrix_token1,
    ACTIONS(2091), 1,
      anon_sym_RBRACE,
    STATE(1001), 1,
      aux_sym_matrix_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [40387] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2093), 4,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_CR,
  [40398] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1546), 4,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_CR,
  [40409] = 5,
    ACTIONS(1865), 1,
      anon_sym_SEMI,
    ACTIONS(1867), 1,
      aux_sym_matrix_token1,
    ACTIONS(2095), 1,
      anon_sym_RBRACK,
    STATE(844), 1,
      aux_sym_matrix_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [40426] = 5,
    ACTIONS(1865), 1,
      anon_sym_SEMI,
    ACTIONS(1867), 1,
      aux_sym_matrix_token1,
    ACTIONS(2097), 1,
      anon_sym_RBRACE,
    STATE(844), 1,
      aux_sym_matrix_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [40443] = 4,
    ACTIONS(656), 1,
      anon_sym_COLON,
    ACTIONS(2099), 1,
      sym_number,
    STATE(1030), 1,
      sym_spread_operator,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [40457] = 4,
    ACTIONS(2101), 1,
      sym_identifier,
    ACTIONS(2103), 1,
      anon_sym_end,
    STATE(1055), 1,
      aux_sym_events_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [40471] = 3,
    ACTIONS(2105), 1,
      sym_identifier,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2107), 2,
      anon_sym_get_DOT,
      anon_sym_set_DOT,
  [40483] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2109), 3,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
  [40493] = 4,
    ACTIONS(2111), 1,
      anon_sym_end,
    ACTIONS(2113), 1,
      anon_sym_catch,
    STATE(1214), 1,
      sym_catch_clause,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [40507] = 3,
    ACTIONS(2117), 1,
      anon_sym_TILDE,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2115), 2,
      anon_sym_end,
      sym_identifier,
  [40519] = 4,
    ACTIONS(2119), 1,
      anon_sym_COMMA,
    ACTIONS(2122), 1,
      anon_sym_RPAREN,
    STATE(1008), 1,
      aux_sym_enum_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [40533] = 4,
    ACTIONS(2124), 1,
      sym_identifier,
    ACTIONS(2126), 1,
      anon_sym_LPAREN,
    STATE(19), 1,
      sym_iterator,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [40547] = 3,
    ACTIONS(2130), 1,
      anon_sym_TILDE,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2128), 2,
      anon_sym_end,
      sym_identifier,
  [40559] = 4,
    ACTIONS(1493), 1,
      anon_sym_RBRACE,
    ACTIONS(2132), 1,
      anon_sym_COMMA,
    STATE(1011), 1,
      aux_sym_validation_functions_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [40573] = 4,
    ACTIONS(2135), 1,
      anon_sym_COMMA,
    ACTIONS(2138), 1,
      anon_sym_RPAREN,
    STATE(1012), 1,
      aux_sym_dimensions_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [40587] = 4,
    ACTIONS(2140), 1,
      anon_sym_COMMA,
    ACTIONS(2142), 1,
      anon_sym_RPAREN,
    STATE(1014), 1,
      aux_sym__lambda_arguments_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [40601] = 4,
    ACTIONS(2140), 1,
      anon_sym_COMMA,
    ACTIONS(2144), 1,
      anon_sym_RPAREN,
    STATE(1052), 1,
      aux_sym__lambda_arguments_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [40615] = 4,
    ACTIONS(1110), 1,
      anon_sym_TILDE,
    ACTIONS(2146), 1,
      sym_identifier,
    STATE(1077), 1,
      sym_ignored_argument,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [40629] = 4,
    ACTIONS(2148), 1,
      sym_identifier,
    ACTIONS(2150), 1,
      anon_sym_LPAREN,
    STATE(1164), 1,
      sym_attributes,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [40643] = 3,
    ACTIONS(2152), 1,
      sym_identifier,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2154), 2,
      anon_sym_get_DOT,
      anon_sym_set_DOT,
  [40655] = 4,
    ACTIONS(2156), 1,
      anon_sym_COMMA,
    ACTIONS(2158), 1,
      anon_sym_RPAREN,
    STATE(1008), 1,
      aux_sym_enum_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [40669] = 3,
    ACTIONS(2162), 1,
      anon_sym_TILDE,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2160), 2,
      anon_sym_end,
      sym_identifier,
  [40681] = 3,
    ACTIONS(2164), 1,
      sym_identifier,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2166), 2,
      anon_sym_get_DOT,
      anon_sym_set_DOT,
  [40693] = 4,
    ACTIONS(1459), 1,
      anon_sym_COMMA,
    ACTIONS(2168), 1,
      anon_sym_RBRACE,
    STATE(1011), 1,
      aux_sym_validation_functions_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [40707] = 4,
    ACTIONS(2170), 1,
      anon_sym_COMMA,
    ACTIONS(2172), 1,
      anon_sym_RPAREN,
    STATE(1012), 1,
      aux_sym_dimensions_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [40721] = 4,
    ACTIONS(2077), 1,
      anon_sym_LPAREN,
    ACTIONS(2081), 1,
      anon_sym_LBRACE,
    STATE(203), 1,
      sym__args,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [40735] = 4,
    ACTIONS(656), 1,
      anon_sym_COLON,
    ACTIONS(2174), 1,
      sym_number,
    STATE(1084), 1,
      sym_spread_operator,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [40749] = 4,
    ACTIONS(2176), 1,
      anon_sym_COMMA,
    ACTIONS(2178), 1,
      anon_sym_RPAREN,
    STATE(1043), 1,
      aux_sym_attributes_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [40763] = 4,
    ACTIONS(2077), 1,
      anon_sym_LPAREN,
    ACTIONS(2081), 1,
      anon_sym_LBRACE,
    STATE(194), 1,
      sym__args,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [40777] = 3,
    ACTIONS(2182), 1,
      anon_sym_EQ,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2180), 2,
      anon_sym_COMMA,
      anon_sym_RPAREN,
  [40789] = 4,
    ACTIONS(2156), 1,
      anon_sym_COMMA,
    ACTIONS(2184), 1,
      anon_sym_RPAREN,
    STATE(1018), 1,
      aux_sym_enum_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [40803] = 3,
    ACTIONS(2188), 1,
      anon_sym_TILDE,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2186), 2,
      anon_sym_end,
      sym_identifier,
  [40815] = 4,
    ACTIONS(2170), 1,
      anon_sym_COMMA,
    ACTIONS(2190), 1,
      anon_sym_RPAREN,
    STATE(1022), 1,
      aux_sym_dimensions_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [40829] = 4,
    ACTIONS(2192), 1,
      anon_sym_COMMA,
    ACTIONS(2195), 1,
      anon_sym_RPAREN,
    STATE(1031), 1,
      aux_sym__argument_attributes_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [40843] = 4,
    ACTIONS(2006), 1,
      anon_sym_LPAREN,
    ACTIONS(2010), 1,
      anon_sym_LBRACE,
    STATE(87), 1,
      sym__args,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [40857] = 4,
    ACTIONS(2006), 1,
      anon_sym_LPAREN,
    ACTIONS(2010), 1,
      anon_sym_LBRACE,
    STATE(96), 1,
      sym__args,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [40871] = 3,
    ACTIONS(2197), 1,
      sym_identifier,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2199), 2,
      anon_sym_get_DOT,
      anon_sym_set_DOT,
  [40883] = 4,
    ACTIONS(2176), 1,
      anon_sym_COMMA,
    ACTIONS(2201), 1,
      anon_sym_RPAREN,
    STATE(1041), 1,
      aux_sym_attributes_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [40897] = 3,
    ACTIONS(2205), 1,
      anon_sym_TILDE,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2203), 2,
      anon_sym_end,
      sym_identifier,
  [40909] = 4,
    ACTIONS(1116), 1,
      anon_sym_LBRACE,
    ACTIONS(1241), 1,
      anon_sym_LPAREN,
    STATE(649), 1,
      sym__args,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [40923] = 4,
    ACTIONS(1923), 1,
      anon_sym_LPAREN,
    ACTIONS(1927), 1,
      anon_sym_LBRACE,
    STATE(361), 1,
      sym__args,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [40937] = 4,
    ACTIONS(1116), 1,
      anon_sym_LBRACE,
    ACTIONS(1241), 1,
      anon_sym_LPAREN,
    STATE(638), 1,
      sym__args,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [40951] = 4,
    ACTIONS(1923), 1,
      anon_sym_LPAREN,
    ACTIONS(1927), 1,
      anon_sym_LBRACE,
    STATE(376), 1,
      sym__args,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [40965] = 4,
    ACTIONS(2176), 1,
      anon_sym_COMMA,
    ACTIONS(2207), 1,
      anon_sym_RPAREN,
    STATE(1056), 1,
      aux_sym_attributes_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [40979] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1279), 3,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
  [40989] = 4,
    ACTIONS(2176), 1,
      anon_sym_COMMA,
    ACTIONS(2209), 1,
      anon_sym_RPAREN,
    STATE(1056), 1,
      aux_sym_attributes_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [41003] = 4,
    ACTIONS(2211), 1,
      sym_identifier,
    ACTIONS(2214), 1,
      anon_sym_end,
    STATE(1044), 1,
      aux_sym_events_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [41017] = 4,
    ACTIONS(2101), 1,
      sym_identifier,
    ACTIONS(2216), 1,
      anon_sym_end,
    STATE(1044), 1,
      aux_sym_events_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [41031] = 4,
    ACTIONS(2218), 1,
      anon_sym_COMMA,
    ACTIONS(2220), 1,
      anon_sym_RPAREN,
    STATE(1031), 1,
      aux_sym__argument_attributes_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [41045] = 3,
    ACTIONS(2222), 1,
      sym_identifier,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2224), 2,
      anon_sym_get_DOT,
      anon_sym_set_DOT,
  [41057] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2226), 3,
      anon_sym_end,
      anon_sym_case,
      anon_sym_otherwise,
  [41067] = 4,
    ACTIONS(2113), 1,
      anon_sym_catch,
    ACTIONS(2228), 1,
      anon_sym_end,
    STATE(1207), 1,
      sym_catch_clause,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [41081] = 4,
    ACTIONS(2218), 1,
      anon_sym_COMMA,
    ACTIONS(2230), 1,
      anon_sym_RPAREN,
    STATE(1046), 1,
      aux_sym__argument_attributes_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [41095] = 4,
    ACTIONS(822), 1,
      anon_sym_LPAREN,
    ACTIONS(830), 1,
      anon_sym_LBRACE,
    STATE(418), 1,
      sym__args,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [41109] = 4,
    ACTIONS(2232), 1,
      anon_sym_COMMA,
    ACTIONS(2235), 1,
      anon_sym_RPAREN,
    STATE(1052), 1,
      aux_sym__lambda_arguments_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [41123] = 3,
    ACTIONS(113), 1,
      anon_sym_else,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2237), 2,
      anon_sym_elseif,
      anon_sym_end,
  [41135] = 4,
    ACTIONS(822), 1,
      anon_sym_LPAREN,
    ACTIONS(830), 1,
      anon_sym_LBRACE,
    STATE(424), 1,
      sym__args,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [41149] = 4,
    ACTIONS(2101), 1,
      sym_identifier,
    ACTIONS(2239), 1,
      anon_sym_end,
    STATE(1044), 1,
      aux_sym_events_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [41163] = 4,
    ACTIONS(2241), 1,
      anon_sym_COMMA,
    ACTIONS(2244), 1,
      anon_sym_RPAREN,
    STATE(1056), 1,
      aux_sym_attributes_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [41177] = 3,
    ACTIONS(2246), 1,
      sym_identifier,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2248), 2,
      anon_sym_get_DOT,
      anon_sym_set_DOT,
  [41189] = 3,
    ACTIONS(2252), 1,
      anon_sym_else,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2250), 2,
      anon_sym_elseif,
      anon_sym_end,
  [41201] = 4,
    ACTIONS(2101), 1,
      sym_identifier,
    ACTIONS(2239), 1,
      anon_sym_end,
    STATE(1045), 1,
      aux_sym_events_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [41215] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2254), 2,
      anon_sym_LPAREN,
      anon_sym_LBRACE,
  [41224] = 3,
    ACTIONS(2256), 1,
      sym_identifier,
    STATE(1037), 1,
      sym_property_name,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [41235] = 3,
    ACTIONS(2258), 1,
      sym_identifier,
    ACTIONS(2260), 1,
      anon_sym_LPAREN,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [41246] = 3,
    ACTIONS(230), 1,
      anon_sym_end,
    ACTIONS(2262), 1,
      anon_sym_endfunction,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [41257] = 3,
    ACTIONS(2264), 1,
      sym_identifier,
    ACTIONS(2266), 1,
      anon_sym_STAR,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [41268] = 3,
    ACTIONS(2256), 1,
      sym_identifier,
    STATE(1032), 1,
      sym_property_name,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [41279] = 3,
    ACTIONS(234), 1,
      anon_sym_end,
    ACTIONS(2268), 1,
      anon_sym_endfunction,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [41290] = 3,
    ACTIONS(2256), 1,
      sym_identifier,
    STATE(1033), 1,
      sym_property_name,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [41301] = 3,
    ACTIONS(2270), 1,
      anon_sym_end,
    ACTIONS(2272), 1,
      anon_sym_endfunction,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [41312] = 3,
    ACTIONS(2274), 1,
      sym_identifier,
    ACTIONS(2276), 1,
      anon_sym_STAR,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [41323] = 3,
    ACTIONS(238), 1,
      anon_sym_end,
    ACTIONS(2278), 1,
      anon_sym_endfunction,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [41334] = 3,
    ACTIONS(2256), 1,
      sym_identifier,
    STATE(1038), 1,
      sym_property_name,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [41345] = 3,
    ACTIONS(2280), 1,
      anon_sym_end,
    ACTIONS(2282), 1,
      anon_sym_endfunction,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [41356] = 3,
    ACTIONS(242), 1,
      anon_sym_end,
    ACTIONS(2284), 1,
      anon_sym_endfunction,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [41367] = 3,
    ACTIONS(2256), 1,
      sym_identifier,
    STATE(1040), 1,
      sym_property_name,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [41378] = 3,
    ACTIONS(2286), 1,
      anon_sym_end,
    ACTIONS(2288), 1,
      anon_sym_endfunction,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [41389] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1544), 2,
      ts_builtin_sym_end,
      anon_sym_function,
  [41398] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2235), 2,
      anon_sym_COMMA,
      anon_sym_RPAREN,
  [41407] = 3,
    ACTIONS(2290), 1,
      sym_identifier,
    ACTIONS(2292), 1,
      anon_sym_LPAREN,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [41418] = 3,
    ACTIONS(2256), 1,
      sym_identifier,
    STATE(1051), 1,
      sym_property_name,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [41429] = 3,
    ACTIONS(2256), 1,
      sym_identifier,
    STATE(1054), 1,
      sym_property_name,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [41440] = 3,
    ACTIONS(2124), 1,
      sym_identifier,
    STATE(19), 1,
      sym_iterator,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [41451] = 3,
    ACTIONS(2294), 1,
      sym_identifier,
    STATE(1089), 1,
      sym_attribute,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [41462] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2122), 2,
      anon_sym_COMMA,
      anon_sym_RPAREN,
  [41471] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2138), 2,
      anon_sym_COMMA,
      anon_sym_RPAREN,
  [41480] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1630), 2,
      ts_builtin_sym_end,
      anon_sym_function,
  [41489] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1646), 2,
      ts_builtin_sym_end,
      anon_sym_function,
  [41498] = 3,
    ACTIONS(2296), 1,
      sym_identifier,
    ACTIONS(2298), 1,
      anon_sym_LPAREN,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [41509] = 3,
    ACTIONS(2300), 1,
      anon_sym_end,
    ACTIONS(2302), 1,
      anon_sym_endfunction,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [41520] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2244), 2,
      anon_sym_COMMA,
      anon_sym_RPAREN,
  [41529] = 3,
    ACTIONS(2304), 1,
      sym_identifier,
    STATE(798), 1,
      sym_property_name,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [41540] = 3,
    ACTIONS(2256), 1,
      sym_identifier,
    STATE(1023), 1,
      sym_property_name,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [41551] = 3,
    ACTIONS(2304), 1,
      sym_identifier,
    STATE(873), 1,
      sym_property_name,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [41562] = 3,
    ACTIONS(2256), 1,
      sym_identifier,
    STATE(1039), 1,
      sym_property_name,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [41573] = 3,
    ACTIONS(337), 1,
      anon_sym_end,
    ACTIONS(2306), 1,
      anon_sym_endfunction,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [41584] = 3,
    ACTIONS(339), 1,
      anon_sym_end,
    ACTIONS(2308), 1,
      anon_sym_endfunction,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [41595] = 3,
    ACTIONS(2294), 1,
      sym_identifier,
    STATE(1035), 1,
      sym_attribute,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [41606] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2310), 2,
      anon_sym_LPAREN,
      anon_sym_LBRACE,
  [41615] = 3,
    ACTIONS(2256), 1,
      sym_identifier,
    STATE(1026), 1,
      sym_property_name,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [41626] = 3,
    ACTIONS(2274), 1,
      sym_identifier,
    ACTIONS(2312), 1,
      anon_sym_STAR,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [41637] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(215), 2,
      ts_builtin_sym_end,
      anon_sym_function,
  [41646] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1608), 2,
      ts_builtin_sym_end,
      anon_sym_function,
  [41655] = 3,
    ACTIONS(2314), 1,
      sym_identifier,
    ACTIONS(2316), 1,
      anon_sym_LPAREN,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [41666] = 3,
    ACTIONS(2318), 1,
      sym_identifier,
    ACTIONS(2320), 1,
      anon_sym_LPAREN,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [41677] = 3,
    ACTIONS(2322), 1,
      sym_identifier,
    ACTIONS(2324), 1,
      anon_sym_LPAREN,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [41688] = 3,
    ACTIONS(2296), 1,
      sym_identifier,
    ACTIONS(2326), 1,
      anon_sym_LPAREN,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [41699] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1604), 2,
      ts_builtin_sym_end,
      anon_sym_function,
  [41708] = 3,
    ACTIONS(232), 1,
      anon_sym_end,
    ACTIONS(2328), 1,
      anon_sym_endfunction,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [41719] = 3,
    ACTIONS(250), 1,
      anon_sym_end,
    ACTIONS(2330), 1,
      anon_sym_endfunction,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [41730] = 3,
    ACTIONS(240), 1,
      anon_sym_end,
    ACTIONS(2332), 1,
      anon_sym_endfunction,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [41741] = 3,
    ACTIONS(2314), 1,
      sym_identifier,
    ACTIONS(2334), 1,
      anon_sym_LPAREN,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [41752] = 3,
    ACTIONS(2336), 1,
      sym_identifier,
    ACTIONS(2338), 1,
      anon_sym_LPAREN,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [41763] = 3,
    ACTIONS(2340), 1,
      anon_sym_end,
    ACTIONS(2342), 1,
      anon_sym_endfunction,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [41774] = 3,
    ACTIONS(2294), 1,
      sym_identifier,
    STATE(1025), 1,
      sym_attribute,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [41785] = 3,
    ACTIONS(2258), 1,
      sym_identifier,
    ACTIONS(2344), 1,
      anon_sym_LPAREN,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [41796] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(156), 2,
      ts_builtin_sym_end,
      anon_sym_function,
  [41805] = 3,
    ACTIONS(2318), 1,
      sym_identifier,
    ACTIONS(2346), 1,
      anon_sym_LPAREN,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [41816] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(179), 2,
      ts_builtin_sym_end,
      anon_sym_function,
  [41825] = 3,
    ACTIONS(2322), 1,
      sym_identifier,
    ACTIONS(2348), 1,
      anon_sym_LPAREN,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [41836] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2350), 2,
      anon_sym_COMMA,
      anon_sym_RPAREN,
  [41845] = 3,
    ACTIONS(2264), 1,
      sym_identifier,
    ACTIONS(2352), 1,
      anon_sym_STAR,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [41856] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(206), 2,
      ts_builtin_sym_end,
      anon_sym_function,
  [41865] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1517), 2,
      ts_builtin_sym_end,
      anon_sym_function,
  [41874] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(195), 2,
      ts_builtin_sym_end,
      anon_sym_function,
  [41883] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(163), 2,
      ts_builtin_sym_end,
      anon_sym_function,
  [41892] = 3,
    ACTIONS(236), 1,
      anon_sym_end,
    ACTIONS(2354), 1,
      anon_sym_endfunction,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [41903] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2214), 2,
      anon_sym_end,
      sym_identifier,
  [41912] = 3,
    ACTIONS(329), 1,
      anon_sym_end,
    ACTIONS(2356), 1,
      anon_sym_endfunction,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [41923] = 3,
    ACTIONS(2358), 1,
      sym_identifier,
    STATE(1213), 1,
      sym_iterator,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [41934] = 3,
    ACTIONS(2360), 1,
      anon_sym_end,
    ACTIONS(2362), 1,
      anon_sym_endfunction,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [41945] = 3,
    ACTIONS(2364), 1,
      sym_identifier,
    ACTIONS(2366), 1,
      anon_sym_LPAREN,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [41956] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1998), 2,
      anon_sym_end,
      sym_identifier,
  [41965] = 3,
    ACTIONS(244), 1,
      anon_sym_end,
    ACTIONS(2368), 1,
      anon_sym_endfunction,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [41976] = 2,
    ACTIONS(2370), 1,
      sym_identifier,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [41984] = 2,
    ACTIONS(2372), 1,
      anon_sym_RPAREN,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [41992] = 2,
    ACTIONS(2374), 1,
      anon_sym_RBRACE,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [42000] = 2,
    ACTIONS(2376), 1,
      anon_sym_RPAREN,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [42008] = 2,
    ACTIONS(2378), 1,
      anon_sym_EQ,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [42016] = 2,
    ACTIONS(2380), 1,
      sym_identifier,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [42024] = 2,
    ACTIONS(2382), 1,
      anon_sym_RPAREN,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [42032] = 2,
    ACTIONS(1659), 1,
      anon_sym_end,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [42040] = 2,
    ACTIONS(2384), 1,
      anon_sym_RBRACE,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [42048] = 2,
    ACTIONS(2386), 1,
      sym_identifier,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [42056] = 2,
    ACTIONS(2388), 1,
      anon_sym_end,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [42064] = 2,
    ACTIONS(2390), 1,
      sym_identifier,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [42072] = 2,
    ACTIONS(2392), 1,
      anon_sym_end,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [42080] = 2,
    ACTIONS(2394), 1,
      anon_sym_EQ,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [42088] = 2,
    ACTIONS(2396), 1,
      anon_sym_RPAREN,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [42096] = 2,
    ACTIONS(2398), 1,
      sym_identifier,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [42104] = 2,
    ACTIONS(2400), 1,
      anon_sym_RPAREN,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [42112] = 2,
    ACTIONS(2384), 1,
      anon_sym_RPAREN,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [42120] = 2,
    ACTIONS(2400), 1,
      anon_sym_RBRACE,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [42128] = 2,
    ACTIONS(2402), 1,
      anon_sym_end,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [42136] = 2,
    ACTIONS(1602), 1,
      anon_sym_end,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [42144] = 2,
    ACTIONS(2404), 1,
      anon_sym_end,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [42152] = 2,
    ACTIONS(2374), 1,
      anon_sym_RPAREN,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [42160] = 2,
    ACTIONS(2406), 1,
      anon_sym_RPAREN,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [42168] = 2,
    ACTIONS(2408), 1,
      sym_identifier,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [42176] = 2,
    ACTIONS(2410), 1,
      anon_sym_RPAREN,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [42184] = 2,
    ACTIONS(2412), 1,
      anon_sym_COLON,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [42192] = 2,
    ACTIONS(2414), 1,
      sym_identifier,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [42200] = 2,
    ACTIONS(2416), 1,
      anon_sym_RPAREN,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [42208] = 2,
    ACTIONS(2418), 1,
      sym_identifier,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [42216] = 2,
    ACTIONS(2420), 1,
      anon_sym_end,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [42224] = 2,
    ACTIONS(2422), 1,
      sym_identifier,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [42232] = 2,
    ACTIONS(2424), 1,
      sym_identifier,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [42240] = 2,
    ACTIONS(2426), 1,
      anon_sym_RPAREN,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [42248] = 2,
    ACTIONS(2428), 1,
      sym_identifier,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [42256] = 2,
    ACTIONS(2430), 1,
      anon_sym_RBRACE,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [42264] = 2,
    ACTIONS(2430), 1,
      anon_sym_RPAREN,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [42272] = 2,
    ACTIONS(2432), 1,
      sym_identifier,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [42280] = 2,
    ACTIONS(2434), 1,
      anon_sym_RPAREN,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [42288] = 2,
    ACTIONS(2436), 1,
      sym_identifier,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [42296] = 2,
    ACTIONS(2438), 1,
      anon_sym_end,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [42304] = 2,
    ACTIONS(2228), 1,
      anon_sym_end,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [42312] = 2,
    ACTIONS(2274), 1,
      sym_identifier,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [42320] = 2,
    ACTIONS(2440), 1,
      sym_identifier,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [42328] = 2,
    ACTIONS(2442), 1,
      sym_identifier,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [42336] = 2,
    ACTIONS(2444), 1,
      anon_sym_end,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [42344] = 2,
    ACTIONS(2446), 1,
      anon_sym_COLON,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [42352] = 2,
    ACTIONS(2448), 1,
      anon_sym_RPAREN,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [42360] = 2,
    ACTIONS(2450), 1,
      anon_sym_COLON,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [42368] = 2,
    ACTIONS(2376), 1,
      anon_sym_RBRACE,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [42376] = 2,
    ACTIONS(2452), 1,
      sym_identifier,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [42384] = 2,
    ACTIONS(2454), 1,
      sym_identifier,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [42392] = 2,
    ACTIONS(2456), 1,
      anon_sym_EQ,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [42400] = 2,
    ACTIONS(2458), 1,
      sym_identifier,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [42408] = 2,
    ACTIONS(2460), 1,
      anon_sym_EQ,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [42416] = 2,
    ACTIONS(2462), 1,
      anon_sym_end,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [42424] = 2,
    ACTIONS(2464), 1,
      anon_sym_EQ,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [42432] = 2,
    ACTIONS(2466), 1,
      ts_builtin_sym_end,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [42440] = 2,
    ACTIONS(2468), 1,
      sym_identifier,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [42448] = 2,
    ACTIONS(2470), 1,
      anon_sym_end,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [42456] = 2,
    ACTIONS(1679), 1,
      anon_sym_end,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [42464] = 2,
    ACTIONS(2472), 1,
      anon_sym_RPAREN,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [42472] = 2,
    ACTIONS(2474), 1,
      anon_sym_RPAREN,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [42480] = 2,
    ACTIONS(2476), 1,
      anon_sym_COLON,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [42488] = 2,
    ACTIONS(2478), 1,
      anon_sym_EQ,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [42496] = 2,
    ACTIONS(2480), 1,
      anon_sym_RPAREN,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [42504] = 2,
    ACTIONS(2482), 1,
      anon_sym_end,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [42512] = 2,
    ACTIONS(1745), 1,
      anon_sym_RPAREN,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [42520] = 2,
    ACTIONS(2484), 1,
      anon_sym_RPAREN,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [42528] = 2,
    ACTIONS(2486), 1,
      anon_sym_RPAREN,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [42536] = 2,
    ACTIONS(2264), 1,
      sym_identifier,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [42544] = 2,
    ACTIONS(1636), 1,
      anon_sym_end,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [42552] = 2,
    ACTIONS(2488), 1,
      anon_sym_end,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [42560] = 2,
    ACTIONS(2490), 1,
      anon_sym_EQ,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [42568] = 2,
    ACTIONS(2111), 1,
      anon_sym_end,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [42576] = 2,
    ACTIONS(2492), 1,
      anon_sym_RPAREN,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [42584] = 2,
    ACTIONS(2494), 1,
      anon_sym_EQ,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [42592] = 2,
    ACTIONS(1491), 1,
      anon_sym_end,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [42600] = 2,
    ACTIONS(2496), 1,
      sym_identifier,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [42608] = 2,
    ACTIONS(2498), 1,
      anon_sym_end,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [42616] = 2,
    ACTIONS(2500), 1,
      anon_sym_COMMA,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [42624] = 2,
    ACTIONS(2502), 1,
      anon_sym_end,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [42632] = 2,
    ACTIONS(2504), 1,
      sym_identifier,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [42640] = 2,
    ACTIONS(2506), 1,
      anon_sym_end,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [42648] = 2,
    ACTIONS(2508), 1,
      sym_identifier,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [42656] = 2,
    ACTIONS(2510), 1,
      anon_sym_end,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
};

static const uint32_t ts_small_parse_table_map[] = {
  [SMALL_STATE(76)] = 0,
  [SMALL_STATE(77)] = 89,
  [SMALL_STATE(78)] = 178,
  [SMALL_STATE(79)] = 263,
  [SMALL_STATE(80)] = 348,
  [SMALL_STATE(81)] = 437,
  [SMALL_STATE(82)] = 511,
  [SMALL_STATE(83)] = 585,
  [SMALL_STATE(84)] = 659,
  [SMALL_STATE(85)] = 737,
  [SMALL_STATE(86)] = 811,
  [SMALL_STATE(87)] = 885,
  [SMALL_STATE(88)] = 954,
  [SMALL_STATE(89)] = 1023,
  [SMALL_STATE(90)] = 1092,
  [SMALL_STATE(91)] = 1161,
  [SMALL_STATE(92)] = 1244,
  [SMALL_STATE(93)] = 1323,
  [SMALL_STATE(94)] = 1392,
  [SMALL_STATE(95)] = 1461,
  [SMALL_STATE(96)] = 1540,
  [SMALL_STATE(97)] = 1609,
  [SMALL_STATE(98)] = 1692,
  [SMALL_STATE(99)] = 1761,
  [SMALL_STATE(100)] = 1844,
  [SMALL_STATE(101)] = 1912,
  [SMALL_STATE(102)] = 1980,
  [SMALL_STATE(103)] = 2048,
  [SMALL_STATE(104)] = 2118,
  [SMALL_STATE(105)] = 2192,
  [SMALL_STATE(106)] = 2266,
  [SMALL_STATE(107)] = 2336,
  [SMALL_STATE(108)] = 2410,
  [SMALL_STATE(109)] = 2480,
  [SMALL_STATE(110)] = 2552,
  [SMALL_STATE(111)] = 2620,
  [SMALL_STATE(112)] = 2690,
  [SMALL_STATE(113)] = 2762,
  [SMALL_STATE(114)] = 2836,
  [SMALL_STATE(115)] = 2906,
  [SMALL_STATE(116)] = 2976,
  [SMALL_STATE(117)] = 3046,
  [SMALL_STATE(118)] = 3114,
  [SMALL_STATE(119)] = 3188,
  [SMALL_STATE(120)] = 3258,
  [SMALL_STATE(121)] = 3326,
  [SMALL_STATE(122)] = 3400,
  [SMALL_STATE(123)] = 3468,
  [SMALL_STATE(124)] = 3536,
  [SMALL_STATE(125)] = 3610,
  [SMALL_STATE(126)] = 3678,
  [SMALL_STATE(127)] = 3752,
  [SMALL_STATE(128)] = 3826,
  [SMALL_STATE(129)] = 3896,
  [SMALL_STATE(130)] = 3966,
  [SMALL_STATE(131)] = 4034,
  [SMALL_STATE(132)] = 4106,
  [SMALL_STATE(133)] = 4174,
  [SMALL_STATE(134)] = 4248,
  [SMALL_STATE(135)] = 4322,
  [SMALL_STATE(136)] = 4396,
  [SMALL_STATE(137)] = 4468,
  [SMALL_STATE(138)] = 4538,
  [SMALL_STATE(139)] = 4606,
  [SMALL_STATE(140)] = 4678,
  [SMALL_STATE(141)] = 4746,
  [SMALL_STATE(142)] = 4820,
  [SMALL_STATE(143)] = 4896,
  [SMALL_STATE(144)] = 4966,
  [SMALL_STATE(145)] = 5036,
  [SMALL_STATE(146)] = 5108,
  [SMALL_STATE(147)] = 5178,
  [SMALL_STATE(148)] = 5245,
  [SMALL_STATE(149)] = 5316,
  [SMALL_STATE(150)] = 5385,
  [SMALL_STATE(151)] = 5456,
  [SMALL_STATE(152)] = 5527,
  [SMALL_STATE(153)] = 5586,
  [SMALL_STATE(154)] = 5645,
  [SMALL_STATE(155)] = 5704,
  [SMALL_STATE(156)] = 5758,
  [SMALL_STATE(157)] = 5863,
  [SMALL_STATE(158)] = 5920,
  [SMALL_STATE(159)] = 5974,
  [SMALL_STATE(160)] = 6073,
  [SMALL_STATE(161)] = 6172,
  [SMALL_STATE(162)] = 6269,
  [SMALL_STATE(163)] = 6368,
  [SMALL_STATE(164)] = 6468,
  [SMALL_STATE(165)] = 6568,
  [SMALL_STATE(166)] = 6668,
  [SMALL_STATE(167)] = 6768,
  [SMALL_STATE(168)] = 6868,
  [SMALL_STATE(169)] = 6920,
  [SMALL_STATE(170)] = 7020,
  [SMALL_STATE(171)] = 7072,
  [SMALL_STATE(172)] = 7172,
  [SMALL_STATE(173)] = 7272,
  [SMALL_STATE(174)] = 7372,
  [SMALL_STATE(175)] = 7472,
  [SMALL_STATE(176)] = 7524,
  [SMALL_STATE(177)] = 7624,
  [SMALL_STATE(178)] = 7676,
  [SMALL_STATE(179)] = 7776,
  [SMALL_STATE(180)] = 7828,
  [SMALL_STATE(181)] = 7928,
  [SMALL_STATE(182)] = 8028,
  [SMALL_STATE(183)] = 8128,
  [SMALL_STATE(184)] = 8228,
  [SMALL_STATE(185)] = 8328,
  [SMALL_STATE(186)] = 8428,
  [SMALL_STATE(187)] = 8528,
  [SMALL_STATE(188)] = 8591,
  [SMALL_STATE(189)] = 8650,
  [SMALL_STATE(190)] = 8713,
  [SMALL_STATE(191)] = 8776,
  [SMALL_STATE(192)] = 8829,
  [SMALL_STATE(193)] = 8888,
  [SMALL_STATE(194)] = 8982,
  [SMALL_STATE(195)] = 9026,
  [SMALL_STATE(196)] = 9120,
  [SMALL_STATE(197)] = 9214,
  [SMALL_STATE(198)] = 9258,
  [SMALL_STATE(199)] = 9302,
  [SMALL_STATE(200)] = 9346,
  [SMALL_STATE(201)] = 9390,
  [SMALL_STATE(202)] = 9434,
  [SMALL_STATE(203)] = 9528,
  [SMALL_STATE(204)] = 9572,
  [SMALL_STATE(205)] = 9663,
  [SMALL_STATE(206)] = 9720,
  [SMALL_STATE(207)] = 9773,
  [SMALL_STATE(208)] = 9836,
  [SMALL_STATE(209)] = 9927,
  [SMALL_STATE(210)] = 10020,
  [SMALL_STATE(211)] = 10083,
  [SMALL_STATE(212)] = 10136,
  [SMALL_STATE(213)] = 10199,
  [SMALL_STATE(214)] = 10290,
  [SMALL_STATE(215)] = 10349,
  [SMALL_STATE(216)] = 10442,
  [SMALL_STATE(217)] = 10505,
  [SMALL_STATE(218)] = 10564,
  [SMALL_STATE(219)] = 10621,
  [SMALL_STATE(220)] = 10678,
  [SMALL_STATE(221)] = 10766,
  [SMALL_STATE(222)] = 10854,
  [SMALL_STATE(223)] = 10942,
  [SMALL_STATE(224)] = 10990,
  [SMALL_STATE(225)] = 11078,
  [SMALL_STATE(226)] = 11126,
  [SMALL_STATE(227)] = 11214,
  [SMALL_STATE(228)] = 11262,
  [SMALL_STATE(229)] = 11350,
  [SMALL_STATE(230)] = 11434,
  [SMALL_STATE(231)] = 11518,
  [SMALL_STATE(232)] = 11606,
  [SMALL_STATE(233)] = 11694,
  [SMALL_STATE(234)] = 11778,
  [SMALL_STATE(235)] = 11862,
  [SMALL_STATE(236)] = 11946,
  [SMALL_STATE(237)] = 12034,
  [SMALL_STATE(238)] = 12122,
  [SMALL_STATE(239)] = 12210,
  [SMALL_STATE(240)] = 12298,
  [SMALL_STATE(241)] = 12346,
  [SMALL_STATE(242)] = 12434,
  [SMALL_STATE(243)] = 12522,
  [SMALL_STATE(244)] = 12610,
  [SMALL_STATE(245)] = 12698,
  [SMALL_STATE(246)] = 12786,
  [SMALL_STATE(247)] = 12874,
  [SMALL_STATE(248)] = 12940,
  [SMALL_STATE(249)] = 13028,
  [SMALL_STATE(250)] = 13116,
  [SMALL_STATE(251)] = 13204,
  [SMALL_STATE(252)] = 13292,
  [SMALL_STATE(253)] = 13380,
  [SMALL_STATE(254)] = 13446,
  [SMALL_STATE(255)] = 13534,
  [SMALL_STATE(256)] = 13622,
  [SMALL_STATE(257)] = 13710,
  [SMALL_STATE(258)] = 13798,
  [SMALL_STATE(259)] = 13886,
  [SMALL_STATE(260)] = 13974,
  [SMALL_STATE(261)] = 14058,
  [SMALL_STATE(262)] = 14142,
  [SMALL_STATE(263)] = 14226,
  [SMALL_STATE(264)] = 14310,
  [SMALL_STATE(265)] = 14394,
  [SMALL_STATE(266)] = 14482,
  [SMALL_STATE(267)] = 14570,
  [SMALL_STATE(268)] = 14658,
  [SMALL_STATE(269)] = 14746,
  [SMALL_STATE(270)] = 14834,
  [SMALL_STATE(271)] = 14922,
  [SMALL_STATE(272)] = 15010,
  [SMALL_STATE(273)] = 15098,
  [SMALL_STATE(274)] = 15186,
  [SMALL_STATE(275)] = 15274,
  [SMALL_STATE(276)] = 15362,
  [SMALL_STATE(277)] = 15450,
  [SMALL_STATE(278)] = 15538,
  [SMALL_STATE(279)] = 15626,
  [SMALL_STATE(280)] = 15714,
  [SMALL_STATE(281)] = 15802,
  [SMALL_STATE(282)] = 15890,
  [SMALL_STATE(283)] = 15978,
  [SMALL_STATE(284)] = 16066,
  [SMALL_STATE(285)] = 16154,
  [SMALL_STATE(286)] = 16242,
  [SMALL_STATE(287)] = 16326,
  [SMALL_STATE(288)] = 16410,
  [SMALL_STATE(289)] = 16494,
  [SMALL_STATE(290)] = 16582,
  [SMALL_STATE(291)] = 16666,
  [SMALL_STATE(292)] = 16750,
  [SMALL_STATE(293)] = 16838,
  [SMALL_STATE(294)] = 16926,
  [SMALL_STATE(295)] = 17014,
  [SMALL_STATE(296)] = 17102,
  [SMALL_STATE(297)] = 17190,
  [SMALL_STATE(298)] = 17278,
  [SMALL_STATE(299)] = 17366,
  [SMALL_STATE(300)] = 17454,
  [SMALL_STATE(301)] = 17542,
  [SMALL_STATE(302)] = 17630,
  [SMALL_STATE(303)] = 17718,
  [SMALL_STATE(304)] = 17806,
  [SMALL_STATE(305)] = 17894,
  [SMALL_STATE(306)] = 17982,
  [SMALL_STATE(307)] = 18070,
  [SMALL_STATE(308)] = 18158,
  [SMALL_STATE(309)] = 18246,
  [SMALL_STATE(310)] = 18334,
  [SMALL_STATE(311)] = 18380,
  [SMALL_STATE(312)] = 18426,
  [SMALL_STATE(313)] = 18514,
  [SMALL_STATE(314)] = 18602,
  [SMALL_STATE(315)] = 18644,
  [SMALL_STATE(316)] = 18732,
  [SMALL_STATE(317)] = 18820,
  [SMALL_STATE(318)] = 18908,
  [SMALL_STATE(319)] = 18996,
  [SMALL_STATE(320)] = 19084,
  [SMALL_STATE(321)] = 19172,
  [SMALL_STATE(322)] = 19260,
  [SMALL_STATE(323)] = 19348,
  [SMALL_STATE(324)] = 19436,
  [SMALL_STATE(325)] = 19524,
  [SMALL_STATE(326)] = 19608,
  [SMALL_STATE(327)] = 19692,
  [SMALL_STATE(328)] = 19776,
  [SMALL_STATE(329)] = 19860,
  [SMALL_STATE(330)] = 19944,
  [SMALL_STATE(331)] = 20032,
  [SMALL_STATE(332)] = 20120,
  [SMALL_STATE(333)] = 20208,
  [SMALL_STATE(334)] = 20296,
  [SMALL_STATE(335)] = 20384,
  [SMALL_STATE(336)] = 20472,
  [SMALL_STATE(337)] = 20560,
  [SMALL_STATE(338)] = 20648,
  [SMALL_STATE(339)] = 20736,
  [SMALL_STATE(340)] = 20824,
  [SMALL_STATE(341)] = 20912,
  [SMALL_STATE(342)] = 20960,
  [SMALL_STATE(343)] = 21048,
  [SMALL_STATE(344)] = 21136,
  [SMALL_STATE(345)] = 21224,
  [SMALL_STATE(346)] = 21276,
  [SMALL_STATE(347)] = 21364,
  [SMALL_STATE(348)] = 21412,
  [SMALL_STATE(349)] = 21500,
  [SMALL_STATE(350)] = 21588,
  [SMALL_STATE(351)] = 21676,
  [SMALL_STATE(352)] = 21764,
  [SMALL_STATE(353)] = 21852,
  [SMALL_STATE(354)] = 21940,
  [SMALL_STATE(355)] = 22006,
  [SMALL_STATE(356)] = 22072,
  [SMALL_STATE(357)] = 22160,
  [SMALL_STATE(358)] = 22213,
  [SMALL_STATE(359)] = 22276,
  [SMALL_STATE(360)] = 22333,
  [SMALL_STATE(361)] = 22376,
  [SMALL_STATE(362)] = 22419,
  [SMALL_STATE(363)] = 22462,
  [SMALL_STATE(364)] = 22519,
  [SMALL_STATE(365)] = 22584,
  [SMALL_STATE(366)] = 22629,
  [SMALL_STATE(367)] = 22686,
  [SMALL_STATE(368)] = 22749,
  [SMALL_STATE(369)] = 22812,
  [SMALL_STATE(370)] = 22855,
  [SMALL_STATE(371)] = 22900,
  [SMALL_STATE(372)] = 22957,
  [SMALL_STATE(373)] = 23000,
  [SMALL_STATE(374)] = 23045,
  [SMALL_STATE(375)] = 23098,
  [SMALL_STATE(376)] = 23155,
  [SMALL_STATE(377)] = 23198,
  [SMALL_STATE(378)] = 23261,
  [SMALL_STATE(379)] = 23304,
  [SMALL_STATE(380)] = 23346,
  [SMALL_STATE(381)] = 23408,
  [SMALL_STATE(382)] = 23450,
  [SMALL_STATE(383)] = 23492,
  [SMALL_STATE(384)] = 23542,
  [SMALL_STATE(385)] = 23606,
  [SMALL_STATE(386)] = 23646,
  [SMALL_STATE(387)] = 23688,
  [SMALL_STATE(388)] = 23730,
  [SMALL_STATE(389)] = 23771,
  [SMALL_STATE(390)] = 23816,
  [SMALL_STATE(391)] = 23861,
  [SMALL_STATE(392)] = 23900,
  [SMALL_STATE(393)] = 23945,
  [SMALL_STATE(394)] = 23988,
  [SMALL_STATE(395)] = 24045,
  [SMALL_STATE(396)] = 24108,
  [SMALL_STATE(397)] = 24147,
  [SMALL_STATE(398)] = 24186,
  [SMALL_STATE(399)] = 24237,
  [SMALL_STATE(400)] = 24276,
  [SMALL_STATE(401)] = 24339,
  [SMALL_STATE(402)] = 24378,
  [SMALL_STATE(403)] = 24435,
  [SMALL_STATE(404)] = 24478,
  [SMALL_STATE(405)] = 24523,
  [SMALL_STATE(406)] = 24564,
  [SMALL_STATE(407)] = 24605,
  [SMALL_STATE(408)] = 24650,
  [SMALL_STATE(409)] = 24689,
  [SMALL_STATE(410)] = 24732,
  [SMALL_STATE(411)] = 24773,
  [SMALL_STATE(412)] = 24818,
  [SMALL_STATE(413)] = 24881,
  [SMALL_STATE(414)] = 24920,
  [SMALL_STATE(415)] = 24983,
  [SMALL_STATE(416)] = 25028,
  [SMALL_STATE(417)] = 25069,
  [SMALL_STATE(418)] = 25114,
  [SMALL_STATE(419)] = 25155,
  [SMALL_STATE(420)] = 25196,
  [SMALL_STATE(421)] = 25237,
  [SMALL_STATE(422)] = 25278,
  [SMALL_STATE(423)] = 25323,
  [SMALL_STATE(424)] = 25366,
  [SMALL_STATE(425)] = 25407,
  [SMALL_STATE(426)] = 25452,
  [SMALL_STATE(427)] = 25497,
  [SMALL_STATE(428)] = 25560,
  [SMALL_STATE(429)] = 25599,
  [SMALL_STATE(430)] = 25638,
  [SMALL_STATE(431)] = 25679,
  [SMALL_STATE(432)] = 25720,
  [SMALL_STATE(433)] = 25761,
  [SMALL_STATE(434)] = 25800,
  [SMALL_STATE(435)] = 25841,
  [SMALL_STATE(436)] = 25886,
  [SMALL_STATE(437)] = 25931,
  [SMALL_STATE(438)] = 25972,
  [SMALL_STATE(439)] = 26017,
  [SMALL_STATE(440)] = 26062,
  [SMALL_STATE(441)] = 26119,
  [SMALL_STATE(442)] = 26158,
  [SMALL_STATE(443)] = 26219,
  [SMALL_STATE(444)] = 26260,
  [SMALL_STATE(445)] = 26305,
  [SMALL_STATE(446)] = 26346,
  [SMALL_STATE(447)] = 26387,
  [SMALL_STATE(448)] = 26430,
  [SMALL_STATE(449)] = 26481,
  [SMALL_STATE(450)] = 26526,
  [SMALL_STATE(451)] = 26573,
  [SMALL_STATE(452)] = 26612,
  [SMALL_STATE(453)] = 26653,
  [SMALL_STATE(454)] = 26698,
  [SMALL_STATE(455)] = 26741,
  [SMALL_STATE(456)] = 26782,
  [SMALL_STATE(457)] = 26840,
  [SMALL_STATE(458)] = 26880,
  [SMALL_STATE(459)] = 26920,
  [SMALL_STATE(460)] = 26959,
  [SMALL_STATE(461)] = 27004,
  [SMALL_STATE(462)] = 27043,
  [SMALL_STATE(463)] = 27086,
  [SMALL_STATE(464)] = 27131,
  [SMALL_STATE(465)] = 27174,
  [SMALL_STATE(466)] = 27213,
  [SMALL_STATE(467)] = 27258,
  [SMALL_STATE(468)] = 27297,
  [SMALL_STATE(469)] = 27340,
  [SMALL_STATE(470)] = 27383,
  [SMALL_STATE(471)] = 27424,
  [SMALL_STATE(472)] = 27465,
  [SMALL_STATE(473)] = 27506,
  [SMALL_STATE(474)] = 27545,
  [SMALL_STATE(475)] = 27592,
  [SMALL_STATE(476)] = 27637,
  [SMALL_STATE(477)] = 27678,
  [SMALL_STATE(478)] = 27719,
  [SMALL_STATE(479)] = 27762,
  [SMALL_STATE(480)] = 27805,
  [SMALL_STATE(481)] = 27846,
  [SMALL_STATE(482)] = 27885,
  [SMALL_STATE(483)] = 27924,
  [SMALL_STATE(484)] = 27967,
  [SMALL_STATE(485)] = 28008,
  [SMALL_STATE(486)] = 28053,
  [SMALL_STATE(487)] = 28096,
  [SMALL_STATE(488)] = 28135,
  [SMALL_STATE(489)] = 28178,
  [SMALL_STATE(490)] = 28219,
  [SMALL_STATE(491)] = 28258,
  [SMALL_STATE(492)] = 28297,
  [SMALL_STATE(493)] = 28342,
  [SMALL_STATE(494)] = 28387,
  [SMALL_STATE(495)] = 28428,
  [SMALL_STATE(496)] = 28473,
  [SMALL_STATE(497)] = 28518,
  [SMALL_STATE(498)] = 28559,
  [SMALL_STATE(499)] = 28598,
  [SMALL_STATE(500)] = 28643,
  [SMALL_STATE(501)] = 28686,
  [SMALL_STATE(502)] = 28727,
  [SMALL_STATE(503)] = 28772,
  [SMALL_STATE(504)] = 28813,
  [SMALL_STATE(505)] = 28856,
  [SMALL_STATE(506)] = 28897,
  [SMALL_STATE(507)] = 28936,
  [SMALL_STATE(508)] = 28981,
  [SMALL_STATE(509)] = 29026,
  [SMALL_STATE(510)] = 29071,
  [SMALL_STATE(511)] = 29114,
  [SMALL_STATE(512)] = 29155,
  [SMALL_STATE(513)] = 29197,
  [SMALL_STATE(514)] = 29239,
  [SMALL_STATE(515)] = 29277,
  [SMALL_STATE(516)] = 29319,
  [SMALL_STATE(517)] = 29359,
  [SMALL_STATE(518)] = 29397,
  [SMALL_STATE(519)] = 29440,
  [SMALL_STATE(520)] = 29483,
  [SMALL_STATE(521)] = 29524,
  [SMALL_STATE(522)] = 29569,
  [SMALL_STATE(523)] = 29612,
  [SMALL_STATE(524)] = 29649,
  [SMALL_STATE(525)] = 29694,
  [SMALL_STATE(526)] = 29735,
  [SMALL_STATE(527)] = 29772,
  [SMALL_STATE(528)] = 29817,
  [SMALL_STATE(529)] = 29854,
  [SMALL_STATE(530)] = 29893,
  [SMALL_STATE(531)] = 29938,
  [SMALL_STATE(532)] = 29983,
  [SMALL_STATE(533)] = 30022,
  [SMALL_STATE(534)] = 30061,
  [SMALL_STATE(535)] = 30100,
  [SMALL_STATE(536)] = 30143,
  [SMALL_STATE(537)] = 30180,
  [SMALL_STATE(538)] = 30225,
  [SMALL_STATE(539)] = 30264,
  [SMALL_STATE(540)] = 30303,
  [SMALL_STATE(541)] = 30344,
  [SMALL_STATE(542)] = 30383,
  [SMALL_STATE(543)] = 30428,
  [SMALL_STATE(544)] = 30465,
  [SMALL_STATE(545)] = 30508,
  [SMALL_STATE(546)] = 30545,
  [SMALL_STATE(547)] = 30582,
  [SMALL_STATE(548)] = 30627,
  [SMALL_STATE(549)] = 30664,
  [SMALL_STATE(550)] = 30709,
  [SMALL_STATE(551)] = 30750,
  [SMALL_STATE(552)] = 30791,
  [SMALL_STATE(553)] = 30830,
  [SMALL_STATE(554)] = 30869,
  [SMALL_STATE(555)] = 30906,
  [SMALL_STATE(556)] = 30943,
  [SMALL_STATE(557)] = 30988,
  [SMALL_STATE(558)] = 31025,
  [SMALL_STATE(559)] = 31068,
  [SMALL_STATE(560)] = 31105,
  [SMALL_STATE(561)] = 31150,
  [SMALL_STATE(562)] = 31195,
  [SMALL_STATE(563)] = 31240,
  [SMALL_STATE(564)] = 31279,
  [SMALL_STATE(565)] = 31323,
  [SMALL_STATE(566)] = 31367,
  [SMALL_STATE(567)] = 31405,
  [SMALL_STATE(568)] = 31445,
  [SMALL_STATE(569)] = 31487,
  [SMALL_STATE(570)] = 31529,
  [SMALL_STATE(571)] = 31573,
  [SMALL_STATE(572)] = 31615,
  [SMALL_STATE(573)] = 31661,
  [SMALL_STATE(574)] = 31707,
  [SMALL_STATE(575)] = 31752,
  [SMALL_STATE(576)] = 31797,
  [SMALL_STATE(577)] = 31842,
  [SMALL_STATE(578)] = 31887,
  [SMALL_STATE(579)] = 31932,
  [SMALL_STATE(580)] = 31977,
  [SMALL_STATE(581)] = 32022,
  [SMALL_STATE(582)] = 32067,
  [SMALL_STATE(583)] = 32112,
  [SMALL_STATE(584)] = 32157,
  [SMALL_STATE(585)] = 32202,
  [SMALL_STATE(586)] = 32245,
  [SMALL_STATE(587)] = 32286,
  [SMALL_STATE(588)] = 32331,
  [SMALL_STATE(589)] = 32376,
  [SMALL_STATE(590)] = 32421,
  [SMALL_STATE(591)] = 32466,
  [SMALL_STATE(592)] = 32508,
  [SMALL_STATE(593)] = 32550,
  [SMALL_STATE(594)] = 32592,
  [SMALL_STATE(595)] = 32634,
  [SMALL_STATE(596)] = 32676,
  [SMALL_STATE(597)] = 32716,
  [SMALL_STATE(598)] = 32754,
  [SMALL_STATE(599)] = 32796,
  [SMALL_STATE(600)] = 32838,
  [SMALL_STATE(601)] = 32877,
  [SMALL_STATE(602)] = 32916,
  [SMALL_STATE(603)] = 32955,
  [SMALL_STATE(604)] = 32988,
  [SMALL_STATE(605)] = 33016,
  [SMALL_STATE(606)] = 33061,
  [SMALL_STATE(607)] = 33114,
  [SMALL_STATE(608)] = 33142,
  [SMALL_STATE(609)] = 33170,
  [SMALL_STATE(610)] = 33198,
  [SMALL_STATE(611)] = 33226,
  [SMALL_STATE(612)] = 33270,
  [SMALL_STATE(613)] = 33298,
  [SMALL_STATE(614)] = 33326,
  [SMALL_STATE(615)] = 33355,
  [SMALL_STATE(616)] = 33384,
  [SMALL_STATE(617)] = 33417,
  [SMALL_STATE(618)] = 33446,
  [SMALL_STATE(619)] = 33469,
  [SMALL_STATE(620)] = 33502,
  [SMALL_STATE(621)] = 33525,
  [SMALL_STATE(622)] = 33554,
  [SMALL_STATE(623)] = 33583,
  [SMALL_STATE(624)] = 33609,
  [SMALL_STATE(625)] = 33637,
  [SMALL_STATE(626)] = 33675,
  [SMALL_STATE(627)] = 33701,
  [SMALL_STATE(628)] = 33729,
  [SMALL_STATE(629)] = 33767,
  [SMALL_STATE(630)] = 33805,
  [SMALL_STATE(631)] = 33833,
  [SMALL_STATE(632)] = 33871,
  [SMALL_STATE(633)] = 33899,
  [SMALL_STATE(634)] = 33924,
  [SMALL_STATE(635)] = 33955,
  [SMALL_STATE(636)] = 33976,
  [SMALL_STATE(637)] = 34015,
  [SMALL_STATE(638)] = 34036,
  [SMALL_STATE(639)] = 34057,
  [SMALL_STATE(640)] = 34088,
  [SMALL_STATE(641)] = 34113,
  [SMALL_STATE(642)] = 34144,
  [SMALL_STATE(643)] = 34177,
  [SMALL_STATE(644)] = 34210,
  [SMALL_STATE(645)] = 34241,
  [SMALL_STATE(646)] = 34272,
  [SMALL_STATE(647)] = 34303,
  [SMALL_STATE(648)] = 34324,
  [SMALL_STATE(649)] = 34345,
  [SMALL_STATE(650)] = 34366,
  [SMALL_STATE(651)] = 34398,
  [SMALL_STATE(652)] = 34420,
  [SMALL_STATE(653)] = 34454,
  [SMALL_STATE(654)] = 34488,
  [SMALL_STATE(655)] = 34514,
  [SMALL_STATE(656)] = 34542,
  [SMALL_STATE(657)] = 34568,
  [SMALL_STATE(658)] = 34602,
  [SMALL_STATE(659)] = 34636,
  [SMALL_STATE(660)] = 34670,
  [SMALL_STATE(661)] = 34704,
  [SMALL_STATE(662)] = 34736,
  [SMALL_STATE(663)] = 34768,
  [SMALL_STATE(664)] = 34802,
  [SMALL_STATE(665)] = 34829,
  [SMALL_STATE(666)] = 34854,
  [SMALL_STATE(667)] = 34881,
  [SMALL_STATE(668)] = 34912,
  [SMALL_STATE(669)] = 34939,
  [SMALL_STATE(670)] = 34966,
  [SMALL_STATE(671)] = 34993,
  [SMALL_STATE(672)] = 35020,
  [SMALL_STATE(673)] = 35039,
  [SMALL_STATE(674)] = 35066,
  [SMALL_STATE(675)] = 35097,
  [SMALL_STATE(676)] = 35124,
  [SMALL_STATE(677)] = 35151,
  [SMALL_STATE(678)] = 35173,
  [SMALL_STATE(679)] = 35199,
  [SMALL_STATE(680)] = 35221,
  [SMALL_STATE(681)] = 35245,
  [SMALL_STATE(682)] = 35269,
  [SMALL_STATE(683)] = 35285,
  [SMALL_STATE(684)] = 35311,
  [SMALL_STATE(685)] = 35335,
  [SMALL_STATE(686)] = 35359,
  [SMALL_STATE(687)] = 35375,
  [SMALL_STATE(688)] = 35399,
  [SMALL_STATE(689)] = 35419,
  [SMALL_STATE(690)] = 35440,
  [SMALL_STATE(691)] = 35461,
  [SMALL_STATE(692)] = 35482,
  [SMALL_STATE(693)] = 35497,
  [SMALL_STATE(694)] = 35520,
  [SMALL_STATE(695)] = 35543,
  [SMALL_STATE(696)] = 35566,
  [SMALL_STATE(697)] = 35587,
  [SMALL_STATE(698)] = 35610,
  [SMALL_STATE(699)] = 35633,
  [SMALL_STATE(700)] = 35650,
  [SMALL_STATE(701)] = 35671,
  [SMALL_STATE(702)] = 35691,
  [SMALL_STATE(703)] = 35711,
  [SMALL_STATE(704)] = 35731,
  [SMALL_STATE(705)] = 35751,
  [SMALL_STATE(706)] = 35771,
  [SMALL_STATE(707)] = 35793,
  [SMALL_STATE(708)] = 35815,
  [SMALL_STATE(709)] = 35837,
  [SMALL_STATE(710)] = 35859,
  [SMALL_STATE(711)] = 35881,
  [SMALL_STATE(712)] = 35903,
  [SMALL_STATE(713)] = 35921,
  [SMALL_STATE(714)] = 35943,
  [SMALL_STATE(715)] = 35963,
  [SMALL_STATE(716)] = 35985,
  [SMALL_STATE(717)] = 36007,
  [SMALL_STATE(718)] = 36031,
  [SMALL_STATE(719)] = 36051,
  [SMALL_STATE(720)] = 36069,
  [SMALL_STATE(721)] = 36091,
  [SMALL_STATE(722)] = 36113,
  [SMALL_STATE(723)] = 36133,
  [SMALL_STATE(724)] = 36155,
  [SMALL_STATE(725)] = 36177,
  [SMALL_STATE(726)] = 36197,
  [SMALL_STATE(727)] = 36217,
  [SMALL_STATE(728)] = 36237,
  [SMALL_STATE(729)] = 36257,
  [SMALL_STATE(730)] = 36277,
  [SMALL_STATE(731)] = 36297,
  [SMALL_STATE(732)] = 36323,
  [SMALL_STATE(733)] = 36347,
  [SMALL_STATE(734)] = 36367,
  [SMALL_STATE(735)] = 36381,
  [SMALL_STATE(736)] = 36395,
  [SMALL_STATE(737)] = 36415,
  [SMALL_STATE(738)] = 36435,
  [SMALL_STATE(739)] = 36457,
  [SMALL_STATE(740)] = 36477,
  [SMALL_STATE(741)] = 36497,
  [SMALL_STATE(742)] = 36517,
  [SMALL_STATE(743)] = 36533,
  [SMALL_STATE(744)] = 36548,
  [SMALL_STATE(745)] = 36569,
  [SMALL_STATE(746)] = 36590,
  [SMALL_STATE(747)] = 36611,
  [SMALL_STATE(748)] = 36628,
  [SMALL_STATE(749)] = 36649,
  [SMALL_STATE(750)] = 36664,
  [SMALL_STATE(751)] = 36679,
  [SMALL_STATE(752)] = 36696,
  [SMALL_STATE(753)] = 36713,
  [SMALL_STATE(754)] = 36728,
  [SMALL_STATE(755)] = 36745,
  [SMALL_STATE(756)] = 36762,
  [SMALL_STATE(757)] = 36777,
  [SMALL_STATE(758)] = 36792,
  [SMALL_STATE(759)] = 36807,
  [SMALL_STATE(760)] = 36824,
  [SMALL_STATE(761)] = 36839,
  [SMALL_STATE(762)] = 36854,
  [SMALL_STATE(763)] = 36869,
  [SMALL_STATE(764)] = 36884,
  [SMALL_STATE(765)] = 36901,
  [SMALL_STATE(766)] = 36922,
  [SMALL_STATE(767)] = 36943,
  [SMALL_STATE(768)] = 36960,
  [SMALL_STATE(769)] = 36979,
  [SMALL_STATE(770)] = 36996,
  [SMALL_STATE(771)] = 37011,
  [SMALL_STATE(772)] = 37026,
  [SMALL_STATE(773)] = 37045,
  [SMALL_STATE(774)] = 37062,
  [SMALL_STATE(775)] = 37079,
  [SMALL_STATE(776)] = 37100,
  [SMALL_STATE(777)] = 37117,
  [SMALL_STATE(778)] = 37134,
  [SMALL_STATE(779)] = 37149,
  [SMALL_STATE(780)] = 37164,
  [SMALL_STATE(781)] = 37179,
  [SMALL_STATE(782)] = 37198,
  [SMALL_STATE(783)] = 37213,
  [SMALL_STATE(784)] = 37230,
  [SMALL_STATE(785)] = 37251,
  [SMALL_STATE(786)] = 37268,
  [SMALL_STATE(787)] = 37285,
  [SMALL_STATE(788)] = 37306,
  [SMALL_STATE(789)] = 37321,
  [SMALL_STATE(790)] = 37338,
  [SMALL_STATE(791)] = 37357,
  [SMALL_STATE(792)] = 37374,
  [SMALL_STATE(793)] = 37391,
  [SMALL_STATE(794)] = 37408,
  [SMALL_STATE(795)] = 37429,
  [SMALL_STATE(796)] = 37444,
  [SMALL_STATE(797)] = 37463,
  [SMALL_STATE(798)] = 37480,
  [SMALL_STATE(799)] = 37497,
  [SMALL_STATE(800)] = 37514,
  [SMALL_STATE(801)] = 37535,
  [SMALL_STATE(802)] = 37550,
  [SMALL_STATE(803)] = 37571,
  [SMALL_STATE(804)] = 37583,
  [SMALL_STATE(805)] = 37597,
  [SMALL_STATE(806)] = 37613,
  [SMALL_STATE(807)] = 37627,
  [SMALL_STATE(808)] = 37647,
  [SMALL_STATE(809)] = 37667,
  [SMALL_STATE(810)] = 37681,
  [SMALL_STATE(811)] = 37695,
  [SMALL_STATE(812)] = 37709,
  [SMALL_STATE(813)] = 37723,
  [SMALL_STATE(814)] = 37743,
  [SMALL_STATE(815)] = 37755,
  [SMALL_STATE(816)] = 37767,
  [SMALL_STATE(817)] = 37787,
  [SMALL_STATE(818)] = 37801,
  [SMALL_STATE(819)] = 37815,
  [SMALL_STATE(820)] = 37835,
  [SMALL_STATE(821)] = 37847,
  [SMALL_STATE(822)] = 37867,
  [SMALL_STATE(823)] = 37879,
  [SMALL_STATE(824)] = 37897,
  [SMALL_STATE(825)] = 37911,
  [SMALL_STATE(826)] = 37927,
  [SMALL_STATE(827)] = 37947,
  [SMALL_STATE(828)] = 37961,
  [SMALL_STATE(829)] = 37981,
  [SMALL_STATE(830)] = 37993,
  [SMALL_STATE(831)] = 38005,
  [SMALL_STATE(832)] = 38019,
  [SMALL_STATE(833)] = 38039,
  [SMALL_STATE(834)] = 38055,
  [SMALL_STATE(835)] = 38071,
  [SMALL_STATE(836)] = 38083,
  [SMALL_STATE(837)] = 38099,
  [SMALL_STATE(838)] = 38111,
  [SMALL_STATE(839)] = 38127,
  [SMALL_STATE(840)] = 38143,
  [SMALL_STATE(841)] = 38163,
  [SMALL_STATE(842)] = 38177,
  [SMALL_STATE(843)] = 38193,
  [SMALL_STATE(844)] = 38207,
  [SMALL_STATE(845)] = 38225,
  [SMALL_STATE(846)] = 38241,
  [SMALL_STATE(847)] = 38261,
  [SMALL_STATE(848)] = 38275,
  [SMALL_STATE(849)] = 38291,
  [SMALL_STATE(850)] = 38305,
  [SMALL_STATE(851)] = 38321,
  [SMALL_STATE(852)] = 38341,
  [SMALL_STATE(853)] = 38361,
  [SMALL_STATE(854)] = 38375,
  [SMALL_STATE(855)] = 38391,
  [SMALL_STATE(856)] = 38407,
  [SMALL_STATE(857)] = 38421,
  [SMALL_STATE(858)] = 38435,
  [SMALL_STATE(859)] = 38447,
  [SMALL_STATE(860)] = 38461,
  [SMALL_STATE(861)] = 38475,
  [SMALL_STATE(862)] = 38489,
  [SMALL_STATE(863)] = 38501,
  [SMALL_STATE(864)] = 38515,
  [SMALL_STATE(865)] = 38535,
  [SMALL_STATE(866)] = 38547,
  [SMALL_STATE(867)] = 38561,
  [SMALL_STATE(868)] = 38573,
  [SMALL_STATE(869)] = 38587,
  [SMALL_STATE(870)] = 38599,
  [SMALL_STATE(871)] = 38613,
  [SMALL_STATE(872)] = 38627,
  [SMALL_STATE(873)] = 38641,
  [SMALL_STATE(874)] = 38653,
  [SMALL_STATE(875)] = 38667,
  [SMALL_STATE(876)] = 38681,
  [SMALL_STATE(877)] = 38695,
  [SMALL_STATE(878)] = 38709,
  [SMALL_STATE(879)] = 38725,
  [SMALL_STATE(880)] = 38745,
  [SMALL_STATE(881)] = 38761,
  [SMALL_STATE(882)] = 38777,
  [SMALL_STATE(883)] = 38791,
  [SMALL_STATE(884)] = 38805,
  [SMALL_STATE(885)] = 38819,
  [SMALL_STATE(886)] = 38835,
  [SMALL_STATE(887)] = 38851,
  [SMALL_STATE(888)] = 38867,
  [SMALL_STATE(889)] = 38881,
  [SMALL_STATE(890)] = 38895,
  [SMALL_STATE(891)] = 38906,
  [SMALL_STATE(892)] = 38917,
  [SMALL_STATE(893)] = 38934,
  [SMALL_STATE(894)] = 38951,
  [SMALL_STATE(895)] = 38966,
  [SMALL_STATE(896)] = 38981,
  [SMALL_STATE(897)] = 38992,
  [SMALL_STATE(898)] = 39003,
  [SMALL_STATE(899)] = 39018,
  [SMALL_STATE(900)] = 39033,
  [SMALL_STATE(901)] = 39044,
  [SMALL_STATE(902)] = 39059,
  [SMALL_STATE(903)] = 39070,
  [SMALL_STATE(904)] = 39087,
  [SMALL_STATE(905)] = 39104,
  [SMALL_STATE(906)] = 39121,
  [SMALL_STATE(907)] = 39132,
  [SMALL_STATE(908)] = 39143,
  [SMALL_STATE(909)] = 39160,
  [SMALL_STATE(910)] = 39177,
  [SMALL_STATE(911)] = 39188,
  [SMALL_STATE(912)] = 39205,
  [SMALL_STATE(913)] = 39222,
  [SMALL_STATE(914)] = 39233,
  [SMALL_STATE(915)] = 39248,
  [SMALL_STATE(916)] = 39259,
  [SMALL_STATE(917)] = 39274,
  [SMALL_STATE(918)] = 39285,
  [SMALL_STATE(919)] = 39300,
  [SMALL_STATE(920)] = 39317,
  [SMALL_STATE(921)] = 39332,
  [SMALL_STATE(922)] = 39347,
  [SMALL_STATE(923)] = 39358,
  [SMALL_STATE(924)] = 39373,
  [SMALL_STATE(925)] = 39384,
  [SMALL_STATE(926)] = 39395,
  [SMALL_STATE(927)] = 39406,
  [SMALL_STATE(928)] = 39421,
  [SMALL_STATE(929)] = 39432,
  [SMALL_STATE(930)] = 39447,
  [SMALL_STATE(931)] = 39458,
  [SMALL_STATE(932)] = 39475,
  [SMALL_STATE(933)] = 39486,
  [SMALL_STATE(934)] = 39497,
  [SMALL_STATE(935)] = 39512,
  [SMALL_STATE(936)] = 39523,
  [SMALL_STATE(937)] = 39540,
  [SMALL_STATE(938)] = 39557,
  [SMALL_STATE(939)] = 39568,
  [SMALL_STATE(940)] = 39585,
  [SMALL_STATE(941)] = 39602,
  [SMALL_STATE(942)] = 39613,
  [SMALL_STATE(943)] = 39630,
  [SMALL_STATE(944)] = 39645,
  [SMALL_STATE(945)] = 39656,
  [SMALL_STATE(946)] = 39671,
  [SMALL_STATE(947)] = 39686,
  [SMALL_STATE(948)] = 39697,
  [SMALL_STATE(949)] = 39708,
  [SMALL_STATE(950)] = 39725,
  [SMALL_STATE(951)] = 39736,
  [SMALL_STATE(952)] = 39747,
  [SMALL_STATE(953)] = 39764,
  [SMALL_STATE(954)] = 39775,
  [SMALL_STATE(955)] = 39792,
  [SMALL_STATE(956)] = 39803,
  [SMALL_STATE(957)] = 39820,
  [SMALL_STATE(958)] = 39837,
  [SMALL_STATE(959)] = 39848,
  [SMALL_STATE(960)] = 39863,
  [SMALL_STATE(961)] = 39880,
  [SMALL_STATE(962)] = 39895,
  [SMALL_STATE(963)] = 39910,
  [SMALL_STATE(964)] = 39925,
  [SMALL_STATE(965)] = 39940,
  [SMALL_STATE(966)] = 39951,
  [SMALL_STATE(967)] = 39962,
  [SMALL_STATE(968)] = 39979,
  [SMALL_STATE(969)] = 39990,
  [SMALL_STATE(970)] = 40001,
  [SMALL_STATE(971)] = 40012,
  [SMALL_STATE(972)] = 40023,
  [SMALL_STATE(973)] = 40040,
  [SMALL_STATE(974)] = 40055,
  [SMALL_STATE(975)] = 40066,
  [SMALL_STATE(976)] = 40077,
  [SMALL_STATE(977)] = 40090,
  [SMALL_STATE(978)] = 40101,
  [SMALL_STATE(979)] = 40112,
  [SMALL_STATE(980)] = 40127,
  [SMALL_STATE(981)] = 40142,
  [SMALL_STATE(982)] = 40157,
  [SMALL_STATE(983)] = 40172,
  [SMALL_STATE(984)] = 40187,
  [SMALL_STATE(985)] = 40202,
  [SMALL_STATE(986)] = 40213,
  [SMALL_STATE(987)] = 40224,
  [SMALL_STATE(988)] = 40241,
  [SMALL_STATE(989)] = 40252,
  [SMALL_STATE(990)] = 40263,
  [SMALL_STATE(991)] = 40274,
  [SMALL_STATE(992)] = 40289,
  [SMALL_STATE(993)] = 40306,
  [SMALL_STATE(994)] = 40321,
  [SMALL_STATE(995)] = 40338,
  [SMALL_STATE(996)] = 40353,
  [SMALL_STATE(997)] = 40370,
  [SMALL_STATE(998)] = 40387,
  [SMALL_STATE(999)] = 40398,
  [SMALL_STATE(1000)] = 40409,
  [SMALL_STATE(1001)] = 40426,
  [SMALL_STATE(1002)] = 40443,
  [SMALL_STATE(1003)] = 40457,
  [SMALL_STATE(1004)] = 40471,
  [SMALL_STATE(1005)] = 40483,
  [SMALL_STATE(1006)] = 40493,
  [SMALL_STATE(1007)] = 40507,
  [SMALL_STATE(1008)] = 40519,
  [SMALL_STATE(1009)] = 40533,
  [SMALL_STATE(1010)] = 40547,
  [SMALL_STATE(1011)] = 40559,
  [SMALL_STATE(1012)] = 40573,
  [SMALL_STATE(1013)] = 40587,
  [SMALL_STATE(1014)] = 40601,
  [SMALL_STATE(1015)] = 40615,
  [SMALL_STATE(1016)] = 40629,
  [SMALL_STATE(1017)] = 40643,
  [SMALL_STATE(1018)] = 40655,
  [SMALL_STATE(1019)] = 40669,
  [SMALL_STATE(1020)] = 40681,
  [SMALL_STATE(1021)] = 40693,
  [SMALL_STATE(1022)] = 40707,
  [SMALL_STATE(1023)] = 40721,
  [SMALL_STATE(1024)] = 40735,
  [SMALL_STATE(1025)] = 40749,
  [SMALL_STATE(1026)] = 40763,
  [SMALL_STATE(1027)] = 40777,
  [SMALL_STATE(1028)] = 40789,
  [SMALL_STATE(1029)] = 40803,
  [SMALL_STATE(1030)] = 40815,
  [SMALL_STATE(1031)] = 40829,
  [SMALL_STATE(1032)] = 40843,
  [SMALL_STATE(1033)] = 40857,
  [SMALL_STATE(1034)] = 40871,
  [SMALL_STATE(1035)] = 40883,
  [SMALL_STATE(1036)] = 40897,
  [SMALL_STATE(1037)] = 40909,
  [SMALL_STATE(1038)] = 40923,
  [SMALL_STATE(1039)] = 40937,
  [SMALL_STATE(1040)] = 40951,
  [SMALL_STATE(1041)] = 40965,
  [SMALL_STATE(1042)] = 40979,
  [SMALL_STATE(1043)] = 40989,
  [SMALL_STATE(1044)] = 41003,
  [SMALL_STATE(1045)] = 41017,
  [SMALL_STATE(1046)] = 41031,
  [SMALL_STATE(1047)] = 41045,
  [SMALL_STATE(1048)] = 41057,
  [SMALL_STATE(1049)] = 41067,
  [SMALL_STATE(1050)] = 41081,
  [SMALL_STATE(1051)] = 41095,
  [SMALL_STATE(1052)] = 41109,
  [SMALL_STATE(1053)] = 41123,
  [SMALL_STATE(1054)] = 41135,
  [SMALL_STATE(1055)] = 41149,
  [SMALL_STATE(1056)] = 41163,
  [SMALL_STATE(1057)] = 41177,
  [SMALL_STATE(1058)] = 41189,
  [SMALL_STATE(1059)] = 41201,
  [SMALL_STATE(1060)] = 41215,
  [SMALL_STATE(1061)] = 41224,
  [SMALL_STATE(1062)] = 41235,
  [SMALL_STATE(1063)] = 41246,
  [SMALL_STATE(1064)] = 41257,
  [SMALL_STATE(1065)] = 41268,
  [SMALL_STATE(1066)] = 41279,
  [SMALL_STATE(1067)] = 41290,
  [SMALL_STATE(1068)] = 41301,
  [SMALL_STATE(1069)] = 41312,
  [SMALL_STATE(1070)] = 41323,
  [SMALL_STATE(1071)] = 41334,
  [SMALL_STATE(1072)] = 41345,
  [SMALL_STATE(1073)] = 41356,
  [SMALL_STATE(1074)] = 41367,
  [SMALL_STATE(1075)] = 41378,
  [SMALL_STATE(1076)] = 41389,
  [SMALL_STATE(1077)] = 41398,
  [SMALL_STATE(1078)] = 41407,
  [SMALL_STATE(1079)] = 41418,
  [SMALL_STATE(1080)] = 41429,
  [SMALL_STATE(1081)] = 41440,
  [SMALL_STATE(1082)] = 41451,
  [SMALL_STATE(1083)] = 41462,
  [SMALL_STATE(1084)] = 41471,
  [SMALL_STATE(1085)] = 41480,
  [SMALL_STATE(1086)] = 41489,
  [SMALL_STATE(1087)] = 41498,
  [SMALL_STATE(1088)] = 41509,
  [SMALL_STATE(1089)] = 41520,
  [SMALL_STATE(1090)] = 41529,
  [SMALL_STATE(1091)] = 41540,
  [SMALL_STATE(1092)] = 41551,
  [SMALL_STATE(1093)] = 41562,
  [SMALL_STATE(1094)] = 41573,
  [SMALL_STATE(1095)] = 41584,
  [SMALL_STATE(1096)] = 41595,
  [SMALL_STATE(1097)] = 41606,
  [SMALL_STATE(1098)] = 41615,
  [SMALL_STATE(1099)] = 41626,
  [SMALL_STATE(1100)] = 41637,
  [SMALL_STATE(1101)] = 41646,
  [SMALL_STATE(1102)] = 41655,
  [SMALL_STATE(1103)] = 41666,
  [SMALL_STATE(1104)] = 41677,
  [SMALL_STATE(1105)] = 41688,
  [SMALL_STATE(1106)] = 41699,
  [SMALL_STATE(1107)] = 41708,
  [SMALL_STATE(1108)] = 41719,
  [SMALL_STATE(1109)] = 41730,
  [SMALL_STATE(1110)] = 41741,
  [SMALL_STATE(1111)] = 41752,
  [SMALL_STATE(1112)] = 41763,
  [SMALL_STATE(1113)] = 41774,
  [SMALL_STATE(1114)] = 41785,
  [SMALL_STATE(1115)] = 41796,
  [SMALL_STATE(1116)] = 41805,
  [SMALL_STATE(1117)] = 41816,
  [SMALL_STATE(1118)] = 41825,
  [SMALL_STATE(1119)] = 41836,
  [SMALL_STATE(1120)] = 41845,
  [SMALL_STATE(1121)] = 41856,
  [SMALL_STATE(1122)] = 41865,
  [SMALL_STATE(1123)] = 41874,
  [SMALL_STATE(1124)] = 41883,
  [SMALL_STATE(1125)] = 41892,
  [SMALL_STATE(1126)] = 41903,
  [SMALL_STATE(1127)] = 41912,
  [SMALL_STATE(1128)] = 41923,
  [SMALL_STATE(1129)] = 41934,
  [SMALL_STATE(1130)] = 41945,
  [SMALL_STATE(1131)] = 41956,
  [SMALL_STATE(1132)] = 41965,
  [SMALL_STATE(1133)] = 41976,
  [SMALL_STATE(1134)] = 41984,
  [SMALL_STATE(1135)] = 41992,
  [SMALL_STATE(1136)] = 42000,
  [SMALL_STATE(1137)] = 42008,
  [SMALL_STATE(1138)] = 42016,
  [SMALL_STATE(1139)] = 42024,
  [SMALL_STATE(1140)] = 42032,
  [SMALL_STATE(1141)] = 42040,
  [SMALL_STATE(1142)] = 42048,
  [SMALL_STATE(1143)] = 42056,
  [SMALL_STATE(1144)] = 42064,
  [SMALL_STATE(1145)] = 42072,
  [SMALL_STATE(1146)] = 42080,
  [SMALL_STATE(1147)] = 42088,
  [SMALL_STATE(1148)] = 42096,
  [SMALL_STATE(1149)] = 42104,
  [SMALL_STATE(1150)] = 42112,
  [SMALL_STATE(1151)] = 42120,
  [SMALL_STATE(1152)] = 42128,
  [SMALL_STATE(1153)] = 42136,
  [SMALL_STATE(1154)] = 42144,
  [SMALL_STATE(1155)] = 42152,
  [SMALL_STATE(1156)] = 42160,
  [SMALL_STATE(1157)] = 42168,
  [SMALL_STATE(1158)] = 42176,
  [SMALL_STATE(1159)] = 42184,
  [SMALL_STATE(1160)] = 42192,
  [SMALL_STATE(1161)] = 42200,
  [SMALL_STATE(1162)] = 42208,
  [SMALL_STATE(1163)] = 42216,
  [SMALL_STATE(1164)] = 42224,
  [SMALL_STATE(1165)] = 42232,
  [SMALL_STATE(1166)] = 42240,
  [SMALL_STATE(1167)] = 42248,
  [SMALL_STATE(1168)] = 42256,
  [SMALL_STATE(1169)] = 42264,
  [SMALL_STATE(1170)] = 42272,
  [SMALL_STATE(1171)] = 42280,
  [SMALL_STATE(1172)] = 42288,
  [SMALL_STATE(1173)] = 42296,
  [SMALL_STATE(1174)] = 42304,
  [SMALL_STATE(1175)] = 42312,
  [SMALL_STATE(1176)] = 42320,
  [SMALL_STATE(1177)] = 42328,
  [SMALL_STATE(1178)] = 42336,
  [SMALL_STATE(1179)] = 42344,
  [SMALL_STATE(1180)] = 42352,
  [SMALL_STATE(1181)] = 42360,
  [SMALL_STATE(1182)] = 42368,
  [SMALL_STATE(1183)] = 42376,
  [SMALL_STATE(1184)] = 42384,
  [SMALL_STATE(1185)] = 42392,
  [SMALL_STATE(1186)] = 42400,
  [SMALL_STATE(1187)] = 42408,
  [SMALL_STATE(1188)] = 42416,
  [SMALL_STATE(1189)] = 42424,
  [SMALL_STATE(1190)] = 42432,
  [SMALL_STATE(1191)] = 42440,
  [SMALL_STATE(1192)] = 42448,
  [SMALL_STATE(1193)] = 42456,
  [SMALL_STATE(1194)] = 42464,
  [SMALL_STATE(1195)] = 42472,
  [SMALL_STATE(1196)] = 42480,
  [SMALL_STATE(1197)] = 42488,
  [SMALL_STATE(1198)] = 42496,
  [SMALL_STATE(1199)] = 42504,
  [SMALL_STATE(1200)] = 42512,
  [SMALL_STATE(1201)] = 42520,
  [SMALL_STATE(1202)] = 42528,
  [SMALL_STATE(1203)] = 42536,
  [SMALL_STATE(1204)] = 42544,
  [SMALL_STATE(1205)] = 42552,
  [SMALL_STATE(1206)] = 42560,
  [SMALL_STATE(1207)] = 42568,
  [SMALL_STATE(1208)] = 42576,
  [SMALL_STATE(1209)] = 42584,
  [SMALL_STATE(1210)] = 42592,
  [SMALL_STATE(1211)] = 42600,
  [SMALL_STATE(1212)] = 42608,
  [SMALL_STATE(1213)] = 42616,
  [SMALL_STATE(1214)] = 42624,
  [SMALL_STATE(1215)] = 42632,
  [SMALL_STATE(1216)] = 42640,
  [SMALL_STATE(1217)] = 42648,
  [SMALL_STATE(1218)] = 42656,
};

static const TSParseActionEntry ts_parse_actions[] = {
  [0] = {.entry = {.count = 0, .reusable = false}},
  [1] = {.entry = {.count = 1, .reusable = false}}, RECOVER(),
  [3] = {.entry = {.count = 1, .reusable = true}}, SHIFT_EXTRA(),
  [5] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_source_file, 0, 0, 0),
  [7] = {.entry = {.count = 1, .reusable = false}}, SHIFT(210),
  [9] = {.entry = {.count = 1, .reusable = true}}, SHIFT(252),
  [11] = {.entry = {.count = 1, .reusable = true}}, SHIFT(266),
  [13] = {.entry = {.count = 1, .reusable = true}}, SHIFT(213),
  [15] = {.entry = {.count = 1, .reusable = true}}, SHIFT(281),
  [17] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1078),
  [19] = {.entry = {.count = 1, .reusable = true}}, SHIFT(172),
  [21] = {.entry = {.count = 1, .reusable = true}}, SHIFT(173),
  [23] = {.entry = {.count = 1, .reusable = false}}, SHIFT(817),
  [25] = {.entry = {.count = 1, .reusable = false}}, SHIFT(283),
  [27] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1081),
  [29] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1009),
  [31] = {.entry = {.count = 1, .reusable = false}}, SHIFT(297),
  [33] = {.entry = {.count = 1, .reusable = false}}, SHIFT(221),
  [35] = {.entry = {.count = 1, .reusable = false}}, SHIFT(789),
  [37] = {.entry = {.count = 1, .reusable = false}}, SHIFT(797),
  [39] = {.entry = {.count = 1, .reusable = false}}, SHIFT(746),
  [41] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1016),
  [43] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6),
  [45] = {.entry = {.count = 1, .reusable = true}}, SHIFT(411),
  [47] = {.entry = {.count = 1, .reusable = false}}, SHIFT(314),
  [49] = {.entry = {.count = 1, .reusable = true}}, SHIFT(747),
  [51] = {.entry = {.count = 1, .reusable = true}}, SHIFT(881),
  [53] = {.entry = {.count = 1, .reusable = true}}, SHIFT(825),
  [55] = {.entry = {.count = 1, .reusable = true}}, SHIFT(674),
  [57] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5),
  [59] = {.entry = {.count = 1, .reusable = false}}, SHIFT(252),
  [61] = {.entry = {.count = 1, .reusable = false}}, SHIFT(266),
  [63] = {.entry = {.count = 1, .reusable = false}}, SHIFT(213),
  [65] = {.entry = {.count = 1, .reusable = false}}, SHIFT(281),
  [67] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1078),
  [69] = {.entry = {.count = 1, .reusable = false}}, SHIFT(267),
  [71] = {.entry = {.count = 1, .reusable = false}}, SHIFT(336),
  [73] = {.entry = {.count = 1, .reusable = false}}, SHIFT(303),
  [75] = {.entry = {.count = 1, .reusable = false}}, SHIFT(172),
  [77] = {.entry = {.count = 1, .reusable = false}}, SHIFT(173),
  [79] = {.entry = {.count = 1, .reusable = false}}, SHIFT(874),
  [81] = {.entry = {.count = 1, .reusable = false}}, SHIFT(278),
  [83] = {.entry = {.count = 1, .reusable = false}}, SHIFT(15),
  [85] = {.entry = {.count = 1, .reusable = false}}, SHIFT(938),
  [87] = {.entry = {.count = 1, .reusable = false}}, SHIFT(766),
  [89] = {.entry = {.count = 1, .reusable = false}}, SHIFT(411),
  [91] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9),
  [93] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_elseif_clause, 2, 0, 7),
  [95] = {.entry = {.count = 1, .reusable = false}}, SHIFT(17),
  [97] = {.entry = {.count = 1, .reusable = false}}, SHIFT(944),
  [99] = {.entry = {.count = 1, .reusable = false}}, SHIFT(158),
  [101] = {.entry = {.count = 1, .reusable = false}}, SHIFT(974),
  [103] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8),
  [105] = {.entry = {.count = 1, .reusable = false}}, SHIFT(917),
  [107] = {.entry = {.count = 1, .reusable = false}}, SHIFT(712),
  [109] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_case_clause, 3, 0, 7),
  [111] = {.entry = {.count = 1, .reusable = false}}, SHIFT(986),
  [113] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_elseif_clause, 3, 0, 7),
  [115] = {.entry = {.count = 1, .reusable = false}}, SHIFT(970),
  [117] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_catch_clause, 3, 0, 0),
  [119] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_catch_clause, 2, 0, 0),
  [121] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_otherwise_clause, 2, 0, 0),
  [123] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_else_clause, 2, 0, 0),
  [125] = {.entry = {.count = 1, .reusable = false}}, SHIFT(14),
  [127] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_else_clause, 1, 0, 0),
  [129] = {.entry = {.count = 1, .reusable = false}}, SHIFT(18),
  [131] = {.entry = {.count = 1, .reusable = false}}, SHIFT(906),
  [133] = {.entry = {.count = 1, .reusable = false}}, SHIFT(969),
  [135] = {.entry = {.count = 1, .reusable = false}}, SHIFT(966),
  [137] = {.entry = {.count = 1, .reusable = false}}, SHIFT(10),
  [139] = {.entry = {.count = 1, .reusable = false}}, SHIFT(941),
  [141] = {.entry = {.count = 1, .reusable = false}}, SHIFT(13),
  [143] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_otherwise_clause, 1, 0, 0),
  [145] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_function_definition, 5, 0, 20),
  [147] = {.entry = {.count = 1, .reusable = false}}, SHIFT(853),
  [149] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1121),
  [151] = {.entry = {.count = 1, .reusable = false}}, SHIFT(733),
  [153] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym_function_definition, 5, 0, 20), SHIFT(766),
  [156] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_function_definition, 5, 0, 14),
  [158] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1124),
  [160] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym_function_definition, 5, 0, 14), SHIFT(766),
  [163] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_function_definition, 6, 0, 14),
  [165] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1106),
  [167] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym_function_definition, 6, 0, 14), SHIFT(766),
  [170] = {.entry = {.count = 1, .reusable = false}}, SHIFT(751),
  [172] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_function_definition, 3, 0, 8),
  [174] = {.entry = {.count = 1, .reusable = false}}, SHIFT(793),
  [176] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym_function_definition, 3, 0, 8), SHIFT(766),
  [179] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_function_definition, 5, 0, 8),
  [181] = {.entry = {.count = 1, .reusable = false}}, SHIFT(752),
  [183] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym_function_definition, 5, 0, 8), SHIFT(766),
  [186] = {.entry = {.count = 1, .reusable = false}}, SHIFT(754),
  [188] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_function_definition, 4, 0, 14),
  [190] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1115),
  [192] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym_function_definition, 4, 0, 14), SHIFT(766),
  [195] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_function_definition, 4, 0, 8),
  [197] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1117),
  [199] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym_function_definition, 4, 0, 8), SHIFT(766),
  [202] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1123),
  [204] = {.entry = {.count = 1, .reusable = false}}, SHIFT(776),
  [206] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_function_definition, 6, 0, 20),
  [208] = {.entry = {.count = 1, .reusable = false}}, SHIFT(786),
  [210] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym_function_definition, 6, 0, 20), SHIFT(766),
  [213] = {.entry = {.count = 1, .reusable = false}}, SHIFT(773),
  [215] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_function_definition, 7, 0, 20),
  [217] = {.entry = {.count = 1, .reusable = false}}, SHIFT(785),
  [219] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym_function_definition, 7, 0, 20), SHIFT(766),
  [222] = {.entry = {.count = 1, .reusable = false}}, SHIFT(774),
  [224] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1100),
  [226] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1085),
  [228] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1122),
  [230] = {.entry = {.count = 1, .reusable = false}}, SHIFT(758),
  [232] = {.entry = {.count = 1, .reusable = false}}, SHIFT(951),
  [234] = {.entry = {.count = 1, .reusable = false}}, SHIFT(761),
  [236] = {.entry = {.count = 1, .reusable = false}}, SHIFT(978),
  [238] = {.entry = {.count = 1, .reusable = false}}, SHIFT(770),
  [240] = {.entry = {.count = 1, .reusable = false}}, SHIFT(990),
  [242] = {.entry = {.count = 1, .reusable = false}}, SHIFT(778),
  [244] = {.entry = {.count = 1, .reusable = false}}, SHIFT(975),
  [246] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_block, 1, 0, 0),
  [248] = {.entry = {.count = 1, .reusable = false}}, SHIFT(955),
  [250] = {.entry = {.count = 1, .reusable = false}}, SHIFT(953),
  [252] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym__block, 2, 0, 0), SHIFT_REPEAT(210),
  [255] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym__block, 2, 0, 0), SHIFT_REPEAT(252),
  [258] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym__block, 2, 0, 0), SHIFT_REPEAT(266),
  [261] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym__block, 2, 0, 0), SHIFT_REPEAT(213),
  [264] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym__block, 2, 0, 0), SHIFT_REPEAT(281),
  [267] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym__block, 2, 0, 0), SHIFT_REPEAT(1078),
  [270] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym__block, 2, 0, 0), SHIFT_REPEAT(172),
  [273] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym__block, 2, 0, 0), SHIFT_REPEAT(173),
  [276] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym__block, 2, 0, 0), SHIFT_REPEAT(874),
  [279] = {.entry = {.count = 1, .reusable = false}}, REDUCE(aux_sym__block, 2, 0, 0),
  [281] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym__block, 2, 0, 0), SHIFT_REPEAT(283),
  [284] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym__block, 2, 0, 0), SHIFT_REPEAT(1081),
  [287] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym__block, 2, 0, 0), SHIFT_REPEAT(1009),
  [290] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym__block, 2, 0, 0), SHIFT_REPEAT(297),
  [293] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym__block, 2, 0, 0), SHIFT_REPEAT(221),
  [296] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym__block, 2, 0, 0), SHIFT_REPEAT(789),
  [299] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym__block, 2, 0, 0), SHIFT_REPEAT(797),
  [302] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym__block, 2, 0, 0), SHIFT_REPEAT(766),
  [305] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym__block, 2, 0, 0), SHIFT_REPEAT(1016),
  [308] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym__block, 2, 0, 0), SHIFT_REPEAT(6),
  [311] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym__block, 2, 0, 0), SHIFT_REPEAT(411),
  [314] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym__block, 2, 0, 0), SHIFT_REPEAT(314),
  [317] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym__block, 2, 0, 0), SHIFT_REPEAT(747),
  [320] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym__block, 2, 0, 0), SHIFT_REPEAT(881),
  [323] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym__block, 2, 0, 0), SHIFT_REPEAT(825),
  [326] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym__block, 2, 0, 0), SHIFT_REPEAT(674),
  [329] = {.entry = {.count = 1, .reusable = false}}, SHIFT(753),
  [331] = {.entry = {.count = 1, .reusable = false}}, SHIFT(900),
  [333] = {.entry = {.count = 1, .reusable = false}}, SHIFT(795),
  [335] = {.entry = {.count = 1, .reusable = false}}, SHIFT(915),
  [337] = {.entry = {.count = 1, .reusable = false}}, SHIFT(890),
  [339] = {.entry = {.count = 1, .reusable = false}}, SHIFT(757),
  [341] = {.entry = {.count = 1, .reusable = false}}, SHIFT(760),
  [343] = {.entry = {.count = 1, .reusable = false}}, SHIFT(749),
  [345] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_source_file, 1, 0, 0),
  [347] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym__block, 2, 0, 0),
  [349] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym__block, 2, 0, 0), SHIFT_REPEAT(853),
  [352] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_block, 1, 0, 0),
  [354] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym_block, 1, 0, 0), SHIFT(766),
  [357] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym__block, 2, 0, 0), SHIFT_REPEAT(817),
  [360] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__expression, 1, 0, 0),
  [362] = {.entry = {.count = 1, .reusable = false}}, SHIFT(183),
  [364] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__binary_expression, 1, 0, 0),
  [366] = {.entry = {.count = 1, .reusable = false}}, SHIFT(738),
  [368] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1067),
  [370] = {.entry = {.count = 1, .reusable = false}}, SHIFT(122),
  [372] = {.entry = {.count = 1, .reusable = false}}, SHIFT(164),
  [374] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__range_element, 1, 0, 0),
  [376] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__expression, 1, 0, 0),
  [378] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym__expression, 1, 0, 0), REDUCE(sym__range_element, 1, 0, 0),
  [381] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__range_element, 1, 0, 0),
  [383] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_unary_operator, 2, 0, 1),
  [385] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_unary_operator, 2, 0, 1),
  [387] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__binary_expression, 1, 0, 0),
  [389] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_field_expression, 2, 0, 4),
  [391] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_field_expression, 2, 0, 4),
  [393] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_handle_operator, 3, 0, 0),
  [395] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1167),
  [397] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_handle_operator, 3, 0, 0),
  [399] = {.entry = {.count = 1, .reusable = false}}, REDUCE(aux_sym_field_expression_repeat1, 2, 0, 12),
  [401] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_field_expression_repeat1, 2, 0, 12), SHIFT_REPEAT(738),
  [404] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_field_expression_repeat1, 2, 0, 12),
  [406] = {.entry = {.count = 1, .reusable = false}}, REDUCE(aux_sym_field_expression_repeat1, 2, 0, 10),
  [408] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_field_expression_repeat1, 2, 0, 10),
  [410] = {.entry = {.count = 1, .reusable = false}}, REDUCE(aux_sym_handle_operator_repeat1, 2, 0, 0),
  [412] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_handle_operator_repeat1, 2, 0, 0), SHIFT_REPEAT(1167),
  [415] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_handle_operator_repeat1, 2, 0, 0),
  [417] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_handle_operator, 2, 0, 0),
  [419] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_handle_operator, 2, 0, 0),
  [421] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_function_call, 4, 0, 17),
  [423] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_function_call, 4, 0, 17),
  [425] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_function_call, 2, 0, 6),
  [427] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_function_call, 2, 0, 6),
  [429] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_function_call, 2, 0, 3),
  [431] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_function_call, 2, 0, 3),
  [433] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1065),
  [435] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_indirect_access, 3, 0, 0),
  [437] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_indirect_access, 3, 0, 0),
  [439] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__args, 2, 0, 0),
  [441] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__args, 2, 0, 0),
  [443] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_function_call, 4, 0, 16),
  [445] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_function_call, 4, 0, 16),
  [447] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__args, 3, 0, 0),
  [449] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__args, 3, 0, 0),
  [451] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_matrix, 4, 0, 0),
  [453] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_matrix, 4, 0, 0),
  [455] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_comparison_operator, 3, 0, 0),
  [457] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_comparison_operator, 3, 0, 0),
  [459] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_string, 2, 0, 0),
  [461] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_string, 2, 0, 0),
  [463] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym__expression, 1, 0, 0), REDUCE(sym__range_element, 1, -1, 0),
  [466] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__range_element, 1, 1, 0),
  [468] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym__expression, 1, 0, 0), REDUCE(sym__range_element, 1, 1, 0),
  [471] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__range_element, 1, 1, 0),
  [473] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_boolean_operator, 3, 0, 11),
  [475] = {.entry = {.count = 1, .reusable = false}}, SHIFT(307),
  [477] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_boolean_operator, 3, 0, 11),
  [479] = {.entry = {.count = 1, .reusable = false}}, SHIFT(305),
  [481] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_lambda, 4, 0, 13),
  [483] = {.entry = {.count = 1, .reusable = false}}, SHIFT(299),
  [485] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_lambda, 4, 0, 13),
  [487] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_not_operator, 2, 0, 0),
  [489] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_not_operator, 2, 0, 0),
  [491] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_matrix, 2, 0, 0),
  [493] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_matrix, 2, 0, 0),
  [495] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_lambda, 5, 0, 18),
  [497] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_lambda, 5, 0, 18),
  [499] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_cell, 2, 0, 0),
  [501] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_cell, 2, 0, 0),
  [503] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_postfix_operator, 2, 0, 2),
  [505] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_postfix_operator, 2, 0, 2),
  [507] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_string, 3, 0, 0),
  [509] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_string, 3, 0, 0),
  [511] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_parenthesis, 3, 0, 0),
  [513] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_parenthesis, 3, 0, 0),
  [515] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__range_element, 1, -1, 0),
  [517] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_matrix, 3, 0, 0),
  [519] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_matrix, 3, 0, 0),
  [521] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_range, 5, 0, 0),
  [523] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym_range, 3, 0, 0), REDUCE(sym_range, 5, 0, 0),
  [526] = {.entry = {.count = 1, .reusable = false}}, SHIFT(222),
  [528] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_range, 5, 0, 0),
  [530] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_cell, 4, 0, 0),
  [532] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_cell, 4, 0, 0),
  [534] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__range_element, 1, -1, 0),
  [536] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_metaclass_operator, 2, 0, 0),
  [538] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_metaclass_operator, 2, 0, 0),
  [540] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_range, 3, 0, 0),
  [542] = {.entry = {.count = 1, .reusable = false}}, SHIFT(330),
  [544] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_range, 3, 0, 0),
  [546] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_cell, 3, 0, 0),
  [548] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_cell, 3, 0, 0),
  [550] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_boolean, 1, 0, 0),
  [552] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_boolean, 1, 0, 0),
  [554] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_binary_operator, 3, 0, 11),
  [556] = {.entry = {.count = 1, .reusable = false}}, SHIFT(325),
  [558] = {.entry = {.count = 1, .reusable = false}}, SHIFT(326),
  [560] = {.entry = {.count = 1, .reusable = false}}, SHIFT(327),
  [562] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_binary_operator, 3, 0, 11),
  [564] = {.entry = {.count = 1, .reusable = false}}, SHIFT(329),
  [566] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1148),
  [568] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_handle_operator_repeat1, 2, 0, 0), SHIFT_REPEAT(1148),
  [571] = {.entry = {.count = 1, .reusable = false}}, SHIFT(216),
  [573] = {.entry = {.count = 1, .reusable = false}}, REDUCE(aux_sym_matrix_repeat1, 1, 0, 0),
  [575] = {.entry = {.count = 1, .reusable = false}}, SHIFT(208),
  [577] = {.entry = {.count = 1, .reusable = false}}, SHIFT(282),
  [579] = {.entry = {.count = 1, .reusable = false}}, SHIFT(254),
  [581] = {.entry = {.count = 1, .reusable = false}}, SHIFT(161),
  [583] = {.entry = {.count = 1, .reusable = false}}, SHIFT(274),
  [585] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1111),
  [587] = {.entry = {.count = 1, .reusable = false}}, SHIFT(174),
  [589] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_matrix_repeat1, 1, 0, 0),
  [591] = {.entry = {.count = 1, .reusable = false}}, SHIFT(171),
  [593] = {.entry = {.count = 1, .reusable = false}}, SHIFT(507),
  [595] = {.entry = {.count = 1, .reusable = false}}, SHIFT(379),
  [597] = {.entry = {.count = 1, .reusable = true}}, SHIFT(833),
  [599] = {.entry = {.count = 1, .reusable = true}}, SHIFT(836),
  [601] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_iterator, 3, 0, 0),
  [603] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_iterator, 3, 0, 0),
  [605] = {.entry = {.count = 1, .reusable = false}}, REDUCE(aux_sym_elseif_clause_repeat1, 2, 0, 0),
  [607] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_elseif_clause_repeat1, 2, 0, 0), SHIFT_REPEAT(158),
  [610] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_elseif_clause_repeat1, 2, 0, 0),
  [612] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_row, 2, 0, 0),
  [614] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_row, 2, 0, 0),
  [616] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_row, 3, 0, 0),
  [618] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_row, 3, 0, 0),
  [620] = {.entry = {.count = 1, .reusable = false}}, SHIFT(207),
  [622] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_ignored_argument, 1, 0, 0),
  [624] = {.entry = {.count = 1, .reusable = false}}, SHIFT(318),
  [626] = {.entry = {.count = 1, .reusable = false}}, SHIFT(350),
  [628] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1116),
  [630] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_ignored_argument, 1, 0, 0),
  [632] = {.entry = {.count = 1, .reusable = false}}, SHIFT(463),
  [634] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_row, 4, 0, 0),
  [636] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_row, 4, 0, 0),
  [638] = {.entry = {.count = 1, .reusable = false}}, SHIFT(247),
  [640] = {.entry = {.count = 1, .reusable = true}}, SHIFT(346),
  [642] = {.entry = {.count = 1, .reusable = true}}, SHIFT(343),
  [644] = {.entry = {.count = 1, .reusable = true}}, SHIFT(244),
  [646] = {.entry = {.count = 1, .reusable = true}}, SHIFT(348),
  [648] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1062),
  [650] = {.entry = {.count = 1, .reusable = true}}, SHIFT(169),
  [652] = {.entry = {.count = 1, .reusable = true}}, SHIFT(180),
  [654] = {.entry = {.count = 1, .reusable = true}}, SHIFT(635),
  [656] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1005),
  [658] = {.entry = {.count = 1, .reusable = true}}, SHIFT(521),
  [660] = {.entry = {.count = 1, .reusable = false}}, SHIFT(458),
  [662] = {.entry = {.count = 1, .reusable = true}}, SHIFT(854),
  [664] = {.entry = {.count = 1, .reusable = true}}, SHIFT(855),
  [666] = {.entry = {.count = 1, .reusable = true}}, SHIFT(94),
  [668] = {.entry = {.count = 1, .reusable = true}}, SHIFT(455),
  [670] = {.entry = {.count = 1, .reusable = true}}, SHIFT(208),
  [672] = {.entry = {.count = 1, .reusable = true}}, SHIFT(282),
  [674] = {.entry = {.count = 1, .reusable = true}}, SHIFT(254),
  [676] = {.entry = {.count = 1, .reusable = true}}, SHIFT(161),
  [678] = {.entry = {.count = 1, .reusable = true}}, SHIFT(274),
  [680] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1111),
  [682] = {.entry = {.count = 1, .reusable = true}}, SHIFT(174),
  [684] = {.entry = {.count = 1, .reusable = true}}, SHIFT(117),
  [686] = {.entry = {.count = 1, .reusable = true}}, SHIFT(171),
  [688] = {.entry = {.count = 1, .reusable = true}}, SHIFT(507),
  [690] = {.entry = {.count = 1, .reusable = false}}, SHIFT(364),
  [692] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym__block, 2, 0, 5),
  [694] = {.entry = {.count = 1, .reusable = false}}, REDUCE(aux_sym__block, 2, 0, 5),
  [696] = {.entry = {.count = 1, .reusable = true}}, SHIFT(170),
  [698] = {.entry = {.count = 1, .reusable = true}}, SHIFT(554),
  [700] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym__block, 3, 0, 5),
  [702] = {.entry = {.count = 1, .reusable = false}}, REDUCE(aux_sym__block, 3, 0, 5),
  [704] = {.entry = {.count = 1, .reusable = true}}, SHIFT(175),
  [706] = {.entry = {.count = 1, .reusable = true}}, SHIFT(490),
  [708] = {.entry = {.count = 1, .reusable = true}}, SHIFT(413),
  [710] = {.entry = {.count = 1, .reusable = true}}, SHIFT(451),
  [712] = {.entry = {.count = 1, .reusable = true}}, SHIFT(491),
  [714] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym__block_repeat1, 2, 0, 0),
  [716] = {.entry = {.count = 1, .reusable = false}}, REDUCE(aux_sym__block_repeat1, 2, 0, 0),
  [718] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym__block_repeat1, 2, 0, 0), SHIFT_REPEAT(175),
  [721] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym__block, 3, 0, 0),
  [723] = {.entry = {.count = 1, .reusable = false}}, REDUCE(aux_sym__block, 3, 0, 0),
  [725] = {.entry = {.count = 1, .reusable = true}}, SHIFT(177),
  [727] = {.entry = {.count = 1, .reusable = true}}, SHIFT(555),
  [729] = {.entry = {.count = 1, .reusable = true}}, SHIFT(198),
  [731] = {.entry = {.count = 1, .reusable = true}}, SHIFT(120),
  [733] = {.entry = {.count = 1, .reusable = true}}, SHIFT(378),
  [735] = {.entry = {.count = 1, .reusable = false}}, SHIFT(184),
  [737] = {.entry = {.count = 1, .reusable = false}}, SHIFT(706),
  [739] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1098),
  [741] = {.entry = {.count = 1, .reusable = false}}, SHIFT(433),
  [743] = {.entry = {.count = 1, .reusable = false}}, SHIFT(181),
  [745] = {.entry = {.count = 1, .reusable = false}}, SHIFT(354),
  [747] = {.entry = {.count = 1, .reusable = false}}, SHIFT(253),
  [749] = {.entry = {.count = 1, .reusable = false}}, SHIFT(355),
  [751] = {.entry = {.count = 1, .reusable = false}}, SHIFT(367),
  [753] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1091),
  [755] = {.entry = {.count = 1, .reusable = false}}, SHIFT(186),
  [757] = {.entry = {.count = 1, .reusable = false}}, SHIFT(724),
  [759] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1074),
  [761] = {.entry = {.count = 1, .reusable = false}}, SHIFT(487),
  [763] = {.entry = {.count = 1, .reusable = false}}, SHIFT(185),
  [765] = {.entry = {.count = 1, .reusable = false}}, SHIFT(384),
  [767] = {.entry = {.count = 1, .reusable = true}}, SHIFT(246),
  [769] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1114),
  [771] = {.entry = {.count = 1, .reusable = true}}, SHIFT(572),
  [773] = {.entry = {.count = 1, .reusable = false}}, SHIFT(313),
  [775] = {.entry = {.count = 1, .reusable = false}}, SHIFT(187),
  [777] = {.entry = {.count = 1, .reusable = true}}, SHIFT(245),
  [779] = {.entry = {.count = 1, .reusable = true}}, SHIFT(268),
  [781] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1087),
  [783] = {.entry = {.count = 1, .reusable = true}}, SHIFT(392),
  [785] = {.entry = {.count = 1, .reusable = false}}, SHIFT(190),
  [787] = {.entry = {.count = 1, .reusable = false}}, SHIFT(358),
  [789] = {.entry = {.count = 1, .reusable = true}}, SHIFT(549),
  [791] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym__block_repeat1, 2, 0, 0), SHIFT_REPEAT(223),
  [794] = {.entry = {.count = 1, .reusable = false}}, SHIFT(368),
  [796] = {.entry = {.count = 1, .reusable = true}}, SHIFT(223),
  [798] = {.entry = {.count = 1, .reusable = true}}, SHIFT(347),
  [800] = {.entry = {.count = 1, .reusable = false}}, SHIFT(375),
  [802] = {.entry = {.count = 1, .reusable = true}}, SHIFT(563),
  [804] = {.entry = {.count = 1, .reusable = false}}, SHIFT(427),
  [806] = {.entry = {.count = 1, .reusable = true}}, SHIFT(306),
  [808] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1104),
  [810] = {.entry = {.count = 1, .reusable = true}}, SHIFT(225),
  [812] = {.entry = {.count = 1, .reusable = false}}, SHIFT(414),
  [814] = {.entry = {.count = 1, .reusable = false}}, SHIFT(377),
  [816] = {.entry = {.count = 1, .reusable = true}}, SHIFT(351),
  [818] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1118),
  [820] = {.entry = {.count = 1, .reusable = true}}, SHIFT(527),
  [822] = {.entry = {.count = 1, .reusable = true}}, SHIFT(178),
  [824] = {.entry = {.count = 1, .reusable = false}}, SHIFT(711),
  [826] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1080),
  [828] = {.entry = {.count = 1, .reusable = true}}, SHIFT(557),
  [830] = {.entry = {.count = 1, .reusable = true}}, SHIFT(165),
  [832] = {.entry = {.count = 1, .reusable = false}}, SHIFT(292),
  [834] = {.entry = {.count = 1, .reusable = false}}, SHIFT(76),
  [836] = {.entry = {.count = 1, .reusable = true}}, SHIFT(284),
  [838] = {.entry = {.count = 1, .reusable = true}}, SHIFT(277),
  [840] = {.entry = {.count = 1, .reusable = true}}, SHIFT(251),
  [842] = {.entry = {.count = 1, .reusable = true}}, SHIFT(275),
  [844] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1130),
  [846] = {.entry = {.count = 1, .reusable = true}}, SHIFT(166),
  [848] = {.entry = {.count = 1, .reusable = true}}, SHIFT(182),
  [850] = {.entry = {.count = 1, .reusable = true}}, SHIFT(127),
  [852] = {.entry = {.count = 1, .reusable = false}}, SHIFT(140),
  [854] = {.entry = {.count = 1, .reusable = true}}, SHIFT(850),
  [856] = {.entry = {.count = 1, .reusable = true}}, SHIFT(848),
  [858] = {.entry = {.count = 1, .reusable = true}}, SHIFT(342),
  [860] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1105),
  [862] = {.entry = {.count = 1, .reusable = false}}, SHIFT(80),
  [864] = {.entry = {.count = 1, .reusable = true}}, SHIFT(349),
  [866] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1110),
  [868] = {.entry = {.count = 1, .reusable = true}}, SHIFT(104),
  [870] = {.entry = {.count = 1, .reusable = false}}, SHIFT(442),
  [872] = {.entry = {.count = 1, .reusable = false}}, SHIFT(356),
  [874] = {.entry = {.count = 1, .reusable = false}}, SHIFT(217),
  [876] = {.entry = {.count = 1, .reusable = true}}, SHIFT(318),
  [878] = {.entry = {.count = 1, .reusable = true}}, SHIFT(503),
  [880] = {.entry = {.count = 1, .reusable = false}}, SHIFT(214),
  [882] = {.entry = {.count = 1, .reusable = true}}, SHIFT(480),
  [884] = {.entry = {.count = 1, .reusable = false}}, SHIFT(212),
  [886] = {.entry = {.count = 1, .reusable = true}}, SHIFT(492),
  [888] = {.entry = {.count = 1, .reusable = false}}, SHIFT(188),
  [890] = {.entry = {.count = 1, .reusable = true}}, SHIFT(434),
  [892] = {.entry = {.count = 1, .reusable = true}}, SHIFT(271),
  [894] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1102),
  [896] = {.entry = {.count = 1, .reusable = false}}, SHIFT(412),
  [898] = {.entry = {.count = 1, .reusable = false}}, SHIFT(78),
  [900] = {.entry = {.count = 1, .reusable = true}}, SHIFT(106),
  [902] = {.entry = {.count = 1, .reusable = false}}, SHIFT(189),
  [904] = {.entry = {.count = 1, .reusable = true}}, SHIFT(439),
  [906] = {.entry = {.count = 1, .reusable = false}}, SHIFT(192),
  [908] = {.entry = {.count = 1, .reusable = true}}, SHIFT(410),
  [910] = {.entry = {.count = 1, .reusable = true}}, SHIFT(293),
  [912] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1103),
  [914] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_field_expression_repeat1, 2, 0, 12), SHIFT_REPEAT(706),
  [917] = {.entry = {.count = 1, .reusable = false}}, SHIFT(395),
  [919] = {.entry = {.count = 1, .reusable = true}}, SHIFT(350),
  [921] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1116),
  [923] = {.entry = {.count = 1, .reusable = true}}, SHIFT(463),
  [925] = {.entry = {.count = 1, .reusable = false}}, SHIFT(79),
  [927] = {.entry = {.count = 1, .reusable = true}}, SHIFT(128),
  [929] = {.entry = {.count = 1, .reusable = false}}, SHIFT(77),
  [931] = {.entry = {.count = 1, .reusable = true}}, SHIFT(133),
  [933] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_function_definition_repeat1, 2, 0, 0),
  [935] = {.entry = {.count = 1, .reusable = false}}, REDUCE(aux_sym_function_definition_repeat1, 2, 0, 0),
  [937] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_function_definition_repeat1, 2, 0, 0), SHIFT_REPEAT(733),
  [940] = {.entry = {.count = 1, .reusable = false}}, SHIFT(366),
  [942] = {.entry = {.count = 1, .reusable = true}}, SHIFT(532),
  [944] = {.entry = {.count = 1, .reusable = false}}, SHIFT(400),
  [946] = {.entry = {.count = 1, .reusable = false}}, SHIFT(300),
  [948] = {.entry = {.count = 1, .reusable = false}}, SHIFT(301),
  [950] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1071),
  [952] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym__expression, 1, 0, 0), REDUCE(sym__range_element, 1, 0, 0),
  [955] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_handle_operator_repeat1, 2, 0, 0), SHIFT_REPEAT(1170),
  [958] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1170),
  [960] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_arguments_statement, 4, 0, 23),
  [962] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_arguments_statement, 4, 0, 23),
  [964] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_arguments_statement, 3, 0, 0),
  [966] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_arguments_statement, 3, 0, 0),
  [968] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__enum_value, 1, 0, 0),
  [970] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_arguments_statement, 5, 0, 23),
  [972] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_arguments_statement, 5, 0, 23),
  [974] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_arguments_statement, 4, 0, 0),
  [976] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_arguments_statement, 4, 0, 0),
  [978] = {.entry = {.count = 1, .reusable = false}}, SHIFT(302),
  [980] = {.entry = {.count = 1, .reusable = false}}, SHIFT(291),
  [982] = {.entry = {.count = 1, .reusable = false}}, SHIFT(290),
  [984] = {.entry = {.count = 1, .reusable = false}}, SHIFT(288),
  [986] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1079),
  [988] = {.entry = {.count = 1, .reusable = true}}, SHIFT(416),
  [990] = {.entry = {.count = 1, .reusable = true}}, SHIFT(672),
  [992] = {.entry = {.count = 1, .reusable = true}}, SHIFT(93),
  [994] = {.entry = {.count = 1, .reusable = true}}, SHIFT(197),
  [996] = {.entry = {.count = 1, .reusable = false}}, SHIFT(256),
  [998] = {.entry = {.count = 1, .reusable = false}}, SHIFT(257),
  [1000] = {.entry = {.count = 1, .reusable = false}}, SHIFT(258),
  [1002] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_handle_operator_repeat1, 2, 0, 0), SHIFT_REPEAT(1162),
  [1005] = {.entry = {.count = 1, .reusable = true}}, SHIFT(372),
  [1007] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1162),
  [1009] = {.entry = {.count = 1, .reusable = false}}, SHIFT(286),
  [1011] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_field_expression_repeat1, 2, 0, 12), SHIFT_REPEAT(724),
  [1014] = {.entry = {.count = 1, .reusable = false}}, SHIFT(335),
  [1016] = {.entry = {.count = 1, .reusable = false}}, SHIFT(334),
  [1018] = {.entry = {.count = 1, .reusable = false}}, SHIFT(332),
  [1020] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_handle_operator_repeat1, 2, 0, 0), SHIFT_REPEAT(1157),
  [1023] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1157),
  [1025] = {.entry = {.count = 1, .reusable = false}}, SHIFT(261),
  [1027] = {.entry = {.count = 1, .reusable = false}}, SHIFT(262),
  [1029] = {.entry = {.count = 1, .reusable = false}}, SHIFT(260),
  [1031] = {.entry = {.count = 1, .reusable = false}}, SHIFT(264),
  [1033] = {.entry = {.count = 1, .reusable = false}}, SHIFT(279),
  [1035] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_field_expression_repeat1, 2, 0, 12), SHIFT_REPEAT(711),
  [1038] = {.entry = {.count = 1, .reusable = false}}, SHIFT(304),
  [1040] = {.entry = {.count = 1, .reusable = false}}, SHIFT(295),
  [1042] = {.entry = {.count = 1, .reusable = false}}, SHIFT(294),
  [1044] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_range, 3, 0, 0), REDUCE(sym_range, 5, 0, 0),
  [1047] = {.entry = {.count = 1, .reusable = true}}, SHIFT(222),
  [1049] = {.entry = {.count = 1, .reusable = false}}, SHIFT(280),
  [1051] = {.entry = {.count = 1, .reusable = true}}, SHIFT(280),
  [1053] = {.entry = {.count = 1, .reusable = true}}, SHIFT(320),
  [1055] = {.entry = {.count = 1, .reusable = true}}, SHIFT(339),
  [1057] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym__expression, 1, 0, 0), REDUCE(sym__range_element, 1, -1, 0),
  [1060] = {.entry = {.count = 1, .reusable = true}}, SHIFT(235),
  [1062] = {.entry = {.count = 1, .reusable = true}}, SHIFT(234),
  [1064] = {.entry = {.count = 1, .reusable = true}}, SHIFT(233),
  [1066] = {.entry = {.count = 1, .reusable = false}}, SHIFT(229),
  [1068] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym__expression, 1, 0, 0), REDUCE(sym__range_element, 1, 1, 0),
  [1071] = {.entry = {.count = 1, .reusable = false}}, SHIFT(321),
  [1073] = {.entry = {.count = 1, .reusable = false}}, SHIFT(322),
  [1075] = {.entry = {.count = 1, .reusable = false}}, SHIFT(323),
  [1077] = {.entry = {.count = 1, .reusable = true}}, SHIFT(433),
  [1079] = {.entry = {.count = 1, .reusable = true}}, SHIFT(487),
  [1081] = {.entry = {.count = 1, .reusable = false}}, SHIFT(239),
  [1083] = {.entry = {.count = 1, .reusable = true}}, SHIFT(239),
  [1085] = {.entry = {.count = 1, .reusable = true}}, SHIFT(237),
  [1087] = {.entry = {.count = 1, .reusable = true}}, SHIFT(236),
  [1089] = {.entry = {.count = 1, .reusable = true}}, SHIFT(122),
  [1091] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_handle_operator_repeat1, 2, 0, 0), SHIFT_REPEAT(1203),
  [1094] = {.entry = {.count = 1, .reusable = false}}, SHIFT(639),
  [1096] = {.entry = {.count = 1, .reusable = false}}, SHIFT(947),
  [1098] = {.entry = {.count = 1, .reusable = false}}, SHIFT(272),
  [1100] = {.entry = {.count = 1, .reusable = false}}, SHIFT(20),
  [1102] = {.entry = {.count = 1, .reusable = false}}, SHIFT(642),
  [1104] = {.entry = {.count = 1, .reusable = true}}, SHIFT(658),
  [1106] = {.entry = {.count = 1, .reusable = true}}, SHIFT(167),
  [1108] = {.entry = {.count = 1, .reusable = true}}, SHIFT(723),
  [1110] = {.entry = {.count = 1, .reusable = true}}, SHIFT(699),
  [1112] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1061),
  [1114] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1189),
  [1116] = {.entry = {.count = 1, .reusable = true}}, SHIFT(163),
  [1118] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1203),
  [1120] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_handle_operator_repeat1, 2, 0, 0), SHIFT_REPEAT(1175),
  [1123] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1138),
  [1125] = {.entry = {.count = 1, .reusable = false}}, SHIFT(662),
  [1127] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1036),
  [1129] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1002),
  [1131] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1064),
  [1133] = {.entry = {.count = 1, .reusable = false}}, SHIFT(717),
  [1135] = {.entry = {.count = 1, .reusable = false}}, SHIFT(337),
  [1137] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_handle_operator_repeat1, 2, 0, 0), SHIFT_REPEAT(1138),
  [1140] = {.entry = {.count = 1, .reusable = true}}, SHIFT(230),
  [1142] = {.entry = {.count = 1, .reusable = true}}, SHIFT(229),
  [1144] = {.entry = {.count = 1, .reusable = true}}, SHIFT(260),
  [1146] = {.entry = {.count = 1, .reusable = true}}, SHIFT(261),
  [1148] = {.entry = {.count = 1, .reusable = true}}, SHIFT(262),
  [1150] = {.entry = {.count = 1, .reusable = true}}, SHIFT(263),
  [1152] = {.entry = {.count = 1, .reusable = true}}, SHIFT(264),
  [1154] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_row, 1, 0, 0),
  [1156] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_row, 1, 0, 0),
  [1158] = {.entry = {.count = 1, .reusable = true}}, SHIFT(159),
  [1160] = {.entry = {.count = 1, .reusable = true}}, SHIFT(325),
  [1162] = {.entry = {.count = 1, .reusable = true}}, SHIFT(326),
  [1164] = {.entry = {.count = 1, .reusable = true}}, SHIFT(327),
  [1166] = {.entry = {.count = 1, .reusable = true}}, SHIFT(328),
  [1168] = {.entry = {.count = 1, .reusable = true}}, SHIFT(329),
  [1170] = {.entry = {.count = 1, .reusable = true}}, SHIFT(160),
  [1172] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7),
  [1174] = {.entry = {.count = 1, .reusable = true}}, SHIFT(291),
  [1176] = {.entry = {.count = 1, .reusable = true}}, SHIFT(290),
  [1178] = {.entry = {.count = 1, .reusable = true}}, SHIFT(288),
  [1180] = {.entry = {.count = 1, .reusable = true}}, SHIFT(287),
  [1182] = {.entry = {.count = 1, .reusable = true}}, SHIFT(286),
  [1184] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1175),
  [1186] = {.entry = {.count = 1, .reusable = false}}, REDUCE(aux_sym_row_repeat1, 2, 0, 0),
  [1188] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_row_repeat1, 2, 0, 0),
  [1190] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_multioutput_variable_repeat1, 2, 0, 0), SHIFT_REPEAT(642),
  [1193] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_multioutput_variable_repeat1, 2, 0, 0), SHIFT_REPEAT(667),
  [1196] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_multioutput_variable_repeat1, 2, 0, 0), SHIFT_REPEAT(353),
  [1199] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_multioutput_variable_repeat1, 2, 0, 0), SHIFT_REPEAT(699),
  [1202] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_multioutput_variable_repeat1, 2, 0, 0),
  [1204] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_multioutput_variable_repeat1, 2, 0, 0), SHIFT_REPEAT(458),
  [1207] = {.entry = {.count = 1, .reusable = false}}, SHIFT(179),
  [1209] = {.entry = {.count = 1, .reusable = true}}, SHIFT(353),
  [1211] = {.entry = {.count = 1, .reusable = true}}, SHIFT(657),
  [1213] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1185),
  [1215] = {.entry = {.count = 1, .reusable = false}}, SHIFT(240),
  [1217] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_default_value, 2, 0, 0),
  [1219] = {.entry = {.count = 1, .reusable = true}}, SHIFT(195),
  [1221] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_arguments, 1, 0, 9),
  [1223] = {.entry = {.count = 1, .reusable = false}}, SHIFT(832),
  [1225] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1200),
  [1227] = {.entry = {.count = 1, .reusable = false}}, SHIFT(688),
  [1229] = {.entry = {.count = 1, .reusable = false}}, SHIFT(968),
  [1231] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_assignment, 3, 0, 11),
  [1233] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1165),
  [1235] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_arguments, 5, 0, 9),
  [1237] = {.entry = {.count = 1, .reusable = false}}, REDUCE(aux_sym_multioutput_variable_repeat1, 1, 0, 0),
  [1239] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_multioutput_variable_repeat1, 1, 0, 0),
  [1241] = {.entry = {.count = 1, .reusable = true}}, SHIFT(176),
  [1243] = {.entry = {.count = 1, .reusable = false}}, REDUCE(aux_sym_multioutput_variable_repeat1, 2, 0, 0),
  [1245] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_arguments, 6, 0, 15),
  [1247] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_arguments, 3, 0, 0),
  [1249] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1019),
  [1251] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_property_name, 2, -1, 0),
  [1253] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1120),
  [1255] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_methods_repeat1, 2, 0, 0), SHIFT_REPEAT(695),
  [1258] = {.entry = {.count = 1, .reusable = false}}, REDUCE(aux_sym_methods_repeat1, 2, 0, 0),
  [1260] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_methods_repeat1, 2, 0, 0), SHIFT_REPEAT(748),
  [1263] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_methods_repeat1, 2, 0, 0), SHIFT_REPEAT(1172),
  [1266] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_methods_repeat1, 2, 0, 0), SHIFT_REPEAT(674),
  [1269] = {.entry = {.count = 1, .reusable = false}}, SHIFT(695),
  [1271] = {.entry = {.count = 1, .reusable = false}}, SHIFT(820),
  [1273] = {.entry = {.count = 1, .reusable = false}}, SHIFT(748),
  [1275] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1172),
  [1277] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_arguments_repeat2, 4, 0, 0),
  [1279] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_arguments_repeat1, 2, 0, 21),
  [1281] = {.entry = {.count = 1, .reusable = false}}, SHIFT(643),
  [1283] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1206),
  [1285] = {.entry = {.count = 1, .reusable = false}}, SHIFT(867),
  [1287] = {.entry = {.count = 1, .reusable = false}}, SHIFT(650),
  [1289] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1029),
  [1291] = {.entry = {.count = 1, .reusable = false}}, SHIFT(830),
  [1293] = {.entry = {.count = 1, .reusable = true}}, SHIFT(902),
  [1295] = {.entry = {.count = 1, .reusable = true}}, SHIFT(728),
  [1297] = {.entry = {.count = 1, .reusable = true}}, SHIFT(727),
  [1299] = {.entry = {.count = 1, .reusable = true}}, SHIFT(726),
  [1301] = {.entry = {.count = 1, .reusable = true}}, SHIFT(704),
  [1303] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_attribute, 3, 0, 0),
  [1305] = {.entry = {.count = 1, .reusable = true}}, SHIFT(910),
  [1307] = {.entry = {.count = 1, .reusable = true}}, SHIFT(958),
  [1309] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_class_definition_repeat1, 2, 0, 0),
  [1311] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_class_definition_repeat1, 2, 0, 0), SHIFT_REPEAT(728),
  [1314] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_class_definition_repeat1, 2, 0, 0), SHIFT_REPEAT(727),
  [1317] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_class_definition_repeat1, 2, 0, 0), SHIFT_REPEAT(726),
  [1320] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_class_definition_repeat1, 2, 0, 0), SHIFT_REPEAT(704),
  [1323] = {.entry = {.count = 1, .reusable = true}}, SHIFT(907),
  [1325] = {.entry = {.count = 1, .reusable = true}}, SHIFT(950),
  [1327] = {.entry = {.count = 1, .reusable = true}}, SHIFT(913),
  [1329] = {.entry = {.count = 1, .reusable = false}}, SHIFT(606),
  [1331] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_field_expression_repeat1, 2, 0, 12), SHIFT_REPEAT(723),
  [1334] = {.entry = {.count = 1, .reusable = true}}, SHIFT(467),
  [1336] = {.entry = {.count = 1, .reusable = true}}, SHIFT(125),
  [1338] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_property_name, 3, -1, 0),
  [1340] = {.entry = {.count = 1, .reusable = true}}, SHIFT(548),
  [1342] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_property_name, 4, -1, 0),
  [1344] = {.entry = {.count = 1, .reusable = true}}, SHIFT(397),
  [1346] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_elseif_clause_repeat1, 2, 0, 0), SHIFT_REPEAT(688),
  [1349] = {.entry = {.count = 1, .reusable = true}}, SHIFT(335),
  [1351] = {.entry = {.count = 1, .reusable = true}}, SHIFT(334),
  [1353] = {.entry = {.count = 1, .reusable = true}}, SHIFT(332),
  [1355] = {.entry = {.count = 1, .reusable = true}}, SHIFT(307),
  [1357] = {.entry = {.count = 1, .reusable = true}}, SHIFT(305),
  [1359] = {.entry = {.count = 1, .reusable = true}}, SHIFT(299),
  [1361] = {.entry = {.count = 1, .reusable = false}}, SHIFT(32),
  [1363] = {.entry = {.count = 1, .reusable = false}}, SHIFT(851),
  [1365] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1034),
  [1367] = {.entry = {.count = 1, .reusable = false}}, SHIFT(26),
  [1369] = {.entry = {.count = 1, .reusable = false}}, SHIFT(788),
  [1371] = {.entry = {.count = 1, .reusable = true}}, SHIFT(256),
  [1373] = {.entry = {.count = 1, .reusable = true}}, SHIFT(257),
  [1375] = {.entry = {.count = 1, .reusable = true}}, SHIFT(258),
  [1377] = {.entry = {.count = 1, .reusable = false}}, SHIFT(62),
  [1379] = {.entry = {.count = 1, .reusable = false}}, SHIFT(61),
  [1381] = {.entry = {.count = 1, .reusable = false}}, SHIFT(29),
  [1383] = {.entry = {.count = 1, .reusable = false}}, SHIFT(70),
  [1385] = {.entry = {.count = 1, .reusable = false}}, SHIFT(55),
  [1387] = {.entry = {.count = 1, .reusable = false}}, SHIFT(903),
  [1389] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1096),
  [1391] = {.entry = {.count = 1, .reusable = false}}, SHIFT(21),
  [1393] = {.entry = {.count = 1, .reusable = false}}, SHIFT(191),
  [1395] = {.entry = {.count = 1, .reusable = true}}, SHIFT(243),
  [1397] = {.entry = {.count = 1, .reusable = false}}, SHIFT(611),
  [1399] = {.entry = {.count = 1, .reusable = true}}, SHIFT(692),
  [1401] = {.entry = {.count = 1, .reusable = false}}, SHIFT(381),
  [1403] = {.entry = {.count = 1, .reusable = false}}, SHIFT(387),
  [1405] = {.entry = {.count = 1, .reusable = false}}, SHIFT(822),
  [1407] = {.entry = {.count = 1, .reusable = false}}, SHIFT(383),
  [1409] = {.entry = {.count = 1, .reusable = true}}, SHIFT(317),
  [1411] = {.entry = {.count = 1, .reusable = false}}, SHIFT(750),
  [1413] = {.entry = {.count = 1, .reusable = false}}, SHIFT(12),
  [1415] = {.entry = {.count = 1, .reusable = false}}, SHIFT(869),
  [1417] = {.entry = {.count = 1, .reusable = false}}, SHIFT(668),
  [1419] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1090),
  [1421] = {.entry = {.count = 1, .reusable = false}}, SHIFT(382),
  [1423] = {.entry = {.count = 1, .reusable = false}}, SHIFT(386),
  [1425] = {.entry = {.count = 1, .reusable = false}}, SHIFT(731),
  [1427] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_property_name, 1, -1, 0),
  [1429] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_arguments_statement_repeat1, 2, 0, 0), SHIFT_REPEAT(611),
  [1432] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_arguments_statement_repeat1, 2, 0, 0), SHIFT_REPEAT(692),
  [1435] = {.entry = {.count = 1, .reusable = false}}, REDUCE(aux_sym_arguments_statement_repeat1, 2, 0, 0),
  [1437] = {.entry = {.count = 1, .reusable = false}}, SHIFT(829),
  [1439] = {.entry = {.count = 1, .reusable = false}}, SHIFT(780),
  [1441] = {.entry = {.count = 1, .reusable = false}}, SHIFT(655),
  [1443] = {.entry = {.count = 1, .reusable = false}}, SHIFT(345),
  [1445] = {.entry = {.count = 1, .reusable = true}}, SHIFT(232),
  [1447] = {.entry = {.count = 1, .reusable = false}}, SHIFT(63),
  [1449] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1003),
  [1451] = {.entry = {.count = 1, .reusable = false}}, SHIFT(659),
  [1453] = {.entry = {.count = 1, .reusable = false}}, SHIFT(713),
  [1455] = {.entry = {.count = 1, .reusable = false}}, SHIFT(39),
  [1457] = {.entry = {.count = 1, .reusable = false}}, SHIFT(28),
  [1459] = {.entry = {.count = 1, .reusable = true}}, SHIFT(732),
  [1461] = {.entry = {.count = 1, .reusable = true}}, SHIFT(865),
  [1463] = {.entry = {.count = 1, .reusable = false}}, SHIFT(745),
  [1465] = {.entry = {.count = 1, .reusable = false}}, SHIFT(715),
  [1467] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1186),
  [1469] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_dimensions, 4, 0, 0),
  [1471] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_dimensions, 3, 0, 0),
  [1473] = {.entry = {.count = 1, .reusable = false}}, SHIFT(756),
  [1475] = {.entry = {.count = 1, .reusable = false}}, SHIFT(664),
  [1477] = {.entry = {.count = 1, .reusable = false}}, SHIFT(84),
  [1479] = {.entry = {.count = 1, .reusable = true}}, SHIFT(269),
  [1481] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1010),
  [1483] = {.entry = {.count = 1, .reusable = false}}, SHIFT(67),
  [1485] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_function_signature, 4, 0, 8),
  [1487] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_function_signature, 4, 0, 8),
  [1489] = {.entry = {.count = 1, .reusable = true}}, SHIFT(278),
  [1491] = {.entry = {.count = 1, .reusable = true}}, SHIFT(974),
  [1493] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_validation_functions_repeat1, 2, 0, 0),
  [1495] = {.entry = {.count = 1, .reusable = false}}, SHIFT(694),
  [1497] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1144),
  [1499] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_command, 1, 0, 0),
  [1501] = {.entry = {.count = 1, .reusable = true}}, SHIFT(767),
  [1503] = {.entry = {.count = 1, .reusable = false}}, SHIFT(697),
  [1505] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1215),
  [1507] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__function_definition_with_end, 5, 0, 14),
  [1509] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__function_definition_with_end, 5, 0, 14),
  [1511] = {.entry = {.count = 1, .reusable = false}}, SHIFT(11),
  [1513] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__function_definition_with_end, 6, 0, 14),
  [1515] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_function_definition, 6, 0, 14),
  [1517] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_function_definition, 6, 0, 8),
  [1519] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__function_definition_with_end, 6, 0, 8),
  [1521] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_function_definition, 6, 0, 8),
  [1523] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__function_definition_with_end, 5, 0, 8),
  [1525] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__function_definition_with_end, 5, 0, 8),
  [1527] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__function_definition_with_end, 6, 0, 20),
  [1529] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_function_definition, 6, 0, 20),
  [1531] = {.entry = {.count = 1, .reusable = false}}, REDUCE(aux_sym_superclasses_repeat1, 2, 0, 0),
  [1533] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_superclasses_repeat1, 2, 0, 0), SHIFT_REPEAT(1092),
  [1536] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_function_signature, 4, 0, 14),
  [1538] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_function_signature, 4, 0, 14),
  [1540] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__function_definition_with_end, 6, 0, 14),
  [1542] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__function_definition_with_end, 6, 0, 8),
  [1544] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_function_definition, 9, 0, 20),
  [1546] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__function_definition_with_end, 9, 0, 20),
  [1548] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_function_definition, 9, 0, 20),
  [1550] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__function_definition_with_end, 6, 0, 20),
  [1552] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__function_definition_with_end, 7, 0, 14),
  [1554] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__function_definition_with_end, 7, 0, 14),
  [1556] = {.entry = {.count = 1, .reusable = false}}, REDUCE(aux_sym_methods_repeat1, 1, 0, 5),
  [1558] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_methods_repeat1, 1, 0, 5),
  [1560] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__function_definition_with_end, 7, 0, 8),
  [1562] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__function_definition_with_end, 7, 0, 8),
  [1564] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_superclasses, 3, 0, 0),
  [1566] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1092),
  [1568] = {.entry = {.count = 1, .reusable = false}}, SHIFT(693),
  [1570] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1183),
  [1572] = {.entry = {.count = 1, .reusable = false}}, SHIFT(698),
  [1574] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1191),
  [1576] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_command, 2, 0, 0),
  [1578] = {.entry = {.count = 1, .reusable = true}}, SHIFT(769),
  [1580] = {.entry = {.count = 1, .reusable = true}}, SHIFT(162),
  [1582] = {.entry = {.count = 1, .reusable = false}}, REDUCE(aux_sym_command_repeat1, 2, 0, 0),
  [1584] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_command_repeat1, 2, 0, 0), SHIFT_REPEAT(769),
  [1587] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__function_definition_with_end, 7, 0, 20),
  [1589] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__function_definition_with_end, 7, 0, 20),
  [1591] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__function_definition_with_end, 8, 0, 14),
  [1593] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__function_definition_with_end, 8, 0, 14),
  [1595] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_row_repeat1, 2, 0, 0), SHIFT_REPEAT(204),
  [1598] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_function_definition, 5, 0, 8),
  [1600] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_function_definition, 5, 0, 14),
  [1602] = {.entry = {.count = 1, .reusable = true}}, SHIFT(935),
  [1604] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_function_definition, 7, 0, 14),
  [1606] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_function_definition, 7, 0, 14),
  [1608] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_function_definition, 7, 0, 8),
  [1610] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_function_definition, 7, 0, 8),
  [1612] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__function_definition_with_end, 8, 0, 20),
  [1614] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__function_definition_with_end, 8, 0, 20),
  [1616] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_function_signature, 3, 0, 3),
  [1618] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_function_signature, 3, 0, 3),
  [1620] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_function_signature, 3, 0, 8),
  [1622] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_function_signature, 3, 0, 8),
  [1624] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__function_definition_with_end, 9, 0, 20),
  [1626] = {.entry = {.count = 1, .reusable = false}}, SHIFT(792),
  [1628] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_persistent_operator, 2, 0, 0),
  [1630] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_function_definition, 8, 0, 20),
  [1632] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_function_definition, 8, 0, 20),
  [1634] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_function_definition, 7, 0, 20),
  [1636] = {.entry = {.count = 1, .reusable = true}}, SHIFT(897),
  [1638] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_function_signature, 2, 0, 3),
  [1640] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_function_signature, 2, 0, 3),
  [1642] = {.entry = {.count = 1, .reusable = false}}, SHIFT(799),
  [1644] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_global_operator, 1, 0, 0),
  [1646] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_function_definition, 8, 0, 14),
  [1648] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_function_definition, 8, 0, 14),
  [1650] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_global_operator_repeat1, 2, 0, 0), SHIFT_REPEAT(792),
  [1653] = {.entry = {.count = 1, .reusable = false}}, REDUCE(aux_sym_global_operator_repeat1, 2, 0, 0),
  [1655] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__function_definition_with_end, 4, 0, 8),
  [1657] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_function_definition, 4, 0, 8),
  [1659] = {.entry = {.count = 1, .reusable = true}}, SHIFT(968),
  [1661] = {.entry = {.count = 1, .reusable = true}}, SHIFT(272),
  [1663] = {.entry = {.count = 1, .reusable = true}}, SHIFT(20),
  [1665] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__function_definition_with_end, 4, 0, 8),
  [1667] = {.entry = {.count = 1, .reusable = false}}, SHIFT(783),
  [1669] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_persistent_operator, 1, 0, 0),
  [1671] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_superclasses, 2, 0, 0),
  [1673] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_global_operator, 2, 0, 0),
  [1675] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_function_signature, 5, 0, 14),
  [1677] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_function_signature, 5, 0, 14),
  [1679] = {.entry = {.count = 1, .reusable = true}}, SHIFT(926),
  [1681] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_events, 4, 0, 0),
  [1683] = {.entry = {.count = 1, .reusable = false}}, SHIFT(34),
  [1685] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_switch_statement_repeat1, 2, 0, 0),
  [1687] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_switch_statement_repeat1, 2, 0, 0), SHIFT_REPEAT(272),
  [1690] = {.entry = {.count = 1, .reusable = false}}, SHIFT(24),
  [1692] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1013),
  [1694] = {.entry = {.count = 1, .reusable = true}}, SHIFT(249),
  [1696] = {.entry = {.count = 1, .reusable = true}}, SHIFT(319),
  [1698] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1007),
  [1700] = {.entry = {.count = 1, .reusable = false}}, SHIFT(675),
  [1702] = {.entry = {.count = 1, .reusable = false}}, SHIFT(64),
  [1704] = {.entry = {.count = 1, .reusable = false}}, SHIFT(30),
  [1706] = {.entry = {.count = 1, .reusable = true}}, SHIFT(226),
  [1708] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_enumeration, 4, 0, 0),
  [1710] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_validation_functions, 4, 0, 0),
  [1712] = {.entry = {.count = 1, .reusable = true}}, SHIFT(338),
  [1714] = {.entry = {.count = 1, .reusable = false}}, SHIFT(779),
  [1716] = {.entry = {.count = 1, .reusable = true}}, SHIFT(315),
  [1718] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_methods, 4, 0, 0),
  [1720] = {.entry = {.count = 1, .reusable = true}}, SHIFT(309),
  [1722] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_properties, 4, 0, 0),
  [1724] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_if_statement_repeat1, 2, 0, 0), SHIFT_REPEAT(278),
  [1727] = {.entry = {.count = 1, .reusable = false}}, REDUCE(aux_sym_if_statement_repeat1, 2, 0, 0),
  [1729] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_if_statement_repeat1, 2, 0, 0),
  [1731] = {.entry = {.count = 1, .reusable = true}}, SHIFT(429),
  [1733] = {.entry = {.count = 1, .reusable = true}}, SHIFT(839),
  [1735] = {.entry = {.count = 1, .reusable = true}}, SHIFT(340),
  [1737] = {.entry = {.count = 1, .reusable = true}}, SHIFT(242),
  [1739] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_properties, 5, 0, 0),
  [1741] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_methods, 5, 0, 0),
  [1743] = {.entry = {.count = 1, .reusable = false}}, SHIFT(743),
  [1745] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_parfor_options, 1, 0, 0),
  [1747] = {.entry = {.count = 1, .reusable = true}}, SHIFT(506),
  [1749] = {.entry = {.count = 1, .reusable = true}}, SHIFT(886),
  [1751] = {.entry = {.count = 1, .reusable = true}}, SHIFT(123),
  [1753] = {.entry = {.count = 1, .reusable = true}}, SHIFT(887),
  [1755] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_events, 5, 0, 0),
  [1757] = {.entry = {.count = 1, .reusable = true}}, SHIFT(885),
  [1759] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_enumeration, 5, 0, 0),
  [1761] = {.entry = {.count = 1, .reusable = true}}, SHIFT(842),
  [1763] = {.entry = {.count = 1, .reusable = true}}, SHIFT(441),
  [1765] = {.entry = {.count = 1, .reusable = true}}, SHIFT(331),
  [1767] = {.entry = {.count = 1, .reusable = false}}, SHIFT(40),
  [1769] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_string_repeat1, 2, 0, 0),
  [1771] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_string_repeat1, 2, 0, 0), SHIFT_REPEAT(842),
  [1774] = {.entry = {.count = 1, .reusable = false}}, SHIFT(707),
  [1776] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_matrix_repeat1, 2, 0, 0), SHIFT_REPEAT(156),
  [1779] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_matrix_repeat1, 2, 0, 0), SHIFT_REPEAT(156),
  [1782] = {.entry = {.count = 1, .reusable = false}}, REDUCE(aux_sym_matrix_repeat1, 2, 0, 0),
  [1784] = {.entry = {.count = 1, .reusable = true}}, SHIFT(231),
  [1786] = {.entry = {.count = 1, .reusable = true}}, SHIFT(102),
  [1788] = {.entry = {.count = 1, .reusable = true}}, SHIFT(834),
  [1790] = {.entry = {.count = 1, .reusable = false}}, SHIFT(57),
  [1792] = {.entry = {.count = 1, .reusable = true}}, SHIFT(838),
  [1794] = {.entry = {.count = 1, .reusable = true}}, SHIFT(965),
  [1796] = {.entry = {.count = 1, .reusable = true}}, SHIFT(298),
  [1798] = {.entry = {.count = 1, .reusable = true}}, SHIFT(526),
  [1800] = {.entry = {.count = 1, .reusable = true}}, SHIFT(878),
  [1802] = {.entry = {.count = 1, .reusable = true}}, SHIFT(880),
  [1804] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1131),
  [1806] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_enum, 1, 0, 0),
  [1808] = {.entry = {.count = 1, .reusable = false}}, SHIFT(209),
  [1810] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_enumeration, 3, 0, 0),
  [1812] = {.entry = {.count = 1, .reusable = false}}, SHIFT(709),
  [1814] = {.entry = {.count = 1, .reusable = false}}, SHIFT(168),
  [1816] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1126),
  [1818] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_events, 3, 0, 0),
  [1820] = {.entry = {.count = 1, .reusable = false}}, SHIFT(660),
  [1822] = {.entry = {.count = 1, .reusable = true}}, SHIFT(259),
  [1824] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_validation_functions, 3, 0, 0),
  [1826] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_methods, 3, 0, 0),
  [1828] = {.entry = {.count = 1, .reusable = false}}, SHIFT(60),
  [1830] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_properties, 3, 0, 0),
  [1832] = {.entry = {.count = 1, .reusable = false}}, SHIFT(911),
  [1834] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1059),
  [1836] = {.entry = {.count = 1, .reusable = false}}, SHIFT(801),
  [1838] = {.entry = {.count = 1, .reusable = false}}, SHIFT(38),
  [1840] = {.entry = {.count = 1, .reusable = false}}, SHIFT(68),
  [1842] = {.entry = {.count = 1, .reusable = true}}, SHIFT(559),
  [1844] = {.entry = {.count = 1, .reusable = true}}, SHIFT(270),
  [1846] = {.entry = {.count = 1, .reusable = true}}, SHIFT(845),
  [1848] = {.entry = {.count = 1, .reusable = false}}, SHIFT(49),
  [1850] = {.entry = {.count = 1, .reusable = false}}, SHIFT(43),
  [1852] = {.entry = {.count = 1, .reusable = false}}, SHIFT(676),
  [1854] = {.entry = {.count = 1, .reusable = true}}, SHIFT(473),
  [1856] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_string_repeat1, 2, 0, 0), SHIFT_REPEAT(887),
  [1859] = {.entry = {.count = 1, .reusable = false}}, SHIFT(227),
  [1861] = {.entry = {.count = 1, .reusable = false}}, SHIFT(46),
  [1863] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_switch_statement, 6, 0, 7),
  [1865] = {.entry = {.count = 1, .reusable = false}}, SHIFT(156),
  [1867] = {.entry = {.count = 1, .reusable = true}}, SHIFT(156),
  [1869] = {.entry = {.count = 1, .reusable = false}}, SHIFT(459),
  [1871] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_arguments_repeat1, 2, 0, 22), SHIFT_REPEAT(202),
  [1874] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_arguments_repeat1, 2, 0, 22),
  [1876] = {.entry = {.count = 1, .reusable = false}}, SHIFT(777),
  [1878] = {.entry = {.count = 1, .reusable = true}}, SHIFT(777),
  [1880] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_try_statement, 5, 0, 0),
  [1882] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_if_statement, 6, 0, 7),
  [1884] = {.entry = {.count = 1, .reusable = true}}, SHIFT(786),
  [1886] = {.entry = {.count = 1, .reusable = true}}, SHIFT(776),
  [1888] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1117),
  [1890] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_class_definition, 5, 0, 14),
  [1892] = {.entry = {.count = 1, .reusable = false}}, SHIFT(857),
  [1894] = {.entry = {.count = 1, .reusable = false}}, SHIFT(858),
  [1896] = {.entry = {.count = 1, .reusable = false}}, SHIFT(465),
  [1898] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_for_statement, 7, 0, 0),
  [1900] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_class_definition, 6, 0, 8),
  [1902] = {.entry = {.count = 1, .reusable = false}}, SHIFT(481),
  [1904] = {.entry = {.count = 1, .reusable = false}}, SHIFT(482),
  [1906] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_class_definition, 5, 0, 8),
  [1908] = {.entry = {.count = 1, .reusable = false}}, SHIFT(814),
  [1910] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_class_definition, 6, 0, 14),
  [1912] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_source_file_repeat1, 2, 0, 0),
  [1914] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_source_file_repeat1, 2, 0, 0), SHIFT_REPEAT(765),
  [1917] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_arguments, 4, 0, 0),
  [1919] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_try_statement, 2, 0, 0),
  [1921] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1124),
  [1923] = {.entry = {.count = 1, .reusable = true}}, SHIFT(186),
  [1925] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1074),
  [1927] = {.entry = {.count = 1, .reusable = true}}, SHIFT(185),
  [1929] = {.entry = {.count = 1, .reusable = true}}, SHIFT(752),
  [1931] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1122),
  [1933] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_function_arguments, 3, 0, 19),
  [1935] = {.entry = {.count = 1, .reusable = true}}, SHIFT(751),
  [1937] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_if_statement, 7, 0, 7),
  [1939] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_attributes, 3, 0, 0),
  [1941] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_switch_statement, 5, 0, 7),
  [1943] = {.entry = {.count = 1, .reusable = false}}, SHIFT(791),
  [1945] = {.entry = {.count = 1, .reusable = true}}, SHIFT(791),
  [1947] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_while_statement, 5, 0, 7),
  [1949] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_source_file, 2, 0, 0),
  [1951] = {.entry = {.count = 1, .reusable = true}}, SHIFT(765),
  [1953] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__argument_attributes, 3, 0, 21),
  [1955] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1071),
  [1957] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_for_statement, 5, 0, 0),
  [1959] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_attributes, 4, 0, 0),
  [1961] = {.entry = {.count = 1, .reusable = true}}, SHIFT(785),
  [1963] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_if_statement, 5, 0, 7),
  [1965] = {.entry = {.count = 1, .reusable = false}}, SHIFT(399),
  [1967] = {.entry = {.count = 1, .reusable = false}}, SHIFT(401),
  [1969] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_if_statement, 3, 0, 7),
  [1971] = {.entry = {.count = 1, .reusable = false}}, SHIFT(130),
  [1973] = {.entry = {.count = 1, .reusable = false}}, SHIFT(138),
  [1975] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_for_statement, 3, 0, 0),
  [1977] = {.entry = {.count = 1, .reusable = false}}, SHIFT(837),
  [1979] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_property_name, 2, -1, 0),
  [1981] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1099),
  [1983] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_while_statement, 3, 0, 7),
  [1985] = {.entry = {.count = 1, .reusable = true}}, SHIFT(193),
  [1987] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_arguments, 2, 0, 15),
  [1989] = {.entry = {.count = 1, .reusable = true}}, SHIFT(196),
  [1991] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_switch_statement, 3, 0, 7),
  [1993] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_try_statement, 4, 0, 0),
  [1995] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_enumeration_repeat1, 2, 0, 0), SHIFT_REPEAT(857),
  [1998] = {.entry = {.count = 1, .reusable = false}}, REDUCE(aux_sym_enumeration_repeat1, 2, 0, 0),
  [2000] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_class_definition, 7, 0, 14),
  [2002] = {.entry = {.count = 1, .reusable = false}}, SHIFT(100),
  [2004] = {.entry = {.count = 1, .reusable = false}}, SHIFT(132),
  [2006] = {.entry = {.count = 1, .reusable = true}}, SHIFT(183),
  [2008] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1067),
  [2010] = {.entry = {.count = 1, .reusable = true}}, SHIFT(164),
  [2012] = {.entry = {.count = 1, .reusable = false}}, SHIFT(408),
  [2014] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_class_definition, 4, 0, 8),
  [2016] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_arguments_repeat2, 2, 0, 0), SHIFT_REPEAT(1165),
  [2019] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_arguments_repeat2, 2, 0, 0),
  [2021] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1065),
  [2023] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1106),
  [2025] = {.entry = {.count = 1, .reusable = true}}, SHIFT(773),
  [2027] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1101),
  [2029] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1101),
  [2031] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1100),
  [2033] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_function_arguments, 2, 0, 0),
  [2035] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_for_statement, 8, 0, 0),
  [2037] = {.entry = {.count = 1, .reusable = false}}, SHIFT(391),
  [2039] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_switch_statement, 4, 0, 7),
  [2041] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_while_statement, 4, 0, 7),
  [2043] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_for_statement, 4, 0, 0),
  [2045] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__argument_attributes, 4, 0, 24),
  [2047] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1093),
  [2049] = {.entry = {.count = 1, .reusable = false}}, SHIFT(759),
  [2051] = {.entry = {.count = 1, .reusable = true}}, SHIFT(759),
  [2053] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_if_statement, 4, 0, 7),
  [2055] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_matrix_repeat1, 2, 0, 0),
  [2057] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_arguments, 6, 0, 9),
  [2059] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1086),
  [2061] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1086),
  [2063] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_property_name, 1, -1, 0),
  [2065] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1069),
  [2067] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1085),
  [2069] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_for_statement, 9, 0, 0),
  [2071] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_try_statement, 3, 0, 0),
  [2073] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_enum, 4, 0, 0),
  [2075] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_arguments, 7, 0, 15),
  [2077] = {.entry = {.count = 1, .reusable = true}}, SHIFT(184),
  [2079] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1091),
  [2081] = {.entry = {.count = 1, .reusable = true}}, SHIFT(181),
  [2083] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1098),
  [2085] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1076),
  [2087] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1076),
  [2089] = {.entry = {.count = 1, .reusable = false}}, SHIFT(546),
  [2091] = {.entry = {.count = 1, .reusable = false}}, SHIFT(545),
  [2093] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_enum, 5, 0, 0),
  [2095] = {.entry = {.count = 1, .reusable = false}}, SHIFT(528),
  [2097] = {.entry = {.count = 1, .reusable = false}}, SHIFT(523),
  [2099] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1030),
  [2101] = {.entry = {.count = 1, .reusable = false}}, SHIFT(861),
  [2103] = {.entry = {.count = 1, .reusable = false}}, SHIFT(862),
  [2105] = {.entry = {.count = 1, .reusable = false}}, SHIFT(702),
  [2107] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1217),
  [2109] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_spread_operator, 1, 0, 0),
  [2111] = {.entry = {.count = 1, .reusable = true}}, SHIFT(948),
  [2113] = {.entry = {.count = 1, .reusable = true}}, SHIFT(712),
  [2115] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_property, 6, 0, 3),
  [2117] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_property, 6, 0, 3),
  [2119] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_enum_repeat1, 2, 0, 0), SHIFT_REPEAT(215),
  [2122] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_enum_repeat1, 2, 0, 0),
  [2124] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1137),
  [2126] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1128),
  [2128] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_property, 5, 0, 3),
  [2130] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_property, 5, 0, 3),
  [2132] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_validation_functions_repeat1, 2, 0, 0), SHIFT_REPEAT(732),
  [2135] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_dimensions_repeat1, 2, 0, 0), SHIFT_REPEAT(1024),
  [2138] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_dimensions_repeat1, 2, 0, 0),
  [2140] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1015),
  [2142] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__lambda_arguments, 1, 0, 0),
  [2144] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__lambda_arguments, 2, 0, 0),
  [2146] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1077),
  [2148] = {.entry = {.count = 1, .reusable = true}}, SHIFT(714),
  [2150] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1113),
  [2152] = {.entry = {.count = 1, .reusable = false}}, SHIFT(725),
  [2154] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1176),
  [2156] = {.entry = {.count = 1, .reusable = true}}, SHIFT(215),
  [2158] = {.entry = {.count = 1, .reusable = true}}, SHIFT(998),
  [2160] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_property, 4, 0, 3),
  [2162] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_property, 4, 0, 3),
  [2164] = {.entry = {.count = 1, .reusable = false}}, SHIFT(701),
  [2166] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1211),
  [2168] = {.entry = {.count = 1, .reusable = true}}, SHIFT(815),
  [2170] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1024),
  [2172] = {.entry = {.count = 1, .reusable = true}}, SHIFT(734),
  [2174] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1084),
  [2176] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1082),
  [2178] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1160),
  [2180] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_attribute, 1, 0, 0),
  [2182] = {.entry = {.count = 1, .reusable = true}}, SHIFT(273),
  [2184] = {.entry = {.count = 1, .reusable = true}}, SHIFT(988),
  [2186] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_property, 3, 0, 3),
  [2188] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_property, 3, 0, 3),
  [2190] = {.entry = {.count = 1, .reusable = true}}, SHIFT(735),
  [2192] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym__argument_attributes_repeat1, 2, 0, 22), SHIFT_REPEAT(1142),
  [2195] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym__argument_attributes_repeat1, 2, 0, 22),
  [2197] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_function_output, 2, 0, 0),
  [2199] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_function_output, 2, 0, 0),
  [2201] = {.entry = {.count = 1, .reusable = true}}, SHIFT(925),
  [2203] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_property, 2, 0, 3),
  [2205] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_property, 2, 0, 3),
  [2207] = {.entry = {.count = 1, .reusable = true}}, SHIFT(933),
  [2209] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1184),
  [2211] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_events_repeat1, 2, 0, 0), SHIFT_REPEAT(861),
  [2214] = {.entry = {.count = 1, .reusable = false}}, REDUCE(aux_sym_events_repeat1, 2, 0, 0),
  [2216] = {.entry = {.count = 1, .reusable = false}}, SHIFT(835),
  [2218] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1142),
  [2220] = {.entry = {.count = 1, .reusable = true}}, SHIFT(971),
  [2222] = {.entry = {.count = 1, .reusable = false}}, SHIFT(729),
  [2224] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1133),
  [2226] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_case_clause, 4, 0, 7),
  [2228] = {.entry = {.count = 1, .reusable = true}}, SHIFT(986),
  [2230] = {.entry = {.count = 1, .reusable = true}}, SHIFT(930),
  [2232] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym__lambda_arguments_repeat1, 2, 0, 0), SHIFT_REPEAT(1015),
  [2235] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym__lambda_arguments_repeat1, 2, 0, 0),
  [2237] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_elseif_clause, 3, 0, 7),
  [2239] = {.entry = {.count = 1, .reusable = false}}, SHIFT(803),
  [2241] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_attributes_repeat1, 2, 0, 0), SHIFT_REPEAT(1082),
  [2244] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_attributes_repeat1, 2, 0, 0),
  [2246] = {.entry = {.count = 1, .reusable = false}}, SHIFT(722),
  [2248] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1177),
  [2250] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_elseif_clause, 4, 0, 7),
  [2252] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_elseif_clause, 4, 0, 7),
  [2254] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_property_name, 4, -1, 0),
  [2256] = {.entry = {.count = 1, .reusable = true}}, SHIFT(981),
  [2258] = {.entry = {.count = 1, .reusable = true}}, SHIFT(626),
  [2260] = {.entry = {.count = 1, .reusable = true}}, SHIFT(808),
  [2262] = {.entry = {.count = 1, .reusable = true}}, SHIFT(758),
  [2264] = {.entry = {.count = 1, .reusable = true}}, SHIFT(604),
  [2266] = {.entry = {.count = 1, .reusable = true}}, SHIFT(682),
  [2268] = {.entry = {.count = 1, .reusable = true}}, SHIFT(761),
  [2270] = {.entry = {.count = 1, .reusable = false}}, SHIFT(763),
  [2272] = {.entry = {.count = 1, .reusable = true}}, SHIFT(763),
  [2274] = {.entry = {.count = 1, .reusable = true}}, SHIFT(618),
  [2276] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1097),
  [2278] = {.entry = {.count = 1, .reusable = true}}, SHIFT(770),
  [2280] = {.entry = {.count = 1, .reusable = false}}, SHIFT(771),
  [2282] = {.entry = {.count = 1, .reusable = true}}, SHIFT(771),
  [2284] = {.entry = {.count = 1, .reusable = true}}, SHIFT(778),
  [2286] = {.entry = {.count = 1, .reusable = false}}, SHIFT(782),
  [2288] = {.entry = {.count = 1, .reusable = true}}, SHIFT(782),
  [2290] = {.entry = {.count = 1, .reusable = true}}, SHIFT(608),
  [2292] = {.entry = {.count = 1, .reusable = true}}, SHIFT(846),
  [2294] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1027),
  [2296] = {.entry = {.count = 1, .reusable = true}}, SHIFT(373),
  [2298] = {.entry = {.count = 1, .reusable = true}}, SHIFT(879),
  [2300] = {.entry = {.count = 1, .reusable = false}}, SHIFT(999),
  [2302] = {.entry = {.count = 1, .reusable = true}}, SHIFT(999),
  [2304] = {.entry = {.count = 1, .reusable = true}}, SHIFT(719),
  [2306] = {.entry = {.count = 1, .reusable = true}}, SHIFT(890),
  [2308] = {.entry = {.count = 1, .reusable = true}}, SHIFT(757),
  [2310] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_property_name, 3, -1, 0),
  [2312] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1060),
  [2314] = {.entry = {.count = 1, .reusable = true}}, SHIFT(86),
  [2316] = {.entry = {.count = 1, .reusable = true}}, SHIFT(821),
  [2318] = {.entry = {.count = 1, .reusable = true}}, SHIFT(438),
  [2320] = {.entry = {.count = 1, .reusable = true}}, SHIFT(819),
  [2322] = {.entry = {.count = 1, .reusable = true}}, SHIFT(464),
  [2324] = {.entry = {.count = 1, .reusable = true}}, SHIFT(828),
  [2326] = {.entry = {.count = 1, .reusable = true}}, SHIFT(864),
  [2328] = {.entry = {.count = 1, .reusable = true}}, SHIFT(951),
  [2330] = {.entry = {.count = 1, .reusable = true}}, SHIFT(953),
  [2332] = {.entry = {.count = 1, .reusable = true}}, SHIFT(990),
  [2334] = {.entry = {.count = 1, .reusable = true}}, SHIFT(852),
  [2336] = {.entry = {.count = 1, .reusable = true}}, SHIFT(610),
  [2338] = {.entry = {.count = 1, .reusable = true}}, SHIFT(816),
  [2340] = {.entry = {.count = 1, .reusable = false}}, SHIFT(989),
  [2342] = {.entry = {.count = 1, .reusable = true}}, SHIFT(989),
  [2344] = {.entry = {.count = 1, .reusable = true}}, SHIFT(813),
  [2346] = {.entry = {.count = 1, .reusable = true}}, SHIFT(840),
  [2348] = {.entry = {.count = 1, .reusable = true}}, SHIFT(826),
  [2350] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym__argument_attributes_repeat1, 2, 0, 21),
  [2352] = {.entry = {.count = 1, .reusable = true}}, SHIFT(686),
  [2354] = {.entry = {.count = 1, .reusable = true}}, SHIFT(978),
  [2356] = {.entry = {.count = 1, .reusable = true}}, SHIFT(753),
  [2358] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1197),
  [2360] = {.entry = {.count = 1, .reusable = false}}, SHIFT(977),
  [2362] = {.entry = {.count = 1, .reusable = true}}, SHIFT(977),
  [2364] = {.entry = {.count = 1, .reusable = true}}, SHIFT(152),
  [2366] = {.entry = {.count = 1, .reusable = true}}, SHIFT(807),
  [2368] = {.entry = {.count = 1, .reusable = true}}, SHIFT(975),
  [2370] = {.entry = {.count = 1, .reusable = true}}, SHIFT(730),
  [2372] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16),
  [2374] = {.entry = {.count = 1, .reusable = true}}, SHIFT(369),
  [2376] = {.entry = {.count = 1, .reusable = true}}, SHIFT(199),
  [2378] = {.entry = {.count = 1, .reusable = true}}, SHIFT(248),
  [2380] = {.entry = {.count = 1, .reusable = true}}, SHIFT(620),
  [2382] = {.entry = {.count = 1, .reusable = true}}, SHIFT(344),
  [2384] = {.entry = {.count = 1, .reusable = true}}, SHIFT(648),
  [2386] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1119),
  [2388] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_catch_clause, 3, 0, 0),
  [2390] = {.entry = {.count = 1, .reusable = true}}, SHIFT(729),
  [2392] = {.entry = {.count = 1, .reusable = true}}, SHIFT(985),
  [2394] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1034),
  [2396] = {.entry = {.count = 1, .reusable = true}}, SHIFT(296),
  [2398] = {.entry = {.count = 1, .reusable = true}}, SHIFT(155),
  [2400] = {.entry = {.count = 1, .reusable = true}}, SHIFT(98),
  [2402] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_otherwise_clause, 2, 0, 0),
  [2404] = {.entry = {.count = 1, .reusable = true}}, SHIFT(966),
  [2406] = {.entry = {.count = 1, .reusable = true}}, SHIFT(352),
  [2408] = {.entry = {.count = 1, .reusable = true}}, SHIFT(514),
  [2410] = {.entry = {.count = 1, .reusable = true}}, SHIFT(224),
  [2412] = {.entry = {.count = 1, .reusable = true}}, SHIFT(333),
  [2414] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_attributes, 3, 0, 0),
  [2416] = {.entry = {.count = 1, .reusable = true}}, SHIFT(324),
  [2418] = {.entry = {.count = 1, .reusable = true}}, SHIFT(457),
  [2420] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_else_clause, 2, 0, 0),
  [2422] = {.entry = {.count = 1, .reusable = true}}, SHIFT(737),
  [2424] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1209),
  [2426] = {.entry = {.count = 1, .reusable = true}}, SHIFT(289),
  [2428] = {.entry = {.count = 1, .reusable = true}}, SHIFT(89),
  [2430] = {.entry = {.count = 1, .reusable = true}}, SHIFT(432),
  [2432] = {.entry = {.count = 1, .reusable = true}}, SHIFT(385),
  [2434] = {.entry = {.count = 1, .reusable = true}}, SHIFT(276),
  [2436] = {.entry = {.count = 1, .reusable = true}}, SHIFT(722),
  [2438] = {.entry = {.count = 1, .reusable = true}}, SHIFT(924),
  [2440] = {.entry = {.count = 1, .reusable = true}}, SHIFT(703),
  [2442] = {.entry = {.count = 1, .reusable = true}}, SHIFT(736),
  [2444] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_catch_clause, 4, 0, 0),
  [2446] = {.entry = {.count = 1, .reusable = true}}, SHIFT(265),
  [2448] = {.entry = {.count = 1, .reusable = true}}, SHIFT(250),
  [2450] = {.entry = {.count = 1, .reusable = true}}, SHIFT(285),
  [2452] = {.entry = {.count = 1, .reusable = true}}, SHIFT(701),
  [2454] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_attributes, 4, 0, 0),
  [2456] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_multioutput_variable, 4, 0, 0),
  [2458] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1050),
  [2460] = {.entry = {.count = 1, .reusable = true}}, SHIFT(313),
  [2462] = {.entry = {.count = 1, .reusable = true}}, SHIFT(891),
  [2464] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_multioutput_variable, 3, 0, 0),
  [2466] = {.entry = {.count = 1, .reusable = true}},  ACCEPT_INPUT(),
  [2468] = {.entry = {.count = 1, .reusable = true}}, SHIFT(725),
  [2470] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_otherwise_clause, 3, 0, 0),
  [2472] = {.entry = {.count = 1, .reusable = true}}, SHIFT(922),
  [2474] = {.entry = {.count = 1, .reusable = true}}, SHIFT(316),
  [2476] = {.entry = {.count = 1, .reusable = true}}, SHIFT(228),
  [2478] = {.entry = {.count = 1, .reusable = true}}, SHIFT(255),
  [2480] = {.entry = {.count = 1, .reusable = true}}, SHIFT(312),
  [2482] = {.entry = {.count = 1, .reusable = true}}, SHIFT(932),
  [2484] = {.entry = {.count = 1, .reusable = true}}, SHIFT(308),
  [2486] = {.entry = {.count = 1, .reusable = true}}, SHIFT(238),
  [2488] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_else_clause, 3, 0, 0),
  [2490] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_multioutput_variable, 5, 0, 0),
  [2492] = {.entry = {.count = 1, .reusable = true}}, SHIFT(241),
  [2494] = {.entry = {.count = 1, .reusable = true}}, SHIFT(220),
  [2496] = {.entry = {.count = 1, .reusable = true}}, SHIFT(705),
  [2498] = {.entry = {.count = 1, .reusable = true}}, SHIFT(970),
  [2500] = {.entry = {.count = 1, .reusable = true}}, SHIFT(636),
  [2502] = {.entry = {.count = 1, .reusable = true}}, SHIFT(896),
  [2504] = {.entry = {.count = 1, .reusable = true}}, SHIFT(702),
  [2506] = {.entry = {.count = 1, .reusable = true}}, SHIFT(928),
  [2508] = {.entry = {.count = 1, .reusable = true}}, SHIFT(741),
  [2510] = {.entry = {.count = 1, .reusable = true}}, SHIFT(969),
};

enum ts_external_scanner_symbol_identifiers {
  ts_external_token_comment = 0,
  ts_external_token_line_continuation = 1,
  ts_external_token_command_name = 2,
  ts_external_token_command_argument = 3,
  ts_external_token__single_quote_string_start = 4,
  ts_external_token__single_quote_string_end = 5,
  ts_external_token__double_quote_string_start = 6,
  ts_external_token__double_quote_string_end = 7,
  ts_external_token_formatting_sequence = 8,
  ts_external_token_escape_sequence = 9,
  ts_external_token_string_content = 10,
  ts_external_token__entry_delimiter = 11,
  ts_external_token__multioutput_variable_start = 12,
  ts_external_token_error_sentinel = 13,
};

static const TSSymbol ts_external_scanner_symbol_map[EXTERNAL_TOKEN_COUNT] = {
  [ts_external_token_comment] = sym_comment,
  [ts_external_token_line_continuation] = sym_line_continuation,
  [ts_external_token_command_name] = sym_command_name,
  [ts_external_token_command_argument] = sym_command_argument,
  [ts_external_token__single_quote_string_start] = sym__single_quote_string_start,
  [ts_external_token__single_quote_string_end] = sym__single_quote_string_end,
  [ts_external_token__double_quote_string_start] = sym__double_quote_string_start,
  [ts_external_token__double_quote_string_end] = sym__double_quote_string_end,
  [ts_external_token_formatting_sequence] = sym_formatting_sequence,
  [ts_external_token_escape_sequence] = sym_escape_sequence,
  [ts_external_token_string_content] = sym_string_content,
  [ts_external_token__entry_delimiter] = sym__entry_delimiter,
  [ts_external_token__multioutput_variable_start] = sym__multioutput_variable_start,
  [ts_external_token_error_sentinel] = sym_error_sentinel,
};

static const bool ts_external_scanner_states[11][EXTERNAL_TOKEN_COUNT] = {
  [1] = {
    [ts_external_token_comment] = true,
    [ts_external_token_line_continuation] = true,
    [ts_external_token_command_name] = true,
    [ts_external_token_command_argument] = true,
    [ts_external_token__single_quote_string_start] = true,
    [ts_external_token__single_quote_string_end] = true,
    [ts_external_token__double_quote_string_start] = true,
    [ts_external_token__double_quote_string_end] = true,
    [ts_external_token_formatting_sequence] = true,
    [ts_external_token_escape_sequence] = true,
    [ts_external_token_string_content] = true,
    [ts_external_token__entry_delimiter] = true,
    [ts_external_token__multioutput_variable_start] = true,
    [ts_external_token_error_sentinel] = true,
  },
  [2] = {
    [ts_external_token_comment] = true,
    [ts_external_token_line_continuation] = true,
    [ts_external_token_command_name] = true,
    [ts_external_token__single_quote_string_start] = true,
    [ts_external_token__double_quote_string_start] = true,
    [ts_external_token__multioutput_variable_start] = true,
  },
  [3] = {
    [ts_external_token_comment] = true,
    [ts_external_token_line_continuation] = true,
    [ts_external_token__single_quote_string_start] = true,
    [ts_external_token__double_quote_string_start] = true,
  },
  [4] = {
    [ts_external_token_comment] = true,
    [ts_external_token_line_continuation] = true,
    [ts_external_token__single_quote_string_start] = true,
    [ts_external_token__double_quote_string_start] = true,
    [ts_external_token__entry_delimiter] = true,
  },
  [5] = {
    [ts_external_token_comment] = true,
    [ts_external_token_line_continuation] = true,
  },
  [6] = {
    [ts_external_token_comment] = true,
    [ts_external_token_line_continuation] = true,
    [ts_external_token__entry_delimiter] = true,
  },
  [7] = {
    [ts_external_token_comment] = true,
    [ts_external_token_line_continuation] = true,
    [ts_external_token__multioutput_variable_start] = true,
  },
  [8] = {
    [ts_external_token_comment] = true,
    [ts_external_token_line_continuation] = true,
    [ts_external_token_command_argument] = true,
  },
  [9] = {
    [ts_external_token_comment] = true,
    [ts_external_token_line_continuation] = true,
    [ts_external_token__double_quote_string_end] = true,
    [ts_external_token_formatting_sequence] = true,
    [ts_external_token_escape_sequence] = true,
    [ts_external_token_string_content] = true,
  },
  [10] = {
    [ts_external_token_comment] = true,
    [ts_external_token_line_continuation] = true,
    [ts_external_token__single_quote_string_end] = true,
    [ts_external_token_formatting_sequence] = true,
    [ts_external_token_escape_sequence] = true,
    [ts_external_token_string_content] = true,
  },
};

#ifdef __cplusplus
extern "C" {
#endif
void *tree_sitter_matlab_external_scanner_create(void);
void tree_sitter_matlab_external_scanner_destroy(void *);
bool tree_sitter_matlab_external_scanner_scan(void *, TSLexer *, const bool *);
unsigned tree_sitter_matlab_external_scanner_serialize(void *, char *);
void tree_sitter_matlab_external_scanner_deserialize(void *, const char *, unsigned);

#ifdef TREE_SITTER_HIDE_SYMBOLS
#define TS_PUBLIC
#elif defined(_WIN32)
#define TS_PUBLIC __declspec(dllexport)
#else
#define TS_PUBLIC __attribute__((visibility("default")))
#endif

TS_PUBLIC const TSLanguage *tree_sitter_matlab(void) {
  static const TSLanguage language = {
    .version = LANGUAGE_VERSION,
    .symbol_count = SYMBOL_COUNT,
    .alias_count = ALIAS_COUNT,
    .token_count = TOKEN_COUNT,
    .external_token_count = EXTERNAL_TOKEN_COUNT,
    .state_count = STATE_COUNT,
    .large_state_count = LARGE_STATE_COUNT,
    .production_id_count = PRODUCTION_ID_COUNT,
    .field_count = FIELD_COUNT,
    .max_alias_sequence_length = MAX_ALIAS_SEQUENCE_LENGTH,
    .parse_table = &ts_parse_table[0][0],
    .small_parse_table = ts_small_parse_table,
    .small_parse_table_map = ts_small_parse_table_map,
    .parse_actions = ts_parse_actions,
    .symbol_names = ts_symbol_names,
    .field_names = ts_field_names,
    .field_map_slices = ts_field_map_slices,
    .field_map_entries = ts_field_map_entries,
    .symbol_metadata = ts_symbol_metadata,
    .public_symbol_map = ts_symbol_map,
    .alias_map = ts_non_terminal_alias_map,
    .alias_sequences = &ts_alias_sequences[0][0],
    .lex_modes = ts_lex_modes,
    .lex_fn = ts_lex,
    .keyword_lex_fn = ts_lex_keywords,
    .keyword_capture_token = sym_identifier,
    .external_scanner = {
      &ts_external_scanner_states[0][0],
      ts_external_scanner_symbol_map,
      tree_sitter_matlab_external_scanner_create,
      tree_sitter_matlab_external_scanner_destroy,
      tree_sitter_matlab_external_scanner_scan,
      tree_sitter_matlab_external_scanner_serialize,
      tree_sitter_matlab_external_scanner_deserialize,
    },
    .primary_state_ids = ts_primary_state_ids,
  };
  return &language;
}
#ifdef __cplusplus
}
#endif
